(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    599412,      23126]*)
(*NotebookOutlinePosition[    624421,      23864]*)
(*  CellTagsIndexPosition[    621846,      23764]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Examples", "Section",
  CellTags->"0.1"],

Cell["Generation of Random Numbers", "Subsection",
  CellTags->{"S0.1", "1.1"}],

Cell["One standard normal variable", "Subsubsection",
  CellTags->{"S0.1", "1.2"}],

Cell[TextData[{
  "Now we will develop a short ",
  StyleBox["Mathematica", "TI"],
  " program to generate random numbers from the standard normal distribution \
using a well\[Hyphen]known method. "
}], "Text",
  CellTags->{"S0.1", "1.3"}],

Cell["\<\
First we generate two random variables from the uniform \
distribution on the interval [\[Hyphen]1 , 1]. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.4"}],

Cell[CellGroupData[{

Cell["r = Table[Random[Real, {-1, 1}], {2}]", "Input",
  CellLabel->"In[1]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \({\(-0.887858410330276903`\), 0.260599591558718035`}\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell["\<\
We repeat this until the sum of the squares of these two numbers is \
less then 1. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.5"}],

Cell["\<\
(s = 1;
While[s >= 1,  
    r = Table[Random[Real, {-1, 1}], {2}];
    s = r . r
    ];)\
\>", "Input",
  CellLabel->"In[2]:=",
  CellTags->"S0.1"],

Cell["We get a pair of independent standard normal variables. ", "MathCaption",
  CellTags->{"S0.1", "1.6"}],

Cell[CellGroupData[{

Cell["r Sqrt[-2 Log[s] / s]", "Input",
  CellLabel->"In[3]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \({\(-0.33919362127946484`\), 0.89909782736674888`}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["We pick the first one. ", "MathCaption",
  CellTags->{"S0.1", "1.7"}],

Cell[CellGroupData[{

Cell["First[r] Sqrt[-2 Log[s]/s]", "Input",
  CellLabel->"In[4]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(\(-0.33919362127946484`\)\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "Now we collect these steps into a program ",
  StyleBox["chance[ ]", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.8"}],

Cell["\<\
chance[ ] :=
   Module[{r, s = 1},
      While[s >= 1,  
         r = Table[Random[Real, {-1, 1}], {2}];
         s = r . r
         ];
      First[r] Sqrt[-2 Log[s] / s]
      ]\
\>", "Input",
  CellLabel->"In[5]:=",
  CellTags->"S0.1"],

Cell["\<\
We generate a list of 2000 random numbers from the standard normal \
distribution. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.9"}],

Cell["data = Table[chance[ ], {2000}];", "Input",
  CellLabel->"In[6]:=",
  CellTags->"S0.1"],

Cell[TextData[{
  "Now we will check how good our random number generator is. We will use the \
function ",
  StyleBox["BinCounts", "MB"],
  " from the standard statistics package. "
}], "MathCaption",
  CellTags->{"S0.1", "1.10"}],

Cell["Needs[\"Statistics`DataManipulation`\"]", "Input",
  CellLabel->"In[7]:=",
  CellTags->"S0.1"],

Cell["\<\
We first tabulate the frequencies in order to compare them with the \
predicted frequencies. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.11"}],

Cell["freq = BinCounts[data, {-5, 5, .25}];", "Input",
  CellLabel->"In[8]:=",
  CellTags->"S0.1"],

Cell[TextData[{
  "This explains what ",
  StyleBox["BinCounts", "MB"],
  " does. "
}], "MathCaption",
  CellTags->{"S0.1", "1.12"}],

Cell[CellGroupData[{

Cell["?BinCounts", "Input",
  CellLabel->"In[9]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \("BinCounts[{x1, x2, ...}, {xmin, xmax, dx}] gives a list of the number \
of elements in the data {x1, x2, ...} that lie in bins from xmin to xmax in \
steps  of dx.  BinCounts[{{x1, y1}, {x2, y2}, ...}, {xmin, xmax, dx}, {ymin, \
ymax, dy}] gives a 2-dimensional array of bin counts for the bivariate data \
{{x1, y1}, {x2, y2}, ...}.  In general, BinCounts gives a p-dimensional array \
of bin counts for p-variate data."\)], "Print"]
}, Open  ]],

Cell["This is the graph of the frequencies. ", "MathCaption",
  CellTags->{"S0.1", "1.13"}],

Cell[CellGroupData[{

Cell["g1 = ListPlot[freq, PlotJoined -> True];", "Input",
  CellLabel->"In[10]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.0147151 0.00277643 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .15354 -12 -4.5 ]
[.01131 .15354 0 4.5 ]
[.01131 .29236 -18 -4.5 ]
[.01131 .29236 0 4.5 ]
[.01131 .43118 -18 -4.5 ]
[.01131 .43118 0 4.5 ]
[.01131 .57 -18 -4.5 ]
[.01131 .57 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(10)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(20)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(30)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(40)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15354 m
.03006 .15354 L
s
[(50)] .01131 .15354 1 0 Mshowa
.02381 .29236 m
.03006 .29236 L
s
[(100)] .01131 .29236 1 0 Mshowa
.02381 .43118 m
.03006 .43118 L
s
[(150)] .01131 .43118 1 0 Mshowa
.02381 .57 m
.03006 .57 L
s
[(200)] .01131 .57 1 0 Mshowa
.125 Mabswid
.02381 .04248 m
.02756 .04248 L
s
.02381 .07024 m
.02756 .07024 L
s
.02381 .09801 m
.02756 .09801 L
s
.02381 .12577 m
.02756 .12577 L
s
.02381 .1813 m
.02756 .1813 L
s
.02381 .20907 m
.02756 .20907 L
s
.02381 .23683 m
.02756 .23683 L
s
.02381 .26459 m
.02756 .26459 L
s
.02381 .32012 m
.02756 .32012 L
s
.02381 .34789 m
.02756 .34789 L
s
.02381 .37565 m
.02756 .37565 L
s
.02381 .40342 m
.02756 .40342 L
s
.02381 .45894 m
.02756 .45894 L
s
.02381 .48671 m
.02756 .48671 L
s
.02381 .51447 m
.02756 .51447 L
s
.02381 .54224 m
.02756 .54224 L
s
.02381 .59777 m
.02756 .59777 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04762 .01472 m
.07143 .01472 L
.09524 .01472 L
.11905 .01749 L
.14286 .01472 L
.16667 .01472 L
.19048 .01472 L
.21429 .01749 L
.2381 .0286 L
.2619 .0286 L
.28571 .04803 L
.30952 .05636 L
.33333 .123 L
.35714 .13965 L
.38095 .23683 L
.40476 .3229 L
.42857 .40897 L
.45238 .45339 L
.47619 .52003 L
.5 .60332 L
.52381 .55334 L
.54762 .54779 L
.57143 .48671 L
.59524 .3812 L
.61905 .26459 L
.64286 .20907 L
.66667 .19796 L
.69048 .09801 L
.71429 .06469 L
.7381 .05359 L
.7619 .04248 L
.78571 .02582 L
.80952 .02027 L
.83333 .01472 L
.85714 .01472 L
.88095 .01472 L
.90476 .01472 L
.92857 .01472 L
.95238 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo001Cool5
0002ool00`00ooooo`0iool30003ool00`00ooooo`0jool20004ool00`00ooooo`0jool30002ool0
0`00ooooo`03ool005Goo`07003oooooool00?oo0000>_oo00<00?ooool00_oo00<00?oo0000?Ooo
00H00?ooool00?oo000lool01P00ooooo`00ool000Coo`00EOoo00L00?ooooooo`00ool0000kool0
1`00oooooooo003oo`0003coo`07003oooooool00?oo0000>_oo100000Coo`00ool000Coo`00EOoo
00L00?ooooooo`00ool0000kool01`00oooooooo003oo`0003goo`06003ooooo003oo`00>_oo00<0
0?oo00000_oo00<00?oo00001?oo001Eool01`00oooooooo003oo`0003[oo`03003oo`0000;oo`03
003oo`0003_oo`03003oo`0000;oo`03003oo`0003_oo`8000;oo`03003oo`0000Coo`00E?oo0P00
1?oo00<00?ooool0>_oo00<00?ooool00_oo00<00?ooool0>ooo00<00?ooool00_oo00<00?ooool0
>ooo00D00?ooooooo`0000Goo`00oooo:?oo000Eool00`00ooooo`3oool@ool001Goo`03003ooooo
0?oooa3oo`005Ooo00<00?ooool0oooo4?oo000Eool00`00ooooo`3oool@ool001Goo`03003ooooo
0?oooa3oo`003_ooo`006P00000Eool00`00ooooo`0:ool00`00ooooo`0;ool00`00ooooo`0:ool0
0`00ooooo`0:ool01000ool000002_oo00<00?ooool02_oo00<00?ooool02_oo00<00?ooool02ooo
00<00?ooool02_oo00<00?ooool02_oo00<00?ooool02ooo00<00?ooool02_oo00<00?ooool02_oo
00<00?ooool02_oo00<00?ooool02ooo00<00?ooool02_oo00<00?ooool00ooo1@000_oo00<00?oo
ool02ooo00<00?ooool02_oo00<00?ooool02_oo00<00?ooool01Ooo000Eool00`00ooooo`0fool2
002Lool4000gool001Goo`03003ooooo03Soo`T0097oo`8003_oo`005Ooo00<00?ooool0@Ooo00<0
0?ooool0S?oo0P00?Ooo000Eool00`00ooooo`12ool00`00ooooo`29ool2000oool001Goo`03003o
oooo04?oo`03003ooooo08Koo`80047oo`005Ooo0P00AOoo00<00?ooool0Q?oo00<00?ooool0@Ooo
000Eool00`00ooooo`15ool00`00ooooo`21ool20014ool001Goo`03003ooooo04Koo`8007ooo`80
04Koo`005Ooo00<00?ooool0B?oo1000NOoo0P00B?oo000Eool00`00ooooo`1<ool2001eool2001:
ool001Goo`03003ooooo04goo`03003ooooo077oo`8004coo`005Ooo00<00?ooool0C_oo00<00?oo
ool0K_oo0P00C_oo000Eool00`00ooooo`1>ool00`00ooooo`1]ool00`00ooooo`1>ool001Goo`80
04ooo`03003ooooo06coo`03003ooooo04ooo`005Ooo00<00?ooool0Cooo00<00?ooool0J_oo00<0
0?ooool0D?oo000Eool00`00ooooo`1?ool00`00ooooo`1Zool00`00ooooo`1@ool001Goo`03003o
oooo053oo`03003ooooo06Soo`03003ooooo057oo`005Ooo00<00?ooool0D?oo00<00?ooool0Iooo
00<00?ooool0D_oo000Eool00`00ooooo`1@ool00`00ooooo`1Vool00`00ooooo`1Cool001Goo`03
003ooooo057oo`03003ooooo06Goo`03003ooooo05?oo`005Ooo00<00?ooool0DOoo00<00?ooool0
I?oo00<00?ooool0E?oo000Eool2001Bool00`00ooooo`1Sool00`00ooooo`1Eool001Goo`03003o
oooo05;oo`03003ooooo06;oo`03003ooooo05Goo`005Ooo00<00?ooool0D_oo00<00?ooool0H_oo
00<00?ooool0EOoo000Eool00`00ooooo`1Cool00`00ooooo`1Pool00`00ooooo`1Fool001Goo`03
003ooooo05?oo`03003ooooo063oo`03003ooooo05Koo`005Ooo00<00?ooool0Dooo00<00?ooool0
H?oo00<00?ooool0E_oo000Eool00`00ooooo`1Dool00`00ooooo`1Oool00`00ooooo`1Fool001Go
o`03003ooooo05Coo`03003ooooo05koo`03003ooooo05Ooo`005Ooo0P00E_oo0P00G_oo00<00?oo
ool0Eooo000Eool00`00ooooo`1Gool00`00ooooo`1Kool00`00ooooo`1Gool001Goo`03003ooooo
05Soo`8005_oo`03003ooooo05Ooo`005Ooo00<00?ooool0F_oo00<00?ooool0F?oo00<00?ooool0
Eooo000Eool00`00ooooo`1Jool00`00ooooo`1Gool00`00ooooo`1Hool000[oo`03003ooooo00;o
o`03003ooooo00?oo`03003ooooo05_oo`03003ooooo05Koo`03003ooooo05Soo`002Ooo00<00?oo
00000_oo00<00?oo00001?oo00<00?ooool0Fooo00<00?ooool0E_oo00<00?ooool0F?oo000;ool0
1P00ooooo`00ool000Coo`<005_oo`03003ooooo05Koo`03003ooooo05Soo`002Ooo0P000ooo00<0
0?oo00001?oo00<00?ooool0Fooo00<00?ooool0E_oo00<00?ooool0F?oo0009ool00`00ooooo`02
ool00`00ool00004ool00`00ooooo`1Lool00`00ooooo`1Dool00`00ooooo`1Iool000Woo`<000?o
o`03003ooooo00?oo`03003ooooo05coo`03003ooooo05Coo`03003ooooo05Woo`005Ooo00<00?oo
ool0G?oo00<00?ooool0E?oo00<00?ooool0FOoo000Eool00`00ooooo`1Lool00`00ooooo`1Dool0
0`00ooooo`1Iool001Goo`03003ooooo05goo`03003ooooo05;oo`03003ooooo05[oo`005Ooo00<0
0?ooool0GOoo00<00?ooool0D_oo00<00?ooool0F_oo000Eool2001Nool00`00ooooo`1Bool00`00
ooooo`1Jool001Goo`03003ooooo05goo`03003ooooo05;oo`03003ooooo05[oo`005Ooo00<00?oo
ool0G_oo00<00?ooool0DOoo00<00?ooool0F_oo000Eool00`00ooooo`1Nool00`00ooooo`1@ool0
0`00ooooo`1Kool001Goo`03003ooooo05koo`03003ooooo053oo`03003ooooo05_oo`005Ooo00<0
0?ooool0G_oo00<00?ooool0Cooo0P00GOoo000Eool00`00ooooo`1Oool00`00ooooo`1<ool2001O
ool001Goo`03003ooooo05ooo`03003ooooo04[oo`80067oo`005Ooo0P00H?oo00<00?ooool0B?oo
0P00Hooo000Eool00`00ooooo`1Oool00`00ooooo`18ool00`00ooooo`1Rool001Goo`03003ooooo
063oo`03003ooooo04Koo`03003ooooo06?oo`005Ooo00<00?ooool0H?oo00<00?ooool0A_oo00<0
0?ooool0Hooo000Eool00`00ooooo`1Pool00`00ooooo`15ool00`00ooooo`1Tool001Goo`03003o
oooo063oo`03003ooooo04Goo`03003ooooo06Coo`005Ooo00<00?ooool0HOoo00<00?ooool0A?oo
00<00?ooool0I?oo000Eool00`00ooooo`1Qool00`00ooooo`13ool00`00ooooo`1Uool001Goo`80
06;oo`03003ooooo04?oo`03003ooooo06Goo`005Ooo00<00?ooool0HOoo00<00?ooool0@_oo00<0
0?ooool0I_oo000Eool00`00ooooo`1Rool00`00ooooo`11ool00`00ooooo`1Vool001Goo`03003o
oooo06;oo`03003ooooo047oo`03003ooooo06Koo`005Ooo00<00?ooool0H_oo00<00?ooool0@?oo
00<00?ooool0Iooo000Eool00`00ooooo`1Rool00`00ooooo`10ool00`00ooooo`1Wool001Goo`03
003ooooo06?oo`03003ooooo03koo`03003ooooo06Soo`005Ooo0P00I?oo00<00?ooool0?_oo00<0
0?ooool0J?oo000Eool00`00ooooo`1Sool00`00ooooo`0nool00`00ooooo`1Xool001Goo`03003o
oooo06Coo`03003ooooo03goo`03003ooooo06Soo`005Ooo00<00?ooool0I?oo00<00?ooool0??oo
00<00?ooool0JOoo000Eool00`00ooooo`1Tool00`00ooooo`0lool00`00ooooo`1Yool001Goo`03
003ooooo06Goo`03003ooooo03_oo`03003ooooo06Woo`000ooo1@000_oo00<00?ooool00_oo00<0
0?ooool00ooo00<00?ooool0IOoo00<00?ooool0>ooo00<00?ooool0JOoo0005ool01`00oooooooo
003oo`0000;oo`03003oo`0000Coo`03003ooooo06Goo`03003ooooo03_oo`03003ooooo06Woo`00
1Ooo00L00?ooooooo`00ool00002ool00`00ool00004ool3001Uool00`00ooooo`0jool00`00oooo
o`1Zool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo00<00?ooool0I_oo00<00?oo
ool0>Ooo00<00?ooool0J_oo0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Coo`03003o
oooo06Koo`03003ooooo03Woo`03003ooooo06[oo`001?oo0P001?oo00<00?ooool00_oo00<00?oo
ool00ooo00<00?ooool0I_oo00<00?ooool0>Ooo00<00?ooool0J_oo000Eool00`00ooooo`1Wool0
0`00ooooo`0gool00`00ooooo`1[ool001Goo`03003ooooo06Ooo`03003ooooo03Ooo`03003ooooo
06_oo`005Ooo00<00?ooool0Iooo00<00?ooool0=ooo00<00?ooool0Jooo000Eool00`00ooooo`1W
ool00`00ooooo`0gool00`00ooooo`1[ool001Goo`8006Woo`03003ooooo03Koo`03003ooooo06_o
o`005Ooo00<00?ooool0J?oo00<00?ooool0=Ooo00<00?ooool0K?oo000Eool00`00ooooo`1Xool0
0`00ooooo`0eool00`00ooooo`1/ool001Goo`03003ooooo06Woo`03003ooooo03Coo`03003ooooo
06coo`005Ooo00<00?ooool0JOoo00<00?ooool0=?oo00<00?ooool0K?oo000Eool00`00ooooo`1Y
ool00`00ooooo`0dool00`00ooooo`1/ool001Goo`03003ooooo06Woo`03003ooooo03?oo`03003o
oooo06goo`005Ooo00<00?ooool0J_oo00<00?ooool0<_oo00<00?ooool0KOoo000Eool2001[ool0
0`00ooooo`0bool00`00ooooo`1]ool001Goo`03003ooooo06[oo`03003ooooo03;oo`03003ooooo
06goo`005Ooo00<00?ooool0J_oo00<00?ooool0<Ooo00<00?ooool0K_oo000Eool00`00ooooo`1[
ool00`00ooooo`0`ool00`00ooooo`1^ool001Goo`03003ooooo06_oo`03003ooooo033oo`03003o
oooo06koo`005Ooo00<00?ooool0Jooo00<00?ooool0<?oo00<00?ooool0K_oo000Eool00`00oooo
o`1[ool00`00ooooo`0`ool00`00ooooo`1^ool001Goo`03003ooooo06coo`03003ooooo02koo`03
003ooooo06ooo`005Ooo0P00KOoo00<00?ooool0;_oo00<00?ooool0Kooo000Eool00`00ooooo`1/
ool00`00ooooo`0^ool00`00ooooo`1_ool001Goo`03003ooooo06coo`03003ooooo02koo`03003o
oooo06ooo`005Ooo00<00?ooool0KOoo00<00?ooool0;Ooo00<00?ooool0Kooo000Eool00`00oooo
o`1]ool00`00ooooo`0/ool00`00ooooo`1`ool001Goo`03003ooooo06goo`03003ooooo02coo`03
003ooooo073oo`005Ooo00<00?ooool0KOoo00<00?ooool0;?oo00<00?ooool0L?oo000Eool2001_
ool00`00ooooo`0[ool00`00ooooo`1`ool001Goo`03003ooooo06koo`03003ooooo02[oo`03003o
oooo077oo`005Ooo00<00?ooool0K_oo00<00?ooool0:_oo00<00?ooool0LOoo000Eool00`00oooo
o`1_ool00`00ooooo`0Yool00`00ooooo`1aool001Goo`03003ooooo06ooo`03003ooooo02Woo`03
003ooooo077oo`005Ooo00<00?ooool0L?oo00<00?ooool09ooo00<00?ooool0L_oo0003ool50002
ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`1`ool00`00ooooo`0Wool00`00ooooo`1b
ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo00<00?ooool0LOoo00<00?ooool0
9_oo00<00?ooool0L_oo0005ool00`00ooooo`03ool01P00ooooo`00ool000Coo`<007;oo`03003o
oooo02Goo`03003ooooo07;oo`001Ooo00@00?ooooooo`8000?oo`03003oo`0000Coo`03003ooooo
07;oo`03003ooooo02Coo`03003ooooo07?oo`001Ooo00D00?ooooooo`0000Coo`03003oo`0000Co
o`03003ooooo07?oo`03003ooooo02?oo`03003ooooo07?oo`001?oo0P000ooo0`000ooo00<00?oo
ool00ooo00<00?ooool0Looo00<00?ooool08ooo00<00?ooool0Looo000Eool00`00ooooo`1dool0
0`00ooooo`0Rool00`00ooooo`1cool001Goo`03003ooooo07Coo`03003ooooo02;oo`03003ooooo
07?oo`005Ooo00<00?ooool0MOoo00<00?ooool08?oo00<00?ooool0M?oo000Eool00`00ooooo`1e
ool00`00ooooo`0Pool00`00ooooo`1dool001Goo`8007Ooo`03003ooooo01ooo`03003ooooo07Co
o`005Ooo00<00?ooool0M_oo00<00?ooool07ooo00<00?ooool0M?oo000Eool00`00ooooo`1fool0
0`00ooooo`0Nool00`00ooooo`1eool001Goo`03003ooooo07Ooo`03003ooooo01goo`03003ooooo
07Goo`005Ooo00<00?ooool0Mooo00<00?ooool07Ooo00<00?ooool0MOoo000Eool00`00ooooo`1h
ool00`00ooooo`0Lool00`00ooooo`1eool001Goo`03003ooooo07Soo`03003ooooo01_oo`03003o
oooo07Koo`005Ooo00<00?ooool0N?oo00<00?ooool06ooo00<00?ooool0M_oo000Eool2001jool0
0`00ooooo`0Jool00`00ooooo`1fool001Goo`03003ooooo07Woo`03003ooooo01[oo`03003ooooo
07Koo`005Ooo00<00?ooool0NOoo00<00?ooool06Ooo00<00?ooool0Mooo000Eool00`00ooooo`1j
ool00`00ooooo`0Hool00`00ooooo`1gool001Goo`03003ooooo07[oo`03003ooooo01Soo`03003o
oooo07Ooo`005Ooo00<00?ooool0Nooo00<00?ooool05_oo00<00?ooool0N?oo000Eool00`00oooo
o`1kool00`00ooooo`0Fool00`00ooooo`1hool001Goo`8007coo`03003ooooo01Koo`03003ooooo
07Soo`005Ooo00<00?ooool0O?oo00<00?ooool05?oo00<00?ooool0NOoo000Eool00`00ooooo`1l
ool00`00ooooo`0Dool00`00ooooo`1iool001Goo`03003ooooo07coo`03003ooooo01?oo`03003o
oooo07[oo`005Ooo00<00?ooool0OOoo00<00?ooool04_oo00<00?ooool0N_oo000Eool00`00oooo
o`1mool00`00ooooo`0Bool00`00ooooo`1jool001Goo`03003ooooo07goo`03003ooooo017oo`03
003ooooo07_oo`005Ooo00<00?ooool0OOoo00<00?ooool04Ooo00<00?ooool0Nooo000Eool2001o
ool00`00ooooo`0@ool00`00ooooo`1kool001Goo`03003ooooo07koo`03003ooooo00ooo`03003o
oooo07coo`005Ooo00<00?ooool0O_oo00<00?ooool03?oo1000O_oo000Eool00`00ooooo`1nool0
0`00ooooo`08ool40022ool001Goo`03003ooooo07ooo`03003ooooo00Koo`03003ooooo08Coo`00
5Ooo00<00?ooool0Oooo00<00?ooool01_oo00<00?ooool0Q?oo0004ool30003ool00`00ooooo`02
ool00`00ooooo`03ool00`00ooooo`1oool00`00ooooo`05ool00`00ooooo`25ool000Coo`03003o
oooo00;oo`03003oo`0000;oo`03003oo`0000Coo`03003ooooo07ooo`03003ooooo00Goo`03003o
oooo08Goo`001Ooo00L00?ooooooo`00ool00002ool00`00ool00004ool30020ool00`00ooooo`03
ool00`00ooooo`26ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo00<00?ooool0
P?oo00<00?ooool00ooo00<00?ooool0Q_oo0004ool00`00ool00002ool00`00ool00002ool00`00
ool00004ool00`00ooooo`20ool00`00ooooo`02ool00`00ooooo`27ool000Goo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00?oo`03003ooooo083oo`03003ooooo00;oo`03003ooooo08Oo
o`005Ooo00<00?ooool0POoo00@00?ooool008[oo`005Ooo00<00?ooool0POoo00@00?ooool008[o
o`005Ooo00<00?ooool0POoo00<00?oo0000Rooo000Eool00`00ooooo`21ool00`00ool0002;ool0
01Goo`8008?oo`03003ooooo08[oo`005Ooo00<00?ooool0P_oo00<00?ooool0R_oo000Eool00`00
ooooo`3oool@ool001Goo`03003ooooo0?oooa3oo`005Ooo00<00?ooool0oooo4?oo000Eool00`00
ooooo`3oool@ool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.22786, -16.3262, \
0.150148, 1.28761}}]
}, Open  ]],

Cell[TextData[{
  "We load the ",
  StyleBox["Options", "MB"],
  " subpackage to get the function ",
  StyleBox["Norm", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.14"}],

Cell[BoxData[
    \(Needs["\<Finance`Options`\>"]\)], "Input",
  CellLabel->"In[11]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Norm\)\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \("Norm[x] returns the cumulative normal distribution function evaluated \
at x."\)], "Print"]
}, Open  ]],

Cell["We compute the predicted frequencies. ", "MathCaption",
  CellTags->{"S0.1", "1.15"}],

Cell["\<\
predfreq = Table[2000 (Norm[x+.25] - Norm[x]),
   {x, -5, 5, .25}];\
\>", "Input",
  CellLabel->"In[13]:=",
  CellTags->"S0.1"],

Cell["This is the corresponding plot. ", "MathCaption",
  CellTags->{"S0.1", "1.16"}],

Cell[CellGroupData[{

Cell["g2 = ListPlot[predfreq, PlotJoined -> True];", "Input",
  CellLabel->"In[14]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0238095 0.0147138 0.0029816 [
[.2381 -0.0125 -6 -9 ]
[.2381 -0.0125 6 0 ]
[.47619 -0.0125 -6 -9 ]
[.47619 -0.0125 6 0 ]
[.71429 -0.0125 -6 -9 ]
[.71429 -0.0125 6 0 ]
[.95238 -0.0125 -6 -9 ]
[.95238 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16379 -12 -4.5 ]
[-0.0125 .16379 0 4.5 ]
[-0.0125 .31287 -18 -4.5 ]
[-0.0125 .31287 0 4.5 ]
[-0.0125 .46195 -18 -4.5 ]
[-0.0125 .46195 0 4.5 ]
[-0.0125 .61103 -18 -4.5 ]
[-0.0125 .61103 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 0 m
.2381 .00625 L
s
[(10)] .2381 -0.0125 0 1 Mshowa
.47619 0 m
.47619 .00625 L
s
[(20)] .47619 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(30)] .71429 -0.0125 0 1 Mshowa
.95238 0 m
.95238 .00625 L
s
[(40)] .95238 -0.0125 0 1 Mshowa
.125 Mabswid
.04762 0 m
.04762 .00375 L
s
.09524 0 m
.09524 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.19048 0 m
.19048 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.52381 0 m
.52381 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7619 0 m
.7619 .00375 L
s
.80952 0 m
.80952 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.90476 0 m
.90476 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .16379 m
.00625 .16379 L
s
[(50)] -0.0125 .16379 1 0 Mshowa
0 .31287 m
.00625 .31287 L
s
[(100)] -0.0125 .31287 1 0 Mshowa
0 .46195 m
.00625 .46195 L
s
[(150)] -0.0125 .46195 1 0 Mshowa
0 .61103 m
.00625 .61103 L
s
[(200)] -0.0125 .61103 1 0 Mshowa
.125 Mabswid
0 .04453 m
.00375 .04453 L
s
0 .07435 m
.00375 .07435 L
s
0 .10416 m
.00375 .10416 L
s
0 .13398 m
.00375 .13398 L
s
0 .19361 m
.00375 .19361 L
s
0 .22343 m
.00375 .22343 L
s
0 .25324 m
.00375 .25324 L
s
0 .28306 m
.00375 .28306 L
s
0 .34269 m
.00375 .34269 L
s
0 .37251 m
.00375 .37251 L
s
0 .40232 m
.00375 .40232 L
s
0 .43214 m
.00375 .43214 L
s
0 .49177 m
.00375 .49177 L
s
0 .52159 m
.00375 .52159 L
s
0 .5514 m
.00375 .5514 L
s
0 .58122 m
.00375 .58122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2381 .61178 m
.2381 .61803 L
s
.47619 .61178 m
.47619 .61803 L
s
.71429 .61178 m
.71429 .61803 L
s
.95238 .61178 m
.95238 .61803 L
s
.125 Mabswid
.04762 .61428 m
.04762 .61803 L
s
.09524 .61428 m
.09524 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.19048 .61428 m
.19048 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.52381 .61428 m
.52381 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7619 .61428 m
.7619 .61803 L
s
.80952 .61428 m
.80952 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.90476 .61428 m
.90476 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16379 m
1 .16379 L
s
.99375 .31287 m
1 .31287 L
s
.99375 .46195 m
1 .46195 L
s
.99375 .61103 m
1 .61103 L
s
.125 Mabswid
.99625 .04453 m
1 .04453 L
s
.99625 .07435 m
1 .07435 L
s
.99625 .10416 m
1 .10416 L
s
.99625 .13398 m
1 .13398 L
s
.99625 .19361 m
1 .19361 L
s
.99625 .22343 m
1 .22343 L
s
.99625 .25324 m
1 .25324 L
s
.99625 .28306 m
1 .28306 L
s
.99625 .34269 m
1 .34269 L
s
.99625 .37251 m
1 .37251 L
s
.99625 .40232 m
1 .40232 L
s
.99625 .43214 m
1 .43214 L
s
.99625 .49177 m
1 .49177 L
s
.99625 .52159 m
1 .52159 L
s
.99625 .5514 m
1 .5514 L
s
.99625 .58122 m
1 .58122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.04762 .01473 L
.07143 .01476 L
.09524 .01484 L
.11905 .01505 L
.14286 .01557 L
.16667 .01677 L
.19048 .01932 L
.21429 .02443 L
.2381 .03397 L
.2619 .05058 L
.28571 .07748 L
.30952 .11793 L
.33333 .17422 L
.35714 .24634 L
.38095 .3308 L
.40476 .42004 L
.42857 .50316 L
.45238 .56784 L
.47619 .60332 L
.5 .60332 L
.52381 .56784 L
.54762 .50316 L
.57143 .42004 L
.59524 .3308 L
.61905 .24634 L
.64286 .17422 L
.66667 .11793 L
.69048 .07748 L
.71429 .05058 L
.7381 .03397 L
.7619 .02443 L
.78571 .01932 L
.80952 .01677 L
.83333 .01557 L
.85714 .01505 L
.88095 .01484 L
.90476 .01476 L
.92857 .01473 L
.95238 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo001Bool5
0002ool00`00ooooo`0gool30003ool00`00ooooo`0gool20004ool00`00ooooo`0hool30002ool0
0`00ooooo`0;ool005Coo`07003oooooool00?oo0000>?oo00<00?ooool00_oo00<00?oo0000>_oo
00H00?ooool00?oo000jool01P00ooooo`00ool000coo`00E?oo00L00?ooooooo`00ool0000iool0
1`00oooooooo003oo`0003Woo`07003oooooool00?oo0000>?oo100000Coo`00ool000coo`00E?oo
00L00?ooooooo`00ool0000iool01`00oooooooo003oo`0003[oo`06003ooooo003oo`00>?oo00<0
0?oo00000_oo00<00?oo00003?oo001Dool01`00oooooooo003oo`0003Soo`03003oo`0000;oo`03
003oo`0003Soo`03003oo`0000;oo`03003oo`0003Woo`8000;oo`03003oo`0000coo`00Dooo0P00
1?oo00<00?ooool0>?oo00<00?ooool00_oo00<00?ooool0>?oo00<00?ooool00_oo00<00?ooool0
>Ooo00D00?ooooooo`0000goo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool0
01Ooool000l000;oo`005ooo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02_oo00<00?oo
ool02_oo00<00?ooool02_oo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?oo
ool02_oo00<00?ooool02_oo00<00?ooool02_oo00<00?ooool02_oo00<00?ooool02_oo00<00?oo
ool02Ooo00<00?ooool02_oo00<00?ooool02_oo00<00?ooool02_oo00<00?ooool02_oo00<00?oo
ool02_oo00<00?ooool02Ooo00<00?ooool02_oo0@000Ooo0Ooo000@ool00`00ooooo`04ool00`00
ooooo`0mool00`00ooooo`0mool00`00ooooo`0mool00`00ooooo`0mool00`00ooooo`0:ool10001
ool1ool000ooo`03003oo`0000Goo`03003ooooo0?ooo`_oo`40007oo`7oo`003ooo00<00?oo0000
1Ooo0P001?oo9000]?oo:P001?oo0P000_oo000?ool00`00ool00005ool00`00ooooo`0Wool;002M
ool<000_ool10001ool1ool000ooo`03003oo`0000Goo`03003ooooo03;oo`<009Ooo`<003_oo`40
007oo`7oo`004?oo00<00?ooool01?oo00<00?ooool0=Ooo0`00TOoo0`00?_oo0@000Ooo0Ooo000G
ool00`00ooooo`0hool4002:ool30011ool10001ool1ool001Ooo`03003ooooo03coo`8008Koo`80
04Coo`40007oo`7oo`005ooo00<00?ooool0?_oo00<00?ooool0POoo0P00A_oo0@000Ooo0Ooo000G
ool00`00ooooo`0oool00`00ooooo`1oool00`00ooooo`16ool10001ool1ool001Ooo`80047oo`80
07koo`03003ooooo04Koo`8000;oo`005ooo00<00?ooool0@_oo00<00?ooool0NOoo0P00B_oo0@00
0Ooo0Ooo000Gool00`00ooooo`13ool00`00ooooo`1gool00`00ooooo`1:ool10001ool1ool001Oo
o`03003ooooo04Coo`03003ooooo07Goo`03003ooooo04_oo`40007oo`7oo`005ooo00<00?ooool0
AOoo00<00?ooool0Looo00<00?ooool0C?oo0@000Ooo0Ooo000Gool00`00ooooo`16ool00`00oooo
o`1aool00`00ooooo`1=ool10001ool1ool001Ooo`03003ooooo04Ooo`03003ooooo073oo`03003o
oooo04goo`40007oo`7oo`005ooo00<00?ooool0B?oo00<00?ooool0K_oo00<00?ooool0C_oo0@00
0Ooo0Ooo000Gool2001:ool00`00ooooo`1/ool00`00ooooo`1>ool20002ool001Ooo`03003ooooo
04[oo`03003ooooo06[oo`03003ooooo053oo`40007oo`7oo`005ooo00<00?ooool0Booo00<00?oo
ool0J?oo00<00?ooool0DOoo0@000Ooo0Ooo000Gool00`00ooooo`1;ool00`00ooooo`1Xool00`00
ooooo`1Aool10001ool1ool001Ooo`03003ooooo04coo`03003ooooo06Koo`03003ooooo05;oo`40
007oo`7oo`005ooo00<00?ooool0C?oo00<00?ooool0IOoo00<00?ooool0Dooo0@000Ooo0Ooo000G
ool00`00ooooo`1=ool00`00ooooo`1Tool00`00ooooo`1Cool10001ool1ool001Ooo`03003ooooo
04goo`03003ooooo06?oo`03003ooooo05Coo`40007oo`7oo`005ooo0P00Cooo00<00?ooool0H_oo
00<00?ooool0Dooo0P000_oo000Gool00`00ooooo`1>ool00`00ooooo`1Qool00`00ooooo`1Eool1
0001ool1ool001Ooo`03003ooooo04ooo`03003ooooo05ooo`03003ooooo05Koo`40007oo`7oo`00
5ooo00<00?ooool0Cooo00<00?ooool0Gooo00<00?ooool0E_oo0@000Ooo0Ooo000Gool00`00oooo
o`1@ool00`00ooooo`1Mool00`00ooooo`1Gool10001ool1ool001Ooo`03003ooooo053oo`03003o
oooo05goo`03003ooooo05Ooo`40007oo`7oo`005ooo00<00?ooool0DOoo00<00?ooool0Fooo00<0
0?ooool0F?oo0@000Ooo0Ooo000Gool00`00ooooo`1Aool00`00ooooo`1Kool00`00ooooo`1Hool1
0001ool1ool001Ooo`8005?oo`03003ooooo05Woo`03003ooooo05Soo`8000;oo`005ooo00<00?oo
ool0D_oo00<00?ooool0FOoo00<00?ooool0FOoo0@000Ooo0Ooo000Gool00`00ooooo`1Bool00`00
ooooo`1Iool00`00ooooo`1Iool10001ool1ool001Ooo`03003ooooo05?oo`03003ooooo05Ooo`03
003ooooo05[oo`40007oo`7oo`005ooo00<00?ooool0Dooo00<00?ooool0Eooo00<00?ooool0F_oo
0@000Ooo0Ooo000Gool00`00ooooo`1Dool00`00ooooo`1Eool00`00ooooo`1Kool10001ool1ool0
00_oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo05Coo`03003ooooo05Goo`03003ooooo
05_oo`40007oo`7oo`002_oo00<00?oo00000_oo00<00?oo00001Ooo00<00?ooool0E?oo00<00?oo
ool0EOoo00<00?ooool0Fooo0@000Ooo0Ooo000<ool01P00ooooo`00ool000Goo`8005Koo`03003o
oooo05?oo`03003ooooo05_oo`8000;oo`002_oo0P000ooo00<00?oo00001Ooo00<00?ooool0EOoo
00<00?ooool0Dooo00<00?ooool0G?oo0@000Ooo0Ooo000:ool00`00ooooo`02ool00`00ool00005
ool00`00ooooo`1Fool00`00ooooo`1Aool00`00ooooo`1Mool10001ool1ool000[oo`<000?oo`03
003ooooo00Coo`03003ooooo05Koo`03003ooooo057oo`03003ooooo05goo`40007oo`7oo`005ooo
00<00?ooool0E_oo00<00?ooool0DOoo00<00?ooool0GOoo0@000Ooo0Ooo000Gool00`00ooooo`1G
ool00`00ooooo`1?ool00`00ooooo`1Nool10001ool1ool001Ooo`03003ooooo05Ooo`03003ooooo
04ooo`03003ooooo05koo`40007oo`7oo`005ooo00<00?ooool0Eooo00<00?ooool0Cooo00<00?oo
ool0G_oo0@000Ooo0Ooo000Gool2001Iool00`00ooooo`1=ool00`00ooooo`1Nool20002ool001Oo
o`03003ooooo05Soo`03003ooooo04goo`03003ooooo05ooo`40007oo`7oo`005ooo00<00?ooool0
F?oo00<00?ooool0COoo00<00?ooool0Gooo0@000Ooo0Ooo000Gool00`00ooooo`1Iool00`00oooo
o`1<ool00`00ooooo`1Oool10001ool1ool001Ooo`03003ooooo05Woo`03003ooooo04_oo`03003o
oooo063oo`40007oo`7oo`005ooo00<00?ooool0F_oo00<00?ooool0B_oo00<00?ooool0H?oo0@00
0Ooo0Ooo000Gool00`00ooooo`1Jool00`00ooooo`1:ool00`00ooooo`1Pool10001ool1ool001Oo
o`03003ooooo05[oo`03003ooooo04Woo`03003ooooo067oo`40007oo`7oo`005ooo0P00G?oo00<0
0?ooool0B?oo00<00?ooool0H?oo0P000_oo000Gool00`00ooooo`1Kool00`00ooooo`18ool00`00
ooooo`1Qool10001ool1ool001Ooo`03003ooooo05_oo`03003ooooo04Ooo`03003ooooo06;oo`40
007oo`7oo`005ooo00<00?ooool0G?oo00<00?ooool0A_oo00<00?ooool0H_oo0@000Ooo0Ooo000G
ool00`00ooooo`1Lool00`00ooooo`16ool00`00ooooo`1Rool10001ool1ool001Ooo`03003ooooo
05coo`03003ooooo04Koo`03003ooooo06;oo`40007oo`7oo`005ooo00<00?ooool0GOoo00<00?oo
ool0A?oo00<00?ooool0Hooo0@000Ooo0Ooo000Gool00`00ooooo`1Mool00`00ooooo`14ool00`00
ooooo`1Sool10001ool1ool001Ooo`03003ooooo05goo`03003ooooo04Coo`03003ooooo06?oo`40
007oo`7oo`005ooo0P00Gooo00<00?ooool0@_oo00<00?ooool0Hooo0P000_oo000Gool00`00oooo
o`1Nool00`00ooooo`12ool00`00ooooo`1Tool10001ool1ool001Ooo`03003ooooo05koo`03003o
oooo04;oo`03003ooooo06Coo`40007oo`7oo`005ooo00<00?ooool0G_oo00<00?ooool0@Ooo00<0
0?ooool0IOoo0@000Ooo0Ooo000Gool00`00ooooo`1Oool00`00ooooo`10ool00`00ooooo`1Uool1
0001ool1ool001Ooo`03003ooooo05ooo`03003ooooo043oo`03003ooooo06Goo`40007oo`7oo`00
5ooo00<00?ooool0Gooo00<00?ooool0?ooo00<00?ooool0I_oo0@000Ooo0Ooo000Gool00`00oooo
o`1Oool00`00ooooo`0oool00`00ooooo`1Vool10001ool1ool001Ooo`80067oo`03003ooooo03ko
o`03003ooooo06Goo`8000;oo`005ooo00<00?ooool0H?oo00<00?ooool0?Ooo00<00?ooool0Iooo
0@000Ooo0Ooo000Gool00`00ooooo`1Pool00`00ooooo`0mool00`00ooooo`1Wool10001ool1ool0
01Ooo`03003ooooo067oo`03003ooooo03coo`03003ooooo06Ooo`40007oo`7oo`005ooo00<00?oo
ool0HOoo00<00?ooool0??oo00<00?ooool0Iooo0@000Ooo0Ooo000Gool00`00ooooo`1Qool00`00
ooooo`0kool00`00ooooo`1Xool10001ool1ool000Coo`D000;oo`03003ooooo00;oo`03003ooooo
00Coo`03003ooooo067oo`03003ooooo03_oo`03003ooooo06Soo`40007oo`7oo`001_oo00L00?oo
ooooo`00ool00002ool00`00ool00005ool00`00ooooo`1Rool00`00ooooo`0jool00`00ooooo`1X
ool10001ool1ool000Koo`07003oooooool00?oo00000_oo00<00?oo00001Ooo0P00Hooo00<00?oo
ool0>Ooo00<00?ooool0J?oo0P000_oo0006ool01`00oooooooo003oo`0000;oo`03003oo`0000Go
o`03003ooooo06;oo`03003ooooo03Woo`03003ooooo06Woo`40007oo`7oo`001_oo00L00?oooooo
o`00ool00002ool00`00ool00005ool00`00ooooo`1Rool00`00ooooo`0iool00`00ooooo`1Yool1
0001ool1ool000Goo`8000Coo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo06?oo`03003o
oooo03Ooo`03003ooooo06[oo`40007oo`7oo`005ooo00<00?ooool0Hooo00<00?ooool0=ooo00<0
0?ooool0J_oo0@000Ooo0Ooo000Gool00`00ooooo`1Sool00`00ooooo`0gool00`00ooooo`1Zool1
0001ool1ool001Ooo`03003ooooo06Coo`03003ooooo03Koo`03003ooooo06[oo`40007oo`7oo`00
5ooo00<00?ooool0I?oo00<00?ooool0=Ooo00<00?ooool0Jooo0@000Ooo0Ooo000Gool2001Uool0
0`00ooooo`0eool00`00ooooo`1Zool20002ool001Ooo`03003ooooo06Coo`03003ooooo03Goo`03
003ooooo06_oo`40007oo`7oo`005ooo00<00?ooool0IOoo00<00?ooool0=?oo00<00?ooool0Jooo
0@000Ooo0Ooo000Gool00`00ooooo`1Uool00`00ooooo`0cool00`00ooooo`1/ool10001ool1ool0
01Ooo`03003ooooo06Goo`03003ooooo03?oo`03003ooooo06coo`40007oo`7oo`005ooo00<00?oo
ool0I_oo00<00?ooool0<_oo00<00?ooool0K?oo0@000Ooo0Ooo000Gool00`00ooooo`1Vool00`00
ooooo`0bool00`00ooooo`1/ool10001ool1ool001Ooo`03003ooooo06Koo`03003ooooo037oo`03
003ooooo06goo`40007oo`7oo`005ooo0P00Iooo00<00?ooool0<Ooo00<00?ooool0K?oo0P000_oo
000Gool00`00ooooo`1Wool00`00ooooo`0`ool00`00ooooo`1]ool10001ool1ool001Ooo`03003o
oooo06Ooo`03003ooooo033oo`03003ooooo06goo`40007oo`7oo`005ooo00<00?ooool0Iooo00<0
0?ooool0;ooo00<00?ooool0K_oo0@000Ooo0Ooo000Gool00`00ooooo`1Wool00`00ooooo`0_ool0
0`00ooooo`1^ool10001ool1ool001Ooo`03003ooooo06Soo`03003ooooo02koo`03003ooooo06ko
o`40007oo`7oo`005ooo00<00?ooool0J?oo00<00?ooool0;_oo00<00?ooool0K_oo0@000Ooo0Ooo
000Gool00`00ooooo`1Xool00`00ooooo`0]ool00`00ooooo`1_ool10001ool1ool001Ooo`8006[o
o`03003ooooo02coo`03003ooooo06koo`8000;oo`005ooo00<00?ooool0JOoo00<00?ooool0;?oo
00<00?ooool0Kooo0@000Ooo0Ooo000Gool00`00ooooo`1Yool00`00ooooo`0/ool00`00ooooo`1_
ool10001ool1ool001Ooo`03003ooooo06Woo`03003ooooo02_oo`03003ooooo073oo`40007oo`7o
o`005ooo00<00?ooool0J_oo00<00?ooool0:_oo00<00?ooool0L?oo0@000Ooo0Ooo000Gool00`00
ooooo`1Zool00`00ooooo`0Zool00`00ooooo`1`ool10001ool1ool001Ooo`03003ooooo06[oo`03
003ooooo02[oo`03003ooooo073oo`40007oo`7oo`005ooo00<00?ooool0Jooo00<00?ooool0:?oo
00<00?ooool0LOoo0@000Ooo0Ooo000Gool2001/ool00`00ooooo`0Xool00`00ooooo`1`ool20002
ool001Ooo`03003ooooo06_oo`03003ooooo02Soo`03003ooooo077oo`40007oo`7oo`005ooo00<0
0?ooool0Jooo00<00?ooool09ooo00<00?ooool0L_oo0@000Ooo0Ooo000Gool00`00ooooo`1/ool0
0`00ooooo`0Vool00`00ooooo`1bool10001ool1ool001Ooo`03003ooooo06coo`03003ooooo02Ko
o`03003ooooo07;oo`40007oo`7oo`005ooo00<00?ooool0K?oo00<00?ooool09Ooo00<00?ooool0
Looo0@000Ooo0Ooo0004ool50002ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`1/ool0
0`00ooooo`0Uool00`00ooooo`1cool10001ool1ool000Koo`07003oooooool00?oo00000_oo00<0
0?oo00001Ooo00<00?ooool0KOoo00<00?ooool09?oo00<00?ooool0Looo0@000Ooo0Ooo0006ool0
0`00ooooo`03ool01P00ooooo`00ool000Goo`8006koo`03003ooooo02?oo`03003ooooo07?oo`80
00;oo`001_oo00@00?ooooooo`8000?oo`03003oo`0000Goo`03003ooooo06goo`03003ooooo02?o
o`03003ooooo07Coo`40007oo`7oo`001_oo00D00?ooooooo`0000Coo`03003oo`0000Goo`03003o
oooo06koo`03003ooooo02;oo`03003ooooo07Coo`40007oo`7oo`001Ooo0P000ooo0`000ooo00<0
0?ooool01?oo00<00?ooool0K_oo00<00?ooool08_oo00<00?ooool0M?oo0@000Ooo0Ooo000Gool0
0`00ooooo`1^ool00`00ooooo`0Qool00`00ooooo`1eool10001ool1ool001Ooo`03003ooooo06ko
o`03003ooooo027oo`03003ooooo07Goo`40007oo`7oo`005ooo00<00?ooool0Kooo00<00?ooool0
8?oo00<00?ooool0MOoo0@000Ooo0Ooo000Gool00`00ooooo`1_ool00`00ooooo`0Oool00`00oooo
o`1fool10001ool1ool001Ooo`80073oo`03003ooooo01ooo`03003ooooo07Goo`8000;oo`005ooo
00<00?ooool0Kooo00<00?ooool07ooo00<00?ooool0M_oo0@000Ooo0Ooo000Gool00`00ooooo`1`
ool00`00ooooo`0Mool00`00ooooo`1gool10001ool1ool001Ooo`03003ooooo073oo`03003ooooo
01goo`03003ooooo07Ooo`40007oo`7oo`005ooo00<00?ooool0L?oo00<00?ooool07Ooo00<00?oo
ool0Mooo0@000Ooo0Ooo000Gool00`00ooooo`1aool00`00ooooo`0Kool00`00ooooo`1hool10001
ool1ool001Ooo`03003ooooo077oo`03003ooooo01_oo`03003ooooo07Soo`40007oo`7oo`005ooo
00<00?ooool0L_oo00<00?ooool06_oo00<00?ooool0N?oo0@000Ooo0Ooo000Gool2001cool00`00
ooooo`0Iool00`00ooooo`1hool20002ool001Ooo`03003ooooo07;oo`03003ooooo01Woo`03003o
oooo07Woo`40007oo`7oo`005ooo00<00?ooool0Looo00<00?ooool06?oo00<00?ooool0NOoo0@00
0Ooo0Ooo000Gool00`00ooooo`1cool00`00ooooo`0Gool00`00ooooo`1jool10001ool1ool001Oo
o`03003ooooo07Coo`03003ooooo01Koo`03003ooooo07[oo`40007oo`7oo`005ooo00<00?ooool0
M?oo00<00?ooool05Ooo00<00?ooool0Nooo0@000Ooo0Ooo000Gool00`00ooooo`1eool00`00oooo
o`0Dool00`00ooooo`1kool10001ool1ool001Ooo`03003ooooo07Goo`03003ooooo01Coo`03003o
oooo07_oo`40007oo`7oo`005ooo0P00M_oo00<00?ooool04ooo00<00?ooool0Nooo0P000_oo000G
ool00`00ooooo`1fool00`00ooooo`0Bool00`00ooooo`1lool10001ool1ool001Ooo`03003ooooo
07Koo`03003ooooo01;oo`03003ooooo07coo`40007oo`7oo`005ooo00<00?ooool0Mooo00<00?oo
ool04?oo00<00?ooool0OOoo0@000Ooo0Ooo000Gool00`00ooooo`1gool00`00ooooo`0@ool00`00
ooooo`1mool10001ool1ool001Ooo`03003ooooo07Soo`03003ooooo00koo`03003ooooo07koo`40
007oo`7oo`005ooo00<00?ooool0N?oo00<00?ooool03_oo00<00?ooool0O_oo0@000Ooo0Ooo000G
ool00`00ooooo`1iool00`00ooooo`0<ool00`00ooooo`1oool10001ool1ool001Ooo`8007[oo`03
003ooooo00_oo`03003ooooo07ooo`8000;oo`005ooo00<00?ooool0N_oo00<00?ooool02Ooo00<0
0?ooool0POoo0@000Ooo0Ooo000Gool00`00ooooo`1kool00`00ooooo`08ool00`00ooooo`21ool1
0001ool1ool001Ooo`03003ooooo07_oo`03003ooooo00Ooo`03003ooooo08;oo`40007oo`7oo`00
5ooo00<00?ooool0O?oo00<00?ooool01Ooo00<00?ooool0Pooo0@000Ooo0Ooo000Gool00`00oooo
o`1lool00`00ooooo`05ool00`00ooooo`23ool10001ool1ool000Goo`<000?oo`03003ooooo00;o
o`03003ooooo00Coo`03003ooooo07goo`L008Koo`40007oo`7oo`001Ooo00<00?ooool00_oo00<0
0?oo00000_oo00<00?oo00001Ooo00<00?ooool0oooo2ooo0@000Ooo0Ooo0006ool01`00oooooooo
003oo`0000;oo`03003oo`0000Goo`8003koo`03003ooooo03goo`03003ooooo03goo`03003ooooo
03goo`03003ooooo00Woo`8000;oo`001_oo00L00?ooooooo`00ool00002ool00`00ool00005ool0
0`00ooooo`09ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool0
0`00ooooo`0:ool00`00ooooo`09ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool0
0`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`09ool00`00ooooo`0:ool0
0`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`09ool0
0`00ooooo`0:ool10001ool1ool000Goo`03003oo`0000;oo`03003oo`0000;oo`03003oo`0000Go
ool000l000;oo`001_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool0oooo5Ooo003ooolX
ool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.59641, -20.3233, \
0.155768, 1.24388}}]
}, Open  ]],

Cell["One way to compare the graphs is to display them together. ", \
"MathCaption",
  CellTags->{"S0.1", "1.17"}],

Cell[CellGroupData[{

Cell["Show[g1, g2];", "Input",
  CellLabel->"In[15]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0232288 0.0147151 0.00277643 [
[.2561 .00222 -6 -9 ]
[.2561 .00222 6 0 ]
[.48839 .00222 -6 -9 ]
[.48839 .00222 6 0 ]
[.72067 .00222 -6 -9 ]
[.72067 .00222 6 0 ]
[.95296 .00222 -6 -9 ]
[.95296 .00222 6 0 ]
[.01131 .15354 -12 -4.5 ]
[.01131 .15354 0 4.5 ]
[.01131 .29236 -18 -4.5 ]
[.01131 .29236 0 4.5 ]
[.01131 .43118 -18 -4.5 ]
[.01131 .43118 0 4.5 ]
[.01131 .57 -18 -4.5 ]
[.01131 .57 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2561 .01472 m
.2561 .02097 L
s
[(10)] .2561 .00222 0 1 Mshowa
.48839 .01472 m
.48839 .02097 L
s
[(20)] .48839 .00222 0 1 Mshowa
.72067 .01472 m
.72067 .02097 L
s
[(30)] .72067 .00222 0 1 Mshowa
.95296 .01472 m
.95296 .02097 L
s
[(40)] .95296 .00222 0 1 Mshowa
.125 Mabswid
.07027 .01472 m
.07027 .01847 L
s
.11672 .01472 m
.11672 .01847 L
s
.16318 .01472 m
.16318 .01847 L
s
.20964 .01472 m
.20964 .01847 L
s
.30256 .01472 m
.30256 .01847 L
s
.34901 .01472 m
.34901 .01847 L
s
.39547 .01472 m
.39547 .01847 L
s
.44193 .01472 m
.44193 .01847 L
s
.53484 .01472 m
.53484 .01847 L
s
.5813 .01472 m
.5813 .01847 L
s
.62776 .01472 m
.62776 .01847 L
s
.67422 .01472 m
.67422 .01847 L
s
.76713 .01472 m
.76713 .01847 L
s
.81359 .01472 m
.81359 .01847 L
s
.86005 .01472 m
.86005 .01847 L
s
.9065 .01472 m
.9065 .01847 L
s
.99942 .01472 m
.99942 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15354 m
.03006 .15354 L
s
[(50)] .01131 .15354 1 0 Mshowa
.02381 .29236 m
.03006 .29236 L
s
[(100)] .01131 .29236 1 0 Mshowa
.02381 .43118 m
.03006 .43118 L
s
[(150)] .01131 .43118 1 0 Mshowa
.02381 .57 m
.03006 .57 L
s
[(200)] .01131 .57 1 0 Mshowa
.125 Mabswid
.02381 .04248 m
.02756 .04248 L
s
.02381 .07024 m
.02756 .07024 L
s
.02381 .09801 m
.02756 .09801 L
s
.02381 .12577 m
.02756 .12577 L
s
.02381 .1813 m
.02756 .1813 L
s
.02381 .20907 m
.02756 .20907 L
s
.02381 .23683 m
.02756 .23683 L
s
.02381 .26459 m
.02756 .26459 L
s
.02381 .32012 m
.02756 .32012 L
s
.02381 .34789 m
.02756 .34789 L
s
.02381 .37565 m
.02756 .37565 L
s
.02381 .40342 m
.02756 .40342 L
s
.02381 .45894 m
.02756 .45894 L
s
.02381 .48671 m
.02756 .48671 L
s
.02381 .51447 m
.02756 .51447 L
s
.02381 .54224 m
.02756 .54224 L
s
.02381 .59777 m
.02756 .59777 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04704 .01472 m
.07027 .01472 L
.0935 .01472 L
.11672 .01749 L
.13995 .01472 L
.16318 .01472 L
.18641 .01472 L
.20964 .01749 L
.23287 .0286 L
.2561 .0286 L
.27933 .04803 L
.30256 .05636 L
.32578 .123 L
.34901 .13965 L
.37224 .23683 L
.39547 .3229 L
.4187 .40897 L
.44193 .45339 L
.46516 .52003 L
.48839 .60332 L
.51161 .55334 L
.53484 .54779 L
.55807 .48671 L
.5813 .3812 L
.60453 .26459 L
.62776 .20907 L
.65099 .19796 L
.67422 .09801 L
.69744 .06469 L
.72067 .05359 L
.7439 .04248 L
.76713 .02582 L
.79036 .02027 L
.81359 .01472 L
.83682 .01472 L
.86005 .01472 L
.88328 .01472 L
.9065 .01472 L
.92973 .01472 L
.95296 .01472 L
s
.04704 .01472 m
.07027 .01473 L
.0935 .01476 L
.11672 .01483 L
.13995 .01503 L
.16318 .01552 L
.18641 .01663 L
.20964 .01901 L
.23287 .02377 L
.2561 .03265 L
.27933 .04811 L
.30256 .07316 L
.32578 .11083 L
.34901 .16324 L
.37224 .2304 L
.39547 .30905 L
.4187 .39216 L
.44193 .46955 L
.46516 .52978 L
.48839 .56282 L
.51161 .56282 L
.53484 .52978 L
.55807 .46955 L
.5813 .39216 L
.60453 .30905 L
.62776 .2304 L
.65099 .16324 L
.67422 .11083 L
.69744 .07316 L
.72067 .04811 L
.7439 .03265 L
.76713 .02377 L
.79036 .01901 L
.81359 .01663 L
.83682 .01552 L
.86005 .01503 L
.88328 .01483 L
.9065 .01476 L
.92973 .01473 L
.95296 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo001Aool5
0002ool00`00ooooo`0hool30003ool00`00ooooo`0hool20004ool00`00ooooo`0iool30002ool0
0`00ooooo`09ool005?oo`07003oooooool00?oo0000>Ooo00<00?ooool00_oo00<00?oo0000>ooo
00H00?ooool00?oo000kool01P00ooooo`00ool000[oo`00Dooo00L00?ooooooo`00ool0000jool0
1`00oooooooo003oo`0003[oo`07003oooooool00?oo0000>Ooo100000Coo`00ool000[oo`00Dooo
00L00?ooooooo`00ool0000jool01`00oooooooo003oo`0003_oo`06003ooooo003oo`00>Ooo00<0
0?oo00000_oo00<00?oo00002_oo001Cool01`00oooooooo003oo`0003Woo`03003oo`0000;oo`03
003oo`0003Woo`03003oo`0000;oo`03003oo`0003[oo`8000;oo`03003oo`0000[oo`00D_oo0P00
1?oo00<00?ooool0>Ooo00<00?ooool00_oo00<00?ooool0>Ooo00<00?ooool00_oo00<00?ooool0
>_oo00D00?ooooooo`0000_oo`00oooo:?oo000Eool00`00ooooo`3oool@ool001Goo`03003ooooo
0?oooa3oo`005Ooo00<00?ooool0oooo4?oo000Eool00`00ooooo`3oool@ool001Goo`03003ooooo
0?oooa3oo`003_ooo`006P00000Eool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool0
0`00ooooo`07ool6000:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00oooo
o`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00oooo
o`0:ool00`00ooooo`0:ool00`00ooooo`0:ool01000oooooooo1P000ooo00<00?ooool02_oo00<0
0?ooool02_oo00<00?ooool02_oo00<00?ooool02_oo0@00000Eool00`00ooooo`0dool5002Cool6
000mool001Goo`03003ooooo03Koo`T008_oo`800003ool00000043oo`005Ooo00<00?ooool0>ooo
0P000_oo00<00?ooool0Q_oo0P0000?oo`000000@_oo000Eool00`00ooooo`0mool200000ooo003o
o`24ool200000ooo00000014ool001Goo`03003ooooo03ooo`<008;oo`800003ool0000004Koo`00
5Ooo0P00@_oo0P00P?oo00@00?ooool004Soo`005Ooo00<00?ooool0@_oo0P00OOoo0P0000?oo`00
0000BOoo000Eool00`00ooooo`14ool2001jool01000ool00000Booo000Eool00`00ooooo`15ool5
001eool3001=ool001Goo`03003ooooo04Koo`04003oooooool2001bool2001?ool001Goo`03003o
oooo04Ooo`05003oooooool0001`ool2001Aool001Goo`03003ooooo04Soo`05003oooooool0001]
ool3001Bool001Goo`03003ooooo04Woo`04003ooooo001/ool00`00ool0001Cool001Goo`8004_o
o`03003oo`0006_oo`03003oo`0005Coo`005Ooo00<00?ooool0Booo00<00?oo0000J_oo0P00EOoo
000Eool00`00ooooo`1<ool2001Yool2001Fool001Goo`03003ooooo04coo`8006Soo`03003oo`00
05Koo`005Ooo00<00?ooool0COoo0P00Iooo0P00Eooo000Eool00`00ooooo`1=ool2001Vool00`00
ool0001Gool001Goo`03003ooooo04koo`03003ooooo06?oo`03003oo`0005Soo`005Ooo00<00?oo
ool0C_oo0P00I?oo0P00FOoo000Eool2001@ool00`00ooooo`1Qool00`00ool0001Iool001Goo`03
003ooooo04ooo`8006;oo`8005[oo`005Ooo00<00?ooool0Cooo0P00HOoo00<00?oo0000F_oo000E
ool00`00ooooo`1@ool2001Pool2001Kool001Goo`03003ooooo053oo`80063oo`8005_oo`005Ooo
00<00?ooool0D?oo00<00?oo0000Gooo00<00?ooool0F_oo000Eool00`00ooooo`1Aool2001Nool2
001Lool001Goo`03003ooooo057oo`03003oo`0005goo`03003ooooo05_oo`005Ooo0P00Dooo0P00
GOoo00<00?ooool0Fooo000Eool00`00ooooo`1Dool2001Jool2001Mool001Goo`03003ooooo05Co
o`04003oo`00001Hool00`00ooooo`1Lool001Goo`03003ooooo05Goo`04003ooooo001Fool2001N
ool001Goo`03003ooooo05Goo`04003ooooo001Fool2001Nool000[oo`03003ooooo00;oo`03003o
oooo00?oo`03003ooooo05Koo`03003oo`0005Goo`03003oo`0005koo`002Ooo00<00?oo00000_oo
00<00?oo00001?oo00<00?ooool0E_oo00@00?ooool005Coo`8005ooo`002ooo00H00?ooool00?oo
0004ool3001Gool00`00ool0001Cool00`00ool0001Oool000Woo`8000?oo`03003oo`0000Coo`03
003ooooo05Ooo`03003oo`0005?oo`03003oo`0005ooo`002Ooo00<00?ooool00_oo00<00?oo0000
1?oo00<00?ooool0F?oo0P00D_oo00@00?ooool005ooo`002Ooo0`000ooo00<00?ooool00ooo00<0
0?ooool0F?oo00<00?oo0000DOoo00<00?oo0000H?oo000Eool00`00ooooo`1Hool00`00ool0001A
ool00`00ool0001Pool001Goo`03003ooooo05Woo`80053oo`04003ooooo001Pool001Goo`03003o
oooo05Woo`80053oo`04003ooooo001Pool001Goo`03003ooooo05Woo`80053oo`03003oo`00067o
o`005Ooo0P00Fooo0P00C_oo00@00?ooool0067oo`005Ooo00<00?ooool0F_oo0P00C_oo00@00?oo
ool0067oo`005Ooo00<00?ooool0F_oo0P00C_oo00@00?ooool0067oo`005Ooo00<00?ooool0Fooo
00<00?ooool0Booo00@00?ooool006;oo`005Ooo00<00?ooool0Fooo00<00?ooool0Booo00@00?oo
ool006;oo`005Ooo00<00?ooool0Fooo0P00C?oo00@00?ooool006;oo`005Ooo00<00?ooool0Fooo
0P00C?oo0`00Hooo000Eool00`00ooooo`1Lool00`00ooooo`19ool2001Uool001Goo`8005goo`03
003ooooo04Ooo`<006Koo`005Ooo00<00?ooool0G?oo0P00B?oo00<00?oo0000I_oo000Eool00`00
ooooo`1Mool00`00ooooo`15ool00`00ool0001Wool001Goo`03003ooooo05goo`03003ooooo04Go
o`03003oo`0006Ooo`005Ooo00<00?ooool0GOoo00<00?ooool0A?oo00@00?ooool006Ooo`005Ooo
00<00?ooool0GOoo0P00AOoo00<00?oo0000J?oo000Eool00`00ooooo`1Nool00`00ooooo`12ool0
1000ooooo`00J?oo000Eool00`00ooooo`1Nool00`00ooooo`12ool01000ooooo`00J?oo000Eool2
001Oool20012ool01000ooooo`00JOoo000Eool00`00ooooo`1Nool20012ool01000ooooo`00JOoo
000Eool00`00ooooo`1Oool00`00ooooo`0oool01@00oooooooo0000JOoo000Eool00`00ooooo`1O
ool20010ool01000ooooo`00J_oo000Eool00`00ooooo`1Oool2000oool01@00oooooooo0000J_oo
000Eool00`00ooooo`1Oool2000oool01@00oooooooo0000J_oo000Eool00`00ooooo`1Pool2000m
ool01@00oooooooo0000Jooo000Eool2001Qool2000mool01@00oooooooo0000Jooo000Eool00`00
ooooo`1Pool2000mool01@00oooooooo0000Jooo000Eool00`00ooooo`1Qool2000lool01000oooo
o`00K?oo000Eool00`00ooooo`1Qool2000kool01@00oooooooo0000K?oo000Eool00`00ooooo`1Q
ool2000kool01@00oooooooo0000K?oo000Eool00`00ooooo`1Rool00`00ooooo`0iool01@00oooo
oooo0000K?oo0003ool50002ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`1Rool2000j
ool01000ooooo`00KOoo0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Coo`03003ooooo
06;oo`8003[oo`04003ooooo001]ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo
0`00H_oo0P00>_oo00@00?ooool006goo`001Ooo00L00?ooooooo`00ool00002ool00`00ool00004
ool00`00ooooo`1Sool2000hool01000ooooo`00K_oo0005ool01`00oooooooo003oo`0000;oo`03
003oo`0000Coo`03003ooooo06?oo`8003Soo`04003ooooo001^ool000Coo`8000Coo`03003ooooo
00;oo`03003ooooo00?oo`03003ooooo06?oo`8003Soo`04003ooooo001^ool001Goo`03003ooooo
06Coo`8003Ooo`03003oo`0006ooo`005Ooo00<00?ooool0I?oo0P00=ooo00<00?oo0000Kooo000E
ool00`00ooooo`1Tool2000fool01000ooooo`00Kooo000Eool00`00ooooo`1Tool00`00ool0000e
ool00`00ool0001`ool001Goo`8006Koo`8003Goo`03003oo`00073oo`005Ooo00<00?ooool0IOoo
0P00=Ooo00<00?oo0000L?oo000Eool00`00ooooo`1Uool2000eool00`00ool0001`ool001Goo`03
003ooooo06Koo`8003Coo`80077oo`005Ooo00<00?ooool0I_oo0P00<ooo00<00?oo0000LOoo000E
ool00`00ooooo`1Vool2000cool00`00ool0001aool001Goo`03003ooooo06Koo`8003?oo`03003o
o`00077oo`005Ooo00<00?ooool0Iooo0P00<_oo0P00L_oo000Eool2001Xool2000bool2001bool0
01Goo`03003ooooo06Ooo`80037oo`03003oo`0007;oo`005Ooo00<00?ooool0Iooo0P00<Ooo00<0
0?oo0000L_oo000Eool00`00ooooo`1Xool2000`ool2001cool001Goo`03003ooooo06Soo`80033o
o`8007?oo`005Ooo00<00?ooool0J?oo0P00<?oo0P00Looo000Eool00`00ooooo`1Xool2000`ool2
001cool001Goo`03003ooooo06Woo`8002koo`8007Coo`005Ooo0P00J_oo0P00;_oo0P00M?oo000E
ool00`00ooooo`1Yool2000^ool2001dool001Goo`03003ooooo06Woo`8002koo`8007Coo`005Ooo
00<00?ooool0J_oo0P00;Ooo00<00?ooool0Looo000Eool00`00ooooo`1Zool2000/ool2001eool0
01Goo`03003ooooo06[oo`8002coo`8007Goo`005Ooo00<00?ooool0J_oo00<00?oo0000:ooo00<0
0?ooool0M?oo000Eool2001/ool2000[ool00`00ooooo`1dool001Goo`03003ooooo06_oo`8002[o
o`8007Koo`005Ooo00<00?ooool0Jooo00<00?oo0000:Ooo00<00?ooool0MOoo000Eool00`00oooo
o`1/ool2000Yool00`00ooooo`1eool001Goo`03003ooooo06coo`8002Woo`03003ooooo07Goo`00
5Ooo00<00?ooool0KOoo0P009ooo00<00?ooool0M_oo0003ool50002ool00`00ooooo`02ool00`00
ooooo`03ool00`00ooooo`1]ool2000Wool00`00ooooo`1fool000Goo`07003oooooool00?oo0000
0_oo00<00?oo00001?oo00<00?ooool0K_oo00<00?ooool09Ooo00<00?ooool0M_oo0005ool00`00
ooooo`03ool01P00ooooo`00ool000Coo`<006ooo`03003ooooo02?oo`8007Soo`001Ooo00@00?oo
ooooo`8000?oo`03003oo`0000Coo`03003ooooo06ooo`03003ooooo02?oo`03003ooooo07Ooo`00
1Ooo00D00?ooooooo`0000Coo`03003oo`0000Coo`03003ooooo06ooo`8002Coo`03003ooooo07Oo
o`001?oo0P000ooo0`000ooo00<00?ooool00ooo00<00?ooool0Kooo0P009?oo00<00?ooool0Mooo
000Eool00`00ooooo`1`ool2000Rool2001iool001Goo`03003ooooo073oo`8002;oo`8007Woo`00
5Ooo00<00?ooool0L?oo00<00?oo00008Ooo00<00?ooool0N?oo000Eool00`00ooooo`1aool2000P
ool2001jool001Goo`8007;oo`03003oo`0001ooo`8007[oo`005Ooo00<00?ooool0LOoo00<00?oo
00007ooo0P00N_oo000Eool00`00ooooo`1bool2000Nool2001kool001Goo`03003ooooo07;oo`03
003oo`0001goo`8007_oo`005Ooo00<00?ooool0L_oo00<00?oo00007Ooo0P00Nooo000Eool00`00
ooooo`1cool2000Lool00`00ool0001kool001Goo`03003ooooo07?oo`03003oo`0001_oo`8007co
o`005Ooo00<00?ooool0Looo00<00?oo00006ooo0P00O?oo000Eool2001eool2000Jool00`00ool0
001lool001Goo`03003ooooo07Coo`8001[oo`03003oo`0007coo`005Ooo00<00?ooool0M?oo00<0
0?oo00006Ooo0P00OOoo000Eool00`00ooooo`1eool2000Hool00`00ool0001mool001Goo`03003o
oooo07Goo`8001Soo`03003oo`0007goo`005Ooo00<00?ooool0M_oo0P005_oo00<00?oo0000O_oo
000Eool00`00ooooo`1fool2000Fool00`00ool0001nool001Goo`8007Ooo`8001Koo`03003oo`00
07koo`005Ooo00<00?ooool0Mooo0P005?oo00<00?oo0000Oooo000Eool00`00ooooo`1gool2000D
ool00`00ool0001oool001Goo`03003ooooo07Ooo`8001Coo`80083oo`005Ooo00<00?ooool0N?oo
0P004_oo00<00?oo0000P?oo000Eool00`00ooooo`1hool2000Bool00`00ool00020ool001Goo`03
003ooooo07Woo`03003ooooo00ooo`03003oo`00087oo`005Ooo00<00?ooool0N_oo00<00?ooool0
3Ooo00@00?ooool0087oo`005Ooo0P00Nooo00<00?ooool03Ooo00@00?ooool0087oo`005Ooo00<0
0?ooool0N_oo0P003Ooo00@00?ooool008;oo`005Ooo00<00?ooool0N_oo00<00?oo00002ooo1@00
P_oo000Eool00`00ooooo`1kool00`00ool00007ool40026ool001Goo`03003ooooo07_oo`03003o
o`0000Ooo`03003oo`0008Ooo`005Ooo00<00?ooool0Nooo00@00?ooool000Goo`03003oo`0008So
o`001?oo0`000ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool0O?oo00<00?ooool01`00
ROoo0004ool00`00ooooo`02ool00`00ool00002ool00`00ool00004ool00`00ooooo`1lool00`00
ooooo`04ool00`00ooooo`29ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo0`00
O?oo00<00?ooool01?oo00<00?ooool0ROoo0005ool01`00oooooooo003oo`0000;oo`03003oo`00
00Coo`03003ooooo07goo`03003ooooo00;oo`03003ooooo08[oo`001?oo00<00?oo00000_oo00<0
0?oo00000_oo00<00?oo00001?oo00<00?ooool0OOoo00<00?ooool00_oo00<00?ooool0R_oo0005
ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`1mool00`00ooooo`02
ool00`00ooooo`2:ool001Goo`03003ooooo07goo`05003oooooool0002=ool001Goo`03003ooooo
07koo`04003ooooo002=ool001Goo`03003ooooo07koo`03003oo`0008koo`005Ooo00<00?ooool0
O_oo00<00?oo0000S_oo000Eool20020ool00`00ooooo`2=ool001Goo`03003ooooo07ooo`03003o
oooo08goo`005Ooo00<00?ooool0oooo4?oo000Eool00`00ooooo`3oool@ool001Goo`03003ooooo
0?oooa3oo`005Ooo00<00?ooool0oooo4?oo0000\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.30855, -16.3262, \
0.153902, 1.28761}}]
}, Open  ]],

Cell["Two correlated standard normal variables", "Subsubsection",
  CellTags->{"S0.1", "1.18"}],

Cell[TextData[{
  "We can modify our program to generate a pair of standard normal variables \
for a given correlation coefficient ",
  StyleBox["rho", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.19"}],

Cell["\<\
chance[rho_] :=
   Module[{r1, r2, s = 1},
      While[s >= 1,  
         {r1, r2} = Table[Random[Real, {-1, 1}], {2}];
         s = {r1, r2} . {r1, r2};
         ];
      Sqrt[-2 Log[s] / s] *
         {r1, rho r1 + Sqrt[1 - rho^2] r2}
      ]\
\>", "Input",
  CellLabel->"In[16]:=",
  CellTags->"S0.1"],

Cell["\<\
We generate 500 pairs of random numbers with \[Hyphen]1.0 as the \
correlation coefficient. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.20"}],

Cell["m = Table[chance[-1.0], {500}];", "Input",
  CellLabel->"In[17]:=",
  CellTags->"S0.1"],

Cell["Here is the corresponding graph. ", "MathCaption",
  CellTags->{"S0.1", "1.21"}],

Cell[CellGroupData[{

Cell["ListPlot[m];", "Input",
  CellLabel->"In[18]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.474645 0.152862 0.324687 0.0944738 [
[.01606 -0.0125 -6 -9 ]
[.01606 -0.0125 6 0 ]
[.16892 -0.0125 -6 -9 ]
[.16892 -0.0125 6 0 ]
[.32178 -0.0125 -6 -9 ]
[.32178 -0.0125 6 0 ]
[.47464 -0.0125 -3 -9 ]
[.47464 -0.0125 3 0 ]
[.62751 -0.0125 -3 -9 ]
[.62751 -0.0125 3 0 ]
[.78037 -0.0125 -3 -9 ]
[.78037 -0.0125 3 0 ]
[.93323 -0.0125 -3 -9 ]
[.93323 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04127 -12 -4.5 ]
[-0.0125 .04127 0 4.5 ]
[-0.0125 .13574 -12 -4.5 ]
[-0.0125 .13574 0 4.5 ]
[-0.0125 .23021 -12 -4.5 ]
[-0.0125 .23021 0 4.5 ]
[-0.0125 .32469 -6 -4.5 ]
[-0.0125 .32469 0 4.5 ]
[-0.0125 .41916 -6 -4.5 ]
[-0.0125 .41916 0 4.5 ]
[-0.0125 .51364 -6 -4.5 ]
[-0.0125 .51364 0 4.5 ]
[-0.0125 .60811 -6 -4.5 ]
[-0.0125 .60811 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01606 0 m
.01606 .00625 L
s
[(-3)] .01606 -0.0125 0 1 Mshowa
.16892 0 m
.16892 .00625 L
s
[(-2)] .16892 -0.0125 0 1 Mshowa
.32178 0 m
.32178 .00625 L
s
[(-1)] .32178 -0.0125 0 1 Mshowa
.47464 0 m
.47464 .00625 L
s
[(0)] .47464 -0.0125 0 1 Mshowa
.62751 0 m
.62751 .00625 L
s
[(1)] .62751 -0.0125 0 1 Mshowa
.78037 0 m
.78037 .00625 L
s
[(2)] .78037 -0.0125 0 1 Mshowa
.93323 0 m
.93323 .00625 L
s
[(3)] .93323 -0.0125 0 1 Mshowa
.125 Mabswid
.04663 0 m
.04663 .00375 L
s
.0772 0 m
.0772 .00375 L
s
.10778 0 m
.10778 .00375 L
s
.13835 0 m
.13835 .00375 L
s
.19949 0 m
.19949 .00375 L
s
.23007 0 m
.23007 .00375 L
s
.26064 0 m
.26064 .00375 L
s
.29121 0 m
.29121 .00375 L
s
.35236 0 m
.35236 .00375 L
s
.38293 0 m
.38293 .00375 L
s
.4135 0 m
.4135 .00375 L
s
.44407 0 m
.44407 .00375 L
s
.50522 0 m
.50522 .00375 L
s
.53579 0 m
.53579 .00375 L
s
.56636 0 m
.56636 .00375 L
s
.59693 0 m
.59693 .00375 L
s
.65808 0 m
.65808 .00375 L
s
.68865 0 m
.68865 .00375 L
s
.71922 0 m
.71922 .00375 L
s
.7498 0 m
.7498 .00375 L
s
.81094 0 m
.81094 .00375 L
s
.84151 0 m
.84151 .00375 L
s
.87209 0 m
.87209 .00375 L
s
.90266 0 m
.90266 .00375 L
s
.9638 0 m
.9638 .00375 L
s
.99438 0 m
.99438 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04127 m
.00625 .04127 L
s
[(-3)] -0.0125 .04127 1 0 Mshowa
0 .13574 m
.00625 .13574 L
s
[(-2)] -0.0125 .13574 1 0 Mshowa
0 .23021 m
.00625 .23021 L
s
[(-1)] -0.0125 .23021 1 0 Mshowa
0 .32469 m
.00625 .32469 L
s
[(0)] -0.0125 .32469 1 0 Mshowa
0 .41916 m
.00625 .41916 L
s
[(1)] -0.0125 .41916 1 0 Mshowa
0 .51364 m
.00625 .51364 L
s
[(2)] -0.0125 .51364 1 0 Mshowa
0 .60811 m
.00625 .60811 L
s
[(3)] -0.0125 .60811 1 0 Mshowa
.125 Mabswid
0 .06016 m
.00375 .06016 L
s
0 .07906 m
.00375 .07906 L
s
0 .09795 m
.00375 .09795 L
s
0 .11684 m
.00375 .11684 L
s
0 .15463 m
.00375 .15463 L
s
0 .17353 m
.00375 .17353 L
s
0 .19242 m
.00375 .19242 L
s
0 .21132 m
.00375 .21132 L
s
0 .24911 m
.00375 .24911 L
s
0 .268 m
.00375 .268 L
s
0 .2869 m
.00375 .2869 L
s
0 .30579 m
.00375 .30579 L
s
0 .34358 m
.00375 .34358 L
s
0 .36248 m
.00375 .36248 L
s
0 .38137 m
.00375 .38137 L
s
0 .40027 m
.00375 .40027 L
s
0 .43806 m
.00375 .43806 L
s
0 .45695 m
.00375 .45695 L
s
0 .47585 m
.00375 .47585 L
s
0 .49474 m
.00375 .49474 L
s
0 .53253 m
.00375 .53253 L
s
0 .55142 m
.00375 .55142 L
s
0 .57032 m
.00375 .57032 L
s
0 .58921 m
.00375 .58921 L
s
0 .02237 m
.00375 .02237 L
s
0 .00348 m
.00375 .00348 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01606 .61178 m
.01606 .61803 L
s
.16892 .61178 m
.16892 .61803 L
s
.32178 .61178 m
.32178 .61803 L
s
.47464 .61178 m
.47464 .61803 L
s
.62751 .61178 m
.62751 .61803 L
s
.78037 .61178 m
.78037 .61803 L
s
.93323 .61178 m
.93323 .61803 L
s
.125 Mabswid
.04663 .61428 m
.04663 .61803 L
s
.0772 .61428 m
.0772 .61803 L
s
.10778 .61428 m
.10778 .61803 L
s
.13835 .61428 m
.13835 .61803 L
s
.19949 .61428 m
.19949 .61803 L
s
.23007 .61428 m
.23007 .61803 L
s
.26064 .61428 m
.26064 .61803 L
s
.29121 .61428 m
.29121 .61803 L
s
.35236 .61428 m
.35236 .61803 L
s
.38293 .61428 m
.38293 .61803 L
s
.4135 .61428 m
.4135 .61803 L
s
.44407 .61428 m
.44407 .61803 L
s
.50522 .61428 m
.50522 .61803 L
s
.53579 .61428 m
.53579 .61803 L
s
.56636 .61428 m
.56636 .61803 L
s
.59693 .61428 m
.59693 .61803 L
s
.65808 .61428 m
.65808 .61803 L
s
.68865 .61428 m
.68865 .61803 L
s
.71922 .61428 m
.71922 .61803 L
s
.7498 .61428 m
.7498 .61803 L
s
.81094 .61428 m
.81094 .61803 L
s
.84151 .61428 m
.84151 .61803 L
s
.87209 .61428 m
.87209 .61803 L
s
.90266 .61428 m
.90266 .61803 L
s
.9638 .61428 m
.9638 .61803 L
s
.99438 .61428 m
.99438 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04127 m
1 .04127 L
s
.99375 .13574 m
1 .13574 L
s
.99375 .23021 m
1 .23021 L
s
.99375 .32469 m
1 .32469 L
s
.99375 .41916 m
1 .41916 L
s
.99375 .51364 m
1 .51364 L
s
.99375 .60811 m
1 .60811 L
s
.125 Mabswid
.99625 .06016 m
1 .06016 L
s
.99625 .07906 m
1 .07906 L
s
.99625 .09795 m
1 .09795 L
s
.99625 .11684 m
1 .11684 L
s
.99625 .15463 m
1 .15463 L
s
.99625 .17353 m
1 .17353 L
s
.99625 .19242 m
1 .19242 L
s
.99625 .21132 m
1 .21132 L
s
.99625 .24911 m
1 .24911 L
s
.99625 .268 m
1 .268 L
s
.99625 .2869 m
1 .2869 L
s
.99625 .30579 m
1 .30579 L
s
.99625 .34358 m
1 .34358 L
s
.99625 .36248 m
1 .36248 L
s
.99625 .38137 m
1 .38137 L
s
.99625 .40027 m
1 .40027 L
s
.99625 .43806 m
1 .43806 L
s
.99625 .45695 m
1 .45695 L
s
.99625 .47585 m
1 .47585 L
s
.99625 .49474 m
1 .49474 L
s
.99625 .53253 m
1 .53253 L
s
.99625 .55142 m
1 .55142 L
s
.99625 .57032 m
1 .57032 L
s
.99625 .58921 m
1 .58921 L
s
.99625 .02237 m
1 .02237 L
s
.99625 .00348 m
1 .00348 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.89028 .06781 Mdot
.4613 .33294 Mdot
.60919 .24153 Mdot
.24754 .46504 Mdot
.25107 .46287 Mdot
.44374 .34379 Mdot
.48743 .31679 Mdot
.44516 .34291 Mdot
.52408 .29413 Mdot
.54605 .28056 Mdot
.51993 .2967 Mdot
.3591 .3961 Mdot
.63426 .22604 Mdot
.38796 .37826 Mdot
.33636 .41015 Mdot
.4242 .35586 Mdot
.4123 .36322 Mdot
.33156 .41312 Mdot
.58642 .25561 Mdot
.70958 .17949 Mdot
.49448 .31243 Mdot
.74656 .15663 Mdot
.58834 .25442 Mdot
.56488 .26892 Mdot
.58441 .25685 Mdot
.51765 .29811 Mdot
.44812 .34108 Mdot
.39217 .37566 Mdot
.3013 .43182 Mdot
.53753 .28582 Mdot
.33051 .41377 Mdot
.55119 .27738 Mdot
.51833 .29769 Mdot
.59111 .25271 Mdot
.69415 .18902 Mdot
.61408 .23851 Mdot
.36837 .39037 Mdot
.29391 .43639 Mdot
.1874 .50221 Mdot
.41724 .36017 Mdot
.49112 .3145 Mdot
.22559 .47861 Mdot
.26589 .45371 Mdot
.35209 .40043 Mdot
.33102 .41345 Mdot
.517 .29851 Mdot
.47227 .32616 Mdot
.35698 .39741 Mdot
.20499 .49134 Mdot
.51235 .30139 Mdot
.5957 .24987 Mdot
.45589 .33628 Mdot
.23659 .47181 Mdot
.5819 .2584 Mdot
.61408 .23851 Mdot
.11313 .54812 Mdot
.39007 .37696 Mdot
.46568 .33023 Mdot
.3586 .39641 Mdot
.33244 .41257 Mdot
.57703 .26141 Mdot
.48377 .31905 Mdot
.51708 .29846 Mdot
.47657 .3235 Mdot
.85337 .09062 Mdot
.72453 .17025 Mdot
.49021 .31507 Mdot
.37064 .38897 Mdot
.43414 .34972 Mdot
.23474 .47296 Mdot
.3237 .41798 Mdot
.75762 .1498 Mdot
.7126 .17762 Mdot
.25863 .45819 Mdot
.80719 .11916 Mdot
.48237 .31991 Mdot
.49168 .31416 Mdot
.58568 .25606 Mdot
.23349 .47373 Mdot
.08535 .56529 Mdot
.4907 .31477 Mdot
.57934 .25998 Mdot
.29555 .43537 Mdot
.5802 .25945 Mdot
.29587 .43518 Mdot
.63807 .22369 Mdot
.29932 .43304 Mdot
.28741 .44041 Mdot
.46648 .32974 Mdot
.57241 .26427 Mdot
.48814 .31635 Mdot
.32704 .41591 Mdot
.49288 .31342 Mdot
.79126 .12901 Mdot
.55399 .27565 Mdot
.53744 .28588 Mdot
.83097 .10447 Mdot
.51461 .29999 Mdot
.34267 .40625 Mdot
.43409 .34975 Mdot
.58874 .25418 Mdot
.88794 .06926 Mdot
.63922 .22297 Mdot
.53996 .28432 Mdot
.24516 .46652 Mdot
.39219 .37565 Mdot
.52854 .29138 Mdot
.20565 .49093 Mdot
.67367 .20168 Mdot
.30766 .42789 Mdot
.67614 .20016 Mdot
.14757 .52683 Mdot
.26257 .45575 Mdot
.24507 .46658 Mdot
.60174 .24614 Mdot
.15172 .52426 Mdot
.40806 .36584 Mdot
.54373 .28199 Mdot
.60483 .24423 Mdot
.55807 .27313 Mdot
.31995 .4203 Mdot
.61175 .23995 Mdot
.5183 .29771 Mdot
.39516 .37381 Mdot
.59505 .25027 Mdot
.45706 .33556 Mdot
.56596 .26825 Mdot
.60854 .24194 Mdot
.41826 .35954 Mdot
.52164 .29564 Mdot
.61807 .23604 Mdot
.54108 .28363 Mdot
.63951 .2228 Mdot
.38673 .37902 Mdot
.44746 .34149 Mdot
.4694 .32793 Mdot
.48166 .32035 Mdot
.51799 .2979 Mdot
.26146 .45644 Mdot
.30018 .43251 Mdot
.49431 .31253 Mdot
.42435 .35577 Mdot
.85356 .09051 Mdot
.51643 .29886 Mdot
.31645 .42245 Mdot
.33997 .40792 Mdot
.60014 .24713 Mdot
.52963 .29071 Mdot
.7058 .18182 Mdot
.41588 .36101 Mdot
.436 .34857 Mdot
.66816 .20509 Mdot
.23829 .47076 Mdot
.18702 .50245 Mdot
.81578 .11385 Mdot
.48024 .32123 Mdot
.25991 .4574 Mdot
.61355 .23884 Mdot
.67026 .20379 Mdot
.60647 .24321 Mdot
.62186 .2337 Mdot
.48231 .31995 Mdot
.47038 .32732 Mdot
.59003 .25337 Mdot
.51516 .29965 Mdot
.50921 .30333 Mdot
.12917 .5382 Mdot
.48016 .32128 Mdot
.54033 .28409 Mdot
.80148 .12269 Mdot
.51497 .29977 Mdot
.38946 .37733 Mdot
.73426 .16423 Mdot
.34429 .40525 Mdot
.56889 .26644 Mdot
.36842 .39034 Mdot
.33911 .40845 Mdot
.28089 .44443 Mdot
.62006 .23482 Mdot
.29586 .43518 Mdot
.32534 .41696 Mdot
.40591 .36717 Mdot
.52827 .29155 Mdot
.72182 .17192 Mdot
.82776 .10645 Mdot
.42603 .35473 Mdot
.77727 .13765 Mdot
.33215 .41275 Mdot
.66416 .20756 Mdot
.57122 .265 Mdot
.52021 .29652 Mdot
.37474 .38643 Mdot
.07342 .57266 Mdot
.38352 .38101 Mdot
.7295 .16718 Mdot
.46663 .32964 Mdot
.70315 .18346 Mdot
.81484 .11443 Mdot
.36386 .39316 Mdot
.65437 .21361 Mdot
.41783 .3598 Mdot
.65849 .21107 Mdot
.55578 .27454 Mdot
.49212 .31389 Mdot
.45442 .33719 Mdot
.56007 .27189 Mdot
.18802 .50183 Mdot
.47465 .32468 Mdot
.63774 .22389 Mdot
.51407 .30032 Mdot
.43643 .34831 Mdot
.46403 .33125 Mdot
.48759 .31669 Mdot
.50435 .30633 Mdot
.19598 .49691 Mdot
.20402 .49194 Mdot
.31333 .42438 Mdot
.68401 .19529 Mdot
.44106 .34545 Mdot
.34003 .40789 Mdot
.29829 .43368 Mdot
.3181 .42144 Mdot
.67348 .2018 Mdot
.61147 .24013 Mdot
.60932 .24145 Mdot
.54512 .28113 Mdot
.48931 .31562 Mdot
.52805 .29168 Mdot
.69313 .18966 Mdot
.3266 .41619 Mdot
.5696 .266 Mdot
.77586 .13853 Mdot
.37947 .38351 Mdot
.62924 .22914 Mdot
.51892 .29733 Mdot
.24714 .46529 Mdot
.60999 .24104 Mdot
.35793 .39682 Mdot
.43048 .35198 Mdot
.58112 .25888 Mdot
.1085 .55098 Mdot
.32301 .4184 Mdot
.3636 .39332 Mdot
.43141 .35141 Mdot
.41118 .36391 Mdot
.51962 .29689 Mdot
.63187 .22752 Mdot
.52414 .2941 Mdot
.39749 .37237 Mdot
.58429 .25693 Mdot
.73422 .16426 Mdot
.57808 .26076 Mdot
.40516 .36763 Mdot
.67161 .20295 Mdot
.4205 .35815 Mdot
.51276 .30113 Mdot
.32991 .41414 Mdot
.76872 .14294 Mdot
.68997 .19161 Mdot
.60713 .24281 Mdot
.61941 .23522 Mdot
.69115 .19088 Mdot
.38297 .38134 Mdot
.02381 .60332 Mdot
.51673 .29868 Mdot
.61845 .23581 Mdot
.66837 .20496 Mdot
.59731 .24887 Mdot
.29717 .43437 Mdot
.39985 .37091 Mdot
.575 .26266 Mdot
.32659 .41619 Mdot
.41163 .36363 Mdot
.29333 .43675 Mdot
.34064 .40751 Mdot
.28791 .44009 Mdot
.19135 .49977 Mdot
.5651 .26878 Mdot
.61591 .23738 Mdot
.38989 .37707 Mdot
.35923 .39602 Mdot
.56356 .26973 Mdot
.36264 .39391 Mdot
.16422 .51654 Mdot
.51348 .30069 Mdot
.4428 .34437 Mdot
.59847 .24816 Mdot
.3639 .39313 Mdot
.65171 .21525 Mdot
.27238 .4497 Mdot
.36585 .39193 Mdot
.50557 .30557 Mdot
.37029 .38918 Mdot
.64604 .21876 Mdot
.79965 .12382 Mdot
.1164 .5461 Mdot
.28601 .44127 Mdot
.4133 .3626 Mdot
.30311 .4307 Mdot
.47689 .3233 Mdot
.4547 .33701 Mdot
.79535 .12648 Mdot
.60581 .24362 Mdot
.71317 .17727 Mdot
.76956 .14242 Mdot
.6674 .20556 Mdot
.25889 .45803 Mdot
.44639 .34215 Mdot
.34501 .40481 Mdot
.11011 .54998 Mdot
.3672 .39109 Mdot
.49358 .31299 Mdot
.42409 .35593 Mdot
.50917 .30335 Mdot
.50794 .30411 Mdot
.31254 .42487 Mdot
.65108 .21565 Mdot
.34043 .40764 Mdot
.71965 .17327 Mdot
.34897 .40236 Mdot
.52458 .29382 Mdot
.35928 .39599 Mdot
.29336 .43673 Mdot
.55056 .27777 Mdot
.54407 .28178 Mdot
.56623 .26809 Mdot
.62269 .23319 Mdot
.68161 .19677 Mdot
.22173 .481 Mdot
.63107 .22801 Mdot
.91237 .05416 Mdot
.6722 .20259 Mdot
.43389 .34988 Mdot
.5232 .29468 Mdot
.38847 .37795 Mdot
.4811 .3207 Mdot
.86273 .08484 Mdot
.63392 .22625 Mdot
.43932 .34652 Mdot
.22591 .47841 Mdot
.55972 .27211 Mdot
.49014 .31511 Mdot
.48948 .31552 Mdot
.52882 .2912 Mdot
.42878 .35303 Mdot
.554 .27564 Mdot
.66107 .20947 Mdot
.76317 .14637 Mdot
.4571 .33553 Mdot
.46796 .32882 Mdot
.50706 .30465 Mdot
.43413 .34973 Mdot
.44256 .34452 Mdot
.61986 .23494 Mdot
.40295 .369 Mdot
.34874 .4025 Mdot
.61101 .24041 Mdot
.32706 .4159 Mdot
.53491 .28744 Mdot
.27647 .44717 Mdot
.79888 .1243 Mdot
.31414 .42388 Mdot
.27194 .44996 Mdot
.42121 .35771 Mdot
.21076 .48778 Mdot
.65727 .21182 Mdot
.34053 .40758 Mdot
.6706 .20358 Mdot
.45901 .33435 Mdot
.39355 .37481 Mdot
.31723 .42198 Mdot
.56408 .26941 Mdot
.56842 .26673 Mdot
.51688 .29858 Mdot
.94553 .03366 Mdot
.68759 .19308 Mdot
.34787 .40304 Mdot
.55707 .27375 Mdot
.47586 .32394 Mdot
.60381 .24486 Mdot
.14107 .53085 Mdot
.70212 .1841 Mdot
.67797 .19903 Mdot
.54275 .2826 Mdot
.46441 .33102 Mdot
.19837 .49544 Mdot
.36536 .39223 Mdot
.12793 .53897 Mdot
.97619 .01472 Mdot
.6517 .21526 Mdot
.47241 .32607 Mdot
.30121 .43188 Mdot
.65571 .21279 Mdot
.46244 .33223 Mdot
.79448 .12702 Mdot
.44259 .3445 Mdot
.55828 .273 Mdot
.53766 .28574 Mdot
.39728 .3725 Mdot
.50985 .30293 Mdot
.56658 .26787 Mdot
.5892 .25389 Mdot
.69224 .19021 Mdot
.37839 .38418 Mdot
.51237 .30137 Mdot
.14639 .52756 Mdot
.63154 .22772 Mdot
.34266 .40626 Mdot
.72984 .16697 Mdot
.33604 .41035 Mdot
.31109 .42577 Mdot
.30398 .43017 Mdot
.40052 .3705 Mdot
.34504 .40479 Mdot
.45655 .33587 Mdot
.31454 .42364 Mdot
.36905 .38995 Mdot
.34573 .40436 Mdot
.51289 .30105 Mdot
.56358 .26972 Mdot
.48713 .31697 Mdot
.48176 .32029 Mdot
.41808 .35964 Mdot
.32471 .41735 Mdot
.54911 .27866 Mdot
.57063 .26537 Mdot
.52755 .29199 Mdot
.58139 .25872 Mdot
.65627 .21244 Mdot
.59078 .25291 Mdot
.37888 .38388 Mdot
.26216 .45601 Mdot
.59306 .2515 Mdot
.29193 .43761 Mdot
.4748 .32459 Mdot
.3759 .38571 Mdot
.34924 .40219 Mdot
.47472 .32464 Mdot
.55196 .2769 Mdot
.65272 .21463 Mdot
.45439 .33721 Mdot
.37624 .3855 Mdot
.64039 .22225 Mdot
.22865 .47672 Mdot
.39142 .37612 Mdot
.46298 .3319 Mdot
.44108 .34543 Mdot
.46533 .33044 Mdot
.76481 .14535 Mdot
.24705 .46535 Mdot
.58666 .25546 Mdot
.3709 .38881 Mdot
.65646 .21232 Mdot
.55096 .27752 Mdot
.66007 .21009 Mdot
.41604 .36091 Mdot
.4211 .35778 Mdot
.70674 .18124 Mdot
.29139 .43795 Mdot
.46884 .32828 Mdot
.54269 .28263 Mdot
.66829 .20501 Mdot
.60214 .24589 Mdot
.42864 .35312 Mdot
.4106 .36427 Mdot
.44801 .34115 Mdot
.32315 .41832 Mdot
.2514 .46266 Mdot
.57084 .26524 Mdot
.58837 .2544 Mdot
.43375 .34996 Mdot
.56318 .26997 Mdot
.6011 .24654 Mdot
.16619 .51532 Mdot
.56943 .26611 Mdot
.57076 .26528 Mdot
.56811 .26692 Mdot
.52919 .29098 Mdot
.19291 .49881 Mdot
.71297 .1774 Mdot
.48372 .31908 Mdot
.24256 .46812 Mdot
.57756 .26108 Mdot
.54732 .27977 Mdot
.53366 .28822 Mdot
.40409 .36829 Mdot
.49815 .31016 Mdot
.43193 .35109 Mdot
.49943 .30937 Mdot
.61114 .24033 Mdot
.40224 .36944 Mdot
.31707 .42207 Mdot
.49435 .31251 Mdot
.5651 .26879 Mdot
.40822 .36574 Mdot
.34443 .40516 Mdot
.3573 .39721 Mdot
.40942 .365 Mdot
.48475 .31844 Mdot
.46727 .32925 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000Hool2
000Xool3000Uool5000Tool00`00ooooo`0Tool5000Vool3000Vool2000Gool001[oo`03003ooooo
02Goo`03003ooooo02Ooo`03003ooooo02?oo`03003oo`0002Ooo`03003ooooo02Koo`03003ooooo
02Soo`03003ooooo01Coo`004ooo0`000ooo00<00?ooool08Ooo0`000ooo00<00?ooool08?oo0`00
0ooo00<00?ooool08ooo00<00?oo00009ooo00<00?ooool09ooo00<00?ooool09_oo00<00?ooool0
5Ooo000Jool00`00ooooo`0Vool00`00ooooo`0Vool00`00ooooo`0Sool00`00ool0000Wool00`00
ooooo`0Wool00`00ooooo`0Wool00`00ooooo`0Dool001Soo`03003oo`0002Ooo`03003oo`0002Oo
o`03003ooooo02?oo`03003oo`0002Ooo`03003ooooo02Koo`03003oo`0002Koo`03003oo`0001Ko
o`006Ooo00<00?ooool09ooo00<00?ooool09Ooo0P009_oo00<00?ooool09Ooo0P00:Ooo00<00?oo
ool09_oo00<00?ooool05Ooo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00
4oooo`004@001?oo000Cool20002ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool30004ool001?oo`05
003oooooool0000Yool00`00ooooo`0Vool00`00ooooo`0Wool00`00ooooo`0Vool00`00ooooo`0V
ool00`00ooooo`0Wool00`00ooooo`0?ool00`00ooooo`02ool001?oo`03003ooooo0?ooo`goo`03
003ooooo00;oo`004ooo00<00?ooool0oooo1_oo0P001Ooo00<00?ooool00_oo000Cool00`00oooo
o`3oool6ool20005ool00`00ooooo`02ool001?oo`800?ooo`goo`8000Coo`004ooo00<00?ooool0
oooo3Ooo00<00?ooool00_oo000Cool00`00ooooo`3oool=ool00`00ooooo`02ool000coo`8000Go
o`03003ooooo0?coo`8000koo`03003ooooo00;oo`003_oo00<00?ooool00_oo00<00?ooool0o?oo
0P003_oo00<00?ooool00_oo0007ool30003ool00`00ooooo`03ool3003oool;ool30004ool000ko
o`03003ooooo00;oo`03003ooooo0?ooo`goo`03003ooooo00;oo`003?oo00<00?oo00001?oo00<0
0?ooool0oooo3Ooo00<00?ooool00_oo000=ool00`00ooooo`03ool00`00ooooo`3oool=ool00`00
ooooo`02ool001?oo`03003ooooo0??oo`8001Ooo`03003ooooo00;oo`004ooo00<00?ooool0looo
0P005ooo00<00?ooool00_oo000Cool2003oool=ool20004ool001?oo`03003ooooo0>goo`8001go
o`03003ooooo00;oo`004ooo00<00?ooool0kOoo0P007Ooo00<00?ooool00_oo000Cool00`00oooo
o`3]ool2000Mool00`00ooooo`02ool001?oo`03003ooooo0?ooo`goo`03003ooooo00;oo`004ooo
0P00oooo3Ooo0P001?oo000Cool00`00ooooo`3Vool2000Tool00`00ooooo`02ool001?oo`03003o
oooo0>Koo`8002Coo`03003ooooo00;oo`004ooo00<00?ooool0hooo0P009ooo00<00?ooool00_oo
000Cool00`00ooooo`3Sool2000Wool00`00ooooo`02ool001?oo`800?ooo`goo`8000Coo`004ooo
00<00?ooool0gOoo0P00;Ooo00<00?ooool00_oo000Cool00`00ooooo`3Lool3000]ool00`00oooo
o`02ool001?oo`03003ooooo0=coo`8002koo`03003ooooo00;oo`004ooo00<00?ooool0fOoo0P00
<Ooo00<00?ooool00_oo000Cool2003Hool4000`ool20004ool001?oo`03003ooooo0=Goo`@003?o
o`03003ooooo00;oo`004ooo00<00?ooool0dooo1000=Ooo00<00?ooool00_oo000<ool30004ool0
0`00ooooo`3Cool4000eool00`00ooooo`02ool000coo`03003ooooo00Coo`03003ooooo0=?oo`80
03Ooo`03003ooooo00;oo`001ooo0`000ooo00<00?ooool00ooo0`00cooo0P00>Ooo0`001?oo000=
ool00`00ooooo`03ool00`00ooooo`3>ool3000kool00`00ooooo`02ool000coo`03003oo`0000Co
o`03003ooooo0<_oo`D003coo`03003ooooo00;oo`003Ooo00<00?ooool00ooo00<00?ooool0booo
1000?Ooo00<00?ooool00_oo000Cool00`00ooooo`39ool4000oool00`00ooooo`02ool001?oo`80
0<[oo`80043oo`8000Coo`004ooo00<00?ooool0a_oo0P00A?oo00<00?ooool00_oo000Cool00`00
ooooo`36ool20014ool00`00ooooo`02ool001?oo`03003ooooo0<;oo`<004Ooo`03003ooooo00;o
o`004ooo00<00?ooool0`?oo1@00Aooo00<00?ooool00_oo000Cool20030ool30019ool20004ool0
01?oo`03003ooooo0;goo`D004[oo`03003ooooo00;oo`004ooo00<00?ooool0^ooo1000COoo00<0
0?ooool00_oo000Cool00`00ooooo`2jool4001>ool00`00ooooo`02ool001?oo`03003ooooo0;So
o`D004ooo`03003ooooo00;oo`004ooo0P00]ooo1000DOoo0P001?oo000Cool00`00ooooo`2eool5
001Bool00`00ooooo`02ool001?oo`03003ooooo0;?oo`@005Goo`03003ooooo00;oo`004ooo00<0
0?ooool0/_oo1000E_oo00<00?ooool00_oo000Cool00`00ooooo`2`ool5001Gool00`00ooooo`02
ool001?oo`03003ooooo0:koo`D005Woo`03003ooooo00;oo`004ooo0P00[_oo1000F_oo0P001?oo
000Cool00`00ooooo`2[ool5001Lool00`00ooooo`02ool001?oo`03003ooooo0:Woo`@005ooo`03
003ooooo00;oo`002ooo1@000ooo00<00?ooool0Z?oo1000H?oo00<00?ooool00_oo000=ool00`00
ooooo`03ool00`00ooooo`2Wool4001Qool00`00ooooo`02ool000Ooo`<000?oo`03003ooooo00?o
o`<00:Goo`@0067oo`<000Coo`003Ooo00<00?ooool00ooo00<00?ooool0Xooo1000IOoo00<00?oo
ool00_oo000=ool00`00ooooo`03ool00`00ooooo`2Qool5001Vool00`00ooooo`02ool000coo`80
00Goo`03003ooooo0:3oo`D006Ooo`03003ooooo00;oo`004ooo00<00?ooool0W_oo1@00JOoo00<0
0?ooool00_oo000Cool2002Nool4001Zool20004ool001?oo`03003ooooo09_oo`D006coo`03003o
oooo00;oo`004ooo00<00?ooool0VOoo1@00K_oo00<00?ooool00_oo000Cool00`00ooooo`2Hool4
001`ool00`00ooooo`02ool001?oo`03003ooooo09Koo`D0077oo`03003ooooo00;oo`004ooo0P00
U_oo1000L_oo0P001?oo000Cool00`00ooooo`2Cool5001dool00`00ooooo`02ool001?oo`03003o
oooo097oo`D007Koo`03003ooooo00;oo`004ooo00<00?ooool0Sooo1@00N?oo00<00?ooool00_oo
000Cool00`00ooooo`2>ool5001iool00`00ooooo`02ool001?oo`8008koo`@007[oo`8000Coo`00
4ooo00<00?ooool0Rooo1@00O?oo00<00?ooool00_oo000Cool00`00ooooo`29ool5001nool00`00
ooooo`02ool001?oo`03003ooooo08Ooo`D0083oo`03003ooooo00;oo`004ooo00<00?ooool0Q_oo
1@00POoo00<00?ooool00_oo000Cool20026ool40022ool20004ool001?oo`03003ooooo08?oo`D0
08Coo`03003ooooo00;oo`004ooo00<00?ooool0POoo1000Qooo00<00?ooool00_oo000=ool00`00
ooooo`03ool00`00ooooo`1oool50028ool00`00ooooo`02ool000coo`03003oo`0000Coo`03003o
oooo07koo`D008Woo`03003ooooo00;oo`003?oo00<00?oo00001?oo0`00O?oo1@00ROoo0`001?oo
000<ool00`00ool00004ool00`00ooooo`1kool4002=ool00`00ooooo`02ool000coo`03003oo`00
00Coo`03003ooooo07Woo`D008koo`03003ooooo00;oo`003Ooo00<00?ooool00ooo00<00?ooool0
Mooo1@00T?oo00<00?ooool00_oo000Cool00`00ooooo`1fool4002Bool00`00ooooo`02ool001?o
o`8007Goo`@009?oo`8000Coo`004ooo00<00?ooool0L_oo1@00UOoo00<00?ooool00_oo000Cool0
0`00ooooo`1aool5002Fool00`00ooooo`02ool001?oo`03003ooooo06ooo`D009Soo`03003ooooo
00;oo`004ooo00<00?ooool0KOoo1@00V_oo00<00?ooool00_oo000Cool2001]ool4002Kool20004
ool001?oo`03003ooooo06_oo`@009goo`03003ooooo00;oo`004ooo00<00?ooool0JOoo1@00W_oo
00<00?ooool00_oo000Cool00`00ooooo`1Wool5002Pool00`00ooooo`02ool001?oo`03003ooooo
06Goo`D00:;oo`03003ooooo00;oo`004ooo00<00?ooool0I?oo1@00Xooo00<00?ooool00_oo000C
ool2001Tool4002Tool20004ool001?oo`03003ooooo067oo`@00:Ooo`03003ooooo00;oo`004ooo
00<00?ooool0Gooo1@00Z?oo00<00?ooool00_oo000Cool00`00ooooo`1Mool5002Zool00`00oooo
o`02ool001?oo`03003ooooo05goo`@00:_oo`03003ooooo00;oo`004ooo0P00Fooo1@00[?oo0P00
1?oo000Cool00`00ooooo`1Hool6002^ool00`00ooooo`02ool001?oo`03003ooooo05Ooo`D00;3o
o`03003ooooo00;oo`002ooo1@000ooo00<00?ooool0E_oo1000/_oo00<00?ooool00_oo000=ool0
0`00ooooo`03ool00`00ooooo`1Dool4002dool00`00ooooo`02ool000goo`03003ooooo00?oo`<0
05;oo`D00;?oo`<000Coo`003Ooo00<00?ooool00ooo00<00?ooool0D?oo1@00]ooo00<00?ooool0
0_oo000=ool00`00ooooo`03ool00`00ooooo`1?ool5002hool00`00ooooo`02ool000coo`8000Go
o`03003ooooo04goo`@00;_oo`03003ooooo00;oo`004ooo00<00?ooool0C?oo1000_?oo00<00?oo
ool00_oo000Cool2001;ool5002lool20004ool001?oo`03003ooooo04Soo`D00;ooo`03003ooooo
00;oo`004ooo00<00?ooool0Aooo1@00`?oo00<00?ooool00_oo000Cool00`00ooooo`16ool30033
ool00`00ooooo`02ool001?oo`03003ooooo04Coo`@00<Coo`03003ooooo00;oo`004ooo0P00@ooo
1000aOoo0P001?oo000Cool00`00ooooo`10ool50037ool00`00ooooo`02ool001?oo`03003ooooo
03ooo`<00<[oo`03003ooooo00;oo`004ooo00<00?ooool0?_oo0`00booo00<00?ooool00_oo000C
ool00`00ooooo`0kool5003<ool00`00ooooo`02ool001?oo`8003_oo`D00<coo`8000Coo`004ooo
00<00?ooool0>?oo1000d?oo00<00?ooool00_oo000Cool00`00ooooo`0hool3003Aool00`00oooo
o`02ool001?oo`03003ooooo03Goo`800=Goo`03003ooooo00;oo`004ooo00<00?ooool0<ooo1000
eOoo00<00?ooool00_oo000Cool2000cool4003Eool20004ool001?oo`03003ooooo033oo`@00=So
o`03003ooooo00;oo`004ooo00<00?ooool0;ooo1000fOoo00<00?ooool00_oo000<ool30004ool0
0`00ooooo`0_ool2003Kool00`00ooooo`02ool000coo`03003ooooo00Coo`03003ooooo0?ooo`go
o`03003ooooo00;oo`003Ooo00<00?ooool00ooo0`00oooo2ooo0`001?oo000=ool00`00ooooo`03
ool00`00ooooo`0Yool2003Qool00`00ooooo`02ool000coo`03003oo`0000Coo`03003ooooo02Wo
o`800>7oo`03003ooooo00;oo`003Ooo00<00?ooool00ooo00<00?ooool09Ooo0P00iOoo00<00?oo
ool00_oo000Cool00`00ooooo`0Tool3003Uool00`00ooooo`02ool001?oo`03003ooooo02;oo`@0
0>Koo`03003ooooo00;oo`004ooo0P008ooo0P00iooo0P001?oo000Cool00`00ooooo`0Oool2003[
ool00`00ooooo`02ool001?oo`03003ooooo01ooo`800>_oo`03003ooooo00;oo`004ooo00<00?oo
ool07?oo0P00k_oo00<00?ooool00_oo000Cool00`00ooooo`0Jool4003^ool00`00ooooo`02ool0
01?oo`8001_oo`<00>koo`8000Coo`004ooo00<00?ooool0oooo3Ooo00<00?ooool00_oo000Cool0
0`00ooooo`3oool=ool00`00ooooo`02ool001?oo`03003ooooo01?oo`800?Ooo`03003ooooo00;o
o`004ooo00<00?ooool04ooo0P00mooo00<00?ooool00_oo000Cool2000Aool2003iool20004ool0
01?oo`03003ooooo013oo`800?[oo`03003ooooo00;oo`004ooo00<00?ooool0oooo3Ooo00<00?oo
ool00_oo000Cool00`00ooooo`3oool=ool00`00ooooo`02ool001?oo`03003ooooo0?ooo`goo`03
003ooooo00;oo`004ooo0P00oooo3Ooo0P001?oo000Cool00`00ooooo`3oool=ool00`00ooooo`02
ool001?oo`03003ooooo0?ooo`goo`03003ooooo00;oo`003?oo0P001Ooo00<00?ooool0oooo3Ooo
00<00?ooool00_oo000>ool00`00ooooo`02ool00`00ooooo`03ool2003oool8ool00`00ooooo`02
ool000goo`03003ooooo00?oo`<000?oo`800?ooo`Koo`<000Coo`003_oo00<00?ooool00_oo00D0
0?ooooooo`0002Woo`03003ooooo02Koo`03003ooooo02Ooo`03003ooooo02Koo`03003ooooo02Ko
o`03003ooooo02Ooo`03003ooooo00ooo`03003ooooo00;oo`003?oo00<00?oo00001?oo00D00?oo
ooooo`0000Soo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Koo`03
003ooooo00Goo`03003ooooo00Goo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Goo`03
003ooooo00Goo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Koo`03
003ooooo00Goo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Koo`03003ooooo00Goo`03
003ooooo00Goo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Goo`03
003ooooo00Koo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Koo`03
003ooooo00Goo`03003ooooo00Goo`03003oo`0000Coo`003Ooo00<00?ooool00oooo`004@001?oo
003ooolXool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.57503, -3.9208, \
0.0241486, 0.0390732}}]
}, Open  ]],

Cell["\<\
We generate 500 pairs of random numbers with \[Hyphen]0.8 as the \
correlation coefficient. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.22"}],

Cell["m = Table[chance[-0.8], {500}];", "Input",
  CellLabel->"In[19]:=",
  CellTags->"S0.1"],

Cell["Here is the corresponding graph. ", "MathCaption",
  CellTags->{"S0.1", "1.23"}],

Cell[CellGroupData[{

Cell["ListPlot[m];", "Input",
  CellLabel->"In[20]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.494335 0.160363 0.305217 0.0925483 [
[.01324 -0.0125 -6 -9 ]
[.01324 -0.0125 6 0 ]
[.17361 -0.0125 -6 -9 ]
[.17361 -0.0125 6 0 ]
[.33397 -0.0125 -6 -9 ]
[.33397 -0.0125 6 0 ]
[.49433 -0.0125 -3 -9 ]
[.49433 -0.0125 3 0 ]
[.6547 -0.0125 -3 -9 ]
[.6547 -0.0125 3 0 ]
[.81506 -0.0125 -3 -9 ]
[.81506 -0.0125 3 0 ]
[.97543 -0.0125 -3 -9 ]
[.97543 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02757 -12 -4.5 ]
[-0.0125 .02757 0 4.5 ]
[-0.0125 .12012 -12 -4.5 ]
[-0.0125 .12012 0 4.5 ]
[-0.0125 .21267 -12 -4.5 ]
[-0.0125 .21267 0 4.5 ]
[-0.0125 .30522 -6 -4.5 ]
[-0.0125 .30522 0 4.5 ]
[-0.0125 .39777 -6 -4.5 ]
[-0.0125 .39777 0 4.5 ]
[-0.0125 .49031 -6 -4.5 ]
[-0.0125 .49031 0 4.5 ]
[-0.0125 .58286 -6 -4.5 ]
[-0.0125 .58286 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01324 0 m
.01324 .00625 L
s
[(-3)] .01324 -0.0125 0 1 Mshowa
.17361 0 m
.17361 .00625 L
s
[(-2)] .17361 -0.0125 0 1 Mshowa
.33397 0 m
.33397 .00625 L
s
[(-1)] .33397 -0.0125 0 1 Mshowa
.49433 0 m
.49433 .00625 L
s
[(0)] .49433 -0.0125 0 1 Mshowa
.6547 0 m
.6547 .00625 L
s
[(1)] .6547 -0.0125 0 1 Mshowa
.81506 0 m
.81506 .00625 L
s
[(2)] .81506 -0.0125 0 1 Mshowa
.97543 0 m
.97543 .00625 L
s
[(3)] .97543 -0.0125 0 1 Mshowa
.125 Mabswid
.04532 0 m
.04532 .00375 L
s
.07739 0 m
.07739 .00375 L
s
.10946 0 m
.10946 .00375 L
s
.14154 0 m
.14154 .00375 L
s
.20568 0 m
.20568 .00375 L
s
.23775 0 m
.23775 .00375 L
s
.26983 0 m
.26983 .00375 L
s
.3019 0 m
.3019 .00375 L
s
.36604 0 m
.36604 .00375 L
s
.39812 0 m
.39812 .00375 L
s
.43019 0 m
.43019 .00375 L
s
.46226 0 m
.46226 .00375 L
s
.52641 0 m
.52641 .00375 L
s
.55848 0 m
.55848 .00375 L
s
.59055 0 m
.59055 .00375 L
s
.62263 0 m
.62263 .00375 L
s
.68677 0 m
.68677 .00375 L
s
.71884 0 m
.71884 .00375 L
s
.75092 0 m
.75092 .00375 L
s
.78299 0 m
.78299 .00375 L
s
.84713 0 m
.84713 .00375 L
s
.87921 0 m
.87921 .00375 L
s
.91128 0 m
.91128 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02757 m
.00625 .02757 L
s
[(-3)] -0.0125 .02757 1 0 Mshowa
0 .12012 m
.00625 .12012 L
s
[(-2)] -0.0125 .12012 1 0 Mshowa
0 .21267 m
.00625 .21267 L
s
[(-1)] -0.0125 .21267 1 0 Mshowa
0 .30522 m
.00625 .30522 L
s
[(0)] -0.0125 .30522 1 0 Mshowa
0 .39777 m
.00625 .39777 L
s
[(1)] -0.0125 .39777 1 0 Mshowa
0 .49031 m
.00625 .49031 L
s
[(2)] -0.0125 .49031 1 0 Mshowa
0 .58286 m
.00625 .58286 L
s
[(3)] -0.0125 .58286 1 0 Mshowa
.125 Mabswid
0 .04608 m
.00375 .04608 L
s
0 .06459 m
.00375 .06459 L
s
0 .0831 m
.00375 .0831 L
s
0 .10161 m
.00375 .10161 L
s
0 .13863 m
.00375 .13863 L
s
0 .15714 m
.00375 .15714 L
s
0 .17565 m
.00375 .17565 L
s
0 .19416 m
.00375 .19416 L
s
0 .23118 m
.00375 .23118 L
s
0 .24969 m
.00375 .24969 L
s
0 .2682 m
.00375 .2682 L
s
0 .28671 m
.00375 .28671 L
s
0 .32373 m
.00375 .32373 L
s
0 .34224 m
.00375 .34224 L
s
0 .36075 m
.00375 .36075 L
s
0 .37926 m
.00375 .37926 L
s
0 .41628 m
.00375 .41628 L
s
0 .43478 m
.00375 .43478 L
s
0 .45329 m
.00375 .45329 L
s
0 .4718 m
.00375 .4718 L
s
0 .50882 m
.00375 .50882 L
s
0 .52733 m
.00375 .52733 L
s
0 .54584 m
.00375 .54584 L
s
0 .56435 m
.00375 .56435 L
s
0 .00906 m
.00375 .00906 L
s
0 .60137 m
.00375 .60137 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01324 .61178 m
.01324 .61803 L
s
.17361 .61178 m
.17361 .61803 L
s
.33397 .61178 m
.33397 .61803 L
s
.49433 .61178 m
.49433 .61803 L
s
.6547 .61178 m
.6547 .61803 L
s
.81506 .61178 m
.81506 .61803 L
s
.97543 .61178 m
.97543 .61803 L
s
.125 Mabswid
.04532 .61428 m
.04532 .61803 L
s
.07739 .61428 m
.07739 .61803 L
s
.10946 .61428 m
.10946 .61803 L
s
.14154 .61428 m
.14154 .61803 L
s
.20568 .61428 m
.20568 .61803 L
s
.23775 .61428 m
.23775 .61803 L
s
.26983 .61428 m
.26983 .61803 L
s
.3019 .61428 m
.3019 .61803 L
s
.36604 .61428 m
.36604 .61803 L
s
.39812 .61428 m
.39812 .61803 L
s
.43019 .61428 m
.43019 .61803 L
s
.46226 .61428 m
.46226 .61803 L
s
.52641 .61428 m
.52641 .61803 L
s
.55848 .61428 m
.55848 .61803 L
s
.59055 .61428 m
.59055 .61803 L
s
.62263 .61428 m
.62263 .61803 L
s
.68677 .61428 m
.68677 .61803 L
s
.71884 .61428 m
.71884 .61803 L
s
.75092 .61428 m
.75092 .61803 L
s
.78299 .61428 m
.78299 .61803 L
s
.84713 .61428 m
.84713 .61803 L
s
.87921 .61428 m
.87921 .61803 L
s
.91128 .61428 m
.91128 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02757 m
1 .02757 L
s
.99375 .12012 m
1 .12012 L
s
.99375 .21267 m
1 .21267 L
s
.99375 .30522 m
1 .30522 L
s
.99375 .39777 m
1 .39777 L
s
.99375 .49031 m
1 .49031 L
s
.99375 .58286 m
1 .58286 L
s
.125 Mabswid
.99625 .04608 m
1 .04608 L
s
.99625 .06459 m
1 .06459 L
s
.99625 .0831 m
1 .0831 L
s
.99625 .10161 m
1 .10161 L
s
.99625 .13863 m
1 .13863 L
s
.99625 .15714 m
1 .15714 L
s
.99625 .17565 m
1 .17565 L
s
.99625 .19416 m
1 .19416 L
s
.99625 .23118 m
1 .23118 L
s
.99625 .24969 m
1 .24969 L
s
.99625 .2682 m
1 .2682 L
s
.99625 .28671 m
1 .28671 L
s
.99625 .32373 m
1 .32373 L
s
.99625 .34224 m
1 .34224 L
s
.99625 .36075 m
1 .36075 L
s
.99625 .37926 m
1 .37926 L
s
.99625 .41628 m
1 .41628 L
s
.99625 .43478 m
1 .43478 L
s
.99625 .45329 m
1 .45329 L
s
.99625 .4718 m
1 .4718 L
s
.99625 .50882 m
1 .50882 L
s
.99625 .52733 m
1 .52733 L
s
.99625 .54584 m
1 .54584 L
s
.99625 .56435 m
1 .56435 L
s
.99625 .00906 m
1 .00906 L
s
.99625 .60137 m
1 .60137 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.72105 .01472 Mdot
.418 .31564 Mdot
.30149 .48308 Mdot
.35606 .28914 Mdot
.31889 .48783 Mdot
.09908 .49757 Mdot
.39593 .23509 Mdot
.36565 .36285 Mdot
.40589 .31948 Mdot
.52953 .22696 Mdot
.55362 .32218 Mdot
.41513 .35195 Mdot
.49569 .41638 Mdot
.33822 .36186 Mdot
.27167 .36941 Mdot
.54724 .31072 Mdot
.34401 .37289 Mdot
.20926 .45198 Mdot
.3803 .33968 Mdot
.47129 .3786 Mdot
.16606 .36021 Mdot
.42294 .26883 Mdot
.5864 .21628 Mdot
.68217 .19139 Mdot
.46754 .39486 Mdot
.36786 .36212 Mdot
.32499 .30421 Mdot
.31854 .31519 Mdot
.72729 .25574 Mdot
.65417 .22494 Mdot
.40219 .30829 Mdot
.48785 .21358 Mdot
.21744 .39268 Mdot
.49429 .26999 Mdot
.34546 .31179 Mdot
.18182 .54269 Mdot
.74867 .26004 Mdot
.68963 .30534 Mdot
.59026 .21396 Mdot
.59974 .30835 Mdot
.27884 .31246 Mdot
.46864 .3812 Mdot
.60408 .23819 Mdot
.32203 .3979 Mdot
.46794 .40491 Mdot
.30373 .41965 Mdot
.53645 .27084 Mdot
.50296 .31811 Mdot
.55913 .29334 Mdot
.31123 .36624 Mdot
.55144 .33097 Mdot
.61876 .2679 Mdot
.39994 .34384 Mdot
.46443 .36371 Mdot
.55418 .29553 Mdot
.55961 .36071 Mdot
.40714 .38853 Mdot
.77508 .21849 Mdot
.48004 .28722 Mdot
.49949 .22329 Mdot
.57622 .23264 Mdot
.59553 .21225 Mdot
.53914 .21993 Mdot
.68299 .22191 Mdot
.53577 .38254 Mdot
.3308 .50006 Mdot
.53183 .31854 Mdot
.46401 .27297 Mdot
.35888 .33259 Mdot
.52773 .26383 Mdot
.45029 .34775 Mdot
.63171 .31355 Mdot
.36705 .34769 Mdot
.62249 .31409 Mdot
.47589 .26958 Mdot
.53095 .30606 Mdot
.69855 .31256 Mdot
.64927 .24001 Mdot
.57604 .27869 Mdot
.3633 .34124 Mdot
.64569 .20547 Mdot
.30225 .40781 Mdot
.56957 .19118 Mdot
.33311 .46561 Mdot
.55094 .19187 Mdot
.54266 .17284 Mdot
.63739 .24089 Mdot
.6514 .1813 Mdot
.50558 .32158 Mdot
.30062 .40006 Mdot
.60343 .36244 Mdot
.56834 .26747 Mdot
.61228 .16667 Mdot
.43625 .26136 Mdot
.5954 .22633 Mdot
.59074 .27786 Mdot
.31457 .40413 Mdot
.68097 .32894 Mdot
.67999 .17868 Mdot
.70289 .17581 Mdot
.40078 .34959 Mdot
.6704 .14249 Mdot
.4425 .37721 Mdot
.7579 .16734 Mdot
.47016 .24468 Mdot
.53525 .343 Mdot
.56599 .16601 Mdot
.6915 .2162 Mdot
.16587 .42617 Mdot
.44889 .45313 Mdot
.43018 .33285 Mdot
.48303 .24626 Mdot
.57416 .22123 Mdot
.5663 .27623 Mdot
.79026 .19797 Mdot
.69105 .14137 Mdot
.20695 .37371 Mdot
.42655 .32788 Mdot
.47438 .33456 Mdot
.54234 .29729 Mdot
.4197 .32905 Mdot
.33124 .40618 Mdot
.42509 .35161 Mdot
.48537 .25823 Mdot
.51756 .26602 Mdot
.33785 .49835 Mdot
.28062 .44691 Mdot
.38281 .27222 Mdot
.58343 .27758 Mdot
.46128 .28804 Mdot
.35942 .42132 Mdot
.55004 .26543 Mdot
.45708 .26813 Mdot
.83326 .1052 Mdot
.63241 .09442 Mdot
.40809 .30866 Mdot
.59188 .34062 Mdot
.51693 .35181 Mdot
.68374 .1258 Mdot
.69752 .27913 Mdot
.3387 .27629 Mdot
.2281 .44247 Mdot
.34106 .30673 Mdot
.16787 .32318 Mdot
.57669 .31391 Mdot
.42934 .45143 Mdot
.34326 .30284 Mdot
.84101 .22026 Mdot
.70775 .18371 Mdot
.40577 .36658 Mdot
.52707 .35403 Mdot
.55634 .25987 Mdot
.25741 .43373 Mdot
.39578 .43289 Mdot
.52106 .39026 Mdot
.42329 .43755 Mdot
.35001 .36173 Mdot
.05365 .60332 Mdot
.47352 .20217 Mdot
.37107 .33025 Mdot
.62102 .24391 Mdot
.47395 .29795 Mdot
.53756 .31577 Mdot
.58514 .24865 Mdot
.42354 .31346 Mdot
.35643 .49764 Mdot
.41611 .28014 Mdot
.77604 .23016 Mdot
.37417 .33134 Mdot
.38934 .39514 Mdot
.5236 .35406 Mdot
.51183 .35295 Mdot
.82423 .19063 Mdot
.34484 .45186 Mdot
.26577 .43996 Mdot
.59852 .28649 Mdot
.49762 .29663 Mdot
.71774 .22844 Mdot
.40353 .43179 Mdot
.59184 .27555 Mdot
.41786 .39808 Mdot
.52176 .25965 Mdot
.64972 .17482 Mdot
.28258 .35899 Mdot
.52946 .17374 Mdot
.7808 .20791 Mdot
.44096 .41839 Mdot
.82194 .12627 Mdot
.46277 .38427 Mdot
.64856 .18691 Mdot
.49744 .24334 Mdot
.63688 .21065 Mdot
.48111 .25421 Mdot
.51596 .26198 Mdot
.30085 .40587 Mdot
.46788 .28914 Mdot
.29819 .36751 Mdot
.20249 .37154 Mdot
.75008 .19649 Mdot
.10718 .54563 Mdot
.61978 .23763 Mdot
.42196 .24041 Mdot
.45967 .35728 Mdot
.58754 .23733 Mdot
.306 .36289 Mdot
.48761 .23522 Mdot
.4235 .35441 Mdot
.24379 .40813 Mdot
.60968 .19433 Mdot
.38798 .31646 Mdot
.58238 .29961 Mdot
.16799 .47394 Mdot
.71095 .14401 Mdot
.46949 .21269 Mdot
.49254 .32351 Mdot
.49396 .31017 Mdot
.63179 .22395 Mdot
.23134 .44054 Mdot
.45311 .30746 Mdot
.36357 .27021 Mdot
.32168 .44633 Mdot
.89956 .11238 Mdot
.63066 .27278 Mdot
.71929 .11315 Mdot
.33953 .44686 Mdot
.5106 .35324 Mdot
.32941 .39195 Mdot
.5337 .26626 Mdot
.41891 .24407 Mdot
.59661 .24925 Mdot
.63717 .33158 Mdot
.97619 .21485 Mdot
.39745 .46184 Mdot
.22453 .31964 Mdot
.44184 .38563 Mdot
.31324 .48142 Mdot
.59871 .33224 Mdot
.56225 .26699 Mdot
.72204 .14284 Mdot
.32586 .37694 Mdot
.39789 .36465 Mdot
.44441 .33097 Mdot
.54307 .21445 Mdot
.27011 .53152 Mdot
.3205 .38814 Mdot
.69267 .25812 Mdot
.88518 .12051 Mdot
.55263 .23038 Mdot
.11206 .55668 Mdot
.55622 .38933 Mdot
.42903 .3865 Mdot
.49936 .25243 Mdot
.67206 .26533 Mdot
.37776 .36063 Mdot
.56197 .21554 Mdot
.41416 .33423 Mdot
.65337 .23257 Mdot
.46676 .37554 Mdot
.71567 .23248 Mdot
.6255 .28399 Mdot
.46328 .29096 Mdot
.4749 .30276 Mdot
.24478 .43046 Mdot
.81428 .13475 Mdot
.69381 .11821 Mdot
.53186 .24484 Mdot
.56201 .31531 Mdot
.39565 .32038 Mdot
.51332 .2928 Mdot
.10058 .45239 Mdot
.55883 .20552 Mdot
.31877 .36878 Mdot
.50281 .31482 Mdot
.21783 .33911 Mdot
.1542 .41563 Mdot
.58475 .27359 Mdot
.51431 .22634 Mdot
.52968 .37467 Mdot
.39759 .42437 Mdot
.541 .27834 Mdot
.61028 .14441 Mdot
.27962 .37586 Mdot
.62546 .20561 Mdot
.34422 .37877 Mdot
.51558 .25355 Mdot
.62392 .32271 Mdot
.34122 .37818 Mdot
.2529 .46125 Mdot
.52167 .22007 Mdot
.51053 .3069 Mdot
.58819 .29382 Mdot
.4749 .38994 Mdot
.03731 .53186 Mdot
.86366 .1305 Mdot
.58217 .29706 Mdot
.57332 .17608 Mdot
.77329 .2601 Mdot
.5921 .293 Mdot
.50405 .22403 Mdot
.62673 .32257 Mdot
.41017 .35676 Mdot
.73847 .23754 Mdot
.66644 .27327 Mdot
.50063 .37093 Mdot
.5521 .26655 Mdot
.3357 .37323 Mdot
.43867 .40413 Mdot
.47414 .4087 Mdot
.4401 .28497 Mdot
.54985 .25348 Mdot
.79631 .08631 Mdot
.83154 .18258 Mdot
.42546 .31233 Mdot
.77085 .19674 Mdot
.46079 .34224 Mdot
.72222 .21383 Mdot
.29684 .38752 Mdot
.38203 .43266 Mdot
.65171 .29713 Mdot
.4435 .33347 Mdot
.62818 .25294 Mdot
.44422 .25233 Mdot
.26792 .42882 Mdot
.67556 .25684 Mdot
.43445 .32831 Mdot
.75552 .17658 Mdot
.23059 .45224 Mdot
.5039 .28364 Mdot
.5838 .24938 Mdot
.54518 .26672 Mdot
.48864 .32202 Mdot
.55976 .2479 Mdot
.67752 .14506 Mdot
.62204 .28982 Mdot
.55915 .19972 Mdot
.27596 .46696 Mdot
.40557 .26093 Mdot
.44921 .39382 Mdot
.49462 .34056 Mdot
.63203 .35303 Mdot
.49253 .21926 Mdot
.35613 .38865 Mdot
.52757 .26641 Mdot
.45962 .20787 Mdot
.54952 .27199 Mdot
.89582 .066 Mdot
.51961 .37708 Mdot
.3348 .40132 Mdot
.60917 .38508 Mdot
.41699 .22389 Mdot
.70579 .21337 Mdot
.55115 .26358 Mdot
.57237 .11321 Mdot
.26368 .31929 Mdot
.40361 .41241 Mdot
.16425 .51031 Mdot
.59862 .29694 Mdot
.20443 .41122 Mdot
.43445 .32991 Mdot
.21077 .39479 Mdot
.40944 .32143 Mdot
.24474 .42589 Mdot
.53024 .26469 Mdot
.65813 .26032 Mdot
.34885 .29655 Mdot
.47004 .2625 Mdot
.90892 .10493 Mdot
.54362 .22063 Mdot
.48171 .30153 Mdot
.58119 .35695 Mdot
.53025 .29195 Mdot
.05298 .50479 Mdot
.54246 .25683 Mdot
.26771 .39391 Mdot
.40885 .42096 Mdot
.6294 .30817 Mdot
.55178 .28564 Mdot
.45754 .31453 Mdot
.13258 .47595 Mdot
.58832 .22737 Mdot
.60139 .29211 Mdot
.70532 .22434 Mdot
.35385 .29357 Mdot
.38091 .35402 Mdot
.45751 .33482 Mdot
.42261 .33474 Mdot
.32912 .45805 Mdot
.70341 .18786 Mdot
.21933 .4083 Mdot
.47496 .3624 Mdot
.48583 .21748 Mdot
.55152 .23153 Mdot
.68343 .28153 Mdot
.4169 .38571 Mdot
.58244 .19346 Mdot
.56454 .34848 Mdot
.4655 .35476 Mdot
.46367 .30316 Mdot
.91831 .14164 Mdot
.55538 .28398 Mdot
.33388 .39583 Mdot
.35638 .23805 Mdot
.08833 .36732 Mdot
.63735 .27876 Mdot
.31419 .41559 Mdot
.29485 .39899 Mdot
.42464 .34459 Mdot
.57704 .35964 Mdot
.65417 .30119 Mdot
.25837 .47778 Mdot
.48571 .32095 Mdot
.58884 .26742 Mdot
.62532 .2531 Mdot
.48357 .25847 Mdot
.20626 .42037 Mdot
.51859 .29121 Mdot
.4089 .38189 Mdot
.2745 .49994 Mdot
.52671 .23545 Mdot
.49222 .3489 Mdot
.58963 .14564 Mdot
.73004 .17738 Mdot
.46684 .3124 Mdot
.78354 .23087 Mdot
.59623 .29405 Mdot
.6176 .18451 Mdot
.50237 .33059 Mdot
.26583 .45292 Mdot
.3021 .42344 Mdot
.48563 .35736 Mdot
.53595 .41774 Mdot
.61176 .25687 Mdot
.58766 .21912 Mdot
.62303 .22232 Mdot
.3625 .3772 Mdot
.36598 .36656 Mdot
.33122 .27758 Mdot
.71462 .34386 Mdot
.38318 .38237 Mdot
.5779 .36291 Mdot
.05464 .46731 Mdot
.39776 .32396 Mdot
.66447 .16684 Mdot
.46058 .34536 Mdot
.62671 .33197 Mdot
.27233 .38142 Mdot
.32519 .35435 Mdot
.56775 .31743 Mdot
.43259 .33871 Mdot
.35777 .36904 Mdot
.44447 .32227 Mdot
.50001 .29625 Mdot
.54717 .21182 Mdot
.49075 .30307 Mdot
.39404 .42063 Mdot
.34919 .39931 Mdot
.52956 .31966 Mdot
.52678 .3716 Mdot
.39969 .3537 Mdot
.48992 .14179 Mdot
.12893 .52718 Mdot
.6768 .1348 Mdot
.4615 .39352 Mdot
.45825 .33112 Mdot
.74481 .13105 Mdot
.49296 .30581 Mdot
.42431 .44808 Mdot
.7463 .17916 Mdot
.46283 .35463 Mdot
.44355 .37269 Mdot
.34583 .43623 Mdot
.65449 .199 Mdot
.69306 .13722 Mdot
.56054 .2565 Mdot
.54436 .3292 Mdot
.40406 .31865 Mdot
.32574 .43869 Mdot
.63816 .12521 Mdot
.31842 .35524 Mdot
.43192 .28751 Mdot
.42356 .29918 Mdot
.36958 .36088 Mdot
.02381 .48057 Mdot
.66898 .22013 Mdot
.82087 .03234 Mdot
.57614 .15428 Mdot
.31246 .34099 Mdot
.26729 .37006 Mdot
.31627 .36595 Mdot
.4352 .29872 Mdot
.22061 .4015 Mdot
.30852 .42165 Mdot
.2309 .45808 Mdot
.45851 .33283 Mdot
.28559 .35629 Mdot
.26326 .46059 Mdot
.39587 .4714 Mdot
.27261 .41034 Mdot
.93204 .09204 Mdot
.45631 .3502 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000Fool2
000Zool3000Xool5000Vool00`00ooooo`0Wool5000Xool3000Yool2000:ool001Soo`03003ooooo
02Ooo`03003ooooo02[oo`03003ooooo02Goo`03003oo`0002[oo`03003ooooo02Soo`03003ooooo
02_oo`03003ooooo00Ooo`004Ooo0`000ooo00<00?ooool08ooo0`000ooo00<00?ooool08ooo0`00
0ooo00<00?ooool09Ooo00<00?oo0000:_oo00<00?ooool0:Ooo00<00?ooool0:Ooo00<00?ooool0
2?oo000Hool00`00ooooo`0Xool00`00ooooo`0Yool00`00ooooo`0Uool00`00ool0000Zool00`00
ooooo`0Yool00`00ooooo`0Zool00`00ooooo`07ool001Koo`03003oo`0002Woo`03003oo`0002[o
o`03003ooooo02Goo`03003oo`0002[oo`03003ooooo02Soo`03003oo`0002Woo`03003oo`0000Wo
o`005ooo00<00?ooool0:Ooo00<00?ooool0:?oo0P00:?oo00<00?ooool0:?oo0P00:ooo00<00?oo
ool0:Ooo00<00?ooool02?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00
4_ooo`004`000ooo000Bool01000ooooo`002?oo00<00?ooool01_oo00<00?ooool01_oo00<00?oo
ool01Ooo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?oo
ool01_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?oo
ool01_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?oo
ool01_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?oo
ool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01_oo00<00?oo
ool01_oo00<00?ooool01_oo00<00?ooool00ooo00<00?ooool00Ooo000Bool01000ooooo`00:ooo
00<00?ooool0:Ooo00<00?ooool0:Ooo00<00?ooool0:Ooo00<00?ooool0:Ooo00<00?ooool0:Ooo
00<00?ooool00ooo00<00?ooool00Ooo000Bool2003oool?ool20003ool001;oo`03003ooooo0<7o
o`8004_oo`03003ooooo007oo`004_oo00<00?ooool0`Ooo0P00Booo00<00?ooool00Ooo000:ool2
0006ool00`00ooooo`3oool?ool00`00ooooo`01ool000coo`03003ooooo00?oo`03003ooooo0?oo
o`ooo`03003ooooo007oo`001Ooo0`000ooo00<00?ooool01?oo0P00oooo3ooo0P000ooo000<ool0
0`00ooooo`03ool00`00ooooo`3Lool2000`ool00`00ooooo`01ool000[oo`03003oo`0000Goo`03
003ooooo0=coo`80033oo`03003ooooo007oo`002ooo00<00?ooool01?oo00<00?ooool0oooo3ooo
00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`800?ooo`ooo`80
00?oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00
ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo
00<00?ooool00Ooo000Bool2003bool2000Jool20003ool001;oo`03003ooooo0?7oo`8001_oo`03
003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000Bool00`00ooooo`3oool?
ool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo0P00oooo3ooo
0P000ooo000Bool00`00ooooo`3Fool2000fool00`00ooooo`01ool001;oo`03003ooooo0=Koo`80
02?oo`80017oo`03003ooooo007oo`004_oo00<00?ooool0ZOoo0P00D?oo0P004Ooo00<00?ooool0
0Ooo000Bool00`00ooooo`2Yool2001Sool00`00ooooo`01ool001;oo`800?ooo`ooo`8000?oo`00
4_oo00<00?ooool0h?oo0P004ooo0P005ooo00<00?ooool00Ooo000Bool00`00ooooo`3Pool2000C
ool2000Gool00`00ooooo`01ool000[oo`<000Goo`03003ooooo09Soo`8002Ooo`8002ooo`8001[o
o`03003ooooo007oo`002_oo00<00?ooool01Ooo00<00?ooool0V?oo0P008?oo0P001Ooo0P00;ooo
0P006_oo00<00?ooool00Ooo0005ool30003ool00`00ooooo`04ool2002kool2000bool2000Mool2
0003ool000_oo`03003ooooo00Coo`03003ooooo0:[oo`8004;oo`8001koo`03003ooooo007oo`00
2_oo00<00?oo00001Ooo00<00?ooool0Z_oo0P002ooo0P009?oo0P00;ooo00<00?ooool00Ooo000;
ool00`00ooooo`04ool00`00ooooo`2gool2000?ool2000Cool20009ool2000Tool00`00ooooo`01
ool001;oo`03003ooooo0;Goo`80017oo`80017oo`8000_oo`8002Coo`03003ooooo007oo`004_oo
0P00]_oo0P000_oo0P008?oo0P00<?oo0P000ooo000Bool00`00ooooo`22ool2000_ool20004ool2
0006ool2000dool2000Eool00`00ooooo`01ool001;oo`03003ooooo08;oo`8001Woo`8000Coo`80
00koo`@000;oo`8000?oo`800003ool0000003Coo`8001Goo`03003ooooo007oo`004_oo00<00?oo
ool0WOoo0P001?oo0P004?oo0P001ooo0P00C_oo00<00?ooool00Ooo000Bool00`00ooooo`2Iool2
001cool00`00ooooo`01ool001;oo`8009[oo`8007;oo`8000?oo`004_oo00<00?ooool0oooo3ooo
00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo09Oo
o`8000[oo`8000goo`8001Ooo`80047oo`03003ooooo007oo`004_oo00<00?ooool0T?oo0P001Ooo
0P002_oo0P003Ooo0P005ooo0P00@Ooo00<00?ooool00Ooo000Bool2002>ool200000ooo00000007
ool2000Cool2000<ool2000=ool20010ool20003ool001;oo`03003ooooo08goo`8000[oo`8001?o
o`8000Koo`8000Coo`8000Koo`8000;oo`800003ool00000047oo`03003ooooo007oo`004_oo00<0
0?ooool0[_oo0P001_oo0P001Ooo0P001Ooo0P000_oo0P005Ooo0P00;Ooo00<00?ooool00Ooo000B
ool00`00ooooo`2Uool20006ool3000=ool2000Pool2000]ool00`00ooooo`01ool001;oo`03003o
oooo09Soo`8000_oo`8000Koo`8000goo`8001ooo`8002ooo`03003ooooo007oo`004_oo0P00U?oo
0P000ooo0P0000?oo`0000001_oo0P004Ooo0P001?oo0P007ooo0P00;_oo0P000ooo000Bool00`00
ooooo`2Cool20006ool20006ool2000Aool2000Aool20004ool20003ool2000hool00`00ooooo`01
ool001;oo`03003ooooo07goo`8001Koo`8001Soo`8001Soo`8000Coo`8000?oo`8003Soo`03003o
oooo007oo`004_oo00<00?ooool0OOoo0P005_oo0P004?oo0P001?oo1000GOoo00<00?ooool00Ooo
0009ool50004ool00`00ooooo`1jool2000Iool2000@ool20004ool2000Rool2000kool00`00oooo
o`01ool000_oo`03003ooooo00Coo`03003ooooo07[oo`@001Coo`8000_oo`8000Woo`8002Goo`80
03_oo`03003ooooo007oo`001Ooo0`000ooo00<00?ooool01?oo0P00OOoo0P000ooo0P003Ooo1000
0_oo0P001?oo1@002Ooo0P003Ooo0P000_oo0P000_oo0P00A?oo0P001?oo0P000ooo000;ool00`00
ooooo`04ool00`00ooooo`21ool40006ool20002ool30004ool20004ool3000Dool20004ool20002
ool20002ool2000=ool2000@ool2000Sool20005ool00`00ooooo`01ool000_oo`03003ooooo00Co
o`03003ooooo06koo`80017oo`L000?oo`8000;oo`@000Koo`8000;oo`8000Ooo`800003ool00000
00Soo`8000;oo`8001Ooo`80013oo`8002[oo`03003ooooo007oo`002_oo0P001_oo00<00?ooool0
K_oo0P005?oo100000?oo`0000000_oo0P000_oo0P001_oo0P000_oo10001Ooo0P0000?oo`000000
1?oo0P001_oo0P001?oo0P00Cooo00<00?ooool00Ooo000Bool00`00ooooo`29ool20002ool20004
ool20008ool4000>ool2000<ool200000ooo0000000>ool4000jool00`00ooooo`01ool001;oo`80
06Woo`8002Woo`8000Coo`8001Coo`8000ooo`8000koo`@003Woo`8000?oo`004_oo00<00?ooool0
GOoo0P002Ooo0P005ooo0P002Ooo0P002ooo0P000_oo0P000_oo0P000_oo0P002?oo0P003ooo0P00
1?oo0P00A_oo00<00?ooool00Ooo000Bool00`00ooooo`1Mool2000@ool2000@ool20009ool2000?
ool20002ool20002ool20003ool200000ooo0000000Gool20016ool00`00ooooo`01ool001;oo`03
003ooooo06koo`<000_oo`8000Koo`8000Ooo`8001Ooo`8000;oo`800003ool0000005ooo`03003o
oooo007oo`004_oo00<00?ooool0K_oo0P003?oo0P000_oo0P000_oo0P001ooo0P001_oo0P001Ooo
0P0000?oo`0000001Ooo0P00I_oo00<00?ooool00Ooo000Bool2001fool20009ool20002ool2000?
ool20005ool200000ooo00000006ool3001Sool20003ool001;oo`03003ooooo07Goo`8000Soo`80
00?oo`8000?oo`8000Goo`@00003ool0000000coo`8000;oo`<000_oo`8000coo`8004Woo`03003o
oooo007oo`004_oo00<00?ooool0Oooo10001_oo10000ooo1`003?oo0P002ooo0P000ooo0P000_oo
0P002?oo0P001?oo0P001?oo0P00?Ooo00<00?ooool00Ooo000Bool00`00ooooo`1[ool20006ool2
0007ool20002ool30006ool50005ool3000Jool20007ool2000>ool20004ool2000mool00`00oooo
o`01ool001;oo`03003ooooo06_oo`8000Koo`8000Ooo`8000_oo`800003ool0000000800003ool0
000000800004ool000000004ool20006ool2000=ool2001Hool00`00ooooo`01ool001;oo`80063o
o`8000ooo`8000Ooo`8000?oo`8000?oo`8000Coo`800003ool0000000L00004ool000000004ool2
0006ool2000=ool2001Gool20003ool001;oo`03003ooooo05ooo`8000Coo`8000Woo`8000Ooo`@0
0003ool0000000?oo`8000[oo`800003ool0000000Soo`8000[oo`8000Soo`8005[oo`03003ooooo
007oo`004_oo00<00?ooool0E_oo10002ooo0P005?oo0P004ooo10000ooo2@002?oo10001_oo0P00
F_oo00<00?ooool00Ooo000Bool00`00ooooo`1Fool4000Dool2000Pool20005ool9000:ool2000;
ool20002ool2001Aool00`00ooooo`01ool001;oo`03003ooooo06koo`8000Coo`80013oo`8000_o
o`<0017oo`8000koo`8000;oo`80057oo`03003ooooo007oo`004_oo0P00G_oo0P004ooo10001?oo
100000?oo`0000001Ooo0P002ooo0`002_oo0P001?oo0`00I?oo0P000ooo000Bool00`00ooooo`1M
ool2000Cool20006ool400000ooo00000007ool400000ooo00000006ool20007ool40004ool2001V
ool00`00ooooo`01ool001;oo`03003ooooo05_oo`@001coo`8000Ooo`<00003ool0000000800004
ool00000ool200000ooo000000020004ool7000<ool2001Nool00`00ooooo`01ool000_oo`03003o
oooo00Coo`03003ooooo05_oo`8001?oo`800003ool0000000Soo`8000Goo`<000Woo`800003ool0
000000Koo`L000coo`8005koo`03003ooooo007oo`002_oo00<00?oo00001Ooo00<00?ooool0EOoo
0P000ooo0P005?oo0P0000?oo`0000001_oo2@005ooo0P004_oo0P00GOoo00<00?ooool00Ooo000:
ool00`00ool00005ool2001Fool20002ool3000Lool200001?oo00000?oo1`000ooo0P000ooo0P00
6Ooo0P001Ooo0P002?oo0P00D_oo0P000ooo000:ool00`00ool00005ool00`00ooooo`1Iool3000>
ool3000;ool20009ool20003ool20003ool20003ool2000<ool20006ool2000?ool2001Cool00`00
ooooo`01ool000[oo`03003oo`0000Goo`03003ooooo04Soo`8000Woo`8000Goo`8000koo`<000?o
o`8000Ooo`800003ool0000000Goo`@000_oo`8000;oo`8000;oo`8000Coo`8000Coo`800003ool0
0000013oo`80057oo`03003ooooo007oo`002ooo00<00?ooool01?oo00<00?ooool0B?oo0P002Ooo
0P004Ooo0P000_oo0P000_oo10001ooo0P0000?oo`0000001ooo0P001_oo10001Ooo0`0000?oo`00
00002_oo0P0000?oo`0000004?oo0P00DOoo00<00?ooool00Ooo000Bool00`00ooooo`0iool20009
ool2000Pool:0005ool2000:ool300001?oo000000001Ooo10000_oo0P000_oo0P003_oo0P00IOoo
00<00?ooool00Ooo000Bool2000[ool2000=ool20009ool2000Rool60007ool2000:ool400000ooo
00000005ool20004ool2000Bool2001Tool20003ool001;oo`03003ooooo02[oo`8003goo`8000Co
o`H000koo`8000coo`8002?oo`8005Koo`03003ooooo007oo`004_oo00<00?ooool0G_oo0P0000Co
o`00000000_oo`P000;oo`8000[oo`8000[oo`@000_oo`8000Goo`800003ool0000000[oo`8005Ko
o`03003ooooo007oo`004_oo00<00?ooool0G_oo0P0000Coo`00000000Woo`@00004ool00000ool2
0002ool20003ool20005ool2000<ool2000;ool20005ool200000ooo0000001Rool00`00ooooo`01
ool001;oo`03003ooooo03Ooo`8001Soo`80017oo`8000Ooo`@00003ool0000000Goo`8000?oo`80
00?oo`8001Woo`8006koo`03003ooooo007oo`004_oo0P00>?oo0P006?oo0P003?oo0P000ooo0P00
0ooo0P001Ooo10001_oo0P001ooo0P002Ooo0P003_oo0P007ooo0P00C?oo0P000ooo000Bool00`00
ooooo`1Oool30007ool20005ool20005ool200000ooo0000000Bool2000_ool2001=ool00`00oooo
o`01ool001;oo`03003ooooo063oo`8000Ooo`8000;oo`800003ool0000000Goo`D000Koo`8000Go
o`8000_oo`8007Koo`03003ooooo007oo`004_oo00<00?ooool0Dooo10003Ooo0P000ooo0P000_oo
0P0000?oo`0000001ooo10001Ooo0P001?oo1P002?oo0P004Ooo0P00Hooo00<00?ooool00Ooo000B
ool00`00ooooo`19ool30007ool4000=ool20003ool200000ooo00000002ool20008ool30004ool2
0005ool200001?oo000000003Ooo0P003?oo0P00Hooo00<00?ooool00Ooo000Bool2000Zool2000N
ool30004ool20006ool20002ool20002ool50007ool2000<ool20002ool200000ooo0000000Bool2
0003ool30004ool2001Zool20003ool001;oo`03003ooooo02Woo`8002Goo`@000Coo`8000;oo`80
00;oo`D000Coo`@000koo`800003ool0000001Goo`8000?oo`8000Goo`8006_oo`03003ooooo007o
o`004_oo00<00?ooool05?oo0P00;ooo0`001Ooo0P000_oo10002Ooo10001ooo10003_oo0P00TOoo
00<00?ooool00Ooo000Bool00`00ooooo`0Dool2000Mool3000?ool30005ool20004ool20003ool4
0002ool2000Eool2000>ool20005ool20020ool00`00ooooo`01ool001;oo`03003ooooo03?oo`<0
01;oo`8000_oo`800003ool00000008000?oo`8001Coo`8000Goo`8000Ooo`8000?oo`D007ooo`03
003ooooo007oo`004_oo0P00BOoo0P002ooo0P000_oo0`000ooo0P005?oo0P001Ooo0`002ooo0P00
00?oo`000000O_oo0P000ooo000Bool00`00ooooo`16ool2000Aool30009ool20005ool2000<ool5
000?ool2001nool00`00ooooo`01ool001;oo`03003ooooo04Koo`8000Goo`8000Coo`80013oo`80
00Coo`D00003ool0000000;oo`8000?oo`8001;oo`8001?oo`8006Woo`03003ooooo007oo`002Ooo
1@001?oo00<00?ooool0COoo0P001?oo0P0000?oo`0000001Ooo0P003?oo0P0000Coo`00003oo`80
00;oo`8000Ooo`8000[oo`8000Soo`8000goo`8006Woo`03003ooooo007oo`002ooo00<00?ooool0
1?oo00<00?ooool0=Ooo10003?oo0P003ooo0`001?oo0P001ooo0P003ooo0P0000?oo`0000001000
2_oo0P002?oo0P00N?oo00<00?ooool00Ooo000;ool00`00ooooo`04ool2000fool4000<ool20005
ool20006ool200000ooo00000002ool20009ool20006ool20007ool200000ooo00000002002?ool2
0003ool000_oo`03003ooooo00Coo`03003ooooo03Soo`8001;oo`@000Coo`800003ool0000000;o
o`80017oo`8009koo`03003ooooo007oo`002ooo00<00?ooool01?oo00<00?ooool0>?oo0P005?oo
0P000_oo0P000_oo0`006ooo0P001_oo0P00T?oo00<00?ooool00Ooo000:ool20006ool00`00oooo
o`0hool20004ool20006ool20006ool20002ool20002ool2000Lool20006ool4002>ool00`00oooo
o`01ool001;oo`03003ooooo03Coo`8000;oo`8000Coo`8000Koo`8000Koo`8001[oo`8001;oo`80
08koo`03003ooooo007oo`004_oo0P009ooo0P003?oo0P007?oo0P005_oo0P005ooo0P002Ooo0P00
OOoo0P000ooo000Bool00`00ooooo`0Vool2000<ool2000Iool200000ooo0000000:ool20008ool2
0002ool20006ool2000=ool20009ool2001nool00`00ooooo`01ool001;oo`03003ooooo03Coo`80
01Soo`@000coo`8000Soo`<00003ool0000000Koo`8009Soo`03003ooooo007oo`004_oo00<00?oo
ool0:Ooo0P005?oo0P003Ooo10005ooo0P00Xooo00<00?ooool00Ooo000Bool00`00ooooo`0Yool2
000Dool20004ool2000Sool2002Rool00`00ooooo`01ool001;oo`80043oo`800004ool00000ool2
000Mool20002ool4002Qool20003ool001;oo`03003ooooo04;oo`80017oo`8000?oo`8000Soo`80
00;oo`8000Koo`8009coo`03003ooooo007oo`004_oo00<00?ooool0>_oo0`001ooo0P003ooo0P00
0ooo0P005?oo0P00W?oo00<00?ooool00Ooo000Bool00`00ooooo`0jool30007ool20003ool20009
ool20003ool2002cool00`00ooooo`01ool001;oo`03003ooooo04Woo`8000Woo`8000?oo`8001Go
o`8009coo`03003ooooo007oo`004_oo0P006?oo0P007?oo0P001?oo0P002?oo0P004ooo0P005?oo
0`001?oo0P00U?oo0P000ooo000Bool00`00ooooo`0Gool2000Lool20004ool20008ool2000Cool2
000Eool20004ool2002Eool00`00ooooo`01ool001;oo`03003ooooo03_oo`8000Coo`800003ool0
0000013oo`800;Koo`03003ooooo007oo`004_oo00<00?ooool0>ooo0P001?oo0P0000?oo`000000
4?oo0P004Ooo0P00Xooo00<00?ooool00Ooo000Bool00`00ooooo`0;ool2000jool2000>ool2000@
ool2002Sool00`00ooooo`01ool001;oo`8000coo`8003[oo`8000koo`8000ooo`800:?oo`8000?o
o`004_oo00<00?ooool08?oo0P002?oo0P00??oo0P00Y?oo00<00?ooool00Ooo000Bool00`00oooo
o`0Pool20008ool2000Fool2003:ool00`00ooooo`01ool001;oo`03003ooooo00;oo`8003koo`80
00[oo`800003ool000000;_oo`03003ooooo007oo`002_oo0`001Ooo00<00?ooool00_oo0P00B_oo
0P0000?oo`000000^ooo00<00?ooool00Ooo000:ool00`00ooooo`05ool00`00ooooo`1Cool2002i
ool00`00ooooo`01ool000_oo`03003ooooo00Coo`8005Coo`800;Soo`8000?oo`002ooo00<00?oo
ool01?oo00<00?ooool05ooo0P00A?oo0P00[ooo00<00?ooool00Ooo000:ool00`00ool00005ool0
0`00ooooo`0Gool2000^ool2000=ool40003ool2002_ool00`00ooooo`01ool000_oo`03003ooooo
00Coo`03003ooooo00[oo`8003_oo`8000goo`@00;Coo`03003ooooo007oo`004_oo00<00?ooool0
2_oo0P00oooo0ooo00<00?ooool00Ooo000Bool2000Zool2003Rool20003ool001;oo`03003ooooo
02Woo`800>?oo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000Bool0
0`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo01ooo`800>goo`03003ooooo007o
o`004_oo0P008?oo0P00k?oo0P000ooo000Bool00`00ooooo`06ool2000nool20036ool00`00oooo
o`01ool001;oo`03003ooooo00Koo`8003koo`800<Koo`03003ooooo007oo`004_oo00<00?ooool0
oooo3ooo00<00?ooool00Ooo000Bool00`00ooooo`0Iool2000Cool2003Nool00`00ooooo`01ool0
01;oo`8001[oo`8001?oo`800=goo`8000?oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo
000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo01[oo`800?;oo`03003o
oooo007oo`004_oo00<00?ooool06_oo0P00l_oo00<00?ooool00Ooo000Bool2003oool?ool20003
ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?oo
ool00Ooo000:ool20006ool00`00ooooo`3oool?ool00`00ooooo`01ool000coo`03003ooooo00?o
o`03003ooooo0?ooo`ooo`03003ooooo007oo`002ooo00<00?ooool01?oo0P00oooo3ooo0P000ooo
000<ool00`00ooooo`03ool00`00ooooo`3oool?ool00`00ooooo`01ool000[oo`03003oo`0000Go
o`03003ooooo0?ooo`ooo`03003ooooo007oo`002ooo00<00?ooool01?oo00<00?ooool0oooo3ooo
00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`8000_oo`800?oo
o`;oo`8000?oo`004_oo00<00?ooool02_oo0P00oooo0ooo00<00?ooool00Ooo000Bool00`00oooo
o`3oool?ool00`00ooooo`01ool001;oo`04003ooooo0008ool00`00ooooo`06ool00`00ooooo`06
ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`03ool00`00ooooo`01ool001;oool001<0
00?oo`00\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.49356, -3.78823, \
0.0227773, 0.0394673}}]
}, Open  ]],

Cell["\<\
We generate 500 pairs of random numbers with 0. as the correlation \
coefficient. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.24"}],

Cell["m = Table[chance[0.], {500}];", "Input",
  CellLabel->"In[21]:=",
  CellTags->"S0.1"],

Cell["Here is the corresponding graph. ", "MathCaption",
  CellTags->{"S0.1", "1.25"}],

Cell[CellGroupData[{

Cell["ListPlot[m];", "Input",
  CellLabel->"In[22]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.546328 0.186916 0.325692 0.104515 [
[.1725 -0.0125 -6 -9 ]
[.1725 -0.0125 6 0 ]
[.35941 -0.0125 -6 -9 ]
[.35941 -0.0125 6 0 ]
[.54633 -0.0125 -3 -9 ]
[.54633 -0.0125 3 0 ]
[.73324 -0.0125 -3 -9 ]
[.73324 -0.0125 3 0 ]
[.92016 -0.0125 -3 -9 ]
[.92016 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01215 -12 -4.5 ]
[-0.0125 .01215 0 4.5 ]
[-0.0125 .11666 -12 -4.5 ]
[-0.0125 .11666 0 4.5 ]
[-0.0125 .22118 -12 -4.5 ]
[-0.0125 .22118 0 4.5 ]
[-0.0125 .32569 -6 -4.5 ]
[-0.0125 .32569 0 4.5 ]
[-0.0125 .43021 -6 -4.5 ]
[-0.0125 .43021 0 4.5 ]
[-0.0125 .53472 -6 -4.5 ]
[-0.0125 .53472 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1725 0 m
.1725 .00625 L
s
[(-2)] .1725 -0.0125 0 1 Mshowa
.35941 0 m
.35941 .00625 L
s
[(-1)] .35941 -0.0125 0 1 Mshowa
.54633 0 m
.54633 .00625 L
s
[(0)] .54633 -0.0125 0 1 Mshowa
.73324 0 m
.73324 .00625 L
s
[(1)] .73324 -0.0125 0 1 Mshowa
.92016 0 m
.92016 .00625 L
s
[(2)] .92016 -0.0125 0 1 Mshowa
.125 Mabswid
.20988 0 m
.20988 .00375 L
s
.24726 0 m
.24726 .00375 L
s
.28465 0 m
.28465 .00375 L
s
.32203 0 m
.32203 .00375 L
s
.3968 0 m
.3968 .00375 L
s
.43418 0 m
.43418 .00375 L
s
.47156 0 m
.47156 .00375 L
s
.50894 0 m
.50894 .00375 L
s
.58371 0 m
.58371 .00375 L
s
.62109 0 m
.62109 .00375 L
s
.65848 0 m
.65848 .00375 L
s
.69586 0 m
.69586 .00375 L
s
.77063 0 m
.77063 .00375 L
s
.80801 0 m
.80801 .00375 L
s
.84539 0 m
.84539 .00375 L
s
.88278 0 m
.88278 .00375 L
s
.13511 0 m
.13511 .00375 L
s
.09773 0 m
.09773 .00375 L
s
.06035 0 m
.06035 .00375 L
s
.02296 0 m
.02296 .00375 L
s
.95754 0 m
.95754 .00375 L
s
.99493 0 m
.99493 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01215 m
.00625 .01215 L
s
[(-3)] -0.0125 .01215 1 0 Mshowa
0 .11666 m
.00625 .11666 L
s
[(-2)] -0.0125 .11666 1 0 Mshowa
0 .22118 m
.00625 .22118 L
s
[(-1)] -0.0125 .22118 1 0 Mshowa
0 .32569 m
.00625 .32569 L
s
[(0)] -0.0125 .32569 1 0 Mshowa
0 .43021 m
.00625 .43021 L
s
[(1)] -0.0125 .43021 1 0 Mshowa
0 .53472 m
.00625 .53472 L
s
[(2)] -0.0125 .53472 1 0 Mshowa
.125 Mabswid
0 .03305 m
.00375 .03305 L
s
0 .05395 m
.00375 .05395 L
s
0 .07486 m
.00375 .07486 L
s
0 .09576 m
.00375 .09576 L
s
0 .13757 m
.00375 .13757 L
s
0 .15847 m
.00375 .15847 L
s
0 .17937 m
.00375 .17937 L
s
0 .20027 m
.00375 .20027 L
s
0 .24208 m
.00375 .24208 L
s
0 .26298 m
.00375 .26298 L
s
0 .28389 m
.00375 .28389 L
s
0 .30479 m
.00375 .30479 L
s
0 .34659 m
.00375 .34659 L
s
0 .3675 m
.00375 .3675 L
s
0 .3884 m
.00375 .3884 L
s
0 .4093 m
.00375 .4093 L
s
0 .45111 m
.00375 .45111 L
s
0 .47201 m
.00375 .47201 L
s
0 .49292 m
.00375 .49292 L
s
0 .51382 m
.00375 .51382 L
s
0 .55562 m
.00375 .55562 L
s
0 .57653 m
.00375 .57653 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.1725 .61178 m
.1725 .61803 L
s
.35941 .61178 m
.35941 .61803 L
s
.54633 .61178 m
.54633 .61803 L
s
.73324 .61178 m
.73324 .61803 L
s
.92016 .61178 m
.92016 .61803 L
s
.125 Mabswid
.20988 .61428 m
.20988 .61803 L
s
.24726 .61428 m
.24726 .61803 L
s
.28465 .61428 m
.28465 .61803 L
s
.32203 .61428 m
.32203 .61803 L
s
.3968 .61428 m
.3968 .61803 L
s
.43418 .61428 m
.43418 .61803 L
s
.47156 .61428 m
.47156 .61803 L
s
.50894 .61428 m
.50894 .61803 L
s
.58371 .61428 m
.58371 .61803 L
s
.62109 .61428 m
.62109 .61803 L
s
.65848 .61428 m
.65848 .61803 L
s
.69586 .61428 m
.69586 .61803 L
s
.77063 .61428 m
.77063 .61803 L
s
.80801 .61428 m
.80801 .61803 L
s
.84539 .61428 m
.84539 .61803 L
s
.88278 .61428 m
.88278 .61803 L
s
.13511 .61428 m
.13511 .61803 L
s
.09773 .61428 m
.09773 .61803 L
s
.06035 .61428 m
.06035 .61803 L
s
.02296 .61428 m
.02296 .61803 L
s
.95754 .61428 m
.95754 .61803 L
s
.99493 .61428 m
.99493 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01215 m
1 .01215 L
s
.99375 .11666 m
1 .11666 L
s
.99375 .22118 m
1 .22118 L
s
.99375 .32569 m
1 .32569 L
s
.99375 .43021 m
1 .43021 L
s
.99375 .53472 m
1 .53472 L
s
.125 Mabswid
.99625 .03305 m
1 .03305 L
s
.99625 .05395 m
1 .05395 L
s
.99625 .07486 m
1 .07486 L
s
.99625 .09576 m
1 .09576 L
s
.99625 .13757 m
1 .13757 L
s
.99625 .15847 m
1 .15847 L
s
.99625 .17937 m
1 .17937 L
s
.99625 .20027 m
1 .20027 L
s
.99625 .24208 m
1 .24208 L
s
.99625 .26298 m
1 .26298 L
s
.99625 .28389 m
1 .28389 L
s
.99625 .30479 m
1 .30479 L
s
.99625 .34659 m
1 .34659 L
s
.99625 .3675 m
1 .3675 L
s
.99625 .3884 m
1 .3884 L
s
.99625 .4093 m
1 .4093 L
s
.99625 .45111 m
1 .45111 L
s
.99625 .47201 m
1 .47201 L
s
.99625 .49292 m
1 .49292 L
s
.99625 .51382 m
1 .51382 L
s
.99625 .55562 m
1 .55562 L
s
.99625 .57653 m
1 .57653 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.52671 .45975 Mdot
.69381 .502 Mdot
.44502 .27243 Mdot
.70101 .36764 Mdot
.52625 .27321 Mdot
.27198 .34227 Mdot
.88524 .29983 Mdot
.33208 .39578 Mdot
.14296 .46551 Mdot
.26457 .46832 Mdot
.57881 .33486 Mdot
.84739 .3396 Mdot
.60562 .30592 Mdot
.7929 .49562 Mdot
.55864 .17161 Mdot
.31222 .44167 Mdot
.32667 .43633 Mdot
.62315 .1938 Mdot
.33909 .3776 Mdot
.83871 .24596 Mdot
.52013 .34946 Mdot
.68798 .31985 Mdot
.47038 .06777 Mdot
.63155 .35937 Mdot
.54662 .30377 Mdot
.57376 .22969 Mdot
.34924 .26142 Mdot
.40871 .28683 Mdot
.70827 .25018 Mdot
.51442 .41005 Mdot
.64239 .10632 Mdot
.37009 .03597 Mdot
.50867 .16471 Mdot
.46074 .27915 Mdot
.58361 .24858 Mdot
.59381 .36646 Mdot
.63626 .21579 Mdot
.88114 .44641 Mdot
.34073 .39787 Mdot
.18716 .39599 Mdot
.68776 .2371 Mdot
.26234 .40203 Mdot
.37846 .30711 Mdot
.41473 .4366 Mdot
.52056 .10426 Mdot
.57471 .43129 Mdot
.60203 .29494 Mdot
.63002 .30284 Mdot
.8268 .41934 Mdot
.72933 .47181 Mdot
.63356 .31395 Mdot
.50002 .25015 Mdot
.84032 .22513 Mdot
.32476 .4126 Mdot
.25026 .46308 Mdot
.76035 .25057 Mdot
.69944 .3893 Mdot
.72795 .3089 Mdot
.45672 .37637 Mdot
.42135 .21573 Mdot
.27267 .2846 Mdot
.55646 .26862 Mdot
.8888 .28044 Mdot
.3102 .29598 Mdot
.36887 .47665 Mdot
.52314 .14639 Mdot
.21127 .27563 Mdot
.6476 .40633 Mdot
.73132 .40371 Mdot
.54972 .36747 Mdot
.51418 .31531 Mdot
.17348 .39463 Mdot
.5011 .30347 Mdot
.49329 .59544 Mdot
.48269 .28459 Mdot
.35258 .18257 Mdot
.81527 .51276 Mdot
.60574 .21423 Mdot
.58112 .09634 Mdot
.26328 .38983 Mdot
.43887 .19257 Mdot
.38306 .4308 Mdot
.6159 .28028 Mdot
.78971 .3693 Mdot
.53518 .43727 Mdot
.66312 .36525 Mdot
.80574 .42589 Mdot
.6014 .22405 Mdot
.21339 .23814 Mdot
.25165 .2219 Mdot
.40657 .3024 Mdot
.57214 .15876 Mdot
.68519 .32077 Mdot
.57998 .31372 Mdot
.38239 .11791 Mdot
.72521 .534 Mdot
.40009 .25163 Mdot
.66536 .32605 Mdot
.60034 .23569 Mdot
.80384 .30161 Mdot
.33607 .37939 Mdot
.59876 .27521 Mdot
.72668 .23844 Mdot
.65975 .26745 Mdot
.34175 .38046 Mdot
.56169 .36978 Mdot
.46683 .26622 Mdot
.62745 .24449 Mdot
.56341 .28387 Mdot
.66507 .35787 Mdot
.54632 .1977 Mdot
.17997 .34147 Mdot
.26302 .41567 Mdot
.60835 .16731 Mdot
.47913 .06324 Mdot
.20453 .44829 Mdot
.72008 .30903 Mdot
.3452 .30599 Mdot
.37753 .26094 Mdot
.67717 .07132 Mdot
.24562 .40689 Mdot
.48147 .38555 Mdot
.71802 .42824 Mdot
.31511 .32568 Mdot
.53833 .44232 Mdot
.91492 .17577 Mdot
.94798 .298 Mdot
.48981 .21625 Mdot
.37371 .33658 Mdot
.73114 .3765 Mdot
.50152 .24146 Mdot
.7397 .29444 Mdot
.29054 .37625 Mdot
.1245 .38219 Mdot
.42061 .51699 Mdot
.57348 .30399 Mdot
.66005 .25755 Mdot
.52276 .37774 Mdot
.61011 .23813 Mdot
.24596 .25413 Mdot
.63489 .1404 Mdot
.48933 .4968 Mdot
.45502 .27753 Mdot
.74903 .14585 Mdot
.6473 .33753 Mdot
.4464 .38971 Mdot
.55422 .4163 Mdot
.45972 .50307 Mdot
.73218 .41787 Mdot
.39705 .34402 Mdot
.78109 .25735 Mdot
.6006 .12987 Mdot
.2564 .42564 Mdot
.49287 .24372 Mdot
.71568 .22429 Mdot
.07165 .35377 Mdot
.5296 .01472 Mdot
.72277 .35062 Mdot
.50988 .336 Mdot
.50019 .31366 Mdot
.27821 .37919 Mdot
.54827 .34802 Mdot
.37793 .39365 Mdot
.79545 .26166 Mdot
.71883 .2166 Mdot
.61437 .35366 Mdot
.93469 .39541 Mdot
.59821 .37365 Mdot
.87264 .4461 Mdot
.84606 .42097 Mdot
.33973 .36387 Mdot
.54359 .28556 Mdot
.34378 .22485 Mdot
.32357 .25477 Mdot
.5607 .27612 Mdot
.18476 .40951 Mdot
.69038 .32338 Mdot
.73952 .49659 Mdot
.48799 .3874 Mdot
.8405 .29278 Mdot
.50147 .42666 Mdot
.71843 .40781 Mdot
.35525 .34721 Mdot
.66976 .08978 Mdot
.9613 .51272 Mdot
.45489 .37767 Mdot
.57348 .26929 Mdot
.59663 .2094 Mdot
.45976 .22878 Mdot
.59513 .25802 Mdot
.47182 .15475 Mdot
.68169 .35185 Mdot
.47121 .31502 Mdot
.97619 .40583 Mdot
.39619 .1869 Mdot
.43516 .49638 Mdot
.67506 .2387 Mdot
.77142 .35237 Mdot
.52334 .2628 Mdot
.30677 .3182 Mdot
.4542 .39916 Mdot
.6768 .31071 Mdot
.49237 .33229 Mdot
.57789 .07075 Mdot
.78131 .19644 Mdot
.42759 .35267 Mdot
.50046 .28374 Mdot
.55213 .24331 Mdot
.40816 .34702 Mdot
.61923 .14424 Mdot
.66235 .38085 Mdot
.60454 .42685 Mdot
.63287 .40797 Mdot
.66139 .16711 Mdot
.28506 .3072 Mdot
.50133 .34468 Mdot
.69376 .37148 Mdot
.53122 .51208 Mdot
.55903 .31483 Mdot
.67493 .31691 Mdot
.59775 .31348 Mdot
.21425 .40769 Mdot
.24696 .29883 Mdot
.75909 .22854 Mdot
.78651 .27604 Mdot
.79877 .37198 Mdot
.39052 .32667 Mdot
.47159 .40159 Mdot
.2223 .25197 Mdot
.1979 .22045 Mdot
.48969 .23989 Mdot
.39793 .35862 Mdot
.18541 .35561 Mdot
.44598 .34595 Mdot
.55554 .20784 Mdot
.34533 .31163 Mdot
.86737 .35914 Mdot
.41155 .51906 Mdot
.86023 .34553 Mdot
.50552 .31232 Mdot
.21067 .18519 Mdot
.45318 .31518 Mdot
.39752 .42162 Mdot
.61346 .38719 Mdot
.5182 .30447 Mdot
.39273 .39881 Mdot
.4311 .34868 Mdot
.53419 .17682 Mdot
.42102 .32973 Mdot
.44365 .23944 Mdot
.61806 .35191 Mdot
.51025 .42091 Mdot
.40636 .20017 Mdot
.5476 .26041 Mdot
.18841 .36951 Mdot
.03134 .4476 Mdot
.49219 .3171 Mdot
.51305 .15528 Mdot
.36055 .35592 Mdot
.6661 .08939 Mdot
.58516 .58292 Mdot
.24741 .2198 Mdot
.45142 .35364 Mdot
.46884 .23162 Mdot
.85165 .30661 Mdot
.52702 .40295 Mdot
.19472 .45314 Mdot
.17284 .47501 Mdot
.66784 .29759 Mdot
.52106 .37637 Mdot
.77331 .25425 Mdot
.43623 .33401 Mdot
.81439 .4405 Mdot
.85594 .25693 Mdot
.68716 .28791 Mdot
.5275 .16127 Mdot
.54371 .50429 Mdot
.44436 .34806 Mdot
.85483 .15238 Mdot
.71903 .39434 Mdot
.27112 .30281 Mdot
.50255 .31849 Mdot
.38607 .46273 Mdot
.02741 .18186 Mdot
.18892 .50589 Mdot
.59857 .2033 Mdot
.62232 .30969 Mdot
.39799 .3099 Mdot
.70054 .36363 Mdot
.54554 .29495 Mdot
.22496 .36844 Mdot
.43922 .33811 Mdot
.40363 .35755 Mdot
.62221 .40396 Mdot
.63734 .21486 Mdot
.34551 .22961 Mdot
.5865 .33008 Mdot
.45617 .13201 Mdot
.49836 .60332 Mdot
.30885 .17287 Mdot
.40184 .44265 Mdot
.39038 .29781 Mdot
.59556 .41402 Mdot
.51056 .18021 Mdot
.21678 .43783 Mdot
.46963 .201 Mdot
.48347 .33456 Mdot
.22783 .49177 Mdot
.68489 .14363 Mdot
.5898 .30691 Mdot
.83855 .50016 Mdot
.3414 .23231 Mdot
.35648 .297 Mdot
.63306 .35144 Mdot
.67935 .23966 Mdot
.27416 .44816 Mdot
.41961 .42908 Mdot
.33344 .52298 Mdot
.7868 .4181 Mdot
.3166 .38146 Mdot
.6197 .30887 Mdot
.47321 .33438 Mdot
.24868 .28202 Mdot
.32533 .32562 Mdot
.69279 .37603 Mdot
.54148 .18726 Mdot
.60654 .37733 Mdot
.83808 .34 Mdot
.60117 .15283 Mdot
.95562 .27318 Mdot
.57366 .39208 Mdot
.63957 .44238 Mdot
.69925 .1303 Mdot
.27802 .16596 Mdot
.49641 .44887 Mdot
.35019 .58634 Mdot
.58632 .21935 Mdot
.60698 .31829 Mdot
.6716 .27076 Mdot
.49373 .36292 Mdot
.80611 .12004 Mdot
.56791 .29605 Mdot
.68094 .34158 Mdot
.42842 .36139 Mdot
.58528 .17363 Mdot
.6191 .40507 Mdot
.42987 .34666 Mdot
.45359 .35831 Mdot
.48064 .30211 Mdot
.20442 .32716 Mdot
.7013 .29665 Mdot
.56596 .32604 Mdot
.53558 .34156 Mdot
.18238 .29091 Mdot
.29484 .15454 Mdot
.40956 .39186 Mdot
.5849 .30523 Mdot
.5515 .43083 Mdot
.82627 .33955 Mdot
.4905 .21548 Mdot
.72884 .20688 Mdot
.38987 .35803 Mdot
.53844 .39241 Mdot
.7508 .38526 Mdot
.40701 .33958 Mdot
.58719 .4148 Mdot
.28675 .28107 Mdot
.51616 .4265 Mdot
.62138 .40575 Mdot
.81668 .38916 Mdot
.62179 .17491 Mdot
.58747 .33529 Mdot
.5289 .22908 Mdot
.52593 .50448 Mdot
.91259 .24866 Mdot
.48901 .20411 Mdot
.42282 .33221 Mdot
.40619 .38954 Mdot
.649 .32955 Mdot
.6209 .38411 Mdot
.31614 .4173 Mdot
.88488 .26537 Mdot
.42764 .33571 Mdot
.32582 .25141 Mdot
.5952 .45502 Mdot
.57878 .41955 Mdot
.36947 .37331 Mdot
.61153 .09643 Mdot
.59025 .45786 Mdot
.45252 .24089 Mdot
.43708 .38548 Mdot
.67352 .48827 Mdot
.44771 .28369 Mdot
.25879 .18784 Mdot
.8107 .12814 Mdot
.82413 .31766 Mdot
.4424 .48953 Mdot
.47437 .26241 Mdot
.50965 .46137 Mdot
.7497 .21626 Mdot
.40516 .40867 Mdot
.49745 .21311 Mdot
.78346 .29202 Mdot
.62403 .35196 Mdot
.53608 .27062 Mdot
.30484 .20191 Mdot
.91456 .38972 Mdot
.69069 .34668 Mdot
.20089 .17457 Mdot
.50912 .47925 Mdot
.61313 .25325 Mdot
.27931 .58494 Mdot
.34723 .23115 Mdot
.47965 .32719 Mdot
.53132 .35212 Mdot
.52639 .3222 Mdot
.66305 .33236 Mdot
.88727 .52148 Mdot
.25327 .27758 Mdot
.16541 .39124 Mdot
.63438 .32067 Mdot
.29907 .32653 Mdot
.54746 .42651 Mdot
.49795 .08036 Mdot
.35295 .29858 Mdot
.49757 .357 Mdot
.3539 .16159 Mdot
.68388 .31403 Mdot
.67445 .28176 Mdot
.52996 .23636 Mdot
.70628 .2728 Mdot
.91263 .24305 Mdot
.83605 .45858 Mdot
.61054 .44445 Mdot
.85181 .36774 Mdot
.51309 .36687 Mdot
.8233 .31591 Mdot
.41714 .20721 Mdot
.75343 .38071 Mdot
.54502 .41053 Mdot
.72831 .39944 Mdot
.77399 .32026 Mdot
.34827 .32019 Mdot
.59421 .15434 Mdot
.14566 .26073 Mdot
.7292 .39153 Mdot
.41603 .32981 Mdot
.74506 .22704 Mdot
.28907 .3565 Mdot
.30187 .26294 Mdot
.5014 .43855 Mdot
.49832 .4166 Mdot
.40514 .42275 Mdot
.25979 .2646 Mdot
.86423 .33994 Mdot
.76422 .29868 Mdot
.67056 .34435 Mdot
.63709 .35832 Mdot
.43421 .22571 Mdot
.54768 .44631 Mdot
.47028 .31857 Mdot
.2534 .29365 Mdot
.49232 .38255 Mdot
.14646 .32578 Mdot
.50572 .26321 Mdot
.54596 .24091 Mdot
.10834 .20822 Mdot
.52152 .3791 Mdot
.85949 .24139 Mdot
.54253 .17506 Mdot
.4465 .1906 Mdot
.4402 .44714 Mdot
.59732 .37021 Mdot
.27359 .14314 Mdot
.65363 .41141 Mdot
.65617 .2988 Mdot
.28728 .22001 Mdot
.64209 .09311 Mdot
.57158 .38016 Mdot
.38129 .40664 Mdot
.50917 .36746 Mdot
.74411 .33482 Mdot
.52152 .31647 Mdot
.61121 .37316 Mdot
.50336 .44775 Mdot
.3718 .4964 Mdot
.47561 .42442 Mdot
.42789 .249 Mdot
.31102 .2835 Mdot
.43817 .25619 Mdot
.49557 .23672 Mdot
.75586 .26471 Mdot
.43943 .26208 Mdot
.35841 .49996 Mdot
.40651 .40356 Mdot
.58458 .32858 Mdot
.82642 .31125 Mdot
.76462 .3586 Mdot
.62669 .14271 Mdot
.02381 .18525 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo0012ool3
000_ool5000^ool00`00ooooo`0^ool5000_ool3000Hool004;oo`03003ooooo037oo`03003ooooo
02goo`03003oo`00037oo`03003ooooo02ooo`03003ooooo01Soo`00?Ooo0`000ooo00<00?ooool0
:_oo0`000ooo00<00?ooool0;Ooo00<00?oo0000<Ooo00<00?ooool0<?oo00<00?ooool05ooo0013
ool00`00ooooo`0`ool00`00ooooo`0]ool00`00ool0000aool00`00ooooo`0`ool00`00ooooo`0G
ool004;oo`03003oo`00037oo`03003ooooo02goo`03003oo`00037oo`03003ooooo02ooo`03003o
o`0001Soo`00@ooo00<00?ooool0;ooo0P00<?oo00<00?ooool0;ooo0P00<_oo00<00?ooool05ooo
003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`004_ooo`004`000ooo000Bool0
0`00ooooo`03ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool0
0`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool0
0`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`07ool0
0`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool0
0`00ooooo`08ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool0
0`00ooooo`08ool00`00ooooo`07ool20003ool000[oo`8000Koo`03003ooooo02coo`03003ooooo
033oo`03003ooooo033oo`03003ooooo033oo`03003ooooo033oo`03003ooooo01?oo`03003ooooo
007oo`003?oo00<00?ooool00ooo00<00?ooool0oooo3ooo00<00?ooool00Ooo0005ool30003ool0
0`00ooooo`04ool2002>ool2001nool20003ool000coo`03003ooooo00?oo`03003ooooo08goo`80
07ooo`03003ooooo007oo`002_oo00<00?oo00001Ooo00<00?ooool0oooo3ooo00<00?ooool00Ooo
000;ool00`00ooooo`04ool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo0?oo
o`ooo`03003ooooo007oo`004_oo0P00oooo3ooo0P000ooo000Bool00`00ooooo`1Qool2002[ool0
0`00ooooo`01ool001;oo`03003ooooo067oo`800:_oo`03003ooooo007oo`004_oo00<00?ooool0
oooo3ooo00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003o
oooo0?ooo`ooo`03003ooooo007oo`004_oo0P00oooo3ooo0P000ooo000Bool00`00ooooo`3oool?
ool00`00ooooo`01ool001;oo`03003ooooo07ooo`8008goo`03003ooooo007oo`004_oo00<00?oo
ool0Oooo0P00SOoo00<00?ooool00Ooo000Bool00`00ooooo`1mool2000Kool2001bool00`00oooo
o`01ool001;oo`03003ooooo07goo`8001_oo`8001Woo`8005Ooo`03003ooooo007oo`004_oo0P00
]_oo0P00E_oo0P000ooo000Bool00`00ooooo`24ool20028ool00`00ooooo`01ool001;oo`03003o
oooo08Coo`8008Soo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000B
ool00`00ooooo`2bool3001Iool00`00ooooo`01ool001;oo`03003ooooo09_oo`8000ooo`8000Co
o`<005Woo`03003ooooo007oo`004_oo0P00W?oo0P001_oo0P001ooo0P00Gooo0P000ooo000Bool0
0`00ooooo`2Sool2001Yool00`00ooooo`01ool001;oo`03003ooooo08[oo`80023oo`80063oo`03
003ooooo007oo`002_oo0`001Ooo00<00?ooool0R_oo0P008?oo0P00H?oo00<00?ooool00Ooo000:
ool00`00ooooo`05ool00`00ooooo`3oool?ool00`00ooooo`01ool000Goo`<000?oo`03003ooooo
00Coo`8006Goo`800:Ooo`8000?oo`002ooo00<00?ooool01?oo00<00?ooool0I?oo0P00L_oo0P00
=?oo00<00?ooool00Ooo000:ool00`00ool00005ool00`00ooooo`3Hool2000dool00`00ooooo`01
ool000_oo`03003ooooo00Coo`03003ooooo0=[oo`8003;oo`03003ooooo007oo`004_oo00<00?oo
ool0NOoo0P009Ooo0P006Ooo0P007Ooo0P00<_oo00<00?ooool00Ooo000Bool00`00ooooo`1iool2
000Uool2000Iool2001Aool00`00ooooo`01ool001;oo`800?ooo`ooo`8000?oo`004_oo00<00?oo
ool0Aooo0P00G_oo0P0000?oo`0000002ooo0P00EOoo00<00?ooool00Ooo000Bool00`00ooooo`17
ool20012ool2000Hool400000ooo0000000;ool2000@ool20013ool00`00ooooo`01ool001;oo`03
003ooooo08_oo`8001Soo`8002;oo`8004?oo`03003ooooo007oo`004_oo00<00?ooool0C?oo0P00
;ooo0P007ooo1000A?oo0P009_oo00<00?ooool00Ooo000Bool00`00ooooo`1<ool2000_ool20009
ool2000Dool40014ool2000Vool00`00ooooo`01ool001;oo`8005koo`8002Woo`8000;oo`8000[o
o`8007?oo`8000?oo`004_oo00<00?ooool0GOoo0P00:?oo0P000ooo0P002_oo0P00M?oo00<00?oo
ool00Ooo000Bool00`00ooooo`18ool2000mool2000Iool2000=ool2001Kool00`00ooooo`01ool0
01;oo`03003ooooo04Soo`8000Koo`8004?oo`8000_oo`8000goo`8005_oo`03003ooooo007oo`00
4_oo00<00?ooool0<ooo0P006ooo0P00?_oo0P000ooo0P001Ooo0P002?oo0P00C_oo0P005_oo00<0
0?ooool00Ooo000Bool2000dool2001Cool20004ool4000:ool20008ool2001>ool2000Eool20003
ool001;oo`03003ooooo00?oo`8005Ooo`8002[oo`8000Coo`8007koo`03003ooooo007oo`004_oo
00<00?ooool00_oo0`00<?oo0P009Ooo0P002_oo0P009_oo0P00O?oo00<00?ooool00Ooo000Bool0
0`00ooooo`02ool2000aool2000<ool2000Sool2000<ool2000Hool2001lool00`00ooooo`01ool0
01;oo`03003ooooo04?oo`8002ooo`@002koo`8006Koo`03003ooooo007oo`004_oo00<00?ooool0
M?oo0P006ooo0P004ooo0P00:_oo0P00>_oo00<00?ooool00Ooo000Bool2001@ool2000Jool2000?
ool2000Cool2000oool2000iool20003ool001;oo`03003ooooo04ooo`8001[oo`8000ooo`8000Co
o`8001coo`8006coo`03003ooooo007oo`004_oo00<00?ooool06Ooo0P00Dooo0P004_oo0P004?oo
0P002Ooo0`008Ooo0P00BOoo00<00?ooool00Ooo000Bool00`00ooooo`0Iool2001Cool2000Dool2
000>ool20009ool2000Rool20019ool00`00ooooo`01ool000Woo`D000Coo`03003ooooo06ooo`80
017oo`@001coo`8000Koo`8001Goo`8000Koo`8004?oo`03003ooooo007oo`002ooo00<00?ooool0
1?oo00<00?ooool0<_oo0P002ooo0P002Ooo0P008ooo0P004Ooo0P006?oo0P001?oo0P001_oo0P00
5Ooo0P001_oo0P00@ooo00<00?ooool00Ooo0005ool30003ool00`00ooooo`04ool2000cool2000;
ool40007ool2001@ool20002ool2001[ool20003ool000_oo`03003ooooo00Coo`03003ooooo047o
o`8001Ooo`8001Ooo`8002_oo`8001koo`8000Koo`8001Soo`8002[oo`03003ooooo007oo`002ooo
00<00?ooool01?oo00<00?ooool0F_oo0`005_oo0P001Ooo0P004Ooo0P002_oo0P009Ooo0P001_oo
0P000_oo0P005?oo0P00:_oo00<00?ooool00Ooo000:ool20006ool00`00ooooo`1Iool4000Mool4
000?ool2000:ool2000aool20010ool00`00ooooo`01ool001;oo`03003ooooo03Koo`80027oo`80
027oo`8000Goo`8000Soo`80017oo`800003ool00000013oo`800003ool0000000Woo`8004Woo`03
003ooooo007oo`004_oo00<00?ooool0=_oo0P00?Ooo0P0000?oo`0000002?oo1@001_oo0P000_oo
0P003Ooo0P0000?oo`0000004?oo1@002Ooo0P008_oo0P009Ooo00<00?ooool00Ooo000Bool2001f
ool200000ooo00000008ool5000:ool4000Cool2000<ool2000Yool20004ool2000=ool2000Eool2
0003ool001;oo`03003ooooo077oo`80013oo`8000koo`8000Ooo`8000[oo`8003Ooo`8001?oo`80
01Koo`03003ooooo007oo`004_oo00<00?ooool0>Ooo0P006_oo0P004_oo0P001_oo0P004_oo0P00
5Ooo0P001_oo0P006?oo0P003?oo0P00:?oo0P005_oo00<00?ooool00Ooo000Bool00`00ooooo`0i
ool20004ool2000Cool3000Bool20009ool2000?ool2000Mool2000Hool2000<ool200000ooo0000
000Eool2000Vool00`00ooooo`01ool001;oo`03003ooooo02Coo`8001Woo`8001?oo`8001koo`80
01coo`8000_oo`8000ooo`8001goo`800003ool0000001;oo`8002Koo`03003ooooo007oo`004_oo
0P009Ooo0P00:?oo0P002ooo0P001_oo0P003ooo0P002?oo0P001_oo0P000ooo0P001Ooo0P002ooo
0P003ooo0P008?oo0P000_oo0P00=Ooo0P000ooo000Bool00`00ooooo`13ool20009ool2000;ool2
0006ool2000?ool20006ool40006ool20003ool2000Sool2000Iool20009ool2000Fool2000Nool0
0`00ooooo`01ool001;oo`03003ooooo04?oo`8003Ooo`80013oo`8000Coo`8000?oo`8001Goo`80
00;oo`8001Goo`80027oo`8001koo`03003ooooo007oo`004_oo00<00?ooool0M_oo0P005?oo1000
1?oo0P000ooo0P001Ooo0P004_oo0P001ooo0P00@_oo0P002ooo00<00?ooool00Ooo000Bool00`00
ooooo`0fool20009ool2000cool4000Bool20007ool20009ool2000Kool2000Dool2000/ool2000;
ool00`00ooooo`01ool001;oo`03003ooooo03Koo`8000Soo`<000Ooo`8002coo`@001Woo`8000go
o`8000koo`8001goo`8001[oo`8001goo`03003ooooo007oo`004_oo0P00@Ooo0P001?oo0P000_oo
0P001Ooo0P008ooo0P000_oo0P001?oo0P000ooo0P002_oo0P000ooo0P003?oo0P003_oo0P00>Ooo
0P007?oo0P000ooo000Bool00`00ooooo`16ool20009ool2000Iool20008ool20008ool20003ool2
000:ool20003ool2000Pool2001Dool00`00ooooo`01ool001;oo`03003ooooo02koo`8003coo`80
04[oo`8001Soo`8000koo`8002[oo`03003ooooo007oo`004_oo00<00?ooool0;_oo0P004Ooo0P00
3_oo0P002_oo0P00<_oo0P001?oo0P002?oo0P006Ooo0P002?oo0P002_oo0P003_oo0P00:_oo00<0
0?ooool00Ooo000Bool00`00ooooo`0oool4000>ool20009ool30008ool2000Xool20004ool20008
ool2000<ool20002ool20007ool20008ool20005ool2000Oool2000?ool2000=ool00`00ooooo`01
ool001;oo`03003ooooo03ooo`8000Goo`8001Coo`8000Woo`8000;oo`8001;oo`8000Coo`8000?o
o`8000Goo`8000Koo`8000goo`8000Goo`8000;oo`8001Soo`8000Woo`8001Coo`8000ooo`8000go
o`03003ooooo007oo`004_oo0P00Aooo0P000_oo0P003_oo0P001ooo0P001_oo0P004_oo0P001?oo
0P000ooo0P001Ooo0P001_oo0P0000Coo`00000000?oo`8000Coo`8002koo`8000_oo`8002Koo`80
00?oo`004_oo00<00?ooool0B_oo0P003_oo0P001ooo0P001?oo0P00<Ooo0`000ooo0P0000Coo`00
000000goo`8000[oo`@001Woo`8000Goo`8002Ooo`03003ooooo007oo`004_oo00<00?ooool0F_oo
0P003Ooo0P003Ooo0P000ooo0P001_oo0`0000?oo`0000002_oo0P001?oo0P000_oo0P001?oo0`00
00?oo`0000002_oo10002?oo10006Ooo0P00;_oo00<00?ooool00Ooo000;ool00`00ooooo`04ool0
0`00ooooo`1@ool2000Vool20002ool30003ool200001Ooo00000000ool010002?oo0P001?oo0P00
0_oo0P0000?oo`0000001Ooo0P002_oo10009?oo0P00;ooo00<00?ooool00Ooo000:ool00`00ool0
0005ool00`00ooooo`1@ool20009ool2000Oool20004ool200000ooo00000004ool3000Dool20005
ool2000:ool5000Fool2000;ool2000_ool00`00ooooo`01ool000[oo`03003oo`0000Goo`8002Go
o`8002coo`800003ool0000000Coo`8002ooo`8000Woo`80013oo`8000Ooo`8000?oo`@001Goo`80
03_oo`8000?oo`002_oo00<00?oo00001Ooo00<00?ooool09?oo0P003_oo0P006?oo0P000_oo0P00
00?oo`0000004?oo0P001Ooo0`003_oo0P005_oo0P000ooo0P003ooo0P000ooo0P001Ooo0P00Dooo
00<00?ooool00Ooo000:ool00`00ool00005ool00`00ooooo`0dool2000Hool2000Gool20005ool3
000>ool20002ool2000Gool2000?ool20002ool2001Kool00`00ooooo`01ool000_oo`03003ooooo
00Coo`03003ooooo06;oo`8000_oo`H000Soo`800004ool00000ool20002ool2000Aool200000ooo
0000000Bool2000Dool20015ool00`00ooooo`01ool001;oo`03003ooooo06;oo`8000Ooo`8000Co
o`D000Ooo`800003ool0000000Goo`80017oo`800003ool0000000koo`8001Soo`8001Goo`800004
ool00000ool20002ool2000Tool00`00ooooo`01ool001;oo`03003ooooo02goo`8001Ooo`80023o
o`800003ool0000000Ooo`8000ooo`8000Ooo`8001goo`8000Coo`800003ool0000002Koo`800004
ool00000ool20002ool2000Tool00`00ooooo`01ool001;oo`8002koo`8001Ooo`8001Goo`8000Wo
o`800003ool0000000Coo`8000;oo`<000goo`8000Ooo`8000;oo`8001ooo`800004ool00000ool2
000/ool2000Tool20003ool001;oo`03003ooooo05goo`8000coo`8000Coo`<00004ool00000000B
ool20006ool2000Aool6000;ool200000ooo00000007ool2000Sool2000Uool00`00ooooo`01ool0
01;oo`03003ooooo00ooo`8001goo`80047oo`<000?oo`80017oo`800003ool0000001Goo`L000_o
o`8000[oo`8000_oo`8003goo`03003ooooo007oo`004_oo00<00?ooool03ooo0P007Ooo0P006ooo
0P004Ooo0P001_oo0P0000Coo`00000000Goo`8000Coo`<000[oo`8000Ooo`8001Goo`8000?oo`<0
00Koo`8001Woo`@001Soo`8002?oo`03003ooooo007oo`004_oo00<00?ooool0Booo0P004Ooo0P00
1_oo0P0000Coo`00000000Goo`8000Goo`8000Woo`<002?oo`<000Koo`8001Woo`8001[oo`8002?o
o`03003ooooo007oo`004_oo00<00?ooool0FOoo0P005_oo0P004?oo0P006Ooo0P004Ooo0P002Ooo
0P00D?oo00<00?ooool00Ooo000Bool2000`ool20008ool2000Nool2000/ool30008ool20002ool2
0006ool3000@ool20009ool2000Fool2000?ool2000Vool20003ool001;oo`03003ooooo02ooo`80
00Soo`8002Koo`8002Coo`<000Soo`8000;oo`8000Ooo`<00003ool0000001Goo`@001Koo`@000go
o`8002Ooo`03003ooooo007oo`004_oo00<00?ooool0Booo0P003?oo0P001_oo0P005_oo0P003ooo
0P005?oo1@005?oo0`002?oo0P004?oo0P00=_oo00<00?ooool00Ooo000Bool00`00ooooo`18ool2
00000ooo0000000;ool3000Mool3000?ool3000;ool20008ool2000=ool20006ool20009ool20004
ool20012ool00`00ooooo`01ool001;oo`03003ooooo01koo`8002Soo`8000Soo`8000Coo`<001go
o`8000Woo`8000Koo`8000_oo`8000coo`8000Woo`8001Ooo`8004;oo`03003ooooo007oo`004_oo
00<00?ooool07_oo0P00<_oo0P007ooo0P002ooo1@007ooo10008Ooo0P00@ooo00<00?ooool00Ooo
000Bool2000Zool2000Iool2000Uool30005ool200000ooo00000008ool3000Fool20009ool2000E
ool20006ool20004ool2000@ool2000Iool2000Eool20003ool001;oo`03003ooooo02Woo`@001Oo
o`80017oo`8000[oo`8000Koo`<000Soo`8001Ooo`8000Soo`80023oo`8000Coo`@001Koo`8001Wo
o`8000Coo`80013oo`03003ooooo007oo`004_oo00<00?ooool0:ooo0P000_oo0P009_oo10002?oo
0P000_oo0P003ooo0P005Ooo0P00<?oo1000=ooo0P004?oo00<00?ooool00Ooo000Bool00`00oooo
o`0_ool2000Cool2000Cool2000<ool2000?ool20003ool2000=ool2000eool20019ool00`00oooo
o`01ool001;oo`03003ooooo04Coo`8001koo`8000Goo`80013oo`8000goo`8001Ooo`<000Goo`80
01Goo`80047oo`8000Goo`03003ooooo007oo`004_oo0P00;ooo0P001_oo0P001ooo0P008ooo0P00
1Ooo0P007?oo0P006_oo0`0000?oo`0000000_oo0P004Ooo0P000_oo0P00@Ooo0P001?oo0P000ooo
000Bool00`00ooooo`0^ool20006ool20007ool2000Dool2000Dool2000Lool20006ool2000<ool2
0008ool20004ool2000?ool2001<ool00`00ooooo`01ool001;oo`03003ooooo04Coo`8000coo`80
0003ool0000002goo`8000_oo`@000Ooo`800003ool0000000koo`8005goo`03003ooooo007oo`00
4_oo00<00?ooool0A?oo0P003?oo0P00<?oo0P0000?oo`0000002_oo0P001Ooo10009_oo0P003Ooo
0P002Ooo0P000ooo0P00:Ooo00<00?ooool00Ooo0009ool50004ool00`00ooooo`1Yool4000Aool2
0007ool2000Aool2000Xool2000=ool20009ool20003ool2000Yool00`00ooooo`01ool000_oo`03
003ooooo00Coo`03003ooooo04;oo`8002Goo`@0017oo`8000Goo`8000;oo`8000Ooo`8000goo`80
01goo`8001Koo`8003Coo`03003ooooo007oo`002ooo00<00?ooool01?oo0P00@ooo0P008Ooo0P00
2?oo0P005?oo0P000_oo0P001ooo0`001?oo0P001_oo0P007Ooo0P005_oo0P00<ooo0P000ooo000;
ool00`00ooooo`04ool00`00ooooo`1Uool20008ool2000Rool20004ool2001cool00`00ooooo`01
ool000_oo`03003ooooo00Coo`03003ooooo03Ooo`8001coo`8001Koo`8001Koo`8000Ooo`8007ko
o`03003ooooo007oo`002_oo0P001_oo00<00?ooool0=ooo0P006?oo0P000_oo0P004ooo0P0000?o
o`0000005_oo0P001ooo0`006_oo0P00;_oo0P00<Ooo00<00?ooool00Ooo000Bool00`00ooooo`1A
ool2000Gool2000Sool200000ooo0000000?ool20006ool2000^ool2000>ool4000Oool00`00oooo
o`01ool001;oo`03003ooooo00Coo`8002koo`80017oo`8002_oo`8000koo`@000[oo`8000ooo`80
04Koo`@001ooo`03003ooooo007oo`004_oo0P001Ooo0P00:ooo0P0000?oo`0000004Ooo0P00:ooo
0P003_oo1000QOoo0P000ooo000Bool00`00ooooo`0aool2001Zool4001]ool00`00ooooo`01ool0
01;oo`03003ooooo08Ooo`8000?oo`8000ooo`@0043oo`8002_oo`03003ooooo007oo`004_oo00<0
0?ooool0@?oo0P008ooo0P008?oo0P000ooo0P00Dooo0P00:ooo00<00?ooool00Ooo000Bool00`00
ooooo`0Sool2000Kool20002ool2000Oool2002Wool00`00ooooo`01ool001;oo`03003ooooo02?o
o`8001ooo`8007goo`8004Woo`03003ooooo007oo`004_oo0P00;?oo0P00U_oo0P00B?oo0P000ooo
000Bool00`00ooooo`0[ool2000dool2000Tool20025ool00`00ooooo`01ool001;oo`03003ooooo
067oo`8002Coo`8008Goo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo
000Bool00`00ooooo`1eool2000mool2001Hool00`00ooooo`01ool001;oo`8003_oo`8003Woo`80
03goo`8005Ooo`8000?oo`004_oo00<00?ooool0>_oo0P009_oo0P003ooo0P003Ooo0P00@_oo0P00
3Ooo0P00=ooo00<00?ooool00Ooo000Bool00`00ooooo`1Nool20002ool2000?ool2000=ool20012
ool2000=ool2000:ool2000[ool00`00ooooo`01ool001;oo`03003ooooo05koo`8001[oo`80013o
o`8000?oo`8002Ooo`8002Goo`8002_oo`03003ooooo007oo`004_oo00<00?ooool0;ooo0P00BOoo
0P004?oo0P000ooo0P009ooo0P00D_oo00<00?ooool00Ooo000Bool00`00ooooo`0_ool2001Lool2
001<ool2000Vool20009ool00`00ooooo`01ool001;oo`8008koo`8004coo`8002Koo`8000Soo`80
00?oo`004_oo00<00?ooool0K?oo0P0000?oo`000000WOoo00<00?ooool00Ooo000Bool00`00oooo
o`1Gool2000Cool200000ooo0000001nool2000Mool00`00ooooo`01ool001;oo`03003ooooo05Oo
o`8009Koo`8001goo`03003ooooo007oo`002_oo0`001Ooo00<00?ooool0oooo3ooo00<00?ooool0
0Ooo000:ool00`00ooooo`05ool00`00ooooo`32ool2001:ool00`00ooooo`01ool000_oo`03003o
oooo00Coo`800<?oo`8004Woo`8000?oo`002ooo00<00?ooool01?oo00<00?ooool0oooo3ooo00<0
0?ooool00Ooo000:ool00`00ool00005ool00`00ooooo`3oool?ool00`00ooooo`01ool000_oo`03
003ooooo00Coo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<0
0?ooool00Ooo000Bool2003oool?ool20003ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007o
o`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00oooo
o`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<0
0?ooool00Ooo000Bool2003oool?ool20003ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007o
o`004_oo00<00?ooool0B?oo0P00D_oo0P00L?oo00<00?ooool00Ooo000Bool00`00ooooo`18ool2
000Bool2000nool2001`ool00`00ooooo`01ool001;oo`03003ooooo05coo`800;3oo`03003ooooo
007oo`004_oo00<00?ooool0Pooo0P00ROoo00<00?ooool00Ooo000Bool20024ool20028ool20003
ool001;oo`03003ooooo08Coo`8008Soo`03003ooooo007oo`004_oo00<00?ooool0Q?oo0P00R?oo
00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo00?o
o`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Oo
o`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Oo
o`03003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Oo
o`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00So
o`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00So
o`03003ooooo00Ooo`8000?oo`004_ooo`004`000ooo0000\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.27543, -3.55039, \
0.0195416, 0.0349484}}]
}, Open  ]],

Cell["\<\
We generate 500 pairs of random numbers with 0.8 as the correlation \
coefficient. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.26"}],

Cell["m = Table[chance[0.8], {500}];", "Input",
  CellLabel->"In[23]:=",
  CellTags->"S0.1"],

Cell["Here is the corresponding graph. ", "MathCaption",
  CellTags->{"S0.1", "1.27"}],

Cell[CellGroupData[{

Cell["ListPlot[m];", "Input",
  CellLabel->"In[24]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.515859 0.15602 0.340572 0.0992953 [
[.0478 -0.0125 -6 -9 ]
[.0478 -0.0125 6 0 ]
[.20382 -0.0125 -6 -9 ]
[.20382 -0.0125 6 0 ]
[.35984 -0.0125 -6 -9 ]
[.35984 -0.0125 6 0 ]
[.51586 -0.0125 -3 -9 ]
[.51586 -0.0125 3 0 ]
[.67188 -0.0125 -3 -9 ]
[.67188 -0.0125 3 0 ]
[.8279 -0.0125 -3 -9 ]
[.8279 -0.0125 3 0 ]
[.98392 -0.0125 -3 -9 ]
[.98392 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04269 -12 -4.5 ]
[-0.0125 .04269 0 4.5 ]
[-0.0125 .14198 -12 -4.5 ]
[-0.0125 .14198 0 4.5 ]
[-0.0125 .24128 -12 -4.5 ]
[-0.0125 .24128 0 4.5 ]
[-0.0125 .34057 -6 -4.5 ]
[-0.0125 .34057 0 4.5 ]
[-0.0125 .43987 -6 -4.5 ]
[-0.0125 .43987 0 4.5 ]
[-0.0125 .53916 -6 -4.5 ]
[-0.0125 .53916 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0478 0 m
.0478 .00625 L
s
[(-3)] .0478 -0.0125 0 1 Mshowa
.20382 0 m
.20382 .00625 L
s
[(-2)] .20382 -0.0125 0 1 Mshowa
.35984 0 m
.35984 .00625 L
s
[(-1)] .35984 -0.0125 0 1 Mshowa
.51586 0 m
.51586 .00625 L
s
[(0)] .51586 -0.0125 0 1 Mshowa
.67188 0 m
.67188 .00625 L
s
[(1)] .67188 -0.0125 0 1 Mshowa
.8279 0 m
.8279 .00625 L
s
[(2)] .8279 -0.0125 0 1 Mshowa
.98392 0 m
.98392 .00625 L
s
[(3)] .98392 -0.0125 0 1 Mshowa
.125 Mabswid
.079 0 m
.079 .00375 L
s
.11021 0 m
.11021 .00375 L
s
.14141 0 m
.14141 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.23502 0 m
.23502 .00375 L
s
.26623 0 m
.26623 .00375 L
s
.29743 0 m
.29743 .00375 L
s
.32864 0 m
.32864 .00375 L
s
.39104 0 m
.39104 .00375 L
s
.42225 0 m
.42225 .00375 L
s
.45345 0 m
.45345 .00375 L
s
.48466 0 m
.48466 .00375 L
s
.54706 0 m
.54706 .00375 L
s
.57827 0 m
.57827 .00375 L
s
.60947 0 m
.60947 .00375 L
s
.64068 0 m
.64068 .00375 L
s
.70308 0 m
.70308 .00375 L
s
.73429 0 m
.73429 .00375 L
s
.76549 0 m
.76549 .00375 L
s
.79669 0 m
.79669 .00375 L
s
.8591 0 m
.8591 .00375 L
s
.89031 0 m
.89031 .00375 L
s
.92151 0 m
.92151 .00375 L
s
.95271 0 m
.95271 .00375 L
s
.0166 0 m
.0166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04269 m
.00625 .04269 L
s
[(-3)] -0.0125 .04269 1 0 Mshowa
0 .14198 m
.00625 .14198 L
s
[(-2)] -0.0125 .14198 1 0 Mshowa
0 .24128 m
.00625 .24128 L
s
[(-1)] -0.0125 .24128 1 0 Mshowa
0 .34057 m
.00625 .34057 L
s
[(0)] -0.0125 .34057 1 0 Mshowa
0 .43987 m
.00625 .43987 L
s
[(1)] -0.0125 .43987 1 0 Mshowa
0 .53916 m
.00625 .53916 L
s
[(2)] -0.0125 .53916 1 0 Mshowa
.125 Mabswid
0 .06255 m
.00375 .06255 L
s
0 .0824 m
.00375 .0824 L
s
0 .10226 m
.00375 .10226 L
s
0 .12212 m
.00375 .12212 L
s
0 .16184 m
.00375 .16184 L
s
0 .1817 m
.00375 .1817 L
s
0 .20156 m
.00375 .20156 L
s
0 .22142 m
.00375 .22142 L
s
0 .26114 m
.00375 .26114 L
s
0 .28099 m
.00375 .28099 L
s
0 .30085 m
.00375 .30085 L
s
0 .32071 m
.00375 .32071 L
s
0 .36043 m
.00375 .36043 L
s
0 .38029 m
.00375 .38029 L
s
0 .40015 m
.00375 .40015 L
s
0 .42001 m
.00375 .42001 L
s
0 .45973 m
.00375 .45973 L
s
0 .47959 m
.00375 .47959 L
s
0 .49944 m
.00375 .49944 L
s
0 .5193 m
.00375 .5193 L
s
0 .02283 m
.00375 .02283 L
s
0 .00297 m
.00375 .00297 L
s
0 .55902 m
.00375 .55902 L
s
0 .57888 m
.00375 .57888 L
s
0 .59874 m
.00375 .59874 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.0478 .61178 m
.0478 .61803 L
s
.20382 .61178 m
.20382 .61803 L
s
.35984 .61178 m
.35984 .61803 L
s
.51586 .61178 m
.51586 .61803 L
s
.67188 .61178 m
.67188 .61803 L
s
.8279 .61178 m
.8279 .61803 L
s
.98392 .61178 m
.98392 .61803 L
s
.125 Mabswid
.079 .61428 m
.079 .61803 L
s
.11021 .61428 m
.11021 .61803 L
s
.14141 .61428 m
.14141 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.23502 .61428 m
.23502 .61803 L
s
.26623 .61428 m
.26623 .61803 L
s
.29743 .61428 m
.29743 .61803 L
s
.32864 .61428 m
.32864 .61803 L
s
.39104 .61428 m
.39104 .61803 L
s
.42225 .61428 m
.42225 .61803 L
s
.45345 .61428 m
.45345 .61803 L
s
.48466 .61428 m
.48466 .61803 L
s
.54706 .61428 m
.54706 .61803 L
s
.57827 .61428 m
.57827 .61803 L
s
.60947 .61428 m
.60947 .61803 L
s
.64068 .61428 m
.64068 .61803 L
s
.70308 .61428 m
.70308 .61803 L
s
.73429 .61428 m
.73429 .61803 L
s
.76549 .61428 m
.76549 .61803 L
s
.79669 .61428 m
.79669 .61803 L
s
.8591 .61428 m
.8591 .61803 L
s
.89031 .61428 m
.89031 .61803 L
s
.92151 .61428 m
.92151 .61803 L
s
.95271 .61428 m
.95271 .61803 L
s
.0166 .61428 m
.0166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04269 m
1 .04269 L
s
.99375 .14198 m
1 .14198 L
s
.99375 .24128 m
1 .24128 L
s
.99375 .34057 m
1 .34057 L
s
.99375 .43987 m
1 .43987 L
s
.99375 .53916 m
1 .53916 L
s
.125 Mabswid
.99625 .06255 m
1 .06255 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .10226 m
1 .10226 L
s
.99625 .12212 m
1 .12212 L
s
.99625 .16184 m
1 .16184 L
s
.99625 .1817 m
1 .1817 L
s
.99625 .20156 m
1 .20156 L
s
.99625 .22142 m
1 .22142 L
s
.99625 .26114 m
1 .26114 L
s
.99625 .28099 m
1 .28099 L
s
.99625 .30085 m
1 .30085 L
s
.99625 .32071 m
1 .32071 L
s
.99625 .36043 m
1 .36043 L
s
.99625 .38029 m
1 .38029 L
s
.99625 .40015 m
1 .40015 L
s
.99625 .42001 m
1 .42001 L
s
.99625 .45973 m
1 .45973 L
s
.99625 .47959 m
1 .47959 L
s
.99625 .49944 m
1 .49944 L
s
.99625 .5193 m
1 .5193 L
s
.99625 .02283 m
1 .02283 L
s
.99625 .00297 m
1 .00297 L
s
.99625 .55902 m
1 .55902 L
s
.99625 .57888 m
1 .57888 L
s
.99625 .59874 m
1 .59874 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.36273 .21328 Mdot
.38364 .1941 Mdot
.21476 .16632 Mdot
.78903 .4832 Mdot
.24485 .25999 Mdot
.53797 .29221 Mdot
.62687 .38161 Mdot
.49238 .39201 Mdot
.47199 .34412 Mdot
.30894 .2575 Mdot
.65022 .42464 Mdot
.34994 .21024 Mdot
.55612 .29315 Mdot
.51933 .42704 Mdot
.27506 .24038 Mdot
.57825 .40494 Mdot
.80722 .45711 Mdot
.69753 .43473 Mdot
.75773 .52062 Mdot
.33413 .35246 Mdot
.44391 .40531 Mdot
.534 .29406 Mdot
.50769 .37757 Mdot
.74458 .41374 Mdot
.55285 .33041 Mdot
.69438 .44593 Mdot
.33934 .16871 Mdot
.50043 .37477 Mdot
.63421 .41205 Mdot
.46966 .34216 Mdot
.15661 .15839 Mdot
.45056 .26986 Mdot
.17769 .23238 Mdot
.60537 .35083 Mdot
.59078 .32129 Mdot
.60749 .31009 Mdot
.26728 .2291 Mdot
.47203 .34714 Mdot
.71214 .4664 Mdot
.36361 .1833 Mdot
.60037 .48243 Mdot
.2463 .24888 Mdot
.59573 .29293 Mdot
.57913 .23065 Mdot
.43702 .20267 Mdot
.4459 .3515 Mdot
.38964 .31181 Mdot
.47024 .26125 Mdot
.71728 .51161 Mdot
.71089 .41678 Mdot
.58127 .42083 Mdot
.51491 .41952 Mdot
.38495 .28873 Mdot
.57233 .36638 Mdot
.30857 .2445 Mdot
.54406 .28181 Mdot
.62739 .41766 Mdot
.21067 .12842 Mdot
.6218 .42053 Mdot
.50629 .24773 Mdot
.55405 .32403 Mdot
.24825 .28645 Mdot
.72569 .51019 Mdot
.33729 .24687 Mdot
.28697 .16322 Mdot
.41802 .41691 Mdot
.6383 .4412 Mdot
.25548 .23902 Mdot
.57877 .43481 Mdot
.70172 .4006 Mdot
.43681 .38541 Mdot
.46609 .28248 Mdot
.37157 .30629 Mdot
.36643 .28373 Mdot
.63495 .38234 Mdot
.21829 .24512 Mdot
.41971 .39684 Mdot
.5498 .4332 Mdot
.4155 .36515 Mdot
.57144 .32593 Mdot
.67343 .37172 Mdot
.97619 .55874 Mdot
.44651 .21001 Mdot
.55728 .31741 Mdot
.4539 .26946 Mdot
.56766 .33196 Mdot
.62401 .38189 Mdot
.5645 .39296 Mdot
.57839 .36502 Mdot
.53265 .24437 Mdot
.46673 .26997 Mdot
.3101 .17113 Mdot
.64011 .33393 Mdot
.64333 .48993 Mdot
.72998 .39577 Mdot
.39663 .24354 Mdot
.35044 .25456 Mdot
.52912 .38985 Mdot
.59597 .30226 Mdot
.43865 .33467 Mdot
.45515 .35172 Mdot
.74423 .5423 Mdot
.64341 .33742 Mdot
.8339 .49154 Mdot
.50005 .2394 Mdot
.4852 .34068 Mdot
.39561 .3581 Mdot
.53628 .37348 Mdot
.7732 .48002 Mdot
.4915 .26527 Mdot
.42111 .41589 Mdot
.50773 .33346 Mdot
.50237 .38836 Mdot
.328 .25382 Mdot
.5156 .32282 Mdot
.68989 .35771 Mdot
.45889 .27264 Mdot
.2369 .23999 Mdot
.58166 .30996 Mdot
.52942 .3107 Mdot
.3771 .25663 Mdot
.29367 .18002 Mdot
.52385 .36215 Mdot
.08401 .17835 Mdot
.57397 .39617 Mdot
.37234 .29784 Mdot
.5403 .40789 Mdot
.02381 .06561 Mdot
.49309 .3185 Mdot
.4169 .36165 Mdot
.46393 .30446 Mdot
.42027 .33989 Mdot
.60871 .46684 Mdot
.50926 .37201 Mdot
.50949 .41628 Mdot
.36877 .20265 Mdot
.28738 .28547 Mdot
.31238 .09484 Mdot
.46693 .37284 Mdot
.34169 .19531 Mdot
.66401 .36869 Mdot
.60244 .29501 Mdot
.33047 .18538 Mdot
.37468 .25941 Mdot
.30877 .23651 Mdot
.79158 .43441 Mdot
.54652 .33313 Mdot
.23195 .22432 Mdot
.46055 .40321 Mdot
.24452 .18543 Mdot
.3846 .31809 Mdot
.52345 .26454 Mdot
.87019 .50935 Mdot
.45732 .33903 Mdot
.5243 .30409 Mdot
.42599 .33274 Mdot
.19549 .22137 Mdot
.64452 .27224 Mdot
.86054 .49428 Mdot
.43846 .33947 Mdot
.37395 .30701 Mdot
.56855 .36193 Mdot
.48585 .24417 Mdot
.18605 .15901 Mdot
.33355 .20327 Mdot
.72305 .42673 Mdot
.45649 .31153 Mdot
.49297 .39136 Mdot
.50486 .26779 Mdot
.71119 .41511 Mdot
.35511 .21254 Mdot
.65795 .50888 Mdot
.49207 .34527 Mdot
.65014 .49388 Mdot
.63841 .43857 Mdot
.39694 .22201 Mdot
.73979 .34103 Mdot
.50535 .4186 Mdot
.53867 .41326 Mdot
.47232 .32788 Mdot
.27376 .22898 Mdot
.70255 .42298 Mdot
.57382 .43122 Mdot
.94409 .58344 Mdot
.62982 .44438 Mdot
.56022 .39613 Mdot
.33591 .22033 Mdot
.48904 .3121 Mdot
.87329 .51364 Mdot
.45325 .28342 Mdot
.57248 .46435 Mdot
.58704 .38475 Mdot
.69028 .37105 Mdot
.41191 .35277 Mdot
.45129 .32847 Mdot
.30615 .30372 Mdot
.50439 .31675 Mdot
.62442 .47854 Mdot
.34405 .28685 Mdot
.33746 .35016 Mdot
.55167 .28646 Mdot
.28224 .21542 Mdot
.44294 .3442 Mdot
.46738 .28103 Mdot
.39024 .25023 Mdot
.79507 .39746 Mdot
.66275 .36784 Mdot
.67816 .54306 Mdot
.5259 .32344 Mdot
.18282 .21313 Mdot
.41823 .30936 Mdot
.53904 .37146 Mdot
.34771 .28058 Mdot
.65373 .53164 Mdot
.56591 .28039 Mdot
.69614 .39901 Mdot
.86989 .59614 Mdot
.3773 .31631 Mdot
.5272 .34652 Mdot
.37339 .22179 Mdot
.52491 .35755 Mdot
.39971 .23535 Mdot
.55304 .25327 Mdot
.56484 .25699 Mdot
.31197 .31918 Mdot
.72892 .4301 Mdot
.37581 .23587 Mdot
.47695 .34101 Mdot
.61573 .3972 Mdot
.32286 .20706 Mdot
.67777 .36258 Mdot
.73045 .34312 Mdot
.50831 .29321 Mdot
.81089 .46927 Mdot
.60019 .42034 Mdot
.584 .32406 Mdot
.623 .36447 Mdot
.48404 .41312 Mdot
.66426 .39992 Mdot
.56204 .41016 Mdot
.6462 .37318 Mdot
.57242 .3313 Mdot
.48521 .33498 Mdot
.41177 .32984 Mdot
.6311 .52261 Mdot
.28675 .21384 Mdot
.48249 .28108 Mdot
.4514 .2361 Mdot
.5305 .36427 Mdot
.30419 .18624 Mdot
.44047 .30699 Mdot
.51202 .38232 Mdot
.58591 .40974 Mdot
.48815 .28323 Mdot
.5767 .40583 Mdot
.32923 .27055 Mdot
.42825 .37106 Mdot
.73086 .42939 Mdot
.60418 .43603 Mdot
.52287 .30135 Mdot
.56048 .38288 Mdot
.25654 .01472 Mdot
.48701 .32694 Mdot
.44394 .28526 Mdot
.88173 .4885 Mdot
.29114 .14283 Mdot
.48063 .38761 Mdot
.82217 .43732 Mdot
.39635 .33572 Mdot
.38784 .25942 Mdot
.50512 .38808 Mdot
.55662 .41434 Mdot
.5612 .43717 Mdot
.68483 .32986 Mdot
.34314 .39118 Mdot
.52057 .33064 Mdot
.39471 .29304 Mdot
.62037 .40087 Mdot
.56356 .38554 Mdot
.59684 .35458 Mdot
.49185 .35477 Mdot
.34871 .2145 Mdot
.56519 .3391 Mdot
.52409 .3582 Mdot
.21743 .20979 Mdot
.55627 .30902 Mdot
.34734 .21406 Mdot
.40425 .30625 Mdot
.36485 .26692 Mdot
.44125 .35432 Mdot
.3388 .19558 Mdot
.41152 .32363 Mdot
.51009 .31967 Mdot
.58177 .35722 Mdot
.55424 .39604 Mdot
.60759 .42513 Mdot
.55292 .27137 Mdot
.66523 .34612 Mdot
.30971 .19879 Mdot
.50211 .35908 Mdot
.24445 .19347 Mdot
.50594 .3475 Mdot
.45525 .32078 Mdot
.30949 .22742 Mdot
.61004 .56422 Mdot
.38763 .21244 Mdot
.54734 .35228 Mdot
.53132 .37003 Mdot
.10183 .03049 Mdot
.43254 .3798 Mdot
.36009 .22051 Mdot
.64423 .4669 Mdot
.57796 .45956 Mdot
.76133 .4343 Mdot
.48181 .32227 Mdot
.61239 .44042 Mdot
.52019 .36118 Mdot
.59649 .40617 Mdot
.43887 .27747 Mdot
.61329 .41016 Mdot
.444 .26896 Mdot
.49724 .37909 Mdot
.50827 .43955 Mdot
.51244 .27835 Mdot
.49871 .22605 Mdot
.67875 .37884 Mdot
.55451 .35316 Mdot
.64666 .41047 Mdot
.54452 .34482 Mdot
.57519 .28896 Mdot
.41756 .26675 Mdot
.41374 .35122 Mdot
.67818 .48568 Mdot
.41907 .20163 Mdot
.62925 .4123 Mdot
.19473 .12216 Mdot
.41194 .28509 Mdot
.34932 .17475 Mdot
.13158 .07719 Mdot
.55029 .33905 Mdot
.4167 .23447 Mdot
.60701 .31834 Mdot
.42339 .21984 Mdot
.62252 .39492 Mdot
.91707 .56809 Mdot
.55682 .35806 Mdot
.41801 .2481 Mdot
.53012 .39272 Mdot
.50309 .27966 Mdot
.37243 .31938 Mdot
.52991 .33982 Mdot
.89013 .56308 Mdot
.47909 .38249 Mdot
.50026 .383 Mdot
.57679 .30967 Mdot
.67834 .40613 Mdot
.62719 .47124 Mdot
.59375 .30753 Mdot
.51405 .33686 Mdot
.28569 .24818 Mdot
.84712 .60332 Mdot
.52905 .25402 Mdot
.61163 .38068 Mdot
.59057 .43939 Mdot
.29775 .28386 Mdot
.46414 .31969 Mdot
.43211 .32998 Mdot
.6835 .43025 Mdot
.3674 .34529 Mdot
.19529 .37186 Mdot
.58841 .24473 Mdot
.73531 .58103 Mdot
.58137 .30286 Mdot
.35789 .17761 Mdot
.21608 .21825 Mdot
.33333 .31899 Mdot
.42664 .31711 Mdot
.49116 .25771 Mdot
.57421 .37716 Mdot
.5581 .40537 Mdot
.43676 .20102 Mdot
.41244 .27057 Mdot
.47794 .2573 Mdot
.50949 .26921 Mdot
.33292 .26677 Mdot
.59098 .33646 Mdot
.42491 .34199 Mdot
.29624 .16417 Mdot
.54951 .40211 Mdot
.60905 .53889 Mdot
.50876 .37687 Mdot
.437 .29718 Mdot
.48209 .26788 Mdot
.53199 .3647 Mdot
.49722 .3624 Mdot
.55341 .27981 Mdot
.40018 .29127 Mdot
.55629 .35327 Mdot
.30116 .23297 Mdot
.39458 .38096 Mdot
.78286 .50483 Mdot
.41987 .21109 Mdot
.22588 .16296 Mdot
.55926 .22149 Mdot
.87475 .51445 Mdot
.74605 .39884 Mdot
.27159 .22962 Mdot
.47449 .30586 Mdot
.58811 .37381 Mdot
.62057 .35391 Mdot
.46226 .34438 Mdot
.50684 .35276 Mdot
.61892 .38685 Mdot
.65866 .42727 Mdot
.48988 .35021 Mdot
.41132 .25104 Mdot
.4044 .27392 Mdot
.64678 .40181 Mdot
.58057 .32761 Mdot
.54201 .37769 Mdot
.67382 .4699 Mdot
.68837 .39305 Mdot
.46637 .40624 Mdot
.55279 .30417 Mdot
.30041 .14588 Mdot
.52516 .29906 Mdot
.50082 .3845 Mdot
.54598 .38626 Mdot
.51885 .39967 Mdot
.52223 .32875 Mdot
.62549 .43117 Mdot
.44456 .32007 Mdot
.64087 .31459 Mdot
.51028 .48028 Mdot
.49615 .34288 Mdot
.59597 .38451 Mdot
.27669 .27097 Mdot
.46277 .27772 Mdot
.75748 .50482 Mdot
.44476 .17602 Mdot
.71684 .4487 Mdot
.39981 .18236 Mdot
.62167 .44513 Mdot
.43552 .26182 Mdot
.53417 .29719 Mdot
.29485 .27302 Mdot
.53597 .33875 Mdot
.51313 .36844 Mdot
.28492 .19197 Mdot
.50736 .33702 Mdot
.48374 .38093 Mdot
.6565 .31568 Mdot
.55986 .32612 Mdot
.66244 .37866 Mdot
.50156 .38063 Mdot
.41246 .24127 Mdot
.37434 .2344 Mdot
.51022 .27467 Mdot
.36806 .2237 Mdot
.55747 .36293 Mdot
.51841 .35083 Mdot
.43228 .21937 Mdot
.53911 .39841 Mdot
.50607 .35722 Mdot
.36486 .33603 Mdot
.34141 .29607 Mdot
.69272 .44869 Mdot
.48214 .32036 Mdot
.70384 .42347 Mdot
.41559 .29008 Mdot
.30955 .44875 Mdot
.45245 .42412 Mdot
.75818 .54638 Mdot
.58807 .39631 Mdot
.32813 .27861 Mdot
.52665 .30969 Mdot
.79771 .46158 Mdot
.60404 .39093 Mdot
.18343 .24883 Mdot
.78135 .35823 Mdot
.70716 .50673 Mdot
.62058 .28979 Mdot
.36876 .28391 Mdot
.68593 .32742 Mdot
.47137 .24741 Mdot
.61842 .46576 Mdot
.54082 .2844 Mdot
.67703 .47504 Mdot
.52064 .31156 Mdot
.44773 .25225 Mdot
.57958 .37843 Mdot
.55136 .27346 Mdot
.49136 .3473 Mdot
.37746 .24128 Mdot
.19406 .23069 Mdot
.58732 .33731 Mdot
.62537 .44916 Mdot
.52499 .35511 Mdot
.54738 .39003 Mdot
.73607 .39486 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000Pool2
000Xool3000Wool5000Uool00`00ooooo`0Vool5000Wool3000Wool20008ool002;oo`03003ooooo
02Goo`03003ooooo02Woo`03003ooooo02Coo`03003oo`0002Woo`03003ooooo02Ooo`03003ooooo
02Woo`03003ooooo00Goo`006ooo0`000ooo00<00?ooool08Ooo0`000ooo00<00?ooool08_oo0`00
0ooo00<00?ooool09?oo00<00?oo0000:Ooo00<00?ooool0:?oo00<00?ooool09ooo00<00?ooool0
1_oo000Rool00`00ooooo`0Vool00`00ooooo`0Xool00`00ooooo`0Tool00`00ool0000Yool00`00
ooooo`0Xool00`00ooooo`0Xool00`00ooooo`05ool0023oo`03003oo`0002Ooo`03003oo`0002Wo
o`03003ooooo02Coo`03003oo`0002Woo`03003ooooo02Ooo`03003oo`0002Ooo`03003oo`0000Oo
o`008Ooo00<00?ooool09ooo00<00?ooool09ooo0P009ooo00<00?ooool09ooo0P00:_oo00<00?oo
ool09ooo00<00?ooool01_oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00
4_ooo`004`000ooo000Bool20002ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`020003ool001;oo`03003o
oooo00[oo`03003ooooo02Ooo`03003ooooo02Soo`03003ooooo02Soo`03003ooooo02Ooo`03003o
oooo02Soo`03003ooooo02Soo`05003oooooool00003ool001;oo`03003ooooo0?ooo`ooo`03003o
oooo007oo`004_oo00<00?ooool0@_oo0P00b_oo00<00?ooool00Ooo000Bool00`00ooooo`12ool2
003:ool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo0P00oooo
3ooo0P000ooo000Bool00`00ooooo`0Hool2003dool00`00ooooo`01ool001;oo`03003ooooo01So
o`800?Coo`03003ooooo007oo`002_oo0P001_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000<
ool00`00ooooo`03ool00`00ooooo`3oool?ool00`00ooooo`01ool000Goo`<000?oo`03003ooooo
00Coo`800?ooo`ooo`8000?oo`003?oo00<00?ooool00ooo00<00?ooool0oooo3ooo00<00?ooool0
0Ooo000:ool00`00ool00005ool00`00ooooo`3oool?ool00`00ooooo`01ool000_oo`03003ooooo
00Coo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool0
0Ooo000Bool2003oool?ool20003ool001;oo`03003ooooo00;oo`800?ooo`_oo`03003ooooo007o
o`004_oo00<00?ooool00_oo0P00oooo2ooo00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool0
0`00ooooo`01ool001;oo`03003ooooo023oo`800>coo`03003ooooo007oo`004_oo00<00?ooool0
8?oo0P00k?oo00<00?ooool00Ooo000Bool2003oool?ool20003ool001;oo`03003ooooo0?ooo`oo
o`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000Bool00`00ooooo`1A
ool2002kool00`00ooooo`01ool001;oo`03003ooooo057oo`800;_oo`03003ooooo007oo`004_oo
0P00oooo3ooo0P000ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo
0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000Bool00`00
ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo
0P00<_oo0P00f_oo0P000ooo000Bool00`00ooooo`0aool20002ool2003Gool00`00ooooo`01ool0
01;oo`03003ooooo03Goo`800=Ooo`03003ooooo007oo`002_oo0`001Ooo00<00?ooool0oooo3ooo
00<00?ooool00Ooo000:ool00`00ooooo`05ool00`00ooooo`3oool?ool00`00ooooo`01ool000Go
o`<000?oo`03003ooooo00Coo`8004coo`800<3oo`8000?oo`002ooo00<00?ooool01?oo00<00?oo
ool0Booo0P0000?oo`000000__oo00<00?ooool00Ooo000:ool00`00ool00005ool00`00ooooo`1>
ool2002nool00`00ooooo`01ool000_oo`03003ooooo00Coo`03003ooooo0?ooo`ooo`03003ooooo
007oo`004_oo00<00?ooool09ooo0P00iOoo00<00?ooool00Ooo000Bool00`00ooooo`0Wool20006
ool2003Mool00`00ooooo`01ool001;oo`80033oo`8000Woo`8000koo`800003ool000000;koo`80
00?oo`004_oo00<00?ooool0=ooo0P0000?oo`0000003_oo0P0000?oo`0000002_oo0P00/ooo00<0
0?ooool00Ooo000Bool00`00ooooo`0gool2000Hool20006ool2002cool00`00ooooo`01ool001;o
o`03003ooooo057oo`8000Soo`8001Soo`8009Ooo`03003ooooo007oo`004_oo00<00?ooool04ooo
0P00=ooo0P003Ooo0P0000?oo`0000005Ooo0P00Uooo00<00?ooool00Ooo000Bool2000Dool2000g
ool2000@ool30008ool2002Rool20003ool001;oo`03003ooooo03ooo`8000koo`8000Goo`8000Oo
o`8000Soo`800:?oo`03003ooooo007oo`004_oo00<00?ooool0?ooo0P003_oo0P001Ooo0P00]_oo
00<00?ooool00Ooo000Bool00`00ooooo`0oool20009ool2000Iool2002Wool00`00ooooo`01ool0
01;oo`03003ooooo03ooo`8000Woo`8000coo`<000[oo`800:Ooo`03003ooooo007oo`004_oo0P00
D_oo0P001Ooo0`004ooo0P000ooo0P00V?oo0P000ooo000Bool00`00ooooo`1Aool20004ool20008
ool2000;ool20003ool2002Iool00`00ooooo`01ool001;oo`03003ooooo05Coo`800003ool00000
00Soo`80013oo`8009Woo`03003ooooo007oo`004_oo00<00?ooool0;_oo0P001ooo0P006ooo0P00
1_oo1@001Ooo0P001ooo0P001Ooo0P00U_oo00<00?ooool00Ooo000Bool00`00ooooo`0^ool20007
ool2000@ool3000?ool60005ool20007ool20005ool2002Fool00`00ooooo`01ool001;oo`03003o
oooo03Ooo`80013oo`<000coo`800004ool00000ool2000@ool4002Jool00`00ooooo`01ool001;o
o`8003;oo`8000Coo`8001ooo`8000Coo`H000Coo`8000Koo`@0027oo`8007Koo`8000?oo`004_oo
00<00?ooool0<Ooo0P002?oo0P004ooo0P003_oo10001?oo0P006_oo0P003ooo0P00Mooo00<00?oo
ool00Ooo000Bool00`00ooooo`0aool20008ool20008ool40007ool2000bool2000Dool2001bool0
0`00ooooo`01ool000Woo`D000Coo`03003ooooo02coo`8000?oo`8001;oo`@000Goo`8001;oo`80
00[oo`8002[oo`8007;oo`03003ooooo007oo`002ooo00<00?ooool01?oo00<00?ooool0;?oo0P00
8?oo10004?oo0`001?oo0P000ooo0P001ooo0P00UOoo00<00?ooool00Ooo0005ool30003ool00`00
ooooo`04ool2000nool20003ool20003ool20007ool2000Aool20004ool20002ool20008ool2000<
ool20026ool20003ool000_oo`03003ooooo00Coo`03003ooooo03Ooo`8000Coo`8000?oo`8000?o
o`8000Ooo`80017oo`8000?oo`8000?oo`8001;oo`8000;oo`8000Ooo`8000goo`8006ooo`03003o
oooo007oo`002ooo00<00?ooool01?oo00<00?ooool0;_oo0P001ooo0P001_oo0P002Ooo0P001?oo
0P001_oo0P003_oo0P001?oo0P003Ooo0P000_oo0P000ooo0P001_oo0P003Ooo0P00Kooo00<00?oo
ool00Ooo000:ool20006ool00`00ooooo`0^ool2000?ool20009ool2000<ool2000=ool20003ool4
0006ool20005ool20007ool2000;ool2001iool00`00ooooo`01ool001;oo`03003ooooo05Koo`80
00Coo`8000Goo`8000;oo`8000?oo`8000Soo`8001Goo`8000Coo`800003ool0000007Koo`03003o
oooo007oo`004_oo00<00?ooool0?ooo0P003ooo0P001?oo0P001?oo0P001?oo0`0000?oo`000000
5ooo0P0000?oo`0000002Ooo0P001ooo0P00M_oo00<00?ooool00Ooo000Bool20010ool2000?ool2
000@ool20002ool2000;ool20007ool200001?oo00000?oo0P00ROoo0P000ooo000Bool00`00oooo
o`1Gool20007ool2000<ool20003ool20007ool20002ool40002ool20003ool20021ool00`00oooo
o`01ool001;oo`03003ooooo04Ooo`8000goo`<000Ooo`8000_oo`<000Goo`D000;oo`8000;oo`@0
00;oo`<000;oo`8000Koo`8007Woo`03003ooooo007oo`004_oo00<00?ooool0Aooo0P000ooo0P00
2?oo0P004_oo0P0000?oo`0000001_oo1P0000?oo`0000002Ooo0P002_oo0P005ooo0P00H?oo00<0
0?ooool00Ooo000Bool00`00ooooo`1<ool20008ool2000Bool20008ool20003ool3000;ool30009
ool2000Gool2001Pool00`00ooooo`01ool001;oo`8005Ooo`8000?oo`8001Ooo`8000Coo`@000;o
o`8000?oo`800003ool0000000Ooo`@000;oo`8007Coo`8000?oo`004_oo00<00?ooool0B_oo0P00
00?oo`0000003?oo0P000ooo0`002_oo0P001_oo0P0000Coo`00003oo`<000;oo`<000;oo`8000Wo
o`D000;oo`8007Goo`03003ooooo007oo`004_oo00<00?ooool0@?oo0P002?oo0P0000?oo`000000
2ooo0P001?oo0`000_oo0P001_oo0P001_oo0P0000?oo`0000001ooo0P003Ooo0P0000?oo`000000
1?oo0P002ooo0P00I_oo00<00?ooool00Ooo000Bool00`00ooooo`10ool2000Hool20009ool20000
1?oo000000000ooo0P005ooo0P001_oo0P000_oo0`000ooo0P001?oo0P001Ooo0P00I_oo00<00?oo
ool00Ooo000Bool00`00ooooo`1Iool2000=ool30003ool20003ool2000Bool20005ool30003ool2
0009ool4001[ool00`00ooooo`01ool001;oo`03003ooooo05Woo`8000Ooo`8000ooo`8001Ooo`@0
017oo`8006_oo`03003ooooo007oo`004_oo0P00DOoo0P004?oo0P005ooo0P003_oo0`001Ooo0P00
1_oo0P000_oo0P00K?oo0P000ooo000Bool00`00ooooo`1@ool2000?ool30006ool20008ool20005
ool200000ooo0000000;ool20006ool20006ool200001?oo00000000KOoo00<00?ooool00Ooo000B
ool00`00ooooo`1Qool30002ool20002ool20002ool20004ool20003ool20003ool2000:ool50005
ool20004ool300000ooo00000002ool2001Zool00`00ooooo`01ool001;oo`03003ooooo06Koo`80
00Koo`8000Woo`8000Ooo`8000Koo`D000Goo`8000Coo`<000Goo`8000Ooo`80067oo`03003ooooo
007oo`004_oo00<00?ooool0DOoo0P001?oo0P002_oo10002_oo0P003ooo0`0000?oo`0000003?oo
0P003?oo0P001ooo0P000_oo0P00GOoo00<00?ooool00Ooo000Bool2001Bool20004ool20009ool5
000:ool20002ool200001?oo00000?oo0P000ooo0P0000Coo`00003oo`D000Woo`8000Ooo`8000?o
o`8000_oo`8005coo`8000?oo`004_oo00<00?ooool0H_oo0P002?oo0P001ooo0P0000Coo`00003o
o`8000?oo`8000Goo`@00003ool0000000Goo`@00003ool0000000;oo`<006ooo`03003ooooo007o
o`004_oo00<00?ooool0K?oo0P001?oo0P000ooo0P001?oo0P000_oo0P002?oo0`001Ooo100000Co
o`00003oo`<001Woo`<005Coo`03003ooooo007oo`004_oo00<00?ooool0K?oo0P000_oo10000ooo
0P001?oo0P000_oo0P001?oo0P0000Coo`00000000Coo`@000;oo`<00003ool0000001[oo`<005Co
o`03003ooooo007oo`002ooo00<00?ooool01?oo00<00?ooool0H?oo0P001_oo0P001_oo0P000_oo
0P002ooo0P001?oo1@001Ooo10000_oo0`000ooo0`002ooo0`00H?oo00<00?ooool00Ooo000:ool0
0`00ool00005ool00`00ooooo`1Pool20006ool20005ool20003ool20003ool20003ool200000ooo
00000004ool30003ool30002ool20002ool20005ool3000;ool3000Hool20016ool00`00ooooo`01
ool000[oo`03003oo`0000Goo`80073oo`<000;oo`<000;oo`L00004ool00000ool20007ool30002
ool20002ool2000/ool40015ool20003ool000[oo`03003oo`0000Goo`03003ooooo063oo`8000ko
o`8000?oo`8000?oo`D000?oo`H000Coo`8000?oo`8001ooo`80013oo`8004Soo`03003ooooo007o
o`002_oo00<00?oo00001Ooo00<00?ooool0F?oo0P001_oo0P002ooo0P001ooo10000ooo0P000ooo
0P000_oo0P000_oo10000ooo0P003_oo0P003ooo0P00F_oo00<00?ooool00Ooo000;ool00`00oooo
o`04ool00`00ooooo`1Gool3000Cool20006ool50008ool20002ool20002ool30005ool40009ool4
0003ool2001Vool00`00ooooo`01ool001;oo`03003ooooo05Ooo`8000ooo`8000?oo`8000Koo`80
00_oo`800004ool000000003ool20005ool40005ool20002ool20005ool2000Aool2000Gool2000j
ool00`00ooooo`01ool001;oo`8006Woo`8000Coo`8001Coo`@000;oo`<000Ooo`800003ool00000
00;oo`8001Soo`8000;oo`8001Ooo`8003Woo`8000?oo`004_oo00<00?ooool0KOoo0`005?oo0P00
1?oo1@001Ooo0P0000?oo`0000000`002_oo0P003Ooo0P00Eooo00<00?ooool00Ooo000Bool00`00
ooooo`1]ool2000Iool20003ool20009ool4000:ool20009ool3001Jool00`00ooooo`01ool001;o
o`03003ooooo037oo`8003koo`8000Woo`8000Woo`<000?oo`@000coo`8000koo`8000;oo`D000?o
o`8005?oo`03003ooooo007oo`004_oo00<00?ooool0<Ooo0P00?_oo0P002Ooo0P001ooo10001_oo
0P002?oo0P000_oo0P003_oo0P001Ooo0P000ooo0P00Dooo00<00?ooool00Ooo000Bool2001Yool2
0008ool2000<ool20002ool50007ool20007ool30007ool2000<ool20003ool2001Eool20003ool0
01;oo`03003ooooo06Soo`8000Soo`8000_oo`<000;oo`<00003ool0000000Koo`8000?oo`8000?o
o`@00003ool0000000;oo`8000;oo`800003ool0000000Goo`8000?oo`8005Koo`03003ooooo007o
o`004_oo00<00?ooool0Looo0P002_oo0P001?oo1@001ooo0P000_oo0`001?oo0P0000?oo`000000
1?oo100000?oo`000000H_oo00<00?ooool00Ooo000Bool00`00ooooo`1Jool2000Gool2000:ool2
0002ool50005ool20002ool30002ool20009ool20002ool2001Wool00`00ooooo`01ool001;oo`03
003ooooo05[oo`8002Ooo`8000Soo`8000?oo`8000;oo`8000Woo`8000?oo`80013oo`8000[oo`<0
04Ooo`03003ooooo007oo`004_oo00<00?ooool0Kooo0P007?oo10000_oo1@0000?oo`0000000_oo
0P001Ooo10004?oo10002?oo0`0000?oo`0000002ooo0P00=ooo00<00?ooool00Ooo000Bool2001`
ool20009ool2000>ool20003ool200000ooo000000030002ool20002ool20005ool40005ool20003
ool20006ool4000:ool2000;ool2000fool20003ool001;oo`03003ooooo07Goo`8000?oo`<000go
o`8000Koo`800003ool0000000?oo`8000?oo`8000Goo`8000Goo`8000?oo`800003ool0000000Go
o`80053oo`03003ooooo007oo`004_oo00<00?ooool0MOoo0P001?oo0P004ooo0P000ooo0`000_oo
100000?oo`0000000ooo0P001ooo0P001_oo0P00Eooo00<00?ooool00Ooo000Bool00`00ooooo`20
ool2000=ool30004ool20004ool20006ool20002ool30002ool2000Iool20014ool00`00ooooo`01
ool001;oo`03003ooooo06koo`<000ooo`8000Goo`8000Koo`8000?oo`80017oo`@001?oo`8000So
o`8004Coo`03003ooooo007oo`004_oo0P00Kooo0`005Ooo1@002Ooo0P001Ooo0P000ooo0P001?oo
0`005Ooo0P00COoo0P000ooo000Bool00`00ooooo`1hool2000<ool200000ooo0000000@ool20003
ool40002ool20006ool2000<ool2001@ool00`00ooooo`01ool001;oo`03003ooooo07Soo`80013o
o`8001Koo`8000[oo`@000[oo`8000Coo`8004[oo`03003ooooo007oo`004_oo00<00?ooool0R_oo
0P003Ooo0P003?oo0P001ooo0P001Ooo0P002Ooo1000B?oo00<00?ooool00Ooo0009ool50004ool0
0`00ooooo`2Bool20005ool30005ool20004ool2000>ool20002ool20006ool30006ool20006ool2
000hool00`00ooooo`01ool000_oo`03003ooooo00Coo`03003ooooo08Ooo`8000Woo`800003ool0
000000?oo`800003ool0000000;oo`8000Soo`8000koo`8000ooo`8000Koo`8000Ooo`8002ooo`03
003ooooo007oo`002ooo00<00?ooool01?oo0P00R?oo0P003?oo0P001_oo0P001?oo0P001Ooo0`00
<?oo0P00;_oo0P000ooo000;ool00`00ooooo`04ool00`00ooooo`2Sool200000ooo00000004000>
ool2001Bool00`00ooooo`01ool000_oo`03003ooooo00Coo`03003ooooo053oo`8005Coo`@000oo
o`<000Coo`8004coo`03003ooooo007oo`002_oo0P001_oo00<00?ooool0D?oo0P00EOoo0P004?oo
0P001Ooo0P00C?oo00<00?ooool00Ooo000Bool00`00ooooo`3Iool2000cool00`00ooooo`01ool0
01;oo`8009_oo`8003[oo`800003ool0000003;oo`8000?oo`004_oo00<00?ooool0V?oo1000>_oo
0P00=_oo00<00?ooool00Ooo000Bool00`00ooooo`2Hool20008ool200000ooo00000005ool2000A
ool2001=ool00`00ooooo`01ool001;oo`03003ooooo0:;oo`800003ool00000008000?oo`8000Ko
o`8000Woo`8001Woo`8003;oo`03003ooooo007oo`004_oo00<00?ooool0Yooo0P002ooo0`008ooo
0P00<_oo00<00?ooool00Ooo000Bool00`00ooooo`2Wool2000<ool2001Gool00`00ooooo`01ool0
01;oo`8008Soo`8001Ooo`8000Goo`8002Koo`8000?oo`8003Ooo`8000?oo`004_oo00<00?ooool0
Qooo0P005ooo0P004ooo0P006?oo0P000ooo0P00>?oo00<00?ooool00Ooo000Bool00`00ooooo`2/
ool20007ool2000fool2000Oool00`00ooooo`01ool001;oo`03003ooooo0:coo`@0033oo`8000Go
o`8000Coo`8001ooo`03003ooooo007oo`004_oo00<00?ooool0[_oo0P00<?oo0P001Ooo0P009Ooo
00<00?ooool00Ooo000Bool2003oool?ool20003ool001;oo`03003ooooo0<_oo`8000Goo`8003[o
o`03003ooooo007oo`004_oo00<00?ooool0/?oo0P002ooo0P003?oo0P001Ooo0P00>_oo00<00?oo
ool00Ooo000Bool00`00ooooo`2`ool2000;ool200000ooo00000002000Vool2000Rool00`00oooo
o`01ool001;oo`03003ooooo0<3oo`@002Koo`<0027oo`03003ooooo007oo`004_oo0P00k?oo0P00
8?oo0P000ooo000Bool00`00ooooo`2Yool2000Pool20011ool00`00ooooo`01ool001;oo`03003o
oooo0:Woo`80023oo`80047oo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool0
0Ooo000:ool30005ool00`00ooooo`2_ool2001Mool00`00ooooo`01ool000[oo`03003ooooo00Go
o`03003ooooo0:ooo`8005goo`03003ooooo007oo`002ooo00<00?ooool01?oo0P00Xooo0P00JOoo
0P000ooo000;ool00`00ooooo`04ool00`00ooooo`2Rool2000Aool2000@ool20015ool00`00oooo
o`01ool000[oo`03003oo`0000Goo`03003ooooo0;Goo`80013oo`8000;oo`80047oo`03003ooooo
007oo`002ooo00<00?ooool01?oo00<00?ooool0booo0P00@Ooo00<00?ooool00Ooo000Bool00`00
ooooo`3oool?ool00`00ooooo`01ool001;oo`800?ooo`Woo`8000Coo`8000?oo`004_oo00<00?oo
ool0kooo0P005_oo0P001Ooo00<00?ooool00Ooo000Bool00`00ooooo`2Sool2001:ool2000Mool0
0`00ooooo`01ool001;oo`03003ooooo0:?oo`8005;oo`8001Goo`03003ooooo007oo`004_oo00<0
0?ooool0mooo0P005Ooo00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool0
01;oo`800<Koo`8004Koo`8000?oo`004_oo00<00?ooool0aOoo0P00=ooo0P003_oo00<00?ooool0
0Ooo000Bool00`00ooooo`3nool2000>ool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03
003ooooo007oo`004_oo00<00?ooool0j_oo0P008_oo00<00?ooool00Ooo000Bool2003[ool2000Q
ool20003ool001;oo`03003ooooo0>Coo`8002Soo`03003ooooo007oo`004_oo00<00?ooool0i?oo
0P00:?oo00<00?ooool00Ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`05003o
ooooool00008ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`06ool01@00oooooooo00000ooo000Boooo000C0003ool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.72876, -3.88688, \
0.0234113, 0.0367856}}]
}, Open  ]],

Cell["\<\
We generate 500 pairs of random numbers with 1.0 as the correlation \
coefficient. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.28"}],

Cell["m = Table[chance[1.0], {500}];", "Input",
  CellLabel->"In[25]:=",
  CellTags->"S0.1"],

Cell["Here is the corresponding graph. ", "MathCaption",
  CellTags->{"S0.1", "1.29"}],

Cell[CellGroupData[{

Cell["ListPlot[m];", "Input",
  CellLabel->"In[26]:=",
  CellTags->"S0.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.518642 0.151875 0.320538 0.093864 [
[.06302 -0.0125 -6 -9 ]
[.06302 -0.0125 6 0 ]
[.21489 -0.0125 -6 -9 ]
[.21489 -0.0125 6 0 ]
[.36677 -0.0125 -6 -9 ]
[.36677 -0.0125 6 0 ]
[.51864 -0.0125 -3 -9 ]
[.51864 -0.0125 3 0 ]
[.67052 -0.0125 -3 -9 ]
[.67052 -0.0125 3 0 ]
[.82239 -0.0125 -3 -9 ]
[.82239 -0.0125 3 0 ]
[.97427 -0.0125 -3 -9 ]
[.97427 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03895 -12 -4.5 ]
[-0.0125 .03895 0 4.5 ]
[-0.0125 .13281 -12 -4.5 ]
[-0.0125 .13281 0 4.5 ]
[-0.0125 .22667 -12 -4.5 ]
[-0.0125 .22667 0 4.5 ]
[-0.0125 .32054 -6 -4.5 ]
[-0.0125 .32054 0 4.5 ]
[-0.0125 .4144 -6 -4.5 ]
[-0.0125 .4144 0 4.5 ]
[-0.0125 .50827 -6 -4.5 ]
[-0.0125 .50827 0 4.5 ]
[-0.0125 .60213 -6 -4.5 ]
[-0.0125 .60213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06302 0 m
.06302 .00625 L
s
[(-3)] .06302 -0.0125 0 1 Mshowa
.21489 0 m
.21489 .00625 L
s
[(-2)] .21489 -0.0125 0 1 Mshowa
.36677 0 m
.36677 .00625 L
s
[(-1)] .36677 -0.0125 0 1 Mshowa
.51864 0 m
.51864 .00625 L
s
[(0)] .51864 -0.0125 0 1 Mshowa
.67052 0 m
.67052 .00625 L
s
[(1)] .67052 -0.0125 0 1 Mshowa
.82239 0 m
.82239 .00625 L
s
[(2)] .82239 -0.0125 0 1 Mshowa
.97427 0 m
.97427 .00625 L
s
[(3)] .97427 -0.0125 0 1 Mshowa
.125 Mabswid
.09339 0 m
.09339 .00375 L
s
.12377 0 m
.12377 .00375 L
s
.15414 0 m
.15414 .00375 L
s
.18452 0 m
.18452 .00375 L
s
.24527 0 m
.24527 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30602 0 m
.30602 .00375 L
s
.33639 0 m
.33639 .00375 L
s
.39714 0 m
.39714 .00375 L
s
.42752 0 m
.42752 .00375 L
s
.45789 0 m
.45789 .00375 L
s
.48827 0 m
.48827 .00375 L
s
.54902 0 m
.54902 .00375 L
s
.57939 0 m
.57939 .00375 L
s
.60977 0 m
.60977 .00375 L
s
.64014 0 m
.64014 .00375 L
s
.70089 0 m
.70089 .00375 L
s
.73127 0 m
.73127 .00375 L
s
.76164 0 m
.76164 .00375 L
s
.79202 0 m
.79202 .00375 L
s
.85277 0 m
.85277 .00375 L
s
.88314 0 m
.88314 .00375 L
s
.91352 0 m
.91352 .00375 L
s
.94389 0 m
.94389 .00375 L
s
.03264 0 m
.03264 .00375 L
s
.00227 0 m
.00227 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03895 m
.00625 .03895 L
s
[(-3)] -0.0125 .03895 1 0 Mshowa
0 .13281 m
.00625 .13281 L
s
[(-2)] -0.0125 .13281 1 0 Mshowa
0 .22667 m
.00625 .22667 L
s
[(-1)] -0.0125 .22667 1 0 Mshowa
0 .32054 m
.00625 .32054 L
s
[(0)] -0.0125 .32054 1 0 Mshowa
0 .4144 m
.00625 .4144 L
s
[(1)] -0.0125 .4144 1 0 Mshowa
0 .50827 m
.00625 .50827 L
s
[(2)] -0.0125 .50827 1 0 Mshowa
0 .60213 m
.00625 .60213 L
s
[(3)] -0.0125 .60213 1 0 Mshowa
.125 Mabswid
0 .05772 m
.00375 .05772 L
s
0 .07649 m
.00375 .07649 L
s
0 .09526 m
.00375 .09526 L
s
0 .11404 m
.00375 .11404 L
s
0 .15158 m
.00375 .15158 L
s
0 .17036 m
.00375 .17036 L
s
0 .18913 m
.00375 .18913 L
s
0 .2079 m
.00375 .2079 L
s
0 .24545 m
.00375 .24545 L
s
0 .26422 m
.00375 .26422 L
s
0 .28299 m
.00375 .28299 L
s
0 .30177 m
.00375 .30177 L
s
0 .33931 m
.00375 .33931 L
s
0 .35808 m
.00375 .35808 L
s
0 .37686 m
.00375 .37686 L
s
0 .39563 m
.00375 .39563 L
s
0 .43318 m
.00375 .43318 L
s
0 .45195 m
.00375 .45195 L
s
0 .47072 m
.00375 .47072 L
s
0 .48949 m
.00375 .48949 L
s
0 .52704 m
.00375 .52704 L
s
0 .54581 m
.00375 .54581 L
s
0 .56458 m
.00375 .56458 L
s
0 .58336 m
.00375 .58336 L
s
0 .02017 m
.00375 .02017 L
s
0 .0014 m
.00375 .0014 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.06302 .61178 m
.06302 .61803 L
s
.21489 .61178 m
.21489 .61803 L
s
.36677 .61178 m
.36677 .61803 L
s
.51864 .61178 m
.51864 .61803 L
s
.67052 .61178 m
.67052 .61803 L
s
.82239 .61178 m
.82239 .61803 L
s
.97427 .61178 m
.97427 .61803 L
s
.125 Mabswid
.09339 .61428 m
.09339 .61803 L
s
.12377 .61428 m
.12377 .61803 L
s
.15414 .61428 m
.15414 .61803 L
s
.18452 .61428 m
.18452 .61803 L
s
.24527 .61428 m
.24527 .61803 L
s
.27564 .61428 m
.27564 .61803 L
s
.30602 .61428 m
.30602 .61803 L
s
.33639 .61428 m
.33639 .61803 L
s
.39714 .61428 m
.39714 .61803 L
s
.42752 .61428 m
.42752 .61803 L
s
.45789 .61428 m
.45789 .61803 L
s
.48827 .61428 m
.48827 .61803 L
s
.54902 .61428 m
.54902 .61803 L
s
.57939 .61428 m
.57939 .61803 L
s
.60977 .61428 m
.60977 .61803 L
s
.64014 .61428 m
.64014 .61803 L
s
.70089 .61428 m
.70089 .61803 L
s
.73127 .61428 m
.73127 .61803 L
s
.76164 .61428 m
.76164 .61803 L
s
.79202 .61428 m
.79202 .61803 L
s
.85277 .61428 m
.85277 .61803 L
s
.88314 .61428 m
.88314 .61803 L
s
.91352 .61428 m
.91352 .61803 L
s
.94389 .61428 m
.94389 .61803 L
s
.03264 .61428 m
.03264 .61803 L
s
.00227 .61428 m
.00227 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03895 m
1 .03895 L
s
.99375 .13281 m
1 .13281 L
s
.99375 .22667 m
1 .22667 L
s
.99375 .32054 m
1 .32054 L
s
.99375 .4144 m
1 .4144 L
s
.99375 .50827 m
1 .50827 L
s
.99375 .60213 m
1 .60213 L
s
.125 Mabswid
.99625 .05772 m
1 .05772 L
s
.99625 .07649 m
1 .07649 L
s
.99625 .09526 m
1 .09526 L
s
.99625 .11404 m
1 .11404 L
s
.99625 .15158 m
1 .15158 L
s
.99625 .17036 m
1 .17036 L
s
.99625 .18913 m
1 .18913 L
s
.99625 .2079 m
1 .2079 L
s
.99625 .24545 m
1 .24545 L
s
.99625 .26422 m
1 .26422 L
s
.99625 .28299 m
1 .28299 L
s
.99625 .30177 m
1 .30177 L
s
.99625 .33931 m
1 .33931 L
s
.99625 .35808 m
1 .35808 L
s
.99625 .37686 m
1 .37686 L
s
.99625 .39563 m
1 .39563 L
s
.99625 .43318 m
1 .43318 L
s
.99625 .45195 m
1 .45195 L
s
.99625 .47072 m
1 .47072 L
s
.99625 .48949 m
1 .48949 L
s
.99625 .52704 m
1 .52704 L
s
.99625 .54581 m
1 .54581 L
s
.99625 .56458 m
1 .56458 L
s
.99625 .58336 m
1 .58336 L
s
.99625 .02017 m
1 .02017 L
s
.99625 .0014 m
1 .0014 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.43334 .26782 Mdot
.22983 .14204 Mdot
.47841 .29568 Mdot
.47081 .29097 Mdot
.65151 .40266 Mdot
.52028 .32155 Mdot
.43154 .26671 Mdot
.50924 .31472 Mdot
.42914 .26522 Mdot
.15619 .09653 Mdot
.58815 .3635 Mdot
.38861 .24017 Mdot
.55032 .34012 Mdot
.4803 .29684 Mdot
.35193 .21751 Mdot
.5619 .34727 Mdot
.44166 .27296 Mdot
.501 .30963 Mdot
.4116 .25438 Mdot
.58014 .35855 Mdot
.61998 .38317 Mdot
.6891 .42588 Mdot
.81934 .50638 Mdot
.32725 .20225 Mdot
.40568 .25072 Mdot
.46558 .28774 Mdot
.61624 .38085 Mdot
.51138 .31605 Mdot
.54845 .33896 Mdot
.45749 .28274 Mdot
.02381 .01472 Mdot
.69408 .42896 Mdot
.12568 .07767 Mdot
.65338 .40381 Mdot
.67092 .41465 Mdot
.75357 .46573 Mdot
.35369 .21859 Mdot
.61835 .38216 Mdot
.80691 .4987 Mdot
.53593 .33123 Mdot
.6276 .38788 Mdot
.31421 .19419 Mdot
.7497 .46334 Mdot
.45513 .28128 Mdot
.57147 .35319 Mdot
.29545 .1826 Mdot
.10378 .06414 Mdot
.25315 .15645 Mdot
.51807 .32019 Mdot
.46534 .2876 Mdot
.78071 .48251 Mdot
.63584 .39297 Mdot
.61897 .38254 Mdot
.61146 .3779 Mdot
.60699 .37514 Mdot
.64704 .39989 Mdot
.38211 .23616 Mdot
.4084 .2524 Mdot
.75228 .46494 Mdot
.30645 .1894 Mdot
.23854 .14742 Mdot
.4806 .29703 Mdot
.60112 .37151 Mdot
.48926 .30238 Mdot
.55895 .34545 Mdot
.39602 .24476 Mdot
.27627 .17074 Mdot
.84414 .52171 Mdot
.50384 .31139 Mdot
.33046 .20423 Mdot
.38853 .24013 Mdot
.37548 .23206 Mdot
.49441 .30556 Mdot
.14226 .08792 Mdot
.90632 .56014 Mdot
.02543 .01572 Mdot
.38724 .23932 Mdot
.43957 .27167 Mdot
.37473 .2316 Mdot
.68738 .42482 Mdot
.72676 .44916 Mdot
.17772 .10984 Mdot
.74163 .45835 Mdot
.48579 .30024 Mdot
.5942 .36724 Mdot
.49481 .30581 Mdot
.63183 .39049 Mdot
.48842 .30186 Mdot
.27666 .17098 Mdot
.70662 .43672 Mdot
.58354 .36065 Mdot
.50367 .31129 Mdot
.41636 .25732 Mdot
.40102 .24785 Mdot
.51305 .31708 Mdot
.82979 .51284 Mdot
.65226 .40312 Mdot
.66971 .41391 Mdot
.56042 .34636 Mdot
.30977 .19145 Mdot
.47022 .29061 Mdot
.47494 .29353 Mdot
.51327 .31722 Mdot
.34307 .21203 Mdot
.48641 .30062 Mdot
.58762 .36317 Mdot
.80373 .49673 Mdot
.43996 .27191 Mdot
.63355 .39156 Mdot
.45917 .28378 Mdot
.5163 .31909 Mdot
.40192 .2484 Mdot
.66167 .40894 Mdot
.73525 .45441 Mdot
.40946 .25306 Mdot
.46295 .28612 Mdot
.52711 .32577 Mdot
.44623 .27578 Mdot
.52918 .32705 Mdot
.44273 .27362 Mdot
.46946 .29014 Mdot
.82183 .50792 Mdot
.61665 .38111 Mdot
.53961 .3335 Mdot
.56199 .34733 Mdot
.57933 .35804 Mdot
.58563 .36194 Mdot
.84063 .51954 Mdot
.55855 .3452 Mdot
.44556 .27537 Mdot
.67867 .41944 Mdot
.65726 .40621 Mdot
.55633 .34383 Mdot
.52184 .32252 Mdot
.48745 .30126 Mdot
.61836 .38217 Mdot
.50204 .31028 Mdot
.42168 .26061 Mdot
.61988 .38311 Mdot
.51855 .32048 Mdot
.42708 .26395 Mdot
.63791 .39425 Mdot
.38397 .23731 Mdot
.59944 .37047 Mdot
.52351 .32355 Mdot
.57682 .3565 Mdot
.2543 .15716 Mdot
.61837 .38217 Mdot
.75121 .46427 Mdot
.4997 .30883 Mdot
.47091 .29104 Mdot
.59064 .36504 Mdot
.28059 .17341 Mdot
.18701 .11558 Mdot
.56031 .34629 Mdot
.37293 .23048 Mdot
.68712 .42466 Mdot
.35093 .21689 Mdot
.32543 .20113 Mdot
.59646 .36863 Mdot
.26059 .16105 Mdot
.73845 .45639 Mdot
.52997 .32754 Mdot
.48649 .30067 Mdot
.49948 .30869 Mdot
.56437 .3488 Mdot
.55481 .34289 Mdot
.54294 .33555 Mdot
.67492 .41712 Mdot
.37376 .231 Mdot
.63889 .39485 Mdot
.38202 .2361 Mdot
.20783 .12844 Mdot
.7287 .45036 Mdot
.37035 .22889 Mdot
.72079 .44547 Mdot
.5947 .36754 Mdot
.60632 .37473 Mdot
.59956 .37055 Mdot
.50835 .31418 Mdot
.79516 .49143 Mdot
.37057 .22902 Mdot
.66682 .41212 Mdot
.48888 .30214 Mdot
.38319 .23682 Mdot
.28566 .17655 Mdot
.52918 .32705 Mdot
.57755 .35695 Mdot
.59968 .37063 Mdot
.78372 .48436 Mdot
.42998 .26574 Mdot
.55093 .34049 Mdot
.49197 .30406 Mdot
.57364 .35453 Mdot
.47921 .29616 Mdot
.72121 .44573 Mdot
.53787 .33242 Mdot
.56877 .35152 Mdot
.37236 .23013 Mdot
.22822 .14105 Mdot
.41372 .2557 Mdot
.78808 .48706 Mdot
.80937 .50022 Mdot
.46947 .29015 Mdot
.70833 .43777 Mdot
.67855 .41937 Mdot
.43338 .26784 Mdot
.48749 .30128 Mdot
.4661 .28806 Mdot
.64795 .40045 Mdot
.67785 .41893 Mdot
.32643 .20175 Mdot
.46977 .29033 Mdot
.38998 .24102 Mdot
.28965 .17901 Mdot
.40034 .24743 Mdot
.46427 .28693 Mdot
.36511 .22565 Mdot
.22532 .13926 Mdot
.3313 .20475 Mdot
.40771 .25198 Mdot
.46501 .28739 Mdot
.42271 .26125 Mdot
.34511 .21329 Mdot
.67771 .41885 Mdot
.2637 .16297 Mdot
.3859 .2385 Mdot
.75291 .46533 Mdot
.49694 .30713 Mdot
.555 .34301 Mdot
.43704 .27011 Mdot
.37093 .22925 Mdot
.53787 .33242 Mdot
.60324 .37282 Mdot
.57434 .35496 Mdot
.5052 .31223 Mdot
.53913 .3332 Mdot
.49805 .30781 Mdot
.54426 .33637 Mdot
.38781 .23968 Mdot
.90472 .55915 Mdot
.55162 .34092 Mdot
.49644 .30682 Mdot
.71903 .44439 Mdot
.52394 .32382 Mdot
.22121 .13672 Mdot
.5519 .34109 Mdot
.6695 .41378 Mdot
.60741 .3754 Mdot
.23438 .14485 Mdot
.43657 .26981 Mdot
.26396 .16313 Mdot
.56613 .34988 Mdot
.41868 .25876 Mdot
.30502 .18851 Mdot
.61997 .38317 Mdot
.75434 .46621 Mdot
.38376 .23718 Mdot
.41679 .25759 Mdot
.29074 .17969 Mdot
.60402 .37331 Mdot
.64802 .4005 Mdot
.62584 .38679 Mdot
.63141 .39023 Mdot
.72352 .44716 Mdot
.55093 .34049 Mdot
.28074 .1735 Mdot
.73023 .45131 Mdot
.41372 .25569 Mdot
.53601 .33127 Mdot
.31492 .19463 Mdot
.76524 .47295 Mdot
.67511 .41724 Mdot
.75897 .46907 Mdot
.42241 .26106 Mdot
.6734 .41618 Mdot
.49425 .30546 Mdot
.62865 .38853 Mdot
.49125 .30361 Mdot
.72773 .44976 Mdot
.47766 .29521 Mdot
.41272 .25507 Mdot
.44104 .27258 Mdot
.45685 .28235 Mdot
.39237 .2425 Mdot
.51517 .3184 Mdot
.46338 .28638 Mdot
.64767 .40028 Mdot
.74593 .46101 Mdot
.53309 .32946 Mdot
.52111 .32206 Mdot
.55995 .34607 Mdot
.45548 .2815 Mdot
.29379 .18157 Mdot
.41832 .25853 Mdot
.5927 .36631 Mdot
.5182 .32027 Mdot
.36469 .22539 Mdot
.65691 .40599 Mdot
.80263 .49605 Mdot
.16621 .10272 Mdot
.39661 .24512 Mdot
.3829 .23665 Mdot
.32945 .20361 Mdot
.59875 .37005 Mdot
.46764 .28902 Mdot
.5648 .34906 Mdot
.5674 .35067 Mdot
.64382 .3979 Mdot
.6224 .38466 Mdot
.52807 .32637 Mdot
.66182 .40903 Mdot
.34416 .2127 Mdot
.62813 .38821 Mdot
.41398 .25585 Mdot
.59293 .36645 Mdot
.40953 .2531 Mdot
.53925 .33328 Mdot
.68347 .42241 Mdot
.54376 .33606 Mdot
.45897 .28366 Mdot
.59327 .36666 Mdot
.59847 .36988 Mdot
.55343 .34204 Mdot
.49911 .30847 Mdot
.52774 .32616 Mdot
.58939 .36426 Mdot
.40407 .24973 Mdot
.40347 .24936 Mdot
.42258 .26117 Mdot
.79598 .49194 Mdot
.57786 .35714 Mdot
.72901 .45055 Mdot
.4763 .29437 Mdot
.44953 .27782 Mdot
.68975 .42629 Mdot
.28523 .17628 Mdot
.64979 .40159 Mdot
.46707 .28867 Mdot
.86735 .53605 Mdot
.56716 .35052 Mdot
.56009 .34616 Mdot
.6156 .38046 Mdot
.59515 .36782 Mdot
.42949 .26544 Mdot
.5878 .36328 Mdot
.39587 .24466 Mdot
.57638 .35622 Mdot
.67492 .41712 Mdot
.38504 .23797 Mdot
.54001 .33375 Mdot
.52128 .32217 Mdot
.81464 .50348 Mdot
.64851 .4008 Mdot
.5778 .3571 Mdot
.28448 .17582 Mdot
.72255 .44656 Mdot
.58327 .36048 Mdot
.47001 .29048 Mdot
.52876 .32679 Mdot
.63405 .39186 Mdot
.41508 .25653 Mdot
.44794 .27684 Mdot
.53302 .32943 Mdot
.24523 .15156 Mdot
.71426 .44144 Mdot
.50447 .31178 Mdot
.65294 .40354 Mdot
.37262 .23029 Mdot
.48399 .29912 Mdot
.6219 .38436 Mdot
.5781 .35728 Mdot
.38692 .23913 Mdot
.51249 .31674 Mdot
.42559 .26303 Mdot
.31801 .19654 Mdot
.51664 .3193 Mdot
.35477 .21926 Mdot
.6782 .41915 Mdot
.28331 .1751 Mdot
.58216 .35979 Mdot
.56236 .34756 Mdot
.35448 .21908 Mdot
.9216 .56958 Mdot
.39158 .24201 Mdot
.73832 .4563 Mdot
.52029 .32156 Mdot
.7103 .43899 Mdot
.47298 .29232 Mdot
.49386 .30522 Mdot
.62862 .38851 Mdot
.42477 .26252 Mdot
.52035 .3216 Mdot
.66967 .41388 Mdot
.51341 .3173 Mdot
.59091 .3652 Mdot
.82046 .50707 Mdot
.41405 .2559 Mdot
.72822 .45007 Mdot
.59344 .36677 Mdot
.52919 .32706 Mdot
.66617 .41172 Mdot
.25393 .15694 Mdot
.35204 .21757 Mdot
.57968 .35826 Mdot
.63675 .39353 Mdot
.40951 .25309 Mdot
.49607 .30659 Mdot
.41097 .25399 Mdot
.28518 .17625 Mdot
.85143 .52621 Mdot
.68434 .42295 Mdot
.56335 .34817 Mdot
.53469 .33045 Mdot
.41026 .25356 Mdot
.58262 .36008 Mdot
.34442 .21286 Mdot
.62128 .38397 Mdot
.30134 .18624 Mdot
.63801 .39431 Mdot
.5627 .34777 Mdot
.46182 .28542 Mdot
.6979 .43133 Mdot
.54224 .33512 Mdot
.33014 .20404 Mdot
.36763 .22721 Mdot
.37121 .22942 Mdot
.18574 .11479 Mdot
.79722 .49271 Mdot
.54549 .33713 Mdot
.65622 .40557 Mdot
.45003 .27813 Mdot
.25116 .15522 Mdot
.4434 .27404 Mdot
.83768 .51771 Mdot
.41356 .2556 Mdot
.4109 .25395 Mdot
.44902 .27751 Mdot
.47005 .29051 Mdot
.55032 .34012 Mdot
.60978 .37686 Mdot
.73444 .45391 Mdot
.61015 .3771 Mdot
.51341 .3173 Mdot
.59816 .36968 Mdot
.52472 .32429 Mdot
.22201 .13721 Mdot
.39707 .2454 Mdot
.6212 .38393 Mdot
.2397 .14814 Mdot
.46201 .28554 Mdot
.58352 .36063 Mdot
.75382 .46589 Mdot
.55781 .34474 Mdot
.36638 .22644 Mdot
.66841 .4131 Mdot
.23069 .14257 Mdot
.51901 .32077 Mdot
.45716 .28254 Mdot
.56525 .34934 Mdot
.39403 .24352 Mdot
.69535 .42975 Mdot
.58139 .35932 Mdot
.41421 .256 Mdot
.49572 .30637 Mdot
.52208 .32266 Mdot
.70965 .43859 Mdot
.48319 .29863 Mdot
.34801 .21508 Mdot
.3911 .24172 Mdot
.53517 .33075 Mdot
.57589 .35592 Mdot
.78358 .48428 Mdot
.4454 .27527 Mdot
.43586 .26938 Mdot
.48401 .29914 Mdot
.65567 .40522 Mdot
.73019 .45128 Mdot
.62007 .38323 Mdot
.97619 .60332 Mdot
.61993 .38314 Mdot
.70253 .43419 Mdot
.29975 .18526 Mdot
.31325 .1936 Mdot
.44825 .27703 Mdot
.34638 .21407 Mdot
.19797 .12235 Mdot
.54918 .33941 Mdot
.62596 .38687 Mdot
.54276 .33545 Mdot
.59552 .36805 Mdot
.45711 .28251 Mdot
.59161 .36563 Mdot
.43851 .27102 Mdot
.67962 .42003 Mdot
.73838 .45635 Mdot
.49964 .30879 Mdot
.38593 .23852 Mdot
.52447 .32414 Mdot
.50213 .31033 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000Tool2
000Wool3000Vool5000Tool00`00ooooo`0Uool5000Uool3000Wool2000:ool002Koo`03003ooooo
02Coo`03003ooooo02Soo`03003ooooo02?oo`03003oo`0002Soo`03003ooooo02Goo`03003ooooo
02Woo`03003ooooo00Ooo`007ooo0`000ooo00<00?ooool08?oo0`000ooo00<00?ooool08Ooo0`00
0ooo00<00?ooool08ooo00<00?oo0000:?oo00<00?ooool09_oo00<00?ooool09ooo00<00?ooool0
2?oo000Vool00`00ooooo`0Uool00`00ooooo`0Wool00`00ooooo`0Sool00`00ool0000Xool00`00
ooooo`0Vool00`00ooooo`0Xool00`00ooooo`07ool002Coo`03003oo`0002Koo`03003oo`0002So
o`03003ooooo02?oo`03003oo`0002Soo`03003ooooo02Goo`03003oo`0002Ooo`03003oo`0000Wo
o`009Ooo00<00?ooool09_oo00<00?ooool09_oo0P009_oo00<00?ooool09_oo0P00:?oo00<00?oo
ool09ooo00<00?ooool02?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00
4_ooo`004`000ooo000Bool20007ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`03ool20003ool001;oo`03
003ooooo00koo`03003ooooo02Koo`03003ooooo02Ooo`03003ooooo02Ooo`03003ooooo02Koo`03
003ooooo02Ooo`03003ooooo02Koo`03003ooooo00Coo`03003ooooo007oo`004_oo00<00?ooool0
oooo3ooo00<00?ooool00Ooo000Bool00`00ooooo`02ool3003oool:ool00`00ooooo`01ool001;o
o`03003ooooo00;oo`<00?ooo`[oo`03003ooooo007oo`004_oo0P00oooo3ooo0P000ooo000Bool0
0`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`00
2_oo0P001_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000<ool00`00ooooo`03ool00`00oooo
o`3oool?ool00`00ooooo`01ool000Goo`<000?oo`03003ooooo00Coo`800?ooo`koo`<000?oo`00
3?oo00<00?ooool00ooo00<00?ooool0oooo3ooo00<00?ooool00Ooo000:ool00`00ool00005ool0
0`00ooooo`3oool?ool00`00ooooo`01ool000_oo`03003ooooo00Coo`03003ooooo0?ooo`ooo`03
003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000Bool2003oool?ool20003
ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool06?oo0P00m?oo00<0
0?ooool00Ooo000Bool00`00ooooo`0Hool2003dool00`00ooooo`01ool001;oo`03003ooooo0?oo
o`ooo`03003ooooo007oo`004_oo0P007ooo0P00kOoo0P000ooo000Bool00`00ooooo`0Nool2003^
ool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0
8ooo0P00jOoo00<00?ooool00Ooo000Bool00`00ooooo`0Sool2003Yool00`00ooooo`01ool001;o
o`800?ooo`ooo`8000?oo`004_oo00<00?ooool09ooo0P00iOoo00<00?ooool00Ooo000Bool00`00
ooooo`0Wool4003Sool00`00ooooo`01ool001;oo`03003ooooo02Woo`800>?oo`03003ooooo007o
o`004_oo00<00?ooool0;?oo0P00h?oo00<00?ooool00Ooo000Bool2000]ool2003Oool20003ool0
01;oo`03003ooooo02ooo`800=goo`03003ooooo007oo`004_oo00<00?ooool0;ooo0P00gOoo00<0
0?ooool00Ooo000Bool00`00ooooo`0bool2003Jool00`00ooooo`01ool000[oo`<000Goo`03003o
oooo03;oo`800003ool000000=Ooo`03003ooooo007oo`002_oo00<00?ooool01Ooo00<00?ooool0
=Ooo0P00eooo00<00?ooool00Ooo0005ool30003ool00`00ooooo`04ool2003oool>ool30003ool0
00_oo`03003ooooo00Coo`03003ooooo03Soo`<00=?oo`03003ooooo007oo`002_oo00<00?oo0000
1Ooo00<00?ooool0>?oo1@00dOoo00<00?ooool00Ooo000;ool00`00ooooo`04ool00`00ooooo`0j
ool5003?ool00`00ooooo`01ool001;oo`03003ooooo03coo`<00<ooo`03003ooooo007oo`004_oo
0P00?_oo1000c?oo0P000ooo000Bool00`00ooooo`0oool4003;ool00`00ooooo`01ool001;oo`03
003ooooo047oo`@00<Woo`03003ooooo007oo`004_oo00<00?ooool0@ooo0`00b?oo00<00?ooool0
0Ooo000Bool00`00ooooo`14ool20038ool00`00ooooo`01ool001;oo`8004Soo`<00<?oo`8000?o
o`004_oo00<00?ooool0Aooo1@00`_oo00<00?ooool00Ooo000Bool00`00ooooo`19ool40031ool0
0`00ooooo`01ool001;oo`03003ooooo04_oo`@00;ooo`03003ooooo007oo`004_oo00<00?ooool0
C?oo1000__oo00<00?ooool00Ooo000Bool2001?ool5002jool20003ool001;oo`03003ooooo04oo
o`D00;[oo`03003ooooo007oo`004_oo00<00?ooool0D_oo0`00^Ooo00<00?ooool00Ooo000Bool0
0`00ooooo`1Cool4002gool00`00ooooo`01ool001;oo`03003ooooo05Goo`<00;Koo`03003ooooo
007oo`004_oo0P00Eooo0P00]Ooo0P000ooo000Bool00`00ooooo`1Jool2002bool00`00ooooo`01
ool001;oo`03003ooooo05[oo`@00;3oo`03003ooooo007oo`002Ooo1@001?oo00<00?ooool0Fooo
1000[ooo00<00?ooool00Ooo000;ool00`00ooooo`04ool00`00ooooo`1Lool3002_ool00`00oooo
o`01ool000Goo`<000?oo`03003ooooo00Coo`80067oo`800:[oo`<000?oo`002ooo00<00?ooool0
1?oo00<00?ooool0H?oo1000Z_oo00<00?ooool00Ooo000;ool00`00ooooo`04ool00`00ooooo`1Q
ool4002Yool00`00ooooo`01ool000[oo`8000Koo`03003ooooo06?oo`@00:Ooo`03003ooooo007o
o`004_oo00<00?ooool0I?oo1@00YOoo00<00?ooool00Ooo000Bool2001Wool4002Sool20003ool0
01;oo`03003ooooo06Soo`@00:;oo`03003ooooo007oo`004_oo00<00?ooool0JOoo1@00X?oo00<0
0?ooool00Ooo000Bool00`00ooooo`1[ool5002Nool00`00ooooo`01ool001;oo`03003ooooo06co
o`D009goo`03003ooooo007oo`004_oo00<00?ooool0K_oo1@00Vooo00<00?ooool00Ooo000Bool2
001`ool5002Iool20003ool001;oo`03003ooooo077oo`D009Soo`03003ooooo007oo`004_oo00<0
0?ooool0Looo1@00U_oo00<00?ooool00Ooo000Bool00`00ooooo`1dool5002Eool00`00ooooo`01
ool001;oo`03003ooooo07Koo`D009?oo`03003ooooo007oo`004_oo0P00NOoo1@00T?oo0P000ooo
000Bool00`00ooooo`1iool5002@ool00`00ooooo`01ool001;oo`03003ooooo07_oo`D008koo`03
003ooooo007oo`004_oo00<00?ooool0O?oo1@00SOoo00<00?ooool00Ooo000Bool00`00ooooo`1n
ool5002;ool00`00ooooo`01ool001;oo`80087oo`@008Woo`8000?oo`004_oo00<00?ooool0POoo
1@00R?oo00<00?ooool00Ooo000Bool00`00ooooo`23ool50026ool00`00ooooo`01ool000_oo`03
003ooooo00Coo`03003ooooo08Coo`D008Goo`03003ooooo007oo`002_oo00<00?oo00001Ooo00<0
0?ooool0Q_oo1@00Pooo00<00?ooool00Ooo000:ool00`00ool00005ool20029ool5001oool30003
ool000[oo`03003oo`0000Goo`03003ooooo08[oo`@0083oo`03003ooooo007oo`002_oo00<00?oo
00001Ooo00<00?ooool0Rooo1@00O_oo00<00?ooool00Ooo000;ool00`00ooooo`04ool00`00oooo
o`2=ool5001lool00`00ooooo`01ool001;oo`03003ooooo08koo`D007_oo`03003ooooo007oo`00
4_oo0P00TOoo1@00N?oo0P000ooo000Bool00`00ooooo`2Bool4001hool00`00ooooo`01ool001;o
o`03003ooooo09?oo`D007Koo`03003ooooo007oo`004_oo00<00?ooool0UOoo1000MOoo00<00?oo
ool00Ooo000Bool00`00ooooo`2Fool5001cool00`00ooooo`01ool001;oo`8009Woo`D0073oo`80
00?oo`004_oo00<00?ooool0V_oo1@00Kooo00<00?ooool00Ooo000Bool00`00ooooo`2Kool5001^
ool00`00ooooo`01ool001;oo`03003ooooo09goo`D006coo`03003ooooo007oo`004_oo00<00?oo
ool0W_oo1@00Jooo00<00?ooool00Ooo000Bool2002Qool5001Xool20003ool001;oo`03003ooooo
0:;oo`D006Ooo`03003ooooo007oo`004_oo00<00?ooool0Y?oo1000I_oo00<00?ooool00Ooo000B
ool00`00ooooo`2Uool5001Tool00`00ooooo`01ool001;oo`03003ooooo0:Ooo`@006?oo`03003o
oooo007oo`004_oo00<00?ooool0ZOoo1000HOoo00<00?ooool00Ooo000Bool2002[ool5001Nool2
0003ool001;oo`03003ooooo0:coo`@005koo`03003ooooo007oo`004_oo00<00?ooool0[Ooo1@00
G?oo00<00?ooool00Ooo0009ool50004ool00`00ooooo`2_ool4001Kool00`00ooooo`01ool000_o
o`03003ooooo00Coo`03003ooooo0;7oo`@005Woo`03003ooooo007oo`002ooo00<00?ooool01?oo
0P00/ooo1@00EOoo0`000ooo000;ool00`00ooooo`04ool00`00ooooo`2cool5001Fool00`00oooo
o`01ool000_oo`03003ooooo00Coo`03003ooooo0;Goo`D005Coo`03003ooooo007oo`002_oo0P00
1_oo00<00?ooool0]ooo1@00D_oo00<00?ooool00Ooo000Bool00`00ooooo`2hool5001Aool00`00
ooooo`01ool001;oo`800;_oo`@004ooo`8000?oo`004_oo00<00?ooool0_?oo1000C_oo00<00?oo
ool00Ooo000Bool00`00ooooo`2mool4001=ool00`00ooooo`01ool001;oo`03003ooooo0;ooo`D0
04[oo`03003ooooo007oo`004_oo00<00?ooool0`Ooo1000BOoo00<00?ooool00Ooo000Bool20034
ool40016ool20003ool001;oo`03003ooooo0<Coo`D004Goo`03003ooooo007oo`004_oo00<00?oo
ool0a_oo1000A?oo00<00?ooool00Ooo000Bool00`00ooooo`38ool40012ool00`00ooooo`01ool0
01;oo`03003ooooo0<Woo`@0047oo`03003ooooo007oo`004_oo0P00booo1@00?_oo0P000ooo000B
ool00`00ooooo`3=ool2000oool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo
007oo`004_oo00<00?ooool0dOoo0P00>ooo00<00?ooool00Ooo000Bool00`00ooooo`3Aool4000i
ool00`00ooooo`01ool001;oo`800=?oo`<003Soo`8000?oo`004_oo00<00?ooool0eOoo0`00=_oo
00<00?ooool00Ooo000Bool00`00ooooo`3Eool5000dool00`00ooooo`01ool000[oo`<000Goo`03
003ooooo0=Ooo`@003?oo`03003ooooo007oo`002_oo00<00?ooool01Ooo00<00?ooool0fOoo1000
<Ooo00<00?ooool00Ooo000;ool00`00ooooo`04ool2003Lool4000]ool30003ool000_oo`03003o
oooo00Coo`03003ooooo0=coo`D002goo`03003ooooo007oo`002_oo00<00?oo00001Ooo00<00?oo
ool0gooo0P00;Ooo00<00?ooool00Ooo000;ool00`00ooooo`04ool00`00ooooo`3Qool3000Zool0
0`00ooooo`01ool001;oo`03003ooooo0>7oo`@002Woo`03003ooooo007oo`004_oo0P00i?oo1000
9_oo0P000ooo000Bool00`00ooooo`3Uool2000Wool00`00ooooo`01ool001;oo`03003ooooo0?oo
o`ooo`03003ooooo007oo`004_oo00<00?ooool0jOoo0P008ooo00<00?ooool00Ooo000Bool00`00
ooooo`3Yool2000Sool00`00ooooo`01ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`00
4_oo0P00oooo3ooo0P000ooo000Bool00`00ooooo`3oool?ool00`00ooooo`01ool001;oo`03003o
oooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0looo0`006?oo00<00?ooool00Ooo000B
ool00`00ooooo`3cool3000Hool00`00ooooo`01ool001;oo`800?ooo`ooo`8000?oo`004_oo00<0
0?ooool0n?oo0P005?oo00<00?ooool00Ooo000Bool00`00ooooo`3hool2000Dool00`00ooooo`01
ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`004_oo00<00?ooool0oooo3ooo00<00?oo
ool00Ooo000Bool2003oool?ool20003ool001;oo`03003ooooo0?ooo`ooo`03003ooooo007oo`00
4_oo00<00?ooool0oooo3ooo00<00?ooool00Ooo000:ool20006ool00`00ooooo`3oool?ool00`00
ooooo`01ool000coo`03003ooooo00?oo`03003ooooo0?ooo`ooo`03003ooooo007oo`002ooo00<0
0?ooool01?oo0P00oooo2Ooo0P000ooo0`000ooo000<ool00`00ooooo`03ool00`00ooooo`3oool8
ool20005ool00`00ooooo`01ool000[oo`03003oo`0000Goo`03003ooooo0?ooo`ooo`03003ooooo
007oo`002ooo00<00?ooool01?oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<0
0?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<0
0?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<0
0?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<0
0?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<0
0?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<0
0?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01?oo00<0
0?ooool00Ooo000Boooo000C0003ool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-3.85207, -3.89866, \
0.0240713, 0.0389481}}]
}, Open  ]],

Cell["Markowitz Efficient Portfolio", "Subsection",
  CellTags->{"S0.2", "2.1"}],

Cell["First we load the subpackage. ", "MathCaption",
  CellTags->{"S0.2", "2.2"}],

Cell["<< Finance`Examples`", "Input",
  CellLabel->"In[27]:=",
  CellTags->"S0.2"],

Cell["\<\
This package modifies the mean and covariance functions so that \
they can be used in the multivariate case. The other functions will be \
explained below. \
\>", "MathCaption",
  CellTags->{"S0.2", "2.3"}],

Cell[CellGroupData[{

Cell["?Finance`Examples`*", "Input",
  CellLabel->"In[28]:=",
  CellTags->"S0.2"],

Cell["\<\
CovarianceMatrix  MeanVector        PortfolioVariance
EfficientFrontier PortfolioMean     ShowWeights\
\>", "Print",
  CellLabel->"From In[28]:="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["MeanVector",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["vectors",
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["give",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["mean",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["vector",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], "a", 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["list",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["vectors",
                "TraditionalForm"]}]}
          }], TopBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["CovarianceMatrix",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["vectors",
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[" ",
              "MR"], 
            RowBox[{
              StyleBox["give",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["covariance",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["matrix",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], "a", 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["list",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["vectors",
                "TraditionalForm"]}]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["PortfolioMean",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(weights, \ means\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[\(compute\ the\ portfolio\ mean\ given\ the\ weights\ \
and\ the\ list\ of\ mean\ returns\),
              "TraditionalForm"]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["EfficientFrontier",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(means, \ covariances, \ x\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], " "}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[\(return\ the\ parametric\ form\ of\ the\ Markowitz\ \
efficient\ frontier\ given\ the\ vector\ of\ mean\ returns\ and\ matrix\ of\ \
covariances\ of\ assests'\ returns\ using\ x\ as\ the\ parameter\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Auxiliary functions. ", "Caption",
  CellTags->"S0.2"],

Cell[TextData[{
  "The file ",
  StyleBox["stocks1.ret", "TI"],
  " contains the returns of five stocks in 24 consecutive months. The first \
line just contains the number of stocks, the second line contains the time \
unit and the stocks' tickers, and the remaining lines start with the month \
number followed by the returns of stocks. "
}], "Text",
  CellTags->{"S0.2", "2.5"}],

Cell[TextData[StyleBox["5\nMonth\tAMR\tBS\t UTX\t  WX\t   Z    \n 1   11.594  \
  1.515   -1.579   -9.360   -0.408\n 2   22.078    5.299    9.947    7.578    \
0.000\n 3   -8.511   -8.000    9.446  -16.327    0.694\n 4   -3.488    0.395  \
  5.164   -8.571   -3.862\n 5   -9.639   -9.764   -3.571  -18.243  -10.949\n \
6  -12.000    6.195   -0.943  -11.570   -8.197\n 7  -10.606   -0.417   -7.619 \
  -8.441   -6.786\n 8   -1.695   -6.276   11.856   -8.220  -13.725\n 9  \
-12.069   -9.091   -3.286  -10.227   -2.273\n10   27.451   15.000   11.186   \
-3.797    2.791\n11  -21.538   -4.465    6.550   -4.021   -8.140\n12  -19.608 \
  -6.132    8.750   12.676   -5.063\n13   48.780   27.156    4.215   12.500   \
35.200\n14   19.672   -2.372    7.355   15.271   12.121\n15    1.370   15.190 \
  13.889   18.000   -0.901\n16    4.054   15.751   17.073   -0.847   18.548\n\
17  -15.584   -9.810    1.042   23.884  -10.958\n18    3.077    4.270   \
20.833    4.196   14.912\n19   -4.478   -6.485   -7.543   -4.027   -5.058\n20 \
   4.688   11.679    3.263   -6.333    4.918\n21  -11.940   -7.285    3.189  \
-18.939   -3.125\n22   -1.695   -3.214   -7.506   -2.856   27.742\n23   \
15.517    0.369   -3.580    5.882   16.026\n24    5.970   -1.866   -7.250   \
-0.926   -2.762\n25   11.268   26.616   15.903   16.822   13.295",
  FontSize->10]], "Print",
  CellLabel->"From In[4]:="],

Cell["We have to open a stream to read in the data. ", "MathCaption",
  CellTags->{"S0.2", "2.6"}],

Cell["\<\
stream = OpenRead[ToFileName[{\"Finance\",\"Data\"}, \
\"stocks1.ret\"]];\
\>", "Input",
  CellLabel->"In[29]:=",
  CellTags->"S0.2"],

Cell["We get the number of assets. ", "MathCaption",
  CellTags->{"S0.2", "2.7"}],

Cell[CellGroupData[{

Cell["n = Read[stream, Number]", "Input",
  CellLabel->"In[30]:=",
  CellTags->"S0.2"],

Cell[BoxData[
    \(5\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["We read in the tickers. ", "MathCaption",
  CellTags->{"S0.2", "2.8"}],

Cell[CellGroupData[{

Cell["\<\
tickers = Rest[Read[stream, Table[Word,{n+1}],
   RecordSeparators -> {\"\\n\",\" \", \"\\t\"}]]\
\>", "Input",
  CellLabel->"In[31]:=",
  CellTags->"S0.2"],

Cell[BoxData[
    \({"AMR", "BS", "UTX", "WX", "Z"}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["We read in the rest of the data. ", "MathCaption",
  CellTags->{"S0.2", "2.9"}],

Cell["aux = Transpose[Partition[ReadList[stream, Number], n+1]];", "Input",
  CellLabel->"In[32]:=",
  CellTags->"S0.2"],

Cell["Finally we close the stream. ", "MathCaption",
  CellTags->{"S0.2", "2.10"}],

Cell["Close[stream];", "Input",
  CellLabel->"In[33]:=",
  CellTags->"S0.2"],

Cell["This defines lists of the months and the stocks' returns. ", \
"MathCaption",
  CellTags->{"S0.2", "2.11"}],

Cell["{months, returns} = {First[aux], Transpose[Rest[aux]]};", "Input",
  CellLabel->"In[34]:=",
  CellTags->"S0.2"],

Cell["These are the means of the returns for each stock. ", "MathCaption",
  CellTags->{"S0.2", "2.12"}],

Cell[CellGroupData[{

Cell["mean1 = MeanVector[returns]", "Input",
  CellLabel->"In[35]:=",
  CellTags->"S0.2"],

Cell[BoxData[
    \({1.70671999999999997`, 2.17032000000000024`, 
      4.2713599999999996`, \(-0.635840000000000138`\), 
      2.56159999999999987`}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["We can display this in tabular form. ", "MathCaption",
  CellTags->{"S0.2", "2.13"}],

Cell[CellGroupData[{

Cell["\<\
PaddedForm[TableForm[mean1,
   TableHeadings -> {tickers},
   TableAlignments -> {Right}], {6, 3}]\
\>", "Input",
  CellLabel->"In[36]:=",
  CellTags->"S0.2"],

Cell[BoxData[
    TagBox[
      InterpretationBox[GridBox[{
            {"\<\"AMR\"\>", 
              InterpretationBox["\<\"   1.707\"\>",
                1.70672,
                AutoDelete->True]},
            {"\<\"BS\"\>", 
              InterpretationBox["\<\"   2.170\"\>",
                2.1703200000000002,
                AutoDelete->True]},
            {"\<\"UTX\"\>", 
              InterpretationBox["\<\"   4.271\"\>",
                4.2713599999999996,
                AutoDelete->True]},
            {"\<\"WX\"\>", 
              InterpretationBox["\<\"  -0.636\"\>",
                -0.63584000000000018,
                AutoDelete->True]},
            {"\<\"Z\"\>", 
              InterpretationBox["\<\"   2.562\"\>",
                2.5615999999999999,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Right}],
        TableForm[ {1.70672, 2.1703200000000002, 
          4.2713599999999996, -0.63584000000000018, 2.5615999999999999}, 
          TableHeadings -> {{"AMR", "BS", "UTX", "WX", "Z"}}, 
          TableAlignments -> {Right}]],
      (PaddedForm[ #, {6, 3}]&)]], "Output",
  CellLabel->"Out[36]//PaddedForm="]
}, Open  ]],

Cell["Next we compute the covariance matrix. ", "MathCaption",
  CellTags->{"S0.2", "2.14"}],

Cell["cov1 = CovarianceMatrix[returns];", "Input",
  CellLabel->"In[37]:=",
  CellTags->"S0.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?PrependTo\)\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \("PrependTo[s, elem] prepends elem to the value of s, and resets s to \
the result."\)], "Print"]
}, Open  ]],

Cell["Here is its display. ", "MathCaption",
  CellTags->{"S0.2", "2.15"}],

Cell[CellGroupData[{

Cell["\<\
PaddedForm[TableForm[Prepend[cov1,
   Map[StringJoin[\"    \",  #]&, tickers]],
   TableHeadings->{PrependTo[tickers, \"  \"]}], {6,  3}]\
\>", "Input",
  CellLabel->"In[39]:=",
  CellTags->"S0.2"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"  \"\>", "\<\"    AMR\"\>", "\<\"    BS\"\>", "\<\"    \
UTX\"\>", "\<\"    WX\"\>", "\<\"    Z\"\>"},
            {"\<\"AMR\"\>", 
              InterpretationBox["\<\" 254.458\"\>",
                254.45827836160007,
                AutoDelete->True], 
              InterpretationBox["\<\" 115.232\"\>",
                115.23174056960001,
                AutoDelete->True], 
              InterpretationBox["\<\"  26.066\"\>",
                26.066371740800008,
                AutoDelete->True], 
              InterpretationBox["\<\"  63.875\"\>",
                63.874624044800001,
                AutoDelete->True], 
              InterpretationBox["\<\" 129.417\"\>",
                129.41675340800001,
                AutoDelete->True]},
            {"\<\"BS\"\>", 
              InterpretationBox["\<\" 115.232\"\>",
                115.23174056960001,
                AutoDelete->True], 
              InterpretationBox["\<\" 112.220\"\>",
                112.21967301759999,
                AutoDelete->True], 
              InterpretationBox["\<\"  39.865\"\>",
                39.865239244799994,
                AutoDelete->True], 
              InterpretationBox["\<\"  48.934\"\>",
                48.934443068799993,
                AutoDelete->True], 
              InterpretationBox["\<\"  75.755\"\>",
                75.755004008000014,
                AutoDelete->True]},
            {"\<\"UTX\"\>", 
              InterpretationBox["\<\"  26.066\"\>",
                26.066371740800008,
                AutoDelete->True], 
              InterpretationBox["\<\"  39.865\"\>",
                39.865239244799994,
                AutoDelete->True], 
              InterpretationBox["\<\"  66.902\"\>",
                66.902126870399997,
                AutoDelete->True], 
              InterpretationBox["\<\"  32.599\"\>",
                32.5987653424,
                AutoDelete->True], 
              InterpretationBox["\<\"  17.664\"\>",
                17.663964703999998,
                AutoDelete->True]},
            {"\<\"WX\"\>", 
              InterpretationBox["\<\"  63.875\"\>",
                63.874624044800001,
                AutoDelete->True], 
              InterpretationBox["\<\"  48.934\"\>",
                48.934443068799993,
                AutoDelete->True], 
              InterpretationBox["\<\"  32.599\"\>",
                32.5987653424,
                AutoDelete->True], 
              InterpretationBox["\<\" 136.805\"\>",
                136.80536829440001,
                AutoDelete->True], 
              InterpretationBox["\<\"  47.834\"\>",
                47.834396024,
                AutoDelete->True]},
            {"\<\"Z\"\>", 
              InterpretationBox["\<\" 129.417\"\>",
                129.41675340800001,
                AutoDelete->True], 
              InterpretationBox["\<\"  75.755\"\>",
                75.755004008000014,
                AutoDelete->True], 
              InterpretationBox["\<\"  17.664\"\>",
                17.663964703999998,
                AutoDelete->True], 
              InterpretationBox["\<\"  47.834\"\>",
                47.834396024,
                AutoDelete->True], 
              InterpretationBox["\<\" 148.859\"\>",
                148.85927064000001,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        (TableForm[ #, TableHeadings -> {{"  ", "AMR", "BS", "UTX", "WX", 
          "Z"}}]&)],
      (PaddedForm[ #, {6, 3}]&)]], "Output",
  CellLabel->"Out[39]//PaddedForm="]
}, Open  ]],

Cell["We will use these labels several times. ", "MathCaption",
  CellTags->{"S0.2", "2.16"}],

Cell["\<\
(label1 = \"Markowitz Efficient Frontier\";
 label2 = {\"Portfolio Variance\", \"Portfolio Mean\"};
 label3 = {\"Portfolio Standard Deviation\",
    \"Portfolio Mean\"}; )\
\>", "Input",
  CellLabel->"In[40]:=",
  CellTags->"S0.2"],

Cell["\<\
The efficient frontier is a parabola in the variance\[Hyphen]mean \
plane. \
\>", "MathCaption",
  CellTags->{"S0.2", "2.17"}],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot[Evaluate[EfficientFrontier[mean1, cov1, x]], {x, \
-.1, 1}, PlotLabel -> label1, FrameLabel -> label2];\
\>", "Input",
  CellLabel->"In[41]:=",
  CellTags->"S0.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.9683 0.0195411 -0.147568 0.121618 [
[.00875 -0.0125 -6 -9 ]
[.00875 -0.0125 6 0 ]
[.20416 -0.0125 -6 -9 ]
[.20416 -0.0125 6 0 ]
[.39957 -0.0125 -6 -9 ]
[.39957 -0.0125 6 0 ]
[.59498 -0.0125 -6 -9 ]
[.59498 -0.0125 6 0 ]
[.7904 -0.0125 -6 -9 ]
[.7904 -0.0125 6 0 ]
[.98581 -0.0125 -9 -9 ]
[.98581 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -56 -24 ]
[.5 -0.0125 56 -9 ]
[-0.0125 .09567 -6 -4.5 ]
[-0.0125 .09567 0 4.5 ]
[-0.0125 .21729 -6 -4.5 ]
[-0.0125 .21729 0 4.5 ]
[-0.0125 .3389 -6 -4.5 ]
[-0.0125 .3389 0 4.5 ]
[-0.0125 .46052 -6 -4.5 ]
[-0.0125 .46052 0 4.5 ]
[-0.0125 .58214 -6 -4.5 ]
[-0.0125 .58214 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -21 -44 ]
[-0.01875 .30902 -6 44 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -86 0 ]
[.5 .63053 86 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00875 0 m
.00875 .00625 L
s
[(50)] .00875 -0.0125 0 1 Mshowa
.20416 0 m
.20416 .00625 L
s
[(60)] .20416 -0.0125 0 1 Mshowa
.39957 0 m
.39957 .00625 L
s
[(70)] .39957 -0.0125 0 1 Mshowa
.59498 0 m
.59498 .00625 L
s
[(80)] .59498 -0.0125 0 1 Mshowa
.7904 0 m
.7904 .00625 L
s
[(90)] .7904 -0.0125 0 1 Mshowa
.98581 0 m
.98581 .00625 L
s
[(100)] .98581 -0.0125 0 1 Mshowa
.125 Mabswid
.04784 0 m
.04784 .00375 L
s
.08692 0 m
.08692 .00375 L
s
.126 0 m
.126 .00375 L
s
.16508 0 m
.16508 .00375 L
s
.24325 0 m
.24325 .00375 L
s
.28233 0 m
.28233 .00375 L
s
.32141 0 m
.32141 .00375 L
s
.36049 0 m
.36049 .00375 L
s
.43866 0 m
.43866 .00375 L
s
.47774 0 m
.47774 .00375 L
s
.51682 0 m
.51682 .00375 L
s
.5559 0 m
.5559 .00375 L
s
.63407 0 m
.63407 .00375 L
s
.67315 0 m
.67315 .00375 L
s
.71223 0 m
.71223 .00375 L
s
.75131 0 m
.75131 .00375 L
s
.82948 0 m
.82948 .00375 L
s
.86856 0 m
.86856 .00375 L
s
.90764 0 m
.90764 .00375 L
s
.94672 0 m
.94672 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -117 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Portfolio) show
123.000000 15.000000 moveto
(Variance) show
171.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .09567 m
.00625 .09567 L
s
[(2)] -0.0125 .09567 1 0 Mshowa
0 .21729 m
.00625 .21729 L
s
[(3)] -0.0125 .21729 1 0 Mshowa
0 .3389 m
.00625 .3389 L
s
[(4)] -0.0125 .3389 1 0 Mshowa
0 .46052 m
.00625 .46052 L
s
[(5)] -0.0125 .46052 1 0 Mshowa
0 .58214 m
.00625 .58214 L
s
[(6)] -0.0125 .58214 1 0 Mshowa
.125 Mabswid
0 .11999 m
.00375 .11999 L
s
0 .14431 m
.00375 .14431 L
s
0 .16864 m
.00375 .16864 L
s
0 .19296 m
.00375 .19296 L
s
0 .24161 m
.00375 .24161 L
s
0 .26593 m
.00375 .26593 L
s
0 .29026 m
.00375 .29026 L
s
0 .31458 m
.00375 .31458 L
s
0 .36323 m
.00375 .36323 L
s
0 .38755 m
.00375 .38755 L
s
0 .41187 m
.00375 .41187 L
s
0 .4362 m
.00375 .4362 L
s
0 .48484 m
.00375 .48484 L
s
0 .50917 m
.00375 .50917 L
s
0 .53349 m
.00375 .53349 L
s
0 .55782 m
.00375 .55782 L
s
0 .07134 m
.00375 .07134 L
s
0 .04702 m
.00375 .04702 L
s
0 .0227 m
.00375 .0227 L
s
0 .60646 m
.00375 .60646 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -118.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 11.5 translate
90 rotate
-105 -11.5 translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Portfolio) show
123.000000 15.000000 moveto
(Mean) show
147.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.00875 .61178 m
.00875 .61803 L
s
.20416 .61178 m
.20416 .61803 L
s
.39957 .61178 m
.39957 .61803 L
s
.59498 .61178 m
.59498 .61803 L
s
.7904 .61178 m
.7904 .61803 L
s
.98581 .61178 m
.98581 .61803 L
s
.125 Mabswid
.04784 .61428 m
.04784 .61803 L
s
.08692 .61428 m
.08692 .61803 L
s
.126 .61428 m
.126 .61803 L
s
.16508 .61428 m
.16508 .61803 L
s
.24325 .61428 m
.24325 .61803 L
s
.28233 .61428 m
.28233 .61803 L
s
.32141 .61428 m
.32141 .61803 L
s
.36049 .61428 m
.36049 .61803 L
s
.43866 .61428 m
.43866 .61803 L
s
.47774 .61428 m
.47774 .61803 L
s
.51682 .61428 m
.51682 .61803 L
s
.5559 .61428 m
.5559 .61803 L
s
.63407 .61428 m
.63407 .61803 L
s
.67315 .61428 m
.67315 .61803 L
s
.71223 .61428 m
.71223 .61803 L
s
.75131 .61428 m
.75131 .61803 L
s
.82948 .61428 m
.82948 .61803 L
s
.86856 .61428 m
.86856 .61803 L
s
.90764 .61428 m
.90764 .61803 L
s
.94672 .61428 m
.94672 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09567 m
1 .09567 L
s
.99375 .21729 m
1 .21729 L
s
.99375 .3389 m
1 .3389 L
s
.99375 .46052 m
1 .46052 L
s
.99375 .58214 m
1 .58214 L
s
.125 Mabswid
.99625 .11999 m
1 .11999 L
s
.99625 .14431 m
1 .14431 L
s
.99625 .16864 m
1 .16864 L
s
.99625 .19296 m
1 .19296 L
s
.99625 .24161 m
1 .24161 L
s
.99625 .26593 m
1 .26593 L
s
.99625 .29026 m
1 .29026 L
s
.99625 .31458 m
1 .31458 L
s
.99625 .36323 m
1 .36323 L
s
.99625 .38755 m
1 .38755 L
s
.99625 .41187 m
1 .41187 L
s
.99625 .4362 m
1 .4362 L
s
.99625 .48484 m
1 .48484 L
s
.99625 .50917 m
1 .50917 L
s
.99625 .53349 m
1 .53349 L
s
.99625 .55782 m
1 .55782 L
s
.99625 .07134 m
1 .07134 L
s
.99625 .04702 m
1 .04702 L
s
.99625 .0227 m
1 .0227 L
s
.99625 .60646 m
1 .60646 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -147 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Markowitz) show
123.000000 15.000000 moveto
(Efficient) show
183.000000 15.000000 moveto
(Frontier) show
231.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.36719 .01472 m
.29695 .03859 L
.22949 .06463 L
.17484 .08909 L
.13023 .11261 L
.0913 .13765 L
.06216 .16175 L
.05046 .17403 L
.04016 .18736 L
.03261 .20019 L
.02983 .20631 L
.0277 .21204 L
.02607 .21761 L
.02541 .22048 L
.02481 .22361 L
.02454 .22538 L
.02432 .22702 L
.02414 .22873 L
.02401 .23027 L
.02396 .231 L
.02391 .23179 L
.02388 .23247 L
.02385 .23322 L
.02383 .23401 L
.02382 .23445 L
.02381 .23485 L
.02381 .23558 L
.02381 .23636 L
.02383 .23711 L
.02384 .23754 L
.02385 .23794 L
.02388 .23875 L
.02393 .23962 L
.02403 .2412 L
.02416 .24265 L
.02458 .24598 L
.02518 .24949 L
.02659 .25542 L
.02871 .26192 L
.03424 .27404 L
.04244 .28699 L
.05323 .30018 L
.06565 .31264 L
.09544 .33641 L
.13587 .3617 L
.18331 .38605 L
.2368 .40947 L
.30224 .4344 L
.37348 .45839 L
.45812 .4839 L
Mistroke
.54832 .50848 L
.6431 .53211 L
.75261 .55727 L
.86645 .58148 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool006?oo`<000Coo`8000;oo`<000?oo`8000;oo`<000?o
o`8000;oo`<000;oo`<000?oo`8001;oo`8000;oo`@00004ool000000002ool30002ool60002ool0
0`00ool000020003ool2001Jool006Coo`03003ooooo00;oo`04003ooooo0002ool01@00oooooooo
00000_oo00@00?ooool000?oo`04003ooooo0002ool00`00ooooo`02ool01@00oooooooo00000_oo
00<00?ooool03_oo00<00?oo00000_oo0`000ooo00<00?ooool00_oo00@00?ooooooo`<000;oo`06
003ooooo003oo`001?oo00<00?ooool0F_oo001Tool30002ool01000ooooo`000_oo00D00?oooooo
o`0000Goo`05003oooooool00002ool01000ooooo`001?oo00D00?ooooooo`0000;oo`03003ooooo
00koo`03003oo`0000Coo`05003oooooool00004ool00`00ooooo`03ool01000ooooo`000_oo00<0
0?oo00001?oo0`00F_oo001Tool01000ooooo`000_oo0P000_oo20000_oo0`000ooo0P000ooo00@0
0?ooooooo`8000Coo`80017oo`04003ooooo0002ool20002ool400000ooo00000004ool200000ooo
000000020002ool30002ool3001Jool006Coo`04003ooooo000;ool00`00ooooo`03ool00`00oooo
o`07ool00`00ooooo`0Iool01@00oooooooo0000O?oo001Sool4000Cool00`00ooooo`05ool20004
ool00`00ooooo`0Dool200000ooo0000000<ool00`00ooooo`1]ool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo000/ool00`00ooooo`02ool00`00ooooo`0Qool20004ool00`00
ooooo`0Rool00`00ooooo`02ool00`00ooooo`0Rool00`00ooooo`02ool00`00ooooo`0Qool20004
ool00`00ooooo`0Mool50002ool00`00ooooo`02ool00`00ooooo`0Hool002_oo`03003oo`0000;o
o`03003oo`0002;oo`03003oo`0000;oo`03003oo`0002?oo`07003oooooool00?oo00008_oo00<0
0?oo00000_oo00<00?oo00009?oo00H00?ooool00?oo000Pool01`00oooooooo003oo`0000;oo`03
003oo`0001Woo`00;Ooo00H00?ooool00?oo000Rool00`00ool00002ool00`00ool0000Sool01`00
oooooooo003oo`0002;oo`03003oo`0000;oo`03003oo`0002?oo`8000;oo`03003oo`00023oo`07
003oooooool00?oo00000_oo00<00?oo00006Ooo000[ool20003ool00`00ool0000Rool20003ool0
0`00ool0000Tool01P00ooooo`00ool002?oo`07003oooooool00?oo00008_oo00<00?oo00000_oo
00<00?oo00008?oo00L00?ooooooo`00ool00002ool00`00ool0000Iool002_oo`03003ooooo00;o
o`03003oo`0002;oo`03003ooooo00;oo`03003oo`0002;oo`03003oo`0000;oo`03003oo`0002;o
o`03003oo`0000;oo`03003oo`0002;oo`03003oo`0000;oo`03003oo`00023oo`07003oooooool0
0?oo00000_oo00<00?oo00006Ooo000[ool30003ool00`00ooooo`0Rool20003ool00`00ooooo`0Q
ool30003ool00`00ooooo`0Rool00`00ooooo`02ool00`00ooooo`0Rool20003ool00`00ooooo`0N
ool20004ool00`00ooooo`02ool00`00ooooo`0Hool00?ooob7oo`00oooo8Ooo003ooolQool00?oo
ob7oo`00;Ooof0006ooo000]ool00`00ool00008ool00`00ooooo`05ool00`00ooooo`05ool00`00
ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00
ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00
ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`06ool01000ooooo`006ooo000]ool00`00ool0000Yool00`00ooooo`0W
ool00`00ooooo`0Wool00`00ooooo`0Wool00`00ooooo`0Wool01000ooooo`006ooo000]ool00`00
ooooo`1;ool20027ool00`00ooooo`0Iool002goo`03003ooooo04Woo`8008Woo`03003ooooo01Wo
o`00;Ooo0P00Aooo0`00R_oo0P006ooo000]ool00`00ooooo`14ool2002>ool00`00ooooo`0Iool0
02goo`03003ooooo047oo`<0093oo`03003ooooo01Woo`00;Ooo00<00?ooool0?ooo0P00Tooo00<0
0?ooool06Ooo000]ool00`00ooooo`0lool3002Eool00`00ooooo`0Iool002goo`8003[oo`<009Oo
o`8001_oo`00;Ooo00<00?ooool0=ooo0P00Vooo00<00?ooool06Ooo000]ool00`00ooooo`0dool3
002Mool00`00ooooo`0Iool002goo`03003ooooo037oo`<00:3oo`03003ooooo01Woo`00;Ooo00<0
0?ooool0;_oo0`00Xooo00<00?ooool06Ooo000]ool00`00ooooo`0/ool2002Vool00`00ooooo`0I
ool002goo`8002_oo`800:Ooo`8001_oo`00;Ooo00<00?ooool09ooo0`00Z_oo00<00?ooool06Ooo
000]ool00`00ooooo`0Uool2002]ool00`00ooooo`0Iool002Ooo`<000?oo`03003ooooo02?oo`80
0:ooo`03003ooooo01Woo`009ooo00<00?ooool00ooo00<00?ooool08Ooo0P00/Ooo00<00?ooool0
6Ooo000Xool00`00ooooo`02ool3000Oool2002aool3000Kool002Soo`03003ooooo00;oo`03003o
oooo01goo`800;Goo`03003ooooo01Woo`009ooo00<00?oo00000ooo00<00?ooool06ooo0P00]ooo
00<00?ooool06Ooo000Xool00`00ooooo`02ool00`00ooooo`0Iool2002iool00`00ooooo`0Iool0
02goo`03003ooooo01Soo`03003ooooo0;Woo`03003ooooo01Woo`006Ooo00<00?ooool00_oo00<0
0?ooool03?oo0P005ooo0P00^ooo0P006ooo000Iool6000>ool00`00ooooo`0Eool00`00ooooo`2l
ool00`00ooooo`0Iool001Woo`06003ooooo003oo`003_oo00<00?ooool05?oo00<00?ooool0_Ooo
00<00?ooool06Ooo000Iool01000ooooo`004?oo00<00?ooool04_oo0P00`?oo00<00?ooool06Ooo
000Jool2000Aool00`00ooooo`0Aool00`00ooooo`30ool00`00ooooo`0Iool002goo`80017oo`03
003ooooo0<3oo`8001_oo`00;Ooo00<00?ooool03ooo00<00?ooool0`_oo00<00?ooool06Ooo000L
ool2000?ool00`00ooooo`0=ool20035ool00`00ooooo`0Iool001_oo`04003ooooo000>ool00`00
ooooo`0<ool00`00ooooo`35ool00`00ooooo`0Iool001_oo`04003ooooo000>ool00`00ooooo`0;
ool00`00ooooo`36ool00`00ooooo`0Iool001coo`8000ooo`8000_oo`03003ooooo0<Koo`8001_o
o`00;Ooo00<00?ooool02Ooo00<00?ooool0b?oo00<00?ooool06Ooo000]ool00`00ooooo`08ool0
0`00ooooo`39ool00`00ooooo`0Iool001_oo`04003ooooo000>ool00`00ooooo`07ool00`00oooo
o`3:ool00`00ooooo`0Iool001_oo`@000koo`03003ooooo00Koo`03003ooooo0<_oo`03003ooooo
01Woo`006ooo00@00?ooool000koo`03003ooooo00Goo`03003ooooo0<coo`03003ooooo01Woo`00
6ooo00@00?ooool000koo`8000Koo`03003ooooo0<_oo`8001_oo`00;Ooo00<00?ooool01?oo00<0
0?ooool0cOoo00<00?ooool06Ooo000Kool00`00ooooo`0?ool00`00ooooo`04ool00`00ooooo`3=
ool00`00ooooo`0Iool001[oo`@000Woo`8000Coo`03003ooooo00?oo`03003ooooo0<koo`03003o
oooo01Woo`006ooo00@00?ooool000[oo`05003oooooool00005ool00`00ooooo`3>ool00`00oooo
o`0Iool001_oo`04003ooooo0009ool00`00ooooo`02ool30003ool00`00ooooo`3<ool3000Kool0
01_oo`03003oo`0000_oo`05003oooooool00005ool00`00ooooo`3>ool00`00ooooo`0Iool002Oo
o`03003oo`0000?oo`03003ooooo00;oo`800=3oo`03003ooooo01Woo`00:?oo00<00?ooool00_oo
00<00?ooool00_oo00<00?ooool0cooo00<00?ooool06Ooo000Kool01000ooooo`003_oo00<00?oo
ool00_oo00<00?ooool0cooo00<00?ooool06Ooo000Jool5000>ool20003ool00`00ooooo`3>ool2
000Kool001Woo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00?oo`03003ooooo0<koo`03
003ooooo01Woo`006Ooo00<00?oo00000_oo00<00?ooool03?oo00<00?ooool00ooo00<00?ooool0
c_oo00<00?ooool06Ooo000]ool00`00ooooo`03ool00`00ooooo`3>ool00`00ooooo`0Iool002go
o`03003ooooo00?oo`03003ooooo0<koo`03003ooooo01Woo`007?oo0P003ooo0P001Ooo00<00?oo
ool0c?oo0P006ooo000Kool01000ooooo`003_oo00<00?ooool01?oo00<00?ooool0cOoo00<00?oo
ool06Ooo000Kool01000ooooo`003_oo00<00?ooool01Ooo00<00?ooool0c?oo00<00?ooool06Ooo
000Lool2000?ool00`00ooooo`05ool00`00ooooo`3<ool00`00ooooo`0Iool002goo`03003ooooo
00Koo`03003ooooo0<_oo`03003ooooo01Woo`00;Ooo00<00?ooool01_oo00<00?ooool0booo00<0
0?ooool06Ooo000Iool00`00ooooo`02ool00`00ooooo`0<ool20008ool00`00ooooo`39ool2000K
ool001Woo`H000koo`03003ooooo00Soo`03003ooooo0<Woo`03003ooooo01Woo`007_oo00<00?oo
ool03?oo00<00?ooool02Ooo00<00?ooool0b?oo00<00?ooool06Ooo000]ool00`00ooooo`0:ool0
0`00ooooo`37ool00`00ooooo`0Iool002goo`03003ooooo00_oo`03003ooooo0<Koo`03003ooooo
01Woo`00;Ooo0P003Ooo0P00aOoo0P006ooo000]ool00`00ooooo`0>ool00`00ooooo`33ool00`00
ooooo`0Iool001_oo`04003ooooo000>ool00`00ooooo`0?ool00`00ooooo`32ool00`00ooooo`0I
ool001Woo`03003oo`0000<000Woo`<000;oo`03003ooooo013oo`800<;oo`03003ooooo01Woo`00
7_oo00<00?ooool02?oo00D00?ooooooo`0001Coo`03003ooooo0;ooo`03003ooooo01Woo`009ooo
10000_oo0`004ooo00<00?ooool0_?oo0`006ooo000Wool00`00ool00003ool00`00ooooo`0Dool2
002nool00`00ooooo`0Iool001coo`8000[oo`8000?oo`03003ooooo01Koo`03003ooooo0;_oo`03
003ooooo01Woo`006ooo00@00?ooool000[oo`05003oooooool0000Iool00`00ooooo`2jool00`00
ooooo`0Iool001_oo`04003ooooo000>ool00`00ooooo`0Hool2002jool00`00ooooo`0Iool001co
o`8000ooo`8001_oo`800;Ooo`8001_oo`00;Ooo00<00?ooool07?oo0P00]_oo00<00?ooool06Ooo
000]ool00`00ooooo`0Nool2002dool00`00ooooo`0Iool002goo`03003ooooo023oo`800;;oo`03
003ooooo01Woo`00;Ooo00<00?ooool08_oo0P00/?oo00<00?ooool06Ooo000]ool2000Uool3002/
ool2000Kool002goo`03003ooooo02Ooo`800:_oo`03003ooooo01Woo`00;Ooo00<00?ooool0:Ooo
0P00ZOoo00<00?ooool06Ooo000Iool6000>ool00`00ooooo`0[ool2002Wool00`00ooooo`0Iool0
01Woo`<000;oo`03003ooooo00coo`03003ooooo02goo`800:Goo`03003ooooo01Woo`007?oo00<0
0?ooool03_oo00<00?ooool0;ooo0`00X_oo00<00?ooool06Ooo000Iool30002ool00`00ooooo`0<
ool2000cool3002Nool2000Kool001Woo`H000koo`03003ooooo03Goo`8009goo`03003ooooo01Wo
o`006Ooo00<00?ooool00_oo00<00?ooool03?oo00<00?ooool0=ooo0`00V_oo00<00?ooool06Ooo
000]ool00`00ooooo`0jool3002Gool00`00ooooo`0Iool001coo`8000ooo`03003ooooo03goo`<0
09Coo`03003ooooo01Woo`006ooo0P0000?oo`00ool03Ooo0P00@Ooo0P00TOoo0P006ooo000Kool2
00000ooo003oo`0=ool00`00ooooo`12ool3002?ool00`00ooooo`0Iool001coo`03003oo`0000ko
o`03003ooooo04Goo`8008goo`03003ooooo01Woo`00:?oo00<00?ooool00_oo00<00?ooool0Aooo
0`00R_oo00<00?ooool06Ooo000Wool00`00ool00003ool00`00ooooo`1:ool20028ool00`00oooo
o`0Iool001goo`8000[oo`04003oooooool3001<ool30023ool3000Kool001_oo`04003oo`000008
ool20004ool00`00ooooo`1?ool40021ool00`00ooooo`0Iool001_oo`04003oo`000008ool00`00
ooooo`03ool00`00ooooo`1Cool4001mool00`00ooooo`0Iool001_oo`@000Soo`<000?oo`03003o
oooo05Ooo`@007Woo`03003ooooo01Woo`007_oo00<00?ooool03?oo00<00?ooool0Fooo1000MOoo
00<00?ooool06Ooo000Kool01000ooooo`003_oo0P00H?oo0`00LOoo0P006ooo000Kool4000>ool0
0`00ooooo`1Rool4001^ool00`00ooooo`0Iool001_oo`03003ooooo00ooo`03003ooooo06Koo`@0
06[oo`03003ooooo01Woo`006ooo00<00?ooool03ooo00<00?ooool0J_oo1000I_oo00<00?ooool0
6Ooo000Lool3000>ool00`00ooooo`1^ool4001Rool00`00ooooo`0Iool001koo`03003ooooo00co
o`8007?oo`<005koo`8001_oo`00;Ooo00<00?ooool0MOoo1000Fooo00<00?ooool06Ooo000]ool0
0`00ooooo`1iool4001Gool00`00ooooo`0Iool002goo`03003ooooo07goo`@005?oo`03003ooooo
01Woo`00;Ooo00<00?ooool0POoo1000Cooo00<00?ooool06Ooo000]ool00`00ooooo`25ool4001;
ool00`00ooooo`0Iool002goo`8008[oo`@004Koo`8001_oo`00;Ooo00<00?ooool0SOoo1000@ooo
00<00?ooool06Ooo000]ool00`00ooooo`2Aool4000oool00`00ooooo`0Iool002goo`03003ooooo
09Goo`@003_oo`03003ooooo01Woo`00;Ooo00<00?ooool0VOoo1000=ooo00<00?ooool06Ooo000]
ool2002Nool5000aool2000Kool002goo`03003ooooo0:;oo`D002goo`03003ooooo01Woo`00;Ooo
00<00?ooool0Yooo1000:Ooo00<00?ooool06Ooo000Wool20004ool00`00ooooo`2[ool5000Tool0
0`00ooooo`0Iool002Ooo`03003oo`0000?oo`03003ooooo0;3oo`D001ooo`03003ooooo01Woo`00
9ooo00<00?oo00000ooo0`00]Ooo1@006?oo0`006ooo000Wool20004ool00`00ooooo`2jool5000E
ool00`00ooooo`0Iool002Ooo`03003ooooo00?oo`03003ooooo0;ooo`@0017oo`03003ooooo01Wo
o`00:?oo0P000ooo00<00?ooool0`ooo1@003?oo00<00?ooool06Ooo000]ool00`00ooooo`38ool5
0007ool00`00ooooo`0Iool002goo`800<koo`<000?oo`8001_oo`00;Ooo00<00?oo0000:Ooo00<0
0?ooool09ooo00<00?ooool09ooo00<00?ooool09ooo00<00?ooool09ooo00@00?ooool001_oo`00
;Ooo00<00?oo00002?oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool0
1Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool0
1Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool0
1Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool0
1_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool0
1_oo00@00?ooool001_oo`00;Ooof0006ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool0
0?ooob7oo`00oooo8Ooo0015ool200001?oo00000?oo100000Goo`0000000?oo00800003ool00000
00;oo`8000;oo`03003oo`0000;oo`<000?oo`8000;oo`@000ooo`D00004ool000000002ool30002
ool30002ool30002ool30003ool200000ooo00000002ool00`00ooooo`02000@ool30003ool30003
ool200000ooo00000002ool00`00ooooo`020002ool30003ool20002ool3000lool004Goo`06003o
ooooool00?oo0`000ooo00L00?ooooooo`00ool00002ool00`00ooooo`0200001?oo003oo`000_oo
00D00?ooooooo`0000;oo`06003ooooo003oo`004?oo00@00?ooool000;oo`03003ooooo00;oo`03
003ooooo00;oo`05003oooooool00005ool01@00oooooooo00001?oo00H00?ooool00?oo0002ool0
0`00ooooo`0>ool00`00ooooo`03ool01@00oooooooo00000_oo00<00?oo00000_oo00<00?oo0000
0_oo00@00?ooool000?oo`03003ooooo00?oo`03003ooooo03_oo`00AOoo00D00?oo003oo`0000?o
o`05003oooooool00003ool30002ool00`00ooooo`0200001?oo003oo`000_oo00D00?ooooooo`00
00Coo`03003oo`00017oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00;oo`05003ooooo
ool00005ool01000oooooooo0`000_oo00H00?ooool00?oo000Cool00`00ooooo`03ool01@00oooo
oooo00000_oo00<00?oo00000_oo00<00?oo00001Ooo00@00?ooooooo`<000?oo`03003ooooo03_o
o`00AOoo0P0000?oo`0000000_oo0P000_oo100000?oo`00ool00P000_oo0P0000Coo`00003oo`80
0003ool0000000;oo`@000;oo`@0013oo`8000?oo`<000;oo`<000;oo`8000?oo`<000;oo`8000?o
o`<00003ool0000000800003ool000000080017oo`8000?oo`@000;oo`800003ool0000000800003
ool00000008000;oo`8000?oo`<000;oo`@003_oo`00AOoo0P0000?oo`0000002ooo00<00?ooool0
4Ooo00<00?ooool05_oo00@00?ooool000;oo`03003ooooo00;oo`03003ooooo01[oo`03003ooooo
017oo`04003ooooo000@ool00`00ooooo`1;ool004Goo`800003ool0000000[oo`8000ooo`03003o
oooo01Woo`D000?oo`03003ooooo00;oo`05003oooooool00009ool00`00ooooo`0Nool5000Fool0
0`00ooooo`15ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {38.631, 0.190611, 0.238564, \
0.0383315}}]
}, Open  ]],

Cell[TextData[{
  "We can evaluate the risk of a portfolio with the functions ",
  StyleBox["PortfolioMean", "MB"],
  " and ",
  StyleBox["PortfolioVariance", "MB"],
  ". "
}], "Text",
  CellTags->{"S0.2", "2.18"}],

Cell["\<\
Suppose our portfolio consists of two assets with mean returns of \
8% and 15%. \
\>", "MathCaption",
  CellTags->{"S0.2", "2.19"}],

Cell[CellGroupData[{

Cell["mean2 = {8., 15.}", "Input",
  CellLabel->"In[42]:=",
  CellTags->"S0.2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        StyleBox["8.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        StyleBox["15.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}], "}"}]], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[{
  "Suppose we know the variances but not the correlation coefficient ",
  StyleBox["rho", "MB"],
  ". The covariance matrix depends on ",
  StyleBox["rho", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.2", "2.20"}],

Cell[CellGroupData[{

Cell["cov2[rho_] = {{8.^2, 8. 15. rho}, {8. 15. rho, 15.^2}}", "Input",
  CellLabel->"In[43]:=",
  CellTags->"S0.2"],

Cell[BoxData[
    \({{64.0000000000000035`, 
        119.999999999999996`\ rho}, {119.999999999999996`\ rho, 
        225.`}}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "We find the Markowitz efficient frontier for different values of ",
  StyleBox["rho", "MB"],
  ". Since we have only two assets it is more instructive to use ",
  StyleBox["PortfolioMean", "MB"],
  " and ",
  StyleBox["PortfolioVariance", "MB"],
  " than ",
  StyleBox["EfficientFrontier", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.2", "2.21"}],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot[Evaluate[Table[{PortfolioVariance[
   {x, 1-x}, cov2[rho]], PortfolioMean[{x, 1-x},
   mean2]}, {rho, -1, 1, .2}]], {x, 0, 1},
   PlotLabel -> label1, FrameLabel -> label2];\
\>", "Input",
  CellLabel->"In[44]:=",
  CellTags->"S0.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238094 0.00423281 -0.657975 0.0840863 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23545 -0.0125 -6 -9 ]
[.23545 -0.0125 6 0 ]
[.44709 -0.0125 -9 -9 ]
[.44709 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.87037 -0.0125 -9 -9 ]
[.87037 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -56 -24 ]
[.5 -0.0125 56 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -6 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -12 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -12 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -12 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -27 -44 ]
[-0.01875 .30902 -12 44 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -86 0 ]
[.5 .63053 86 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23545 0 m
.23545 .00625 L
s
[(50)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(100)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(150)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(200)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.06614 0 m
.06614 .00375 L
s
.10847 0 m
.10847 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.19312 0 m
.19312 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.32011 0 m
.32011 .00375 L
s
.36243 0 m
.36243 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.48942 0 m
.48942 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.57407 0 m
.57407 .00375 L
s
.6164 0 m
.6164 .00375 L
s
.70106 0 m
.70106 .00375 L
s
.74339 0 m
.74339 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82804 0 m
.82804 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.95503 0 m
.95503 .00375 L
s
.99735 0 m
.99735 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -117 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Portfolio) show
123.000000 15.000000 moveto
(Variance) show
171.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(8)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(9)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(10)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(11)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(12)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(13)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(14)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(15)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08198 m
.00375 .08198 L
s
0 .11562 m
.00375 .11562 L
s
0 .13244 m
.00375 .13244 L
s
0 .14925 m
.00375 .14925 L
s
0 .16607 m
.00375 .16607 L
s
0 .1997 m
.00375 .1997 L
s
0 .21652 m
.00375 .21652 L
s
0 .23334 m
.00375 .23334 L
s
0 .25016 m
.00375 .25016 L
s
0 .28379 m
.00375 .28379 L
s
0 .30061 m
.00375 .30061 L
s
0 .31743 m
.00375 .31743 L
s
0 .33424 m
.00375 .33424 L
s
0 .36788 m
.00375 .36788 L
s
0 .38469 m
.00375 .38469 L
s
0 .40151 m
.00375 .40151 L
s
0 .41833 m
.00375 .41833 L
s
0 .45196 m
.00375 .45196 L
s
0 .46878 m
.00375 .46878 L
s
0 .4856 m
.00375 .4856 L
s
0 .50242 m
.00375 .50242 L
s
0 .53605 m
.00375 .53605 L
s
0 .55287 m
.00375 .55287 L
s
0 .56968 m
.00375 .56968 L
s
0 .5865 m
.00375 .5865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -124.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 11.5 translate
90 rotate
-105 -11.5 translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Portfolio) show
123.000000 15.000000 moveto
(Mean) show
147.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.23545 .61178 m
.23545 .61803 L
s
.44709 .61178 m
.44709 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.87037 .61178 m
.87037 .61803 L
s
.125 Mabswid
.06614 .61428 m
.06614 .61803 L
s
.10847 .61428 m
.10847 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.19312 .61428 m
.19312 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.32011 .61428 m
.32011 .61803 L
s
.36243 .61428 m
.36243 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.48942 .61428 m
.48942 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.57407 .61428 m
.57407 .61803 L
s
.6164 .61428 m
.6164 .61803 L
s
.70106 .61428 m
.70106 .61803 L
s
.74339 .61428 m
.74339 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.82804 .61428 m
.82804 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.95503 .61428 m
.95503 .61803 L
s
.99735 .61428 m
.99735 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03153 m
1 .03153 L
s
.99625 .04835 m
1 .04835 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .08198 m
1 .08198 L
s
.99625 .11562 m
1 .11562 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .14925 m
1 .14925 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .1997 m
1 .1997 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .23334 m
1 .23334 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .28379 m
1 .28379 L
s
.99625 .30061 m
1 .30061 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .33424 m
1 .33424 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .38469 m
1 .38469 L
s
.99625 .40151 m
1 .40151 L
s
.99625 .41833 m
1 .41833 L
s
.99625 .45196 m
1 .45196 L
s
.99625 .46878 m
1 .46878 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50242 m
1 .50242 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .55287 m
1 .55287 L
s
.99625 .56968 m
1 .56968 L
s
.99625 .5865 m
1 .5865 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -147 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Markowitz) show
123.000000 15.000000 moveto
(Efficient) show
183.000000 15.000000 moveto
(Frontier) show
231.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.97619 .60332 m
.86139 .57944 L
.7446 .5534 L
.64289 .52894 L
.55237 .50542 L
.46388 .48039 L
.38635 .45629 L
.31217 .43067 L
.24873 .406 L
.19512 .38225 L
.14609 .357 L
.10667 .33268 L
.07598 .30929 L
.06197 .29629 L
.05107 .2844 L
.04164 .27197 L
.03467 .26043 L
.02934 .2487 L
.02724 .2425 L
.0263 .23906 L
.02556 .23589 L
.02497 .23286 L
.02447 .22953 L
.02427 .22792 L
.0241 .22619 L
.02403 .22524 L
.02397 .22436 L
.02392 .22354 L
.02388 .22266 L
.02385 .2219 L
.02384 .2215 L
.02383 .22107 L
.02381 .22031 L
.02381 .21959 L
.02381 .21919 L
.02381 .21874 L
.02382 .21828 L
.02383 .21785 L
.02385 .21708 L
.02388 .21626 L
.02391 .21547 L
.02396 .21462 L
.02407 .21308 L
.02436 .21019 L
.02478 .20717 L
.02528 .20434 L
.02681 .19791 L
.02881 .19164 L
.03152 .1849 L
.03847 .17182 L
Mistroke
.04712 .15939 L
.06908 .13576 L
.10038 .1106 L
.13824 .08639 L
.18677 .06066 L
.24164 .03586 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.8693 .57944 L
.76037 .5534 L
.66532 .52894 L
.58055 .50542 L
.49745 .48039 L
.42442 .45629 L
.35428 .43067 L
.29401 .406 L
.24277 .38225 L
.19554 .357 L
.15714 .33268 L
.12678 .30929 L
.10151 .2844 L
.09233 .27294 L
.08408 .26043 L
.07741 .24737 L
.07484 .24086 L
.07294 .23495 L
.07137 .22869 L
.07081 .22583 L
.07032 .2228 L
.06991 .21955 L
.06977 .21811 L
.06964 .21657 L
.06959 .2157 L
.06954 .21491 L
.0695 .2141 L
.06948 .21336 L
.06945 .21249 L
.06944 .21203 L
.06944 .21155 L
.06943 .21073 L
.06943 .21027 L
.06943 .20983 L
.06944 .20911 L
.06946 .20833 L
.06948 .2076 L
.0695 .20693 L
.06959 .2053 L
.0697 .20376 L
.07 .20069 L
.07044 .19736 L
.07157 .19141 L
.07298 .18592 L
.07712 .17433 L
.0835 .16157 L
.09126 .14955 L
.10149 .13664 L
.12747 .11113 L
Mistroke
.15972 .08656 L
.19744 .06292 L
.24478 .03777 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.87721 .57944 L
.77614 .5534 L
.68775 .52894 L
.60872 .50542 L
.53102 .48039 L
.4625 .45629 L
.3964 .43067 L
.33928 .406 L
.29042 .38225 L
.24498 .357 L
.2076 .33268 L
.17757 .30929 L
.15195 .2844 L
.13349 .26043 L
.12598 .24737 L
.12313 .24136 L
.12052 .23495 L
.11833 .22853 L
.11673 .22271 L
.11548 .21686 L
.11463 .21135 L
.11432 .20847 L
.11418 .20682 L
.11407 .20532 L
.11399 .20372 L
.11396 .20285 L
.11393 .20202 L
.11392 .20125 L
.11391 .20054 L
.1139 .19977 L
.1139 .19937 L
.1139 .19894 L
.11391 .19822 L
.11392 .19746 L
.11394 .19682 L
.11396 .19611 L
.11404 .19452 L
.11413 .19305 L
.11435 .19038 L
.11467 .18752 L
.11515 .18423 L
.11569 .18119 L
.11728 .17433 L
.11909 .16828 L
.12142 .16188 L
.12702 .14978 L
.13367 .13846 L
.15223 .11447 L
.17865 .08896 L
Mistroke
.21061 .06438 L
.24738 .04075 L
.29299 .01559 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.88512 .57944 L
.79191 .5534 L
.71018 .52894 L
.63689 .50542 L
.56459 .48039 L
.50057 .45629 L
.43851 .43067 L
.38456 .406 L
.33807 .38225 L
.29442 .357 L
.25807 .33268 L
.22836 .30929 L
.20239 .2844 L
.18289 .26043 L
.17506 .24825 L
.16809 .23495 L
.16299 .22223 L
.1612 .21655 L
.15961 .21041 L
.15888 .20701 L
.15831 .20388 L
.15786 .20095 L
.15745 .19773 L
.15717 .19484 L
.15698 .19214 L
.1569 .19065 L
.15685 .18929 L
.15683 .18853 L
.15682 .18814 L
.15681 .18772 L
.1568 .18694 L
.1568 .18623 L
.1568 .18553 L
.1568 .18476 L
.15682 .18396 L
.15683 .18321 L
.15685 .18251 L
.15687 .18187 L
.15694 .18044 L
.15703 .1789 L
.15715 .17723 L
.15745 .1742 L
.1578 .17134 L
.15826 .16832 L
.15929 .1629 L
.16072 .15707 L
.16261 .1508 L
.16695 .13948 L
.17348 .1264 L
Mistroke
.18116 .11397 L
.19979 .09034 L
.22539 .06518 L
.25566 .04097 L
.29387 .01524 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.89303 .57944 L
.80768 .5534 L
.73261 .52894 L
.66506 .50542 L
.59816 .48039 L
.53865 .45629 L
.48063 .43067 L
.42984 .406 L
.38571 .38225 L
.34387 .357 L
.30853 .33268 L
.27916 .30929 L
.25282 .2844 L
.2323 .26043 L
.22368 .24825 L
.21567 .23495 L
.2093 .22208 L
.2047 .21041 L
.20111 .19825 L
.19965 .19158 L
.19912 .18858 L
.19862 .18529 L
.19825 .18238 L
.19793 .17926 L
.19778 .17753 L
.19768 .17596 L
.19759 .17436 L
.19752 .17288 L
.19748 .17152 L
.19747 .17083 L
.19745 .17008 L
.19745 .16932 L
.19744 .1685 L
.19744 .16773 L
.19745 .16702 L
.19746 .16635 L
.19747 .16573 L
.19749 .16505 L
.19751 .16432 L
.19757 .16282 L
.19764 .16147 L
.19785 .15847 L
.19815 .1553 L
.1989 .14961 L
.2 .14349 L
.20157 .13676 L
.2053 .12474 L
.21063 .11183 L
.22519 .08632 L
Mistroke
.24429 .06174 L
.26736 .03811 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.90093 .57944 L
.82345 .5534 L
.75504 .52894 L
.69323 .50542 L
.63173 .48039 L
.57672 .45629 L
.52274 .43067 L
.47512 .406 L
.43336 .38225 L
.39331 .357 L
.359 .33268 L
.32995 .30929 L
.30326 .2844 L
.28171 .26043 L
.26325 .23495 L
.25574 .22223 L
.2498 .21041 L
.24471 .19826 L
.24087 .18681 L
.23921 .18072 L
.2377 .17413 L
.2366 .16818 L
.23581 .16263 L
.23546 .15955 L
.2352 .15675 L
.23498 .15364 L
.23488 .15193 L
.23481 .1503 L
.23476 .14873 L
.23475 .14794 L
.23474 .14748 L
.23473 .14706 L
.23472 .14632 L
.23472 .14552 L
.23472 .14481 L
.23472 .14407 L
.23473 .14326 L
.23474 .1428 L
.23474 .14239 L
.23478 .14083 L
.23481 .13995 L
.23485 .139 L
.23493 .13728 L
.23513 .13426 L
.23537 .13143 L
.23614 .125 L
.23717 .11873 L
.23858 .11199 L
.24224 .09891 L
Mistroke
.24683 .08648 L
.25858 .06285 L
.27542 .0377 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.90884 .57944 L
.83922 .5534 L
.77747 .52894 L
.7214 .50542 L
.66531 .48039 L
.61479 .45629 L
.56485 .43067 L
.5204 .406 L
.48101 .38225 L
.44275 .357 L
.40947 .33268 L
.38074 .30929 L
.3537 .2844 L
.33112 .26043 L
.31083 .23495 L
.29489 .21041 L
.28291 .18681 L
.27764 .17363 L
.27376 .16169 L
.2706 .14924 L
.26846 .13751 L
.26768 .13147 L
.26734 .12817 L
.26708 .1251 L
.26691 .12247 L
.26676 .11965 L
.2667 .11805 L
.26666 .11653 L
.26664 .11587 L
.26663 .11516 L
.26662 .11439 L
.26661 .11368 L
.26661 .11298 L
.26661 .11221 L
.26661 .11141 L
.26662 .11066 L
.26662 .10996 L
.26664 .10932 L
.26667 .10789 L
.26672 .10635 L
.26678 .10468 L
.26695 .10165 L
.26715 .09879 L
.26742 .09577 L
.26804 .09035 L
.2689 .08452 L
.27004 .07825 L
.2727 .06693 L
.27671 .05385 L
Mistroke
.28144 .04142 L
.29297 .01779 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.91675 .57944 L
.85499 .5534 L
.7999 .52894 L
.74957 .50542 L
.69888 .48039 L
.65287 .45629 L
.60697 .43067 L
.56567 .406 L
.52866 .38225 L
.4922 .357 L
.45993 .33268 L
.43154 .30929 L
.40414 .2844 L
.38053 .26043 L
.3584 .23495 L
.33998 .21041 L
.32494 .18681 L
.31182 .16169 L
.302 .13751 L
.29806 .12516 L
.29459 .11181 L
.29205 .09891 L
.29111 .09277 L
.2904 .08704 L
.28985 .08143 L
.28963 .07855 L
.28943 .07541 L
.28934 .07363 L
.28926 .07198 L
.28921 .07043 L
.28916 .06873 L
.28914 .068 L
.28913 .06721 L
.28912 .06652 L
.28911 .06578 L
.2891 .06498 L
.2891 .06454 L
.2891 .06414 L
.28909 .06341 L
.2891 .06264 L
.2891 .06188 L
.2891 .06144 L
.28911 .06104 L
.28912 .06022 L
.28914 .05935 L
.28917 .05776 L
.28922 .05631 L
.28937 .05279 L
.28956 .04945 L
Mistroke
.29004 .04349 L
.29075 .03699 L
.29238 .0262 L
.29471 .01472 L
Mfstroke
.97619 .60332 m
.92466 .57944 L
.87076 .5534 L
.82232 .52894 L
.77775 .50542 L
.73245 .48039 L
.69094 .45629 L
.64908 .43067 L
.61095 .406 L
.57631 .38225 L
.54164 .357 L
.5104 .33268 L
.48233 .30929 L
.45458 .2844 L
.42994 .26043 L
.40598 .23495 L
.38507 .21041 L
.36698 .18681 L
.34989 .16169 L
.33555 .13751 L
.32258 .11181 L
.3123 .08704 L
.30446 .06322 L
.30125 .05114 L
.29832 .03788 L
.29471 .01472 L
s
.97619 .60332 m
.93256 .57944 L
.88653 .5534 L
.84475 .52894 L
.80592 .50542 L
.76602 .48039 L
.72902 .45629 L
.6912 .43067 L
.65623 .406 L
.62395 .38225 L
.59108 .357 L
.56086 .33268 L
.53313 .30929 L
.50502 .2844 L
.47935 .26043 L
.45356 .23495 L
.43016 .21041 L
.40901 .18681 L
.38795 .16169 L
.36909 .13751 L
.35057 .11181 L
.3342 .08704 L
.31982 .06322 L
.306 .03788 L
.29471 .01472 L
s
.97619 .60332 m
.94047 .57944 L
.9023 .5534 L
.86718 .52894 L
.83409 .50542 L
.79959 .48039 L
.76709 .45629 L
.73331 .43067 L
.70151 .406 L
.6716 .38225 L
.64053 .357 L
.61133 .33268 L
.58392 .30929 L
.55545 .2844 L
.52876 .26043 L
.50113 .23495 L
.47526 .21041 L
.45105 .18681 L
.42602 .16169 L
.40263 .13751 L
.37855 .11181 L
.3561 .08704 L
.33518 .06322 L
.31368 .03788 L
.29471 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool006coo`<000Coo`8000;oo`<000?oo`8000;oo`<000?o
o`8000;oo`<000;oo`<000?oo`8001;oo`8000;oo`@00004ool000000002ool30002ool60002ool0
0`00ool000020003ool2001Hool006goo`03003ooooo00;oo`04003ooooo0002ool01@00oooooooo
00000_oo00@00?ooool000?oo`04003ooooo0002ool00`00ooooo`02ool01@00oooooooo00000_oo
00<00?ooool03_oo00<00?oo00000_oo0`000ooo00<00?ooool00_oo00@00?ooooooo`<000;oo`06
003ooooo003oo`001?oo00<00?ooool0F?oo001]ool30002ool01000ooooo`000_oo00D00?oooooo
o`0000Goo`05003oooooool00002ool01000ooooo`001?oo00D00?ooooooo`0000;oo`03003ooooo
00koo`03003oo`0000Coo`05003oooooool00004ool00`00ooooo`03ool01000ooooo`000_oo00<0
0?oo00001?oo0`00F?oo001]ool01000ooooo`000_oo0P000_oo20000_oo0`000ooo0P000ooo00@0
0?ooooooo`8000Coo`80017oo`04003ooooo0002ool20002ool400000ooo00000004ool200000ooo
000000020002ool30002ool3001Hool006goo`04003ooooo000;ool00`00ooooo`03ool00`00oooo
o`07ool00`00ooooo`0Iool01@00oooooooo0000N_oo001/ool4000Cool00`00ooooo`05ool20004
ool00`00ooooo`0Dool200000ooo0000000<ool00`00ooooo`1[ool00?ooobSoo`00oooo:?oo003o
oolXool00?ooobSoo`00oooo:?oo000hool00`00ooooo`0Zool00`00ooooo`02ool00`00ooooo`0R
ool50002ool00`00ooooo`02ool00`00ooooo`0Pool50002ool00`00ooooo`02ool00`00ooooo`0Q
ool30003ool00`00ooooo`02ool00`00ooooo`0[ool003Ooo`03003oo`0002[oo`03003oo`0000;o
o`03003oo`0002Goo`07003oooooool00?oo00000_oo00<00?oo00008ooo00L00?ooooooo`00ool0
0002ool00`00ool0000Rool00`00ooooo`02ool00`00ool00002ool00`00ool0000/ool003Ooo`03
003oo`0002coo`06003ooooo003oo`009Ooo00L00?ooooooo`00ool00002ool00`00ool0000Sool0
0`00ooooo`03ool01P00ooooo`00ool002?oo`07003oooooool00?oo00000_oo00<00?oo0000;?oo
000gool00`00ool0000Zool20003ool00`00ool0000Uool01`00oooooooo003oo`0000;oo`03003o
o`0002?oo`04003oooooool20003ool00`00ool0000Sool01`00oooooooo003oo`0000;oo`03003o
o`0002coo`00=ooo00<00?oo0000:_oo00<00?ooool00_oo00<00?oo00009Ooo00L00?ooooooo`00
ool00002ool00`00ool0000Sool01@00oooooooo00001?oo00<00?oo00008_oo00<00?oo00000_oo
00<00?oo00000_oo00<00?oo0000;?oo000hool00`00ooooo`0Yool30003ool00`00ooooo`0Sool2
0004ool00`00ooooo`02ool00`00ooooo`0Qool20003ool30003ool00`00ooooo`0Rool00`00oooo
o`02ool00`00ooooo`02ool00`00ooooo`0[ool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSo
o`00oooo:?oo000coooO000Eool002koo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo02co
o`03003ooooo02coo`03003ooooo02coo`03003ooooo02_oo`03003ooooo01[oo`03003ooooo01?o
o`00;Ooo00<00?oo00000ooo00<00?ooool0fooo00<00?ooool04ooo000]ool00`00ool00003ool3
000nool2002Jool2000Eool002koo`03003ooooo00;oo`03003ooooo03coo`D009[oo`03003ooooo
01?oo`00;Ooo00<00?oo00000ooo00<00?ooool0>_oo2000VOoo00<00?ooool04ooo000^ool00`00
ooooo`02ool00`00ooooo`0gool800000ooo0000002Iool00`00ooooo`0Cool003?oo`8003Koo`L0
0004ool00000ool3002Gool2000Eool003?oo`03003ooooo03;oo`T00005ool00?oo003oo`020000
0ooo003oo`2Fool00`00ooooo`0Cool003?oo`03003ooooo033oo`D00003ool00?oo008000;oo`09
003oo`00ool00?oo003oo`0009Koo`03003ooooo01?oo`00<ooo0P00;ooo200000Coo`00ool000;o
o`07003oo`00ool00?oo00000_oo00<00?ooool0T_oo0P005Ooo000cool00`00ooooo`0[ool50000
1?oo003oo`000_oo00<00?oo00000_oo00H00?ooool00?oo0002ool01000ooooo`00U?oo00<00?oo
ool04ooo000cool00`00ooooo`0Yool200001?oo00000?oo0P0000Goo`00ooooo`0000;oo`04003o
oooo0002ool00`00ool00002ool01000ooooo`00U?oo00<00?ooool04ooo000cool00`00ooooo`0W
ool200001?oo00000?oo0P0000?oo`0000000_oo00@00?ooool000;oo`05003oooooool00002ool0
1000ooooo`000_oo00<00?ooool0TOoo00<00?ooool04ooo000cool2000Vool20002ool01000oooo
o`000_oo00D00?ooooooo`0000?oo`04003ooooo0003ool01000ooooo`000_oo00D00?ooooooo`00
097oo`8001Goo`00<ooo00<00?ooool08ooo0P000_oo0P0000?oo`0000000_oo00D00?ooooooo`00
00?oo`05003oooooool00003ool01000ooooo`000ooo00D00?ooooooo`00097oo`03003ooooo01?o
o`00<ooo00<00?ooool08Ooo0P000ooo00@00?ooool000?oo`05003oooooool00004ool01000oooo
o`001?oo00D00?ooooooo`0000?oo`05003oooooool0002@ool00`00ooooo`0Cool003?oo`03003o
oooo01ooo`8000?oo`8000;oo`05003oooooool00004ool01@00oooooooo00000ooo00<00?ooool0
0_oo00D00?ooooooo`0000?oo`05003oooooool0002@ool00`00ooooo`0Cool003?oo`8001koo`80
00?oo`8000;oo`8000Coo`05003oooooool00004ool01@00oooooooo00001?oo00<00?ooool00_oo
00D00?ooooooo`0000?oo`03003ooooo08coo`8001Goo`00<ooo00<00?ooool07?oo00<00?ooool0
0_oo00D00?ooooooo`0000Goo`05003oooooool00004ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`02ool01@00oooooooo0000S_oo00<00?ooool04ooo000]ool20004
ool00`00ooooo`0Jool20003ool20003ool00`00ooooo`03ool01@00oooooooo00001Ooo00<00?oo
ool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00ooo00D00?ooooooo`0008goo`03
003ooooo01?oo`00;ooo00D00?ooooooo`0001_oo`03003ooooo00;oo`03003ooooo00;oo`03003o
oooo00?oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00;oo`03003o
oooo00?oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo08[oo`03003ooooo01?oo`00;_oo
0P000ooo0`005ooo0P001?oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00_oo00<00?oo
ool00ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?oo
ool00_oo00<00?ooool0R?oo0P005Ooo000]ool00`00ool00003ool00`00ooooo`0Eool20004ool2
0004ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00oooo
o`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`28ool00`00oooo
o`0Cool002goo`03003oo`0000?oo`03003ooooo01Coo`03003ooooo00?oo`03003ooooo00?oo`03
003ooooo00Coo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00Coo`03003ooooo00?oo`03
003ooooo00?oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo08Ooo`03003ooooo01?oo`00
;_oo0P000ooo0P005?oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool0
0ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool0
0ooo00<00?ooool00ooo00<00?ooool0QOoo0P005Ooo000cool00`00ooooo`0Bool00`00ooooo`03
ool00`00ooooo`03ool00`00ooooo`04ool00`00ooooo`03ool00`00ooooo`04ool00`00ooooo`04
ool00`00ooooo`04ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`04ool00`00ooooo`25
ool00`00ooooo`0Cool001Woo`03003ooooo00;oo`03003ooooo01;oo`03003ooooo013oo`8000Go
o`03003ooooo00?oo`03003ooooo00Goo`03003ooooo00?oo`03003ooooo00Coo`03003ooooo00Co
o`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00Coo`03003ooooo08Co
o`03003ooooo01?oo`006Ooo1P005?oo00<00?ooool03ooo00<00?ooool01?oo00<00?ooool01?oo
00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo
00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0Pooo00<00?ooool04ooo
000Iool01P00ooooo`00ool001Coo`8000ooo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo
00Coo`03003ooooo00Coo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo
00Goo`03003ooooo00?oo`03003ooooo00Goo`03003ooooo087oo`8001Goo`006Ooo00@00?ooool0
01Koo`03003ooooo00goo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00Goo`03003ooooo
00Coo`03003ooooo00Coo`8000Koo`03003ooooo00Coo`03003ooooo00Goo`03003ooooo00Coo`03
003ooooo00Goo`03003ooooo087oo`03003ooooo01?oo`006_oo0P005ooo00<00?ooool03?oo00<0
0?ooool01?oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool01?oo00<0
0?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool01Ooo00<0
0?ooool0P?oo00<00?ooool04ooo000cool00`00ooooo`0;ool00`00ooooo`05ool00`00ooooo`04
ool00`00ooooo`04ool00`00ooooo`06ool00`00ooooo`04ool00`00ooooo`05ool00`00ooooo`05
ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`06ool00`00ooooo`1oool00`00ooooo`0C
ool003?oo`8000_oo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo00Ko
o`03003ooooo00Coo`03003ooooo00Goo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Co
o`03003ooooo00Koo`03003ooooo07goo`8001Goo`007?oo0P005Ooo00<00?ooool02Ooo00<00?oo
ool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?oo
ool01?oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?oo
ool0O_oo00<00?ooool04ooo000Kool01000ooooo`005?oo00<00?ooool02?oo00<00?ooool01Ooo
00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo
00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool01_oo00<00?ooool0OOoo
00<00?ooool04ooo000Kool01000ooooo`005?oo0P002?oo00<00?ooool01_oo00<00?ooool01Ooo
00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo
00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool0Nooo0P005Ooo000Lool2
000Eool00`00ooooo`07ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`06ool00`00oooo
o`05ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00oooo
o`05ool00`00ooooo`06ool00`00ooooo`1kool00`00ooooo`0Cool002Ooo`D000;oo`03003ooooo
00;oo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Koo`03003ooooo
00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo
00Goo`03003ooooo00Koo`03003ooooo07[oo`03003ooooo01?oo`00:Ooo00L00?ooooooo`00ool0
0003ool00`00ooooo`05ool00`00ooooo`07ool00`00ooooo`05ool00`00ooooo`06ool00`00oooo
o`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00oooo
o`06ool00`00ooooo`06ool00`00ooooo`1iool00`00ooooo`0Cool001_oo`04003ooooo000:ool0
1`00oooooooo003oo`0000?oo`<000Goo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ko
o`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ko
o`03003ooooo00Koo`03003ooooo00Koo`03003ooooo07Ooo`8001Goo`006ooo10002_oo00L00?oo
ooooo`00ool00003ool00`00ooooo`04ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`06
ool00`00ooooo`06ool20008ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`07ool00`00
ooooo`06ool00`00ooooo`06ool00`00ooooo`1gool00`00ooooo`0Cool001_oo`04003ooooo000:
ool01`00oooooooo003oo`0000?oo`03003ooooo00Coo`03003ooooo00Koo`03003ooooo00Ooo`03
003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo07Koo`03003ooooo01?oo`00
6ooo00@00?ooool000Woo`8000Coo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00Ooo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo07Goo`03
003ooooo01?oo`00<ooo0P001?oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<0
0?ooool01ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<0
0?ooool01ooo00<00?ooool01_oo0P00M?oo0P005Ooo000Kool00`00ooooo`0Eool00`00ooooo`03
ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07
ool00`00ooooo`1bool00`00ooooo`0Cool001[oo`@001Goo`03003ooooo00?oo`03003ooooo00Oo
o`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Oo
o`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo077o
o`03003ooooo01?oo`006ooo00@00?ooool001Coo`03003ooooo00?oo`03003ooooo00Ooo`03003o
oooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Soo`03003o
oooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo073oo`03003o
oooo01?oo`006ooo00@00?ooool001Coo`8000Coo`03003ooooo00Ooo`03003ooooo00Ooo`03003o
oooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003o
oooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo06koo`8001Goo`006ooo00<00?oo
00005Ooo00<00?ooool00ooo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool02?oo00<00?oo
ool01ooo00<00?ooool01ooo00<00?ooool02?oo00<00?ooool01ooo00<00?ooool01ooo00<00?oo
ool02?oo00<00?ooool01ooo00<00?ooool0K_oo00<00?ooool04ooo000cool00`00ooooo`03ool0
0`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool0
0`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool0
0`00ooooo`1]ool00`00ooooo`0Cool003?oo`8000Coo`03003ooooo00Soo`03003ooooo00Ooo`03
003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03
003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo06_oo`8001Goo`006ooo00@0
0?ooool001Coo`03003ooooo00?oo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Soo`03
003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03
003ooooo00Soo`03003ooooo00Soo`03003ooooo06_oo`03003ooooo01?oo`006_oo1@005?oo00<0
0?ooool00ooo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool01ooo00<00?ooool02?oo00<0
0?ooool02?oo00<00?ooool01ooo00<00?ooool02?oo00<00?ooool01ooo00<00?ooool02?oo00<0
0?ooool02?oo00<00?ooool0J_oo00<00?ooool04ooo000Iool00`00ool00002ool00`00ooooo`0B
ool00`00ooooo`04ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07
ool00`00ooooo`09ool00`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`08
ool00`00ooooo`08ool00`00ooooo`1Yool00`00ooooo`0Cool001Woo`03003oo`0000;oo`03003o
oooo01;oo`8000Goo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Soo`03003ooooo00So
o`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Ooo`8000Woo`8000Wo
o`8006Soo`8001Goo`00<ooo00<00?ooool01Ooo00<00?ooool02?oo00<00?ooool01ooo00<00?oo
ool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool0I_oo00<00?ooool04ooo000Wool:
0002ool00`00ooooo`05ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`1Uool00`00ooooo`0Cool001coo`8000_oo`03003ooooo
00;oo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo
00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo
00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo06Coo`03003ooooo01?oo`006ooo00@0
0?ooool000[oo`03003ooooo00;oo`03003ooooo00;oo`<000Koo`03003ooooo00Soo`03003ooooo
00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Woo`03003ooooo00Soo`03003ooooo
00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo06;oo`8001Goo`00
6ooo00@00?ooool000[oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo
00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Woo`03003ooooo
00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo
06;oo`03003ooooo01?oo`007?oo0P002ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool0
2?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool0
2?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool0
2Ooo00<00?ooool0HOoo00<00?ooool04ooo000Xool20003ool20004ool00`00ooooo`08ool00`00
ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`09ool00`00
ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`09ool00`00
ooooo`1Pool00`00ooooo`0Cool003?oo`8000[oo`03003ooooo00Soo`03003ooooo00Soo`03003o
oooo00Soo`03003ooooo00Soo`03003ooooo00Woo`03003ooooo00Soo`03003ooooo00Soo`03003o
oooo00Soo`03003ooooo00Soo`03003ooooo00Woo`03003ooooo05koo`8001Goo`006Ooo00<00?oo
ool00_oo00<00?ooool04_oo00<00?ooool02_oo00<00?ooool02?oo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool02?oo0P002_oo00<00?ooool0G_oo00<00?ooool04ooo000Iool6000Dool0
0`00ooooo`0;ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool0
0`00ooooo`09ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`09ool0
0`00ooooo`08ool00`00ooooo`1Mool00`00ooooo`0Cool001koo`03003ooooo01;oo`8000goo`03
003ooooo00Soo`8000Woo`8000Woo`8000Woo`8000[oo`8000Woo`8000Woo`8000Woo`8000[oo`03
003ooooo00Soo`8005coo`8001Goo`00<ooo00<00?ooool03Ooo00<00?ooool02Ooo00<00?ooool0
2?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?ooool0
2?oo00<00?ooool02?oo00<00?ooool02?oo0P002_oo00<00?ooool0F_oo00<00?ooool04ooo000c
ool00`00ooooo`0>ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08
ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`09
ool00`00ooooo`08ool00`00ooooo`1Iool00`00ooooo`0Cool003?oo`03003ooooo00ooo`8000[o
o`03003ooooo00Soo`03003ooooo00Soo`8000Woo`8000[oo`03003ooooo00Soo`03003ooooo00So
o`03003ooooo00Soo`8000[oo`03003ooooo00Soo`03003ooooo05Soo`03003ooooo01?oo`00<ooo
0P004_oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool0E_oo0P005Ooo000Kool01000ooooo`005?oo00<00?ooool04_oo00<00?oo
ool02?oo0P002Ooo0P002_oo00<00?ooool02?oo00<00?ooool02?oo0P002Ooo0P002Ooo0P002_oo
00<00?ooool02?oo0P002Ooo0P00Eooo00<00?ooool04ooo000Iool00`00ool00003000Dool00`00
ooooo`0Cool2000:ool00`00ooooo`08ool00`00ooooo`08ool20009ool2000:ool00`00ooooo`08
ool00`00ooooo`08ool00`00ooooo`08ool2000:ool00`00ooooo`08ool00`00ooooo`1Dool00`00
ooooo`0Cool001koo`03003ooooo01;oo`03003ooooo01Goo`03003ooooo00Soo`03003ooooo00So
o`03003ooooo00Woo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo00So
o`03003ooooo00Woo`03003ooooo00Soo`03003ooooo00Soo`03003ooooo05?oo`03003ooooo01?o
o`00<ooo0P005ooo0P002Ooo0P002Ooo0P002_oo00<00?ooool02?oo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?ooool02?oo00<00?oo
ool0DOoo0P005Ooo000cool00`00ooooo`0Hool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool20009ool20009ool20009ool20009ool2000:ool00`00ooooo`08ool00`00ooooo`08ool0
0`00ooooo`1Aool00`00ooooo`0Cool001coo`8000Woo`D00004ool000000003ool00`00ooooo`0I
ool20009ool20009ool2000:ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00
ooooo`08ool00`00ooooo`08ool20009ool20009ool00`00ooooo`1@ool00`00ooooo`0Cool001_o
o`04003ooooo000:ool01@00oooooooo00001Ooo00<00?ooool06ooo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?oo
ool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?ooool01ooo00<00?ooool0Cooo00<00?oo
ool04ooo000Kool01000ooooo`002_oo00<00?ooool00_oo00<00?ooool00_oo0`007?oo0P002Ooo
0P002Ooo0P002Ooo0P002Ooo0P002Ooo0P002Ooo0P002Ooo0P002_oo00<00?ooool02?oo00<00?oo
ool01ooo00<00?ooool0COoo0P005Ooo000Lool2000;ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`0Nool20009ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`07ool00`00ooooo`1=ool00`00ooooo`0Cool002Woo`07003oooooool00?oo00000ooo00<00?oo
ool08?oo0P002?oo0P002Ooo0P002Ooo0P002Ooo0P002Ooo0P002Ooo0P002Ooo0P002Ooo0P002Ooo
0P002?oo0P00COoo00<00?ooool04ooo000Xool20004ool00`00ooooo`02ool2000Sool20008ool2
0009ool20009ool20009ool20009ool20009ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`07ool00`00ooooo`19ool2000Eool003?oo`03003ooooo02Coo`8000Soo`80
00Woo`8000Woo`8000Woo`8000Woo`8000Soo`8000Woo`8000Woo`03003ooooo00Soo`03003ooooo
00Ooo`03003ooooo04Woo`03003ooooo01?oo`00<ooo00<00?ooool09_oo0P002?oo0P002Ooo0P00
2Ooo0P002Ooo0P002Ooo0P002?oo0P002Ooo0P002?oo0P002Ooo0P002?oo0P00BOoo00<00?ooool0
4ooo000cool00`00ooooo`0Xool20008ool20009ool20009ool00`00ooooo`08ool00`00ooooo`08
ool00`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`08ool00`00ooooo`07
ool00`00ooooo`16ool00`00ooooo`0Cool003?oo`8002_oo`8000Soo`8000Woo`8000Soo`8000Wo
o`8000Woo`8000Soo`8000Woo`03003ooooo00Ooo`03003ooooo00Soo`03003ooooo00Ooo`03003o
oooo04Coo`8001Goo`00<ooo00<00?ooool0;?oo0P002?oo0P002Ooo0P002?oo0P002Ooo0P002Ooo
00<00?ooool01ooo00<00?ooool01ooo0P002?oo0P002Ooo00<00?ooool01ooo00<00?ooool0A?oo
00<00?ooool04ooo000Iool6000Dool00`00ooooo`0^ool20008ool20009ool20008ool20009ool0
0`00ooooo`07ool20008ool20009ool00`00ooooo`07ool00`00ooooo`07ool20008ool20014ool0
0`00ooooo`0Cool001Woo`<000;oo`03003ooooo01;oo`03003ooooo033oo`8000Soo`8000Woo`80
00Soo`8000Soo`8000Woo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo
00Soo`03003ooooo00Ooo`03003ooooo047oo`03003ooooo01?oo`007?oo00<00?ooool05?oo0P00
<ooo0P002?oo0P002Ooo0P002?oo0P002?oo0P002?oo0P002?oo0P002?oo0P002?oo0P002Ooo00<0
0?ooool01ooo00<00?ooool0?ooo0P005Ooo000Iool30002ool00`00ooooo`0Bool00`00ooooo`0d
ool30007ool30008ool20008ool20008ool20008ool00`00ooooo`07ool00`00ooooo`07ool00`00
ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`0oool00`00ooooo`0Cool001Wo
o`H001Coo`03003ooooo03Ooo`<000Ooo`8000Soo`8000Soo`8000Soo`8000Ooo`8000Soo`8000So
o`8000Soo`8000Soo`8000Soo`8003ooo`03003ooooo01?oo`006Ooo00<00?ooool00_oo00<00?oo
ool04_oo0P00>ooo0P001ooo0`001ooo0P002?oo0P002?oo0P001ooo0P002?oo0P002?oo0P002?oo
00<00?ooool01ooo00<00?ooool01ooo00<00?ooool0>ooo0P005Ooo000cool00`00ooooo`0lool3
0007ool30006ool30007ool30007ool20007ool20008ool20008ool20007ool20008ool20008ool0
0`00ooooo`0kool00`00ooooo`0Cool001coo`8000Woo`D00003ool0000000Coo`03003ooooo03oo
o`<000Ooo`8000Ooo`8000Soo`8000Ooo`8000Ooo`8000Soo`8000Soo`8000Ooo`8000Soo`8000Oo
o`8003_oo`03003ooooo01?oo`006ooo0P0000?oo`00ool02Ooo00<00?ooool00ooo00D00?oooooo
o`0004Coo`<000Koo`<000Koo`<000Ooo`<000Koo`<000Koo`8000Soo`8000Soo`03003ooooo00Ko
o`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo03Soo`03003ooooo01?oo`006ooo0P0000?o
o`00ool02Ooo00<00?ooool00_oo00<00?ooool00_oo0`00AOoo0P001ooo0P001ooo0P002?oo0P00
1ooo0P001_oo0P002?oo0P001ooo0P001ooo0P002?oo00<00?ooool01_oo00<00?ooool0=_oo0P00
5Ooo000Lool00`00ool0000:ool00`00ooooo`03ool01@00oooooooo0000BOoo0`001_oo0`001_oo
0`001ooo0P001ooo0P001_oo0P002?oo0P001ooo0P001ooo0P001ooo0P001ooo0P00=ooo00<00?oo
ool04ooo000Yool01`00oooooooo003oo`0000?oo`03003ooooo04[oo`<000Koo`<000Koo`8000Oo
o`8000Ooo`8000Koo`8000Soo`8000Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ko
o`03003ooooo03Coo`03003ooooo01?oo`00:?oo0P001?oo00<00?ooool00_oo00<00?ooool0COoo
0P001ooo0P001_oo0`001_oo0P001ooo0P001_oo0P002?oo0P001_oo0P001ooo0P001ooo00<00?oo
ool01_oo00<00?ooool0<ooo00<00?ooool04ooo000Mool2000Dool2001@ool30006ool30006ool2
0006ool20007ool20006ool20008ool20006ool20007ool20006ool20007ool2000bool2000Eool0
01_oo`04003oo`00000Dool00`00ooooo`1Bool30006ool30005ool30005ool30006ool30005ool3
0007ool20006ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`0`ool0
0`00ooooo`0Cool001_oo`04003oo`00000Dool00`00ooooo`1Eool40005ool30005ool30005ool3
0006ool20006ool20007ool20005ool20007ool20006ool20007ool2000`ool00`00ooooo`0Cool0
01_oo`@001Coo`03003ooooo05Woo`<000Goo`<000Goo`<000Goo`<000Goo`<000Goo`<000Koo`80
00Goo`8000Ooo`8000Koo`03003ooooo00Koo`03003ooooo02goo`03003ooooo01?oo`007_oo00<0
0?ooool04_oo0P00GOoo0`001Ooo10001?oo0`001Ooo0`001Ooo0`001Ooo0`001Ooo0P001Ooo0P00
1ooo0P001Ooo0P001ooo00<00?ooool0:ooo0P005Ooo000Kool01000ooooo`005?oo00<00?ooool0
Gooo10001Ooo0`001?oo0`001Ooo0`001Ooo0P001_oo0P001Ooo0P001Ooo0P001ooo0P001Ooo0P00
1_oo0P00;?oo00<00?ooool04ooo000Kool4000Dool00`00ooooo`1Sool30005ool30004ool30005
ool30004ool30005ool30004ool20005ool20007ool00`00ooooo`04ool00`00ooooo`05ool00`00
ooooo`0Yool00`00ooooo`0Cool001_oo`03003ooooo01Goo`8006Ooo`<000Goo`<000Coo`<000Go
o`8000Goo`8000Koo`8000Coo`8000Goo`8000Koo`8000Goo`8000Koo`03003ooooo02Ooo`8001Go
o`006ooo00<00?ooool05Ooo00<00?ooool0JOoo10001?oo0`001?oo0`001?oo0`001?oo0`001Ooo
0P001?oo0P001Ooo0P001_oo0P001Ooo00<00?ooool01?oo00<00?ooool09ooo00<00?ooool04ooo
000Lool3000Dool00`00ooooo`1]ool30004ool30004ool20005ool30004ool20005ool20004ool2
0005ool20006ool00`00ooooo`03ool20005ool2000Wool00`00ooooo`0Cool001koo`03003ooooo
01;oo`03003ooooo073oo`<000Coo`<000?oo`<000Goo`8000Coo`<000Coo`8000Coo`8000Goo`80
00Goo`8000Goo`03003ooooo00Coo`03003ooooo02Coo`03003ooooo01?oo`00<ooo0P00M?oo1000
0ooo0`000ooo0`001?oo0`001?oo0P001?oo0P001?oo0P001Ooo0P001Ooo0P001?oo0P001Ooo00<0
0?ooool08_oo0P005Ooo000cool00`00ooooo`1gool30003ool30003ool30004ool30003ool30003
ool30003ool30004ool30004ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`0Rool00`00
ooooo`0Cool002Ooo`D000;oo`<000;oo`03003ooooo07[oo`@000;oo`@000;oo`@000?oo`<000?o
o`<000?oo`<000?oo`8000Goo`8000?oo`8000Coo`8000Coo`8002;oo`03003ooooo01?oo`00:Ooo
00<00?ooool00ooo00D00?ooooooo`00083oo`@000;oo`@000;oo`<000?oo`<000?oo`<000?oo`80
00?oo`<000Coo`8000?oo`8000Coo`8000Coo`03003ooooo01ooo`03003ooooo01?oo`00:Ooo00@0
0?ooooooo`@000;oo`<008;oo`@000;oo`@00003ool00000008000;oo`@000;oo`<000;oo`<000?o
o`<000?oo`8000?oo`8000Coo`8000?oo`8001koo`8001Goo`00:Ooo00L00?ooooooo`00ool00003
ool00`00ooooo`26ool40002ool400000ooo000000020002ool30002ool30002ool30003ool20003
ool20003ool20004ool20003ool2000Mool00`00ooooo`0Cool002Woo`03003ooooo00;oo`8000?o
o`03003ooooo08[oo`D00003ool0000000800004ool000000002ool30002ool30002ool30002ool3
0002ool30002ool30003ool00`00ooooo`02ool00`00ooooo`0Jool00`00ooooo`0Cool002Soo`80
00Goo`05003oooooool0002Aool400000ooo0000000600000ooo0000000200000ooo000000020000
1?oo000000000_oo0`000_oo0P000ooo0P000_oo0P000ooo0P006_oo00<00?ooool04ooo000cool2
002Dool=00001?oo000000000_oo0`0000Coo`00000000;oo`8000;oo`8000?oo`8000;oo`8000?o
o`03003ooooo01Koo`8001Goo`00<ooo00<00?ooool0V?oo400000Goo`0000000?oo00<00005ool0
0000003oo`030002ool20002ool20002ool2000Gool00`00ooooo`0Cool003?oo`03003ooooo09go
oaH00005ool00000003oo`020002ool20002ool20002ool2000Eool00`00ooooo`0Cool003?oo`80
0:;oo`h00003ool0000000@00003ool0000000@00003ool0000000;oo`05003oooooool0000Cool2
000Eool003?oo`03003ooooo0:Kooa<00004ool00000ool200001?oo00000?oo0P000_oo00<00?oo
ool04Ooo00<00?ooool04ooo000cool00`00ooooo`2ZoolG00001?oo00000?oo0P0000?oo`000000
4Ooo00<00?ooool04ooo000cool00`00ooooo`2^ool@00000ooo0000000500001Ooo003ooooo0000
4?oo00<00?ooool04ooo000cool2002coolH00000ooo003oo`0=ool2000Eool003?oo`03003ooooo
0;KooaP000goo`03003ooooo01?oo`00<ooo00<00?ooool0^_oo4`0000?oo`00ool02ooo00<00?oo
ool04ooo000cool00`00ooooo`2ooolB000:ool00`00ooooo`0Cool003?oo`800<Goo`h000Soo`80
01Goo`009ooo1@000_oo00<00?ooool00_oo00<00?ooool0bOoo2`001ooo00<00?ooool04ooo000Y
ool01`00oooooooo003oo`0000?oo`03003ooooo0<ooo`L000Goo`03003ooooo01?oo`00:Ooo00<0
0?ooool00ooo00@00?ooooooo`<00=Coo`<000?oo`8001Goo`00:Ooo00@00?ooooooo`8000Coo`03
003ooooo0=_oo`03003ooooo01?oo`00:Ooo00D00?ooooooo`0000Goo`03003ooooo00?oo`03003o
oooo02coo`03003ooooo02coo`03003ooooo02coo`03003ooooo02_oo`03003ooooo01[oo`03003o
oooo01?oo`00:?oo0P000ooo0`000ooo00<00?ooool00ooo00<00?ooool01_oo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool04ooo000coooO000Eool00?ooobSoo`00oooo:?oo003ooolXool0
0?ooobSoo`00oooo:?oo003ooolXool004koo`800004ool00000ool400001Ooo00000000ool00P00
00?oo`0000000_oo0P000_oo00<00?oo00000_oo0`000ooo0P000_oo10003ooo1@0000Coo`000000
00;oo`<000;oo`<000;oo`<000;oo`<000?oo`800003ool0000000;oo`03003ooooo0080013oo`<0
00?oo`<000?oo`800003ool0000000;oo`03003ooooo008000;oo`<000?oo`8000;oo`<003[oo`00
C_oo00H00?ooooooo`00ool30003ool01`00oooooooo003oo`0000;oo`03003ooooo00800004ool0
0?oo0002ool01@00oooooooo00000_oo00H00?ooool00?oo000@ool01000ooooo`000_oo00<00?oo
ool00_oo00<00?ooool00_oo00D00?ooooooo`0000Goo`05003oooooool00004ool01P00ooooo`00
ool000;oo`03003ooooo00koo`03003ooooo00?oo`05003oooooool00002ool00`00ool00002ool0
0`00ool00002ool01000ooooo`000ooo00<00?ooool00ooo00<00?ooool0>Ooo001>ool01@00ool0
0?oo00000ooo00D00?ooooooo`0000?oo`<000;oo`03003ooooo00800004ool00?oo0002ool01@00
oooooooo00001?oo00<00?oo00004Ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo
00D00?ooooooo`0000Goo`04003oooooool30002ool01P00ooooo`00ool001?oo`03003ooooo00?o
o`05003oooooool00002ool00`00ool00002ool00`00ool00005ool01000oooooooo0`000ooo00<0
0?ooool0>Ooo001>ool200000ooo00000002ool20002ool400000ooo003oo`020002ool200001?oo
00000?oo0P0000?oo`0000000_oo10000_oo10004?oo0P000ooo0`000_oo0`000_oo0P000ooo0`00
0_oo0P000ooo0`0000?oo`0000000P0000?oo`0000000P004Ooo0P000ooo10000_oo0P0000?oo`00
00000P0000?oo`0000000P000_oo0P000ooo0`000_oo1000>Ooo001>ool200000ooo0000000;ool0
0`00ooooo`0Aool00`00ooooo`0Fool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool06_oo
00<00?ooool04Ooo00@00?ooool0013oo`03003ooooo04Woo`00C_oo0P0000?oo`0000002_oo0P00
3ooo00<00?ooool06Ooo1@000ooo00<00?ooool00_oo00D00?ooooooo`0000Woo`03003ooooo01ko
o`D001Koo`03003ooooo04?oo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool0
0001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-60.9047, 6.38946, \
1.06515, 0.0536185}}]
}, Open  ]],

Cell["\<\
Sometimes the portfolio's standard deviation is used instead of the \
variance. \
\>", "MathCaption",
  CellTags->{"S0.2", "2.22"}],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot[Evaluate[Table[
   {Sqrt[PortfolioVariance[{x, 1-x}, cov2[rho]]],
   PortfolioMean[{x, 1-x}, mean2]},
   {rho, -1, 1, .2}]], {x, 0, 1},
   PlotLabel -> label1, FrameLabel -> label3];\
\>", "Input",
  CellLabel->"In[45]:=",
  CellTags->"S0.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0233251 0.0635244 -0.657975 0.0840863 [
[.02333 -0.0125 -3 -9 ]
[.02333 -0.0125 3 0 ]
[.15037 -0.0125 -3 -9 ]
[.15037 -0.0125 3 0 ]
[.27742 -0.0125 -3 -9 ]
[.27742 -0.0125 3 0 ]
[.40447 -0.0125 -3 -9 ]
[.40447 -0.0125 3 0 ]
[.53152 -0.0125 -3 -9 ]
[.53152 -0.0125 3 0 ]
[.65857 -0.0125 -6 -9 ]
[.65857 -0.0125 6 0 ]
[.78562 -0.0125 -6 -9 ]
[.78562 -0.0125 6 0 ]
[.91267 -0.0125 -6 -9 ]
[.91267 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -86 -24 ]
[.5 -0.0125 86 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .0988 -6 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -12 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -12 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -12 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -12 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -12 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -27 -44 ]
[-0.01875 .30902 -12 44 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -86 0 ]
[.5 .63053 86 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02333 0 m
.02333 .00625 L
s
[(0)] .02333 -0.0125 0 1 Mshowa
.15037 0 m
.15037 .00625 L
s
[(2)] .15037 -0.0125 0 1 Mshowa
.27742 0 m
.27742 .00625 L
s
[(4)] .27742 -0.0125 0 1 Mshowa
.40447 0 m
.40447 .00625 L
s
[(6)] .40447 -0.0125 0 1 Mshowa
.53152 0 m
.53152 .00625 L
s
[(8)] .53152 -0.0125 0 1 Mshowa
.65857 0 m
.65857 .00625 L
s
[(10)] .65857 -0.0125 0 1 Mshowa
.78562 0 m
.78562 .00625 L
s
[(12)] .78562 -0.0125 0 1 Mshowa
.91267 0 m
.91267 .00625 L
s
[(14)] .91267 -0.0125 0 1 Mshowa
.125 Mabswid
.05509 0 m
.05509 .00375 L
s
.08685 0 m
.08685 .00375 L
s
.11861 0 m
.11861 .00375 L
s
.18214 0 m
.18214 .00375 L
s
.2139 0 m
.2139 .00375 L
s
.24566 0 m
.24566 .00375 L
s
.30918 0 m
.30918 .00375 L
s
.34095 0 m
.34095 .00375 L
s
.37271 0 m
.37271 .00375 L
s
.43623 0 m
.43623 .00375 L
s
.468 0 m
.468 .00375 L
s
.49976 0 m
.49976 .00375 L
s
.56328 0 m
.56328 .00375 L
s
.59504 0 m
.59504 .00375 L
s
.62681 0 m
.62681 .00375 L
s
.69033 0 m
.69033 .00375 L
s
.72209 0 m
.72209 .00375 L
s
.75386 0 m
.75386 .00375 L
s
.81738 0 m
.81738 .00375 L
s
.84914 0 m
.84914 .00375 L
s
.8809 0 m
.8809 .00375 L
s
.94443 0 m
.94443 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -147 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Portfolio) show
123.000000 15.000000 moveto
(Standard) show
177.000000 15.000000 moveto
(Deviation) show
231.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(8)] -0.0125 .01472 1 0 Mshowa
0 .0988 m
.00625 .0988 L
s
[(9)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(10)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(11)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(12)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(13)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(14)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(15)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08198 m
.00375 .08198 L
s
0 .11562 m
.00375 .11562 L
s
0 .13244 m
.00375 .13244 L
s
0 .14925 m
.00375 .14925 L
s
0 .16607 m
.00375 .16607 L
s
0 .1997 m
.00375 .1997 L
s
0 .21652 m
.00375 .21652 L
s
0 .23334 m
.00375 .23334 L
s
0 .25016 m
.00375 .25016 L
s
0 .28379 m
.00375 .28379 L
s
0 .30061 m
.00375 .30061 L
s
0 .31743 m
.00375 .31743 L
s
0 .33424 m
.00375 .33424 L
s
0 .36788 m
.00375 .36788 L
s
0 .38469 m
.00375 .38469 L
s
0 .40151 m
.00375 .40151 L
s
0 .41833 m
.00375 .41833 L
s
0 .45196 m
.00375 .45196 L
s
0 .46878 m
.00375 .46878 L
s
0 .4856 m
.00375 .4856 L
s
0 .50242 m
.00375 .50242 L
s
0 .53605 m
.00375 .53605 L
s
0 .55287 m
.00375 .55287 L
s
0 .56968 m
.00375 .56968 L
s
0 .5865 m
.00375 .5865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -124.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 11.5 translate
90 rotate
-105 -11.5 translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Portfolio) show
123.000000 15.000000 moveto
(Mean) show
147.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02333 .61178 m
.02333 .61803 L
s
.15037 .61178 m
.15037 .61803 L
s
.27742 .61178 m
.27742 .61803 L
s
.40447 .61178 m
.40447 .61803 L
s
.53152 .61178 m
.53152 .61803 L
s
.65857 .61178 m
.65857 .61803 L
s
.78562 .61178 m
.78562 .61803 L
s
.91267 .61178 m
.91267 .61803 L
s
.125 Mabswid
.05509 .61428 m
.05509 .61803 L
s
.08685 .61428 m
.08685 .61803 L
s
.11861 .61428 m
.11861 .61803 L
s
.18214 .61428 m
.18214 .61803 L
s
.2139 .61428 m
.2139 .61803 L
s
.24566 .61428 m
.24566 .61803 L
s
.30918 .61428 m
.30918 .61803 L
s
.34095 .61428 m
.34095 .61803 L
s
.37271 .61428 m
.37271 .61803 L
s
.43623 .61428 m
.43623 .61803 L
s
.468 .61428 m
.468 .61803 L
s
.49976 .61428 m
.49976 .61803 L
s
.56328 .61428 m
.56328 .61803 L
s
.59504 .61428 m
.59504 .61803 L
s
.62681 .61428 m
.62681 .61803 L
s
.69033 .61428 m
.69033 .61803 L
s
.72209 .61428 m
.72209 .61803 L
s
.75386 .61428 m
.75386 .61803 L
s
.81738 .61428 m
.81738 .61803 L
s
.84914 .61428 m
.84914 .61803 L
s
.8809 .61428 m
.8809 .61803 L
s
.94443 .61428 m
.94443 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .0988 m
1 .0988 L
s
.99375 .18289 m
1 .18289 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .35106 m
1 .35106 L
s
.99375 .43515 m
1 .43515 L
s
.99375 .51923 m
1 .51923 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03153 m
1 .03153 L
s
.99625 .04835 m
1 .04835 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .08198 m
1 .08198 L
s
.99625 .11562 m
1 .11562 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .14925 m
1 .14925 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .1997 m
1 .1997 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .23334 m
1 .23334 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .28379 m
1 .28379 L
s
.99625 .30061 m
1 .30061 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .33424 m
1 .33424 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .38469 m
1 .38469 L
s
.99625 .40151 m
1 .40151 L
s
.99625 .41833 m
1 .41833 L
s
.99625 .45196 m
1 .45196 L
s
.99625 .46878 m
1 .46878 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50242 m
1 .50242 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .55287 m
1 .55287 L
s
.99625 .56968 m
1 .56968 L
s
.99625 .5865 m
1 .5865 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -147 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Markowitz) show
123.000000 15.000000 moveto
(Efficient) show
183.000000 15.000000 moveto
(Frontier) show
231.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.97619 .60332 m
.91692 .57944 L
.85228 .5534 L
.79157 .52894 L
.73319 .50542 L
.67104 .48039 L
.61122 .45629 L
.54764 .43067 L
.48639 .406 L
.42745 .38225 L
.36476 .357 L
.30439 .33268 L
.24635 .30929 L
.18454 .2844 L
.12506 .26043 L
.09482 .24825 L
.06182 .23495 L
.04653 .22879 L
.03814 .22541 L
.03023 .22223 L
.02664 .22078 L
.02467 .21999 L
.02381 .21925 L
.02579 .21845 L
.02797 .21757 L
.0318 .21603 L
.04575 .21041 L
.10544 .18637 L
.16889 .1608 L
.23002 .13618 L
.28882 .11249 L
.35138 .08728 L
.41162 .06302 L
.46954 .03969 L
.53121 .01484 L
.53152 .01472 L
s
.97619 .60332 m
.92113 .57944 L
.8613 .5534 L
.80536 .52894 L
.75186 .50542 L
.6953 .48039 L
.64133 .45629 L
.58463 .43067 L
.53086 .406 L
.48021 .38225 L
.42794 .357 L
.37985 .33268 L
.33664 .30929 L
.29549 .2844 L
.26302 .26043 L
.24939 .24737 L
.24429 .24136 L
.23975 .23495 L
.23619 .22853 L
.23386 .22271 L
.23305 .2199 L
.23271 .21842 L
.23241 .21686 L
.2322 .21549 L
.23211 .21477 L
.23203 .21399 L
.23197 .21328 L
.23193 .21263 L
.2319 .21197 L
.23188 .21135 L
.23187 .21065 L
.23188 .20989 L
.23189 .20917 L
.23192 .20851 L
.23197 .20779 L
.23204 .20699 L
.23222 .20538 L
.23247 .2038 L
.23282 .2021 L
.23363 .19905 L
.23469 .19598 L
.23591 .19308 L
.23877 .18766 L
.24791 .17529 L
.25927 .16389 L
.29112 .13954 L
.32895 .11612 L
.3744 .09119 L
.42152 .06719 L
.47407 .04168 L
Mistroke
.52636 .01711 L
.53152 .01472 L
Mfstroke
.97619 .60332 m
.92532 .57944 L
.87022 .5534 L
.81892 .52894 L
.77007 .50542 L
.7187 .48039 L
.67003 .45629 L
.61932 .43067 L
.57174 .406 L
.52748 .38225 L
.48251 .357 L
.44192 .33268 L
.40619 .30929 L
.37284 .2844 L
.34668 .26043 L
.33611 .24825 L
.32696 .23495 L
.32364 .22879 L
.32077 .22223 L
.31963 .21904 L
.31871 .21603 L
.31797 .21313 L
.3174 .21041 L
.31694 .20754 L
.31675 .20601 L
.31659 .20438 L
.31653 .20356 L
.31647 .20267 L
.31645 .20226 L
.31644 .20182 L
.31641 .20104 L
.3164 .2003 L
.31639 .1996 L
.3164 .19883 L
.3164 .1984 L
.31641 .198 L
.31644 .19734 L
.31647 .19663 L
.31655 .19535 L
.31668 .19383 L
.31683 .19244 L
.31728 .18943 L
.31784 .18659 L
.31949 .18058 L
.32188 .17422 L
.32781 .16281 L
.33627 .15072 L
.34606 .1394 L
.37208 .1154 L
.40618 .08989 L
Mistroke
.44381 .06532 L
.48337 .04168 L
.52819 .01653 L
.53152 .01472 L
Mfstroke
.97619 .60332 m
.92949 .57944 L
.87905 .5534 L
.83224 .52894 L
.78784 .50542 L
.74135 .48039 L
.69751 .45629 L
.6521 .43067 L
.60977 .406 L
.57068 .38225 L
.53125 .357 L
.49591 .33268 L
.46493 .30929 L
.43593 .2844 L
.41277 .26043 L
.40305 .24825 L
.39421 .23495 L
.38759 .22223 L
.38314 .21041 L
.38225 .20728 L
.38141 .20388 L
.3808 .20089 L
.38026 .19773 L
.37989 .19487 L
.37974 .19336 L
.3796 .19174 L
.37951 .19025 L
.37945 .18889 L
.37942 .18824 L
.37941 .18752 L
.3794 .18685 L
.37939 .18623 L
.37939 .1855 L
.3794 .18474 L
.37941 .18408 L
.37943 .18337 L
.37946 .18259 L
.3795 .18177 L
.37959 .18028 L
.37971 .17877 L
.37986 .17735 L
.38019 .17469 L
.3807 .17152 L
.38128 .16858 L
.383 .16196 L
.385 .15597 L
.38728 .15037 L
.39381 .13761 L
.41094 .11361 L
.43528 .0881 L
Mistroke
.46376 .06353 L
.49496 .03989 L
.53148 .01474 L
.53152 .01472 L
Mfstroke
.97619 .60332 m
.93364 .57944 L
.88779 .5534 L
.84536 .52894 L
.80521 .50542 L
.7633 .48039 L
.72391 .45629 L
.68325 .43067 L
.64549 .406 L
.61071 .38225 L
.57571 .357 L
.54433 .33268 L
.51672 .30929 L
.49058 .2844 L
.46916 .26043 L
.45101 .23495 L
.44392 .22223 L
.4386 .21041 L
.43467 .19899 L
.43299 .1926 L
.43181 .18681 L
.43132 .1838 L
.4309 .18061 L
.43062 .1779 L
.43039 .17491 L
.43029 .17323 L
.43023 .1717 L
.43021 .17086 L
.4302 .17038 L
.43019 .16993 L
.43018 .16912 L
.43018 .16871 L
.43018 .16826 L
.43019 .16745 L
.4302 .16672 L
.43021 .16591 L
.43024 .16505 L
.43029 .16362 L
.43038 .16205 L
.43049 .16048 L
.43063 .15878 L
.43096 .1557 L
.43183 .14993 L
.43324 .14319 L
.43492 .13698 L
.43902 .12538 L
.44493 .11263 L
.46049 .08769 L
.48002 .0637 L
.50509 .03819 L
Mistroke
.53152 .01472 L
Mfstroke
.97619 .60332 m
.93777 .57944 L
.89644 .5534 L
.85826 .52894 L
.8222 .50542 L
.78462 .48039 L
.74935 .45629 L
.713 .43067 L
.67926 .406 L
.64818 .38225 L
.61684 .357 L
.58862 .33268 L
.56357 .30929 L
.53948 .2844 L
.51918 .26043 L
.5011 .23495 L
.48749 .21041 L
.48214 .19803 L
.47823 .18681 L
.47501 .17465 L
.4737 .16798 L
.47322 .16498 L
.47277 .16169 L
.47244 .15878 L
.47215 .15565 L
.47203 .15393 L
.47193 .15236 L
.47185 .15076 L
.4718 .14928 L
.47176 .14792 L
.47175 .14723 L
.47174 .14647 L
.47173 .14571 L
.47173 .1449 L
.47174 .14412 L
.47174 .14342 L
.47175 .14275 L
.47176 .14212 L
.4718 .14071 L
.47186 .13933 L
.47193 .13786 L
.47215 .13457 L
.47242 .13153 L
.47329 .12467 L
.47435 .11862 L
.47576 .11222 L
.47925 .10012 L
.48346 .0888 L
.49529 .06481 L
.51192 .0393 L
Mistroke
.53151 .01472 L
.53152 .01472 L
Mfstroke
.97619 .60332 m
.94188 .57944 L
.90501 .5534 L
.87097 .52894 L
.83883 .50542 L
.80535 .48039 L
.77394 .45629 L
.74152 .43067 L
.71138 .406 L
.68353 .38225 L
.65531 .357 L
.62968 .33268 L
.60666 .30929 L
.58413 .2844 L
.5646 .26043 L
.54642 .23495 L
.53169 .21041 L
.52033 .18681 L
.51525 .17363 L
.51147 .16169 L
.50838 .14924 L
.50627 .13751 L
.5055 .13147 L
.50516 .12817 L
.50491 .1251 L
.50473 .12247 L
.50459 .11965 L
.50453 .11805 L
.50449 .11653 L
.50447 .11587 L
.50446 .11516 L
.50445 .11439 L
.50444 .11368 L
.50444 .11298 L
.50444 .11221 L
.50444 .11141 L
.50445 .11066 L
.50446 .10996 L
.50447 .10932 L
.5045 .10789 L
.50455 .10635 L
.50461 .10468 L
.50478 .10165 L
.50498 .09879 L
.50525 .09577 L
.50586 .09035 L
.5067 .08452 L
.50783 .07825 L
.51044 .06693 L
.51434 .05385 L
Mistroke
.51892 .04142 L
.52989 .01779 L
.53152 .01472 L
Mfstroke
.97619 .60332 m
.94598 .57944 L
.9135 .5534 L
.88349 .52894 L
.85514 .50542 L
.82556 .48039 L
.79774 .45629 L
.76895 .43067 L
.74207 .406 L
.71708 .38225 L
.69156 .357 L
.66813 .33268 L
.64679 .30929 L
.62548 .2844 L
.60649 .26043 L
.58811 .23495 L
.57234 .21041 L
.55913 .18681 L
.54733 .16169 L
.53832 .13751 L
.53465 .12516 L
.53141 .11181 L
.52902 .09891 L
.52814 .09277 L
.52746 .08704 L
.52694 .08143 L
.52673 .07855 L
.52654 .07541 L
.52645 .07363 L
.52639 .07198 L
.52633 .07043 L
.52629 .06873 L
.52627 .068 L
.52626 .06721 L
.52625 .06652 L
.52624 .06578 L
.52623 .06498 L
.52623 .06454 L
.52623 .06414 L
.52623 .06341 L
.52623 .06264 L
.52623 .06188 L
.52624 .06144 L
.52624 .06104 L
.52625 .06022 L
.52626 .05935 L
.5263 .05776 L
.52634 .05631 L
.52648 .05279 L
.52667 .04945 L
Mistroke
.52712 .04349 L
.5278 .03699 L
.52933 .0262 L
.53152 .01472 L
Mfstroke
.97619 .60332 m
.95005 .57944 L
.9219 .5534 L
.89583 .52894 L
.87113 .50542 L
.84526 .48039 L
.82083 .45629 L
.7954 .43067 L
.77149 .406 L
.74908 .38225 L
.72594 .357 L
.70442 .33268 L
.68448 .30929 L
.66416 .2844 L
.64557 .26043 L
.62693 .23495 L
.61019 .21041 L
.5953 .18681 L
.58088 .16169 L
.56848 .13751 L
.55702 .11181 L
.54776 .08704 L
.54058 .06322 L
.53762 .05114 L
.5349 .03788 L
.53152 .01472 L
s
.97619 .60332 m
.95411 .57944 L
.93023 .5534 L
.908 .52894 L
.88682 .50542 L
.86451 .48039 L
.84327 .45629 L
.82098 .43067 L
.7998 .406 L
.77973 .38225 L
.75872 .357 L
.73887 .33268 L
.72014 .30929 L
.70064 .2844 L
.68233 .26043 L
.6634 .23495 L
.64574 .21041 L
.62932 .18681 L
.61252 .16169 L
.59706 .13751 L
.58146 .11181 L
.5673 .08704 L
.55455 .06322 L
.54201 .03788 L
.53152 .01472 L
s
.97619 .60332 m
.95815 .57944 L
.93848 .5534 L
.92 .52894 L
.90223 .50542 L
.88332 .48039 L
.86511 .45629 L
.84576 .43067 L
.82712 .406 L
.80918 .38225 L
.7901 .357 L
.77173 .33268 L
.75406 .30929 L
.73525 .2844 L
.71715 .26043 L
.6979 .23495 L
.67936 .21041 L
.66153 .18681 L
.64255 .16169 L
.62428 .13751 L
.60487 .11181 L
.58616 .08704 L
.56816 .06322 L
.54902 .03788 L
.53152 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool004koo`<000Coo`8000;oo`<000?oo`8000;oo`<000?o
o`8000;oo`<000;oo`<000?oo`80017oo`<000?oo`8000;oo`H000;oo`03003ooooo00<00003ool0
000000800004ool000000003ool3000>ool40003ool20003ool20002ool30002ool40002ool20002
ool30003ool200000ooo00000002ool00`00ooooo`0hool004ooo`03003ooooo00;oo`04003ooooo
0002ool01@00oooooooo00000_oo00@00?ooool000?oo`04003ooooo0002ool00`00ooooo`02ool0
1@00oooooooo00000_oo00<00?ooool03_oo00<00?oo00000_oo00D00?ooool00?oo00<000;oo`06
003ooooo003oo`000_oo00<00?oo00000P000ooo00D00?ooooooo`0000;oo`03003ooooo00goo`06
003ooooo003oo`001Ooo0P000ooo00@00?ooooooo`<000;oo`04003ooooo0002ool01@00oooooooo
00000_oo00<00?oo00000_oo00<00?ooool0>?oo001?ool30002ool01000ooooo`000_oo00D00?oo
ooooo`0000Goo`05003oooooool00002ool01000ooooo`001?oo00D00?ooooooo`0000;oo`03003o
oooo013oo`04003ooooo0006ool01000ooooo`000_oo00<00?oo00000_oo00D00?ooooooo`0000?o
o`05003oooooool00002ool00`00ooooo`0=ool01@00ooooo`00ool00`000_oo00@00?ooool000;o
o`03003ooooo00?oo`04003ooooo0005ool01@00oooooooo00000_oo00<00?oo00000_oo00<00?oo
ool0>?oo001?ool01000ooooo`000_oo0P000_oo20000_oo0`000ooo0P000ooo00@00?ooooooo`80
00Coo`8001;oo`03003ooooo00@000?oo`800003ool00000008000?oo`<000;oo`8000;oo`@000;o
o`<000ooo`05003ooooo003oo`0300000ooo00000002ool01000ool000001?oo0P0000?oo`000000
0P000_oo0P001?oo0P0000?oo`0000000P00>ooo001?ool01000ooooo`002ooo00<00?ooool00ooo
00<00?ooool01ooo00<00?ooool06_oo00<00?oo00000_oo00<00?ooool03ooo00<00?ooool03?oo
00<00?ooool03Ooo00@00?ooool001Goo`03003ooooo04[oo`00C_oo10004ooo00<00?ooool01Ooo
0P001?oo00<00?ooool05Ooo0`004ooo0P003Ooo0P003_oo10003Ooo00<00?ooool03?oo00<00?oo
ool0A?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00>?oo00<00?ooool0
6?oo0`006_oo0`006Ooo0P006ooo00<00?ooool05?oo1@000_oo00<00?ooool04ooo1@0000Coo`00
000001?oo`D000;oo`<002Coo`00=ooo00<00?oo00006Ooo00<00?ooool06ooo00<00?ooool06?oo
00<00?oo00006Ooo00<00?oo00005ooo00L00?ooooooo`00ool0000Fool01@00oooooooo00005ooo
00<00?ooool00ooo00<00?ooool08ooo000gool00`00ool0000Jool00`00ooooo`0Hool4000Iool0
0`00ool0000Iool00`00ool0000Gool01`00oooooooo003oo`0001Koo`03003ooooo00;oo`03003o
oooo01Coo`04003oooooool4000Tool003Ooo`03003oo`0001[oo`03003ooooo01Soo`03003oo`00
01[oo`8001_oo`03003ooooo01Koo`07003oooooool00?oo00005_oo00<00?ooool00_oo00<00?oo
ool05?oo00L00?ooooooo`00ool0000Uool003Ooo`03003oo`0001Woo`03003oo`0001[oo`8001[o
o`03003ooooo01Woo`03003oo`0001Ooo`07003oooooool00?oo00005_oo00L00?ooooooo`00ool0
000Eool00`00ooooo`02ool2000Uool003Soo`03003ooooo01Woo`03003ooooo01[oo`03003ooooo
01Woo`8001[oo`03003ooooo01Goo`8000Coo`03003ooooo01Coo`8000Coo`03003ooooo01?oo`80
00Goo`03003ooooo02?oo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool003?o
oml001Goo`00;_oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool06Ooo00<00?ooool06Ooo
00<00?ooool06Ooo00<00?ooool06Ooo00<00?ooool06Ooo00<00?ooool06_oo00<00?ooool06Ooo
00<00?ooool04?oo00<00?ooool04ooo000]ool00`00ool00003ool00`00ooooo`3Kool00`00oooo
o`0Cool002goo`03003oo`0000?oo`<007;oo`<006Goo`8001Goo`00;_oo00<00?ooool00_oo00<0
0?ooool0L?oo1@00I_oo00<00?ooool04ooo000]ool00`00ool00003ool00`00ooooo`1]ool9001U
ool00`00ooooo`0Cool002koo`03003ooooo00;oo`03003ooooo06[oo``006Goo`03003ooooo01?o
o`00<ooo0P00JOoo1`0000Goo`0000000?oo00<006?oo`8001Goo`00<ooo00<00?ooool0IOoo1`00
00Goo`00ool00?oo00800003ool00?oo008006?oo`03003ooooo01?oo`00<ooo00<00?ooool0Hooo
0P000_oo01800?oo00000?oo003oo`00ool00?oo003oo`00ool00?oo001Rool00`00ooooo`0Cool0
03?oo`8006;oo`8000;oo`D00009ool00?ooool00?oo003oo`0000;oo`04003oo`00001Qool2000E
ool003?oo`03003ooooo05ooo`8000;oo`H00007ool00?ooool00?oo00000_oo00P00?ooool00?oo
003oo`00HOoo00<00?ooool04ooo000cool00`00ooooo`1Mool20002ool400000ooo003oo`02ool0
0`00ool00002ool01000ooooo`000_oo00<00?oo00000_oo00<00?ooool0G_oo00<00?ooool04ooo
000cool00`00ooooo`1Kool20002ool40002ool01@00oooooooo00000_oo00@00?ooool000;oo`04
003ooooo0002ool00`00ool0001Pool00`00ooooo`0Cool003?oo`8005Woo`<000;oo`800003ool0
0?oo00;oo`05003oooooool00002ool01@00oooooooo00000_oo00@00?ooool000;oo`04003ooooo
001Nool2000Eool003?oo`03003ooooo05Goo`<000;oo`<00003ool0000000?oo`05003oooooool0
0003ool01@00oooooooo00000_oo00@00?ooool000?oo`04003ooooo001Nool00`00ooooo`0Cool0
03?oo`03003ooooo05?oo`8000?oo`8000?oo`03003ooooo00;oo`05003oooooool00003ool01@00
oooooooo00000ooo00D00?ooooooo`0000;oo`05003oooooool0001Mool00`00ooooo`0Cool003?o
o`03003ooooo053oo`<000?oo`8000?oo`8000?oo`8000Coo`05003oooooool00003ool01@00oooo
oooo00000ooo00D00?ooooooo`0000;oo`03003ooooo05_oo`03003ooooo01?oo`00<ooo0P00C_oo
0`001?oo0P001?oo00<00?ooool00_oo00<00?ooool00ooo00D00?ooooooo`0000Coo`05003ooooo
ool00004ool01000ooooo`000ooo00<00?ooool0FOoo0P005Ooo000cool00`00ooooo`1:ool30005
ool20004ool20004ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool01@00oooooooo
00001?oo00D00?ooooooo`0000?oo`03003ooooo05Woo`03003ooooo01?oo`00;Ooo0P001?oo00<0
0?ooool0B?oo0P001_oo0P001Ooo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00ooo00<0
0?ooool00_oo00<00?ooool00_oo00D00?ooooooo`0000Coo`05003oooooool0001Jool00`00oooo
o`0Cool002ooo`05003oooooool00018ool20006ool20005ool20005ool00`00ooooo`04ool00`00
ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool01@00oooooooo00001?oo
00<00?ooool0Eooo00<00?ooool04ooo000^ool20003ool30013ool30006ool20006ool00`00oooo
o`04ool00`00ooooo`04ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`1Eool2000Eool002goo`03003oo`00
00?oo`03003ooooo047oo`8000Ooo`8000Ooo`03003ooooo00Goo`03003ooooo00?oo`03003ooooo
00Coo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`05003oooooool00005ool00`00
ooooo`1Eool00`00ooooo`0Cool002goo`03003oo`0000?oo`03003ooooo03ooo`8000Ooo`8000Oo
o`8000Ooo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00?oo`03003o
oooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo05Coo`03003ooooo01?oo`00;_oo
0P000ooo0P00?Ooo0`001ooo0P002?oo00<00?ooool01_oo00<00?ooool01?oo00<00?ooool01?oo
00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00ooo
00<00?ooool0D_oo0P005Ooo000cool00`00ooooo`0jool20009ool00`00ooooo`07ool00`00oooo
o`06ool00`00ooooo`04ool00`00ooooo`05ool00`00ooooo`03ool00`00ooooo`04ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`1Cool00`00ooooo`0Cool001Woo`03
003ooooo00;oo`03003ooooo01;oo`03003ooooo03Ooo`<000Woo`8000Woo`03003ooooo00Koo`03
003ooooo00Goo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00?oo`03
003ooooo00?oo`03003ooooo00?oo`03003ooooo05;oo`03003ooooo01?oo`006Ooo1P005?oo00<0
0?ooool0=?oo0`002ooo00<00?ooool02?oo00<00?ooool01ooo00<00?ooool01Ooo00<00?ooool0
1?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool0
0ooo00<00?ooool0DOoo00<00?ooool04ooo000Iool01P00ooooo`00ool001Coo`8003?oo`8000go
o`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Go
o`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo053o
o`8001Goo`006Ooo00@00?ooool001Koo`03003ooooo02ooo`<000goo`8000[oo`03003ooooo00Oo
o`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo00?o
o`03003ooooo00Coo`03003ooooo00?oo`03003ooooo053oo`03003ooooo01?oo`006_oo0P005ooo
00<00?ooool0;Ooo0P003ooo00<00?ooool02Ooo00<00?ooool01ooo00<00?ooool01_oo00<00?oo
ool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?oo
ool00ooo00<00?ooool0Cooo00<00?ooool04ooo000cool00`00ooooo`0Zool3000?ool2000;ool0
0`00ooooo`08ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`03ool00`00ooooo`04ool00`00ooooo`03ool00`00ooooo`1?ool00`00ooooo`0Cool0
03?oo`8002Soo`<0017oo`03003ooooo00[oo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo
00Koo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo
00?oo`03003ooooo04goo`8001Goo`007?oo0P005Ooo00<00?ooool09Ooo0P004ooo00<00?ooool0
2_oo00<00?ooool02Ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool0
1Ooo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0COoo00<00?ooool0
4ooo000Kool01000ooooo`005?oo00<00?ooool08_oo0`004ooo0P003Ooo00<00?ooool02?oo00<0
0?ooool02?oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<0
0?ooool01?oo00<00?ooool00ooo00<00?ooool0COoo00<00?ooool04ooo000Kool01000ooooo`00
5?oo0P008Ooo0P005Ooo00<00?ooool03?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?ooool0
1_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool0Booo0P005Ooo000Lool2000Eool00`00ooooo`0Nool2000Fool00`00ooooo`0<
ool00`00ooooo`0:ool00`00ooooo`08ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`04
ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`04ool00`00ooooo`1;ool00`00ooooo`0C
ool002Ooo`D000;oo`03003ooooo00;oo`03003ooooo01_oo`<001Ooo`03003ooooo00goo`03003o
oooo00[oo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Goo`03003o
oooo00Coo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo04[oo`03003ooooo01?oo`00:Ooo
00L00?ooooooo`00ool00003ool00`00ooooo`0Iool2000Iool00`00ooooo`0=ool00`00ooooo`0;
ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05
ool00`00ooooo`04ool00`00ooooo`04ool00`00ooooo`1:ool00`00ooooo`0Cool001_oo`04003o
oooo000:ool01`00oooooooo003oo`0000?oo`<001Ooo`8001[oo`03003ooooo00koo`03003ooooo
00_oo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Goo`03003ooooo
00Coo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo04Soo`8001Goo`006ooo10002_oo00L0
0?ooooooo`00ool00003ool00`00ooooo`0Dool3000Kool00`00ooooo`0?ool00`00ooooo`0;ool0
0`00ooooo`08ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`05ool00`00ooooo`04ool00`00ooooo`18ool00`00ooooo`0Cool001_oo`04003ooooo
000:ool01`00oooooooo003oo`0000?oo`03003ooooo01;oo`8001koo`03003ooooo00ooo`03003o
oooo00_oo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Koo`03003o
oooo00Goo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo04Ooo`03003ooooo01?oo`006ooo
00@00?ooool000Woo`8000Coo`03003ooooo00;oo`03003ooooo00ooo`<001ooo`03003ooooo013o
o`03003ooooo00_oo`03003ooooo00Woo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Go
o`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo04Koo`03003ooooo01?o
o`00<ooo0P003Ooo0`008_oo00<00?ooool04?oo00<00?ooool02ooo00<00?ooool02Ooo00<00?oo
ool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?oo
ool01?oo00<00?ooool0AOoo0P005Ooo000Kool00`00ooooo`0Eool00`00ooooo`0:ool2000Uool0
0`00ooooo`0@ool00`00ooooo`0;ool00`00ooooo`0:ool00`00ooooo`07ool00`00ooooo`07ool0
0`00ooooo`05ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`15ool0
0`00ooooo`0Cool001[oo`@001Goo`03003ooooo00Soo`8002Ooo`03003ooooo013oo`03003ooooo
00_oo`03003ooooo00[oo`03003ooooo00Soo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo
00Koo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo04Coo`03003ooooo01?oo`006ooo00@0
0?ooool001Coo`03003ooooo00Koo`8002Woo`03003ooooo013oo`03003ooooo00_oo`03003ooooo
00[oo`03003ooooo00Woo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo
00Goo`03003ooooo00Coo`03003ooooo04?oo`03003ooooo01?oo`006ooo00@00?ooool001Coo`80
00Coo`<002_oo`03003ooooo013oo`03003ooooo00coo`03003ooooo00[oo`03003ooooo00Soo`03
003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Coo`03
003ooooo04;oo`8001Goo`006ooo00<00?oo00005Ooo00<00?ooool00ooo0P00;?oo00<00?ooool0
4Ooo00<00?ooool02ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool01_oo00<00?ooool0
1_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool0@_oo00<00?ooool0
4ooo000cool00`00ooooo`05ool4000Yool00`00ooooo`0@ool00`00ooooo`0<ool00`00ooooo`09
ool00`00ooooo`09ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06
ool00`00ooooo`04ool00`00ooooo`11ool00`00ooooo`0Cool003?oo`8000[oo`8002Soo`03003o
oooo013oo`03003ooooo00_oo`03003ooooo00[oo`03003ooooo00Woo`03003ooooo00Koo`03003o
oooo00Koo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo043oo`8001Go
o`006ooo00@00?ooool001Coo`03003ooooo00_oo`8002Koo`03003ooooo013oo`03003ooooo00co
o`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Go
o`03003ooooo00Koo`03003ooooo00Coo`03003ooooo043oo`03003ooooo01?oo`006_oo1@005?oo
00<00?ooool03Ooo0P009Ooo00<00?ooool04?oo00<00?ooool03?oo00<00?ooool02Ooo00<00?oo
ool02Ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01_oo00<00?oo
ool01?oo00<00?ooool0?ooo00<00?ooool04ooo000Iool00`00ool00002ool00`00ooooo`0Bool0
0`00ooooo`0?ool2000Tool00`00ooooo`0?ool00`00ooooo`0<ool00`00ooooo`0:ool00`00oooo
o`09ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`06ool00`00oooo
o`04ool00`00ooooo`0nool00`00ooooo`0Cool001Woo`03003oo`0000;oo`03003ooooo01;oo`80
01;oo`<0027oo`03003ooooo013oo`03003ooooo00coo`03003ooooo00Woo`03003ooooo00Woo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Coo`03
003ooooo03goo`8001Goo`00<ooo00<00?ooool05?oo10007_oo0P004Ooo00<00?ooool03?oo00<0
0?ooool02Ooo00<00?ooool02Ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<0
0?ooool01Ooo00<00?ooool01?oo00<00?ooool0?Ooo00<00?ooool04ooo000Wool:0002ool00`00
ooooo`0Hool3000Mool00`00ooooo`0?ool00`00ooooo`0<ool00`00ooooo`09ool00`00ooooo`09
ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`04
ool00`00ooooo`0lool00`00ooooo`0Cool001coo`8000_oo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo01_oo`8001coo`03003ooooo00ooo`03003ooooo00coo`03003ooooo00Woo`03003o
oooo00Woo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Goo`03003o
oooo00Coo`03003ooooo03_oo`03003ooooo01?oo`006ooo00@00?ooool000[oo`03003ooooo00;o
o`03003ooooo00;oo`<001goo`8001_oo`03003ooooo00ooo`03003ooooo00coo`03003ooooo00Wo
o`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Go
o`03003ooooo00Coo`03003ooooo03[oo`8001Goo`006ooo00@00?ooool000[oo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo01ooo`8001[oo`80013oo`03003ooooo00coo`03003ooooo00Wo
o`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Go
o`03003ooooo00Coo`03003ooooo03[oo`03003ooooo01?oo`007?oo0P002ooo00<00?ooool00_oo
00<00?ooool00_oo00<00?ooool08Ooo0P006_oo00<00?ooool03_oo00<00?ooool02ooo00<00?oo
ool02Ooo00<00?ooool02Ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<00?oo
ool01Ooo00<00?ooool01?oo00<00?ooool0>Ooo00<00?ooool04ooo000Xool20003ool20004ool0
0`00ooooo`0Sool2000Iool00`00ooooo`0>ool00`00ooooo`0;ool00`00ooooo`09ool00`00oooo
o`08ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00oooo
o`04ool00`00ooooo`0iool00`00ooooo`0Cool003?oo`8002Koo`<001Ooo`03003ooooo00koo`03
003ooooo00_oo`03003ooooo00Woo`03003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Koo`03003ooooo00Goo`03003ooooo00Coo`03003ooooo03Ooo`8001Goo`006Ooo00<0
0?ooool00_oo00<00?ooool04_oo00<00?ooool0:?oo0`005Ooo0P003ooo0P003?oo0P002_oo00<0
0?ooool02?oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<0
0?ooool01?oo00<00?ooool0=ooo00<00?ooool04ooo000Iool6000Dool00`00ooooo`0[ool2000E
ool2000?ool00`00ooooo`0;ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`07ool00`00
ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`0fool00`00
ooooo`0Cool001koo`03003ooooo01;oo`8002koo`<001Coo`8000koo`03003ooooo00_oo`03003o
oooo00Soo`8000Woo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo00Go
o`03003ooooo00Goo`03003ooooo03Coo`8001Goo`00<ooo00<00?ooool0<?oo0`004ooo0P003Ooo
0P003?oo0P002_oo00<00?ooool01ooo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01Ooo
00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool0=?oo00<00?ooool04ooo000cool00`00oooo
o`0cool3000Bool00`00ooooo`0<ool00`00ooooo`0;ool00`00ooooo`08ool00`00ooooo`07ool0
0`00ooooo`07ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool0
0`00ooooo`0cool00`00ooooo`0Cool003?oo`03003ooooo03Koo`80017oo`8000goo`8000coo`03
003ooooo00Soo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Goo`03
003ooooo00Goo`03003ooooo00Goo`03003ooooo03;oo`03003ooooo01?oo`00<ooo0P00>Ooo0`00
4?oo0P003Ooo00<00?ooool02_oo00<00?ooool02?oo00<00?ooool01ooo00<00?ooool01ooo00<0
0?ooool01_oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool0<?oo0P00
5Ooo000Kool01000ooooo`005?oo00<00?ooool0>ooo0`003ooo0P003?oo0P002ooo0P002Ooo0P00
2?oo0P002?oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool01Ooo00<0
0?ooool0<Ooo00<00?ooool04ooo000Iool00`00ool00003000Dool00`00ooooo`0nool2000?ool2
000<ool2000;ool00`00ooooo`08ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`06ool0
0`00ooooo`05ool00`00ooooo`04ool00`00ooooo`05ool00`00ooooo`0`ool00`00ooooo`0Cool0
01koo`03003ooooo01;oo`03003ooooo043oo`<000koo`8000coo`03003ooooo00Woo`03003ooooo
00Soo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Goo`03003ooooo
00Coo`03003ooooo00Goo`03003ooooo02ooo`03003ooooo01?oo`00<ooo0P00A?oo0P003_oo0P00
2ooo0P002_oo00<00?ooool02?oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<0
0?ooool01Ooo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool0;Ooo0P005Ooo000cool00`00
ooooo`15ool2000>ool2000;ool00`00ooooo`08ool20009ool00`00ooooo`07ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`04ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`0^
ool00`00ooooo`0Cool001coo`8000Woo`D00004ool000000003ool00`00ooooo`17ool2000>ool0
0`00ooooo`09ool2000:ool00`00ooooo`07ool20008ool00`00ooooo`06ool00`00ooooo`06ool0
0`00ooooo`04ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`0]ool00`00ooooo`0Cool0
01_oo`04003ooooo000:ool01@00oooooooo00001Ooo00<00?ooool0BOoo0P003Ooo0P002ooo00<0
0?ooool02?oo00<00?ooool02?oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<0
0?ooool01Ooo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool0;?oo00<00?ooool04ooo000K
ool01000ooooo`002_oo00<00?ooool00_oo00<00?ooool00_oo0`00Booo0P003Ooo0P002_oo0P00
2Ooo0P002Ooo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<0
0?ooool01Ooo00<00?ooool01?oo00<00?ooool0:ooo0P005Ooo000Lool2000;ool00`00ooooo`02
ool00`00ooooo`02ool00`00ooooo`1=ool3000<ool2000:ool00`00ooooo`08ool00`00ooooo`07
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`05
ool00`00ooooo`04ool00`00ooooo`0[ool00`00ooooo`0Cool002Woo`07003oooooool00?oo0000
0ooo00<00?ooool0D?oo0`002ooo0P002Ooo0P002Ooo0P002?oo0P001ooo0P001ooo00<00?ooool0
1Ooo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool0:_oo00<00?ooool0
4ooo000Xool20004ool00`00ooooo`02ool2001Dool2000;ool20009ool20009ool20008ool00`00
ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`05ool00`00
ooooo`04ool00`00ooooo`0Xool2000Eool003?oo`03003ooooo05Goo`<000[oo`<000Soo`8000Wo
o`8000Ooo`8000Ooo`03003ooooo00Goo`8000Koo`03003ooooo00Coo`8000Goo`03003ooooo00Co
o`03003ooooo02Woo`03003ooooo01?oo`00<ooo00<00?ooool0F?oo0`002_oo0P002?oo0P002Ooo
0P001ooo0P001_oo0P001ooo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool00ooo00<00?oo
ool01?oo00<00?ooool0:?oo00<00?ooool04ooo000cool00`00ooooo`1Kool30009ool20008ool2
0009ool00`00ooooo`06ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`04ool00`00oooo
o`05ool00`00ooooo`03ool00`00ooooo`04ool00`00ooooo`0Wool00`00ooooo`0Cool003?oo`80
05ooo`8000Woo`8000Soo`8000Soo`8000Ooo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo
00Coo`03003ooooo00Goo`03003ooooo00?oo`03003ooooo00Coo`03003ooooo02Goo`8001Goo`00
<ooo00<00?ooool0H?oo0P002Ooo0P002?oo0P002?oo00<00?ooool01Ooo0P001_oo00<00?ooool0
1Ooo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool0
9_oo00<00?ooool04ooo000Iool6000Dool00`00ooooo`1Rool20009ool20008ool00`00ooooo`06
ool20007ool00`00ooooo`04ool20006ool00`00ooooo`04ool00`00ooooo`05ool00`00ooooo`03
ool00`00ooooo`03ool00`00ooooo`0Uool00`00ooooo`0Cool001Woo`<000;oo`03003ooooo01;o
o`03003ooooo06Coo`8000Woo`8000Ooo`8000Soo`03003ooooo00Goo`03003ooooo00Goo`03003o
oooo00Coo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00Coo`03003o
oooo02Coo`03003ooooo01?oo`007?oo00<00?ooool05?oo0P00Iooo0P002Ooo0P001ooo0P001ooo
0P001_oo0P001_oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool00ooo
00<00?ooool00ooo00<00?ooool08ooo0P005Ooo000Iool30002ool00`00ooooo`0Bool00`00oooo
o`1Xool30008ool20007ool20007ool00`00ooooo`05ool00`00ooooo`04ool00`00ooooo`04ool0
0`00ooooo`04ool00`00ooooo`04ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`0Sool0
0`00ooooo`0Cool001Woo`H001Coo`03003ooooo06_oo`<000Ooo`8000Ooo`8000Koo`8000Koo`80
00Goo`8000Goo`8000Goo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo
02;oo`03003ooooo01?oo`006Ooo00<00?ooool00_oo00<00?ooool04_oo0P00Kooo0P001ooo0P00
1ooo0P001_oo0P001_oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool0
1?oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool08?oo0P005Ooo000cool00`00ooooo`1`
ool30006ool30006ool20006ool20005ool20005ool20005ool00`00ooooo`03ool20005ool00`00
ooooo`02ool00`00ooooo`03ool00`00ooooo`0Qool00`00ooooo`0Cool001coo`8000Woo`D00003
ool0000000Coo`03003ooooo07?oo`<000Koo`8000Koo`8000Koo`8000Goo`8000Goo`8000Coo`80
00Goo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo023oo`03003ooooo
01?oo`006ooo0P0000?oo`00ool02Ooo00<00?ooool00ooo00D00?ooooooo`0007Soo`<000Goo`<0
00Goo`8000Koo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00?oo`03
003ooooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo01ooo`03003ooooo01?oo`00
6ooo0P0000?oo`00ool02Ooo00<00?ooool00_oo00<00?ooool00_oo0`00NOoo0P001_oo0P001Ooo
0P001Ooo0P001Ooo0P001Ooo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00ooo00<00?oo
ool00_oo00<00?ooool00ooo00<00?ooool07Ooo0P005Ooo000Lool00`00ool0000:ool00`00oooo
o`03ool01@00oooooooo0000OOoo0P001_oo0P001Ooo0P001Ooo0P001Ooo00<00?ooool00ooo0P00
1?oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool0
7_oo00<00?ooool04ooo000Yool01`00oooooooo003oo`0000?oo`03003ooooo07goo`<000Goo`80
00Goo`8000Goo`03003ooooo00?oo`8000Goo`03003ooooo00;oo`8000Coo`03003ooooo00?oo`03
003ooooo00;oo`03003ooooo00;oo`03003ooooo01goo`03003ooooo01?oo`00:?oo0P001?oo00<0
0?ooool00_oo00<00?ooool0P?oo0P001Ooo0P001Ooo0P001?oo0P001Ooo00<00?ooool00ooo00<0
0?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00ooo00<0
0?ooool07?oo00<00?ooool04ooo000Mool2000Dool20023ool20005ool20005ool20004ool20004
ool20004ool20004ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02
ool00`00ooooo`0Kool2000Eool001_oo`04003oo`00000Dool00`00ooooo`24ool30004ool30004
ool20004ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool00`00
ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0Kool00`00ooooo`0Cool001_o
o`04003oo`00000Dool00`00ooooo`27ool20005ool20004ool20003ool20004ool20004ool20003
ool20003ool20003ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0Jool00`00ooooo`0C
ool001_oo`@001Coo`03003ooooo08Woo`<000Coo`8000Coo`8000?oo`8000Coo`8000Coo`03003o
oooo00;oo`03003ooooo00;oo`05003oooooool00004ool00`00ooooo`02ool00`00ooooo`0Iool0
0`00ooooo`0Cool001koo`03003ooooo01;oo`8008goo`<000?oo`<000?oo`8000?oo`8000Coo`80
00?oo`03003ooooo00;oo`03003ooooo00;oo`04003oooooool20003ool01@00oooooooo00006_oo
0P005Ooo000Kool01000ooooo`005?oo00<00?ooool0Sooo0P001?oo0P000ooo0P000ooo0P001?oo
0P000_oo0P000ooo0P000ooo0P000ooo00D00?ooooooo`0000?oo`03003ooooo01Soo`03003ooooo
01?oo`006ooo10005?oo00<00?ooool0TOoo0`000ooo0P000ooo0P000ooo0P001?oo00D00?oooooo
o`0000Coo`03003ooooo00;oo`05003oooooool00003ool01@00oooooooo00006Ooo00<00?ooool0
4ooo000Kool00`00ooooo`0Eool2002Eool20003ool20003ool20003ool20003ool20002ool20003
ool00`00ooooo`02ool01@00oooooooo00000ooo00D00?ooooooo`0001Ooo`8001Goo`006ooo00<0
0?ooool05Ooo00<00?ooool0U_oo0P000ooo0P000ooo0P000ooo0P000ooo00D00?ooooooo`0000?o
o`03003ooooo00;oo`05003oooooool00003ool01@00oooooooo00005ooo00<00?ooool04ooo000L
ool3000Dool00`00ooooo`2Hool30002ool20003ool20003ool01000oooooooo0P000_oo0P000_oo
0P000ooo00D00?ooooooo`0000?oo`05003oooooool0000Fool00`00ooooo`0Cool001koo`03003o
oooo01;oo`03003ooooo09_oo`8000;oo`8000?oo`8000;oo`8000?oo`05003oooooool00003ool0
1@00oooooooo00000ooo00@00?ooool000?oo`03003ooooo01Coo`03003ooooo01?oo`00<ooo0P00
W_oo0P000_oo0P000ooo0P000_oo0P000_oo0P000_oo0P000_oo00D00?ooooooo`0000?oo`04003o
oooo0003ool00`00ooooo`0Bool2000Eool003?oo`03003ooooo09ooo`<00004ool000000002ool2
0002ool01@00oooooooo00000ooo00@00?ooool000?oo`05003oooooool00002ool01@00oooooooo
00005?oo00<00?ooool04ooo000Wool50002ool30002ool00`00ooooo`2Rool20002ool20002ool2
00000ooo00000002ool20002ool200000ooo00000002ool01@00oooooooo00000_oo00D00?oooooo
o`0001?oo`03003ooooo01?oo`00:Ooo00<00?ooool00ooo00D00?ooooooo`000:Koo`<00003ool0
000000;oo`800003ool0000000;oo`8000;oo`04003ooooo0002ool01@00oooooooo00000_oo00@0
0?ooool001?oo`03003ooooo01?oo`00:Ooo00@00?ooooooo`@000;oo`<00:Ooo`H00004ool00000
ool20002ool200001?oo00000?oo0P0000?oo`0000000_oo00@00?ooool000;oo`03003ooooo00oo
o`8001Goo`00:Ooo00L00?ooooooo`00ool00003ool00`00ooooo`2Zool200001?oo00000?oo0P00
00?oo`0000000_oo0P0000Coo`00003oo`800005ool00?ooool00002ool00`00ool0000Bool00`00
ooooo`0Cool002Woo`03003ooooo00;oo`8000?oo`03003ooooo0:coo`/000;oo`04003ooooo0002
ool00`00ool00002ool01P00ooooo`00ool0017oo`03003ooooo01?oo`00:?oo0P001Ooo00D00?oo
ooooo`000;7oo`800004ool00000ool400001?oo00000?oo0P0000?oo`0000000P0000Ooo`00oooo
o`00ool0000@ool00`00ooooo`0Cool003?oo`800;;oo`D00003ool0000000800005ool00000ool0
0002ool01@00ool00?oo00000_oo00<00?oo00003_oo0P005Ooo000cool00`00ooooo`2dool90000
0ooo0000000200001Ooo003oo`00ool00P0000Coo`00ool000koo`03003ooooo01?oo`00<ooo00<0
0?ooool0]ooo200000?oo`0000001P0000Koo`00ool00?oo000=ool00`00ooooo`0Cool003?oo`80
0;[oo`P0000>ool00?oo003oo`00ool00?oo003oo`00ool000_oo`8001Goo`00<ooo00<00?ooool0
_?oo300000Soo`00ool00?oo003oo`002ooo00<00?ooool04ooo000cool00`00ooooo`2nool=0000
0ooo003oo`02000;ool00`00ooooo`0Cool003?oo`03003ooooo0<7oo`d00003ool0000000[oo`03
003ooooo01?oo`00<ooo0P00a?oo2@0000Koo`0000000?oo0008ool2000Eool003?oo`03003ooooo
0<Koo``000Woo`03003ooooo01?oo`00<ooo00<00?ooool0b?oo2`002?oo00<00?ooool04ooo000c
ool00`00ooooo`3;ool90007ool00`00ooooo`0Cool003?oo`800<koo`P000Goo`8001Goo`009ooo
1@000_oo00<00?ooool00_oo00<00?ooool0d?oo1@001_oo00<00?ooool04ooo000Yool01`00oooo
oooo003oo`0000?oo`03003ooooo0=?oo`<000Goo`03003ooooo01?oo`00:Ooo00<00?ooool00ooo
00@00?ooooooo`<00=Goo`8000?oo`8001Goo`00:Ooo00@00?ooooooo`8000Coo`03003ooooo0=_o
o`03003ooooo01?oo`00:Ooo00D00?ooooooo`0000Goo`03003ooooo00?oo`03003ooooo01Woo`03
003ooooo01Woo`03003ooooo01Woo`03003ooooo01Woo`03003ooooo01Woo`03003ooooo01[oo`03
003ooooo01Woo`03003ooooo013oo`03003ooooo01?oo`00:?oo0P000ooo0`000ooo00<00?ooool0
0ooo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool00_oo00<00?ooool04ooo000coooO000Eool00?ooobSoo`00oooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool004koo`800004ool00000ool400001Ooo00000000ool0
0P0000?oo`0000000_oo0P000_oo00<00?oo00000_oo0`000ooo0P000_oo10003ooo1@0000Coo`00
000000;oo`<000;oo`<000;oo`<000;oo`<000?oo`800003ool0000000;oo`03003ooooo0080013o
o`<000?oo`<000?oo`800003ool0000000;oo`03003ooooo008000;oo`<000?oo`8000;oo`<003[o
o`00C_oo00H00?ooooooo`00ool30003ool01`00oooooooo003oo`0000;oo`03003ooooo00800004
ool00?oo0002ool01@00oooooooo00000_oo00H00?ooool00?oo000@ool01000ooooo`000_oo00<0
0?ooool00_oo00<00?ooool00_oo00D00?ooooooo`0000Goo`05003oooooool00004ool01P00oooo
o`00ool000;oo`03003ooooo00koo`03003ooooo00?oo`05003oooooool00002ool00`00ool00002
ool00`00ool00002ool01000ooooo`000ooo00<00?ooool00ooo00<00?ooool0>Ooo001>ool01@00
ool00?oo00000ooo00D00?ooooooo`0000?oo`<000;oo`03003ooooo00800004ool00?oo0002ool0
1@00oooooooo00001?oo00<00?oo00004Ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool0
0_oo00D00?ooooooo`0000Goo`04003oooooool30002ool01P00ooooo`00ool001?oo`03003ooooo
00?oo`05003oooooool00002ool00`00ool00002ool00`00ool00005ool01000oooooooo0`000ooo
00<00?ooool0>Ooo001>ool200000ooo00000002ool20002ool400000ooo003oo`020002ool20000
1?oo00000?oo0P0000?oo`0000000_oo10000_oo10004?oo0P000ooo0`000_oo0`000_oo0P000ooo
0`000_oo0P000ooo0`0000?oo`0000000P0000?oo`0000000P004Ooo0P000ooo10000_oo0P0000?o
o`0000000P0000?oo`0000000P000_oo0P000ooo0`000_oo1000>Ooo001>ool200000ooo0000000;
ool00`00ooooo`0Aool00`00ooooo`0Fool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool0
6_oo00<00?ooool04Ooo00@00?ooool0013oo`03003ooooo04Woo`00C_oo0P0000?oo`0000002_oo
0P003ooo00<00?ooool06Ooo1@000ooo00<00?ooool00_oo00D00?ooooooo`0000Woo`03003ooooo
01koo`D001Koo`03003ooooo04?oo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolX
ool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-4.05063, 6.38946, \
0.070974, 0.0536185}}]
}, Open  ]],

Cell["Betas and Security\[Hyphen]Market Line", "Subsection",
  CellTags->{"S0.3", "3.1"}],

Cell["\<\
The Capital Asset Pricing Model (CAPM) is an equilibrium model of \
capital markets. The model's main conclusion is that the equilibrium relation \
between risk and return is given by the Security\[Hyphen]Market Line \
\>", \
"Text",
  CellTags->{"S0.3", "3.2"}],

Cell[BoxData[
    \(TraditionalForm\`E[R\_i] = 
      R\_F + \(\[Beta]\_i\)(E[R\_M] - R\_F)\)], "DisplayFormula",
  CellTags->"S0.3"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\_i\)], "InlineFormula",
    CellTags->"S0.3"],
  " is the return on asset ",
  Cell[BoxData[
      \(TraditionalForm\`i\)], "InlineFormula",
    CellTags->"S0.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\_F\)], "InlineFormula",
    CellTags->"S0.3"],
  " is the risk\[Hyphen]free rate. "
}], "Text",
  CellTags->{"S0.3", "3.3"}],

Cell[TextData[{
  "We open a stream to the file ",
  StyleBox["stocks2.ret", "TI"],
  " containing the returns of stocks. "
}], "MathCaption",
  CellTags->{"S0.3", "3.4"}],

Cell["\<\
stream = OpenRead[ToFileName[{\"Finance\",\"Data\"}, \
\"stocks2.ret\"]];\
\>", "Input",
  CellLabel->"In[46]:=",
  CellTags->"S0.3"],

Cell["We read in the number of assets. ", "MathCaption",
  CellTags->{"S0.3", "3.5"}],

Cell[CellGroupData[{

Cell["n = Read[stream, Number]", "Input",
  CellLabel->"In[47]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \(12\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell["We read in the tickers. ", "MathCaption",
  CellTags->{"S0.3", "3.6"}],

Cell[CellGroupData[{

Cell["\<\
tickers = Rest[Read[stream, Table[Word, {n+1}],
   RecordSeparators -> {\"\\n\", \" \", \"\\t\"}]]\
\>", "Input",
  CellLabel->"In[48]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \({"AMR", "ALD", "AA", "AC", "IBM", "KO", "S", "T", "BS", "UTX", "WX", 
      "Z"}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell["We read the rest of the data. ", "MathCaption",
  CellTags->{"S0.3", "3.7"}],

Cell["\<\
aux = Transpose[Partition[
   ReadList[stream, Number], n+1]];\
\>", "Input",
  CellLabel->"In[49]:=",
  CellTags->"S0.3"],

Cell["Finally we close the stream. ", "MathCaption",
  CellTags->{"S0.3", "3.8"}],

Cell["Close[stream];", "Input",
  CellLabel->"In[50]:=",
  CellTags->"S0.3"],

Cell["We define lists of the months and returns of stocks. ", "MathCaption",
  CellTags->{"S0.3", "3.9"}],

Cell["{months, returns} = {First[aux], Transpose[Rest[aux]]};", "Input",
  CellLabel->"In[51]:=",
  CellTags->"S0.3"],

Cell[TextData[{
  "We will use the Standard & Poor 500 index as a model of the whole market. \
The file ",
  StyleBox["SP500.idx", "TI"],
  " contains the values of the index for the same periods as the stocks in \
the file ",
  StyleBox["stocks2.ret", "TI"],
  ". We have to compute the returns for this index. "
}], "Text",
  CellTags->{"S0.3", "3.10"}],

Cell["We read in the dates and the values of the index. ", "MathCaption",
  CellTags->{"S0.3", "3.11"}],

Cell[CellGroupData[{

Cell["\<\
idx  = ReadList[ToFileName[{\"Finance\", \"Data\"}, \"SP500.idx\"],
   {Number, Number}]\
\>", "Input",
  CellLabel->"In[52]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0", ",", 
            StyleBox["97.54999999999999`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"1", ",", 
            StyleBox["96.5700000000000002`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", 
            StyleBox["96.2199999999999988`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", 
            StyleBox["93.9799999999999968`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", 
            StyleBox["90.3100000000000058`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5", ",", 
            StyleBox["87.2799999999999975`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6", ",", 
            StyleBox["85.9999999999999964`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7", ",", 
            StyleBox["79.3100000000000004`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"8", ",", 
            StyleBox["72.1500000000000074`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"9", ",", 
            StyleBox["63.5400000000000009`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"10", ",", 
            StyleBox["73.9000000000000056`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"11", ",", 
            StyleBox["69.9699999999999988`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"12", ",", 
            StyleBox["68.5599999999999987`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"13", ",", 
            StyleBox["76.9800000000000039`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"14", ",", 
            StyleBox["81.5900000000000069`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"15", ",", 
            StyleBox["83.3600000000000029`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"16", ",", 
            StyleBox["87.3000000000000042`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"17", ",", 
            StyleBox["91.1500000000000021`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"18", ",", 
            StyleBox["95.1900000000000012`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"19", ",", 
            StyleBox["88.75`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"20", ",", 
            StyleBox["86.8799999999999883`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"21", ",", 
            StyleBox["83.8700000000000045`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"22", ",", 
            StyleBox["89.0399999999999991`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"23", ",", 
            StyleBox["91.2399999999999877`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"24", ",", 
            StyleBox["90.1900000000000012`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"25", ",", 
            StyleBox["100.859999999999994`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell["This creates a list of index values only. ", "MathCaption",
  CellTags->{"S0.3", "3.12"}],

Cell[CellGroupData[{

Cell["aux = Transpose[idx][[2]]", "Input",
  CellLabel->"In[53]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        StyleBox["97.54999999999999`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["96.5700000000000002`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["96.2199999999999988`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["93.9799999999999968`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["90.3100000000000058`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["87.2799999999999975`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["85.9999999999999964`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["79.3100000000000004`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["72.1500000000000074`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["63.5400000000000009`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["73.9000000000000056`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["69.9699999999999988`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["68.5599999999999987`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["76.9800000000000039`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["81.5900000000000069`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["83.3600000000000029`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["87.3000000000000042`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["91.1500000000000021`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["95.1900000000000012`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["88.75`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["86.8799999999999883`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["83.8700000000000045`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["89.0399999999999991`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["91.2399999999999877`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["90.1900000000000012`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["100.859999999999994`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5]}], "}"}]], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["\<\
We compute the returns for the Standard & Poor 500 index. We are \
assuming that they are good estimates for the returns of the whole market. \
\
\>", "MathCaption",
  CellTags->{"S0.3", "3.13"}],

Cell[CellGroupData[{

Cell["ret[SP500] ^= 100 (Rest[aux]/Drop[aux, -1] - 1)", "Input",
  CellLabel->"In[54]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \({\(-1.00461301896462851`\), \(-0.362431396914142389`\), \
\(-2.3279983371440327`\), \(-3.90508618855076594`\), \
\(-3.35511017606022754`\), \(-1.46654445462878202`\), \(-7.77906976744185918`\
\), \(-9.02786533854493811`\), \(-11.9334719334719396`\), 
      16.3046899590809202`, \(-5.31799729364006434`\), \
\(-2.01514934972130133`\), 12.2812135355892637`, 5.98856845934010451`, 
      2.16938350288025105`, 4.72648752399231764`, 4.4100801832760661`, 
      4.43225452550739529`, \(-6.76541653535035436`\), \
\(-2.10704225352112972`\), \(-3.46454880294658762`\), 6.16430189579109111`, 
      2.47079964061094337`, \(-1.15081104778604892`\), 
      11.8305798869054124`}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[TextData[{
  "This creates a function ",
  StyleBox["ret", "MB"],
  " that takes a stock ticker as an argument and gives the list of returns \
for that stock. "
}], "MathCaption",
  CellTags->{"S0.3", "3.14"}],

Cell["\<\
MapThread[ (ret[#1] ^= #2)&,
   {ToExpression[tickers], Transpose[returns]}];\
\>", "Input",
  CellLabel->"In[55]:=",
  CellTags->"S0.3"],

Cell["Here is the list of returns for AMR. ", "MathCaption",
  CellTags->{"S0.3", "3.15"}],

Cell[CellGroupData[{

Cell["ret[AMR]", "Input",
  CellLabel->"In[56]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        StyleBox["11.5939999999999998`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5], ",", 
        StyleBox["22.0779999999999976`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5], ",", 
        RowBox[{"-", 
          StyleBox["8.51099999999999923`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4]}], ",", 
        RowBox[{"-", 
          StyleBox["3.48799999999999998`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4]}], ",", 
        RowBox[{"-", 
          StyleBox["9.63899999999999934`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4]}], ",", 
        RowBox[{"-", 
          StyleBox["11.9999999999999996`",
            StyleBoxAutoDelete->True,
            PrintPrecision->5]}], ",", 
        RowBox[{"-", 
          StyleBox["10.6059999999999998`",
            StyleBoxAutoDelete->True,
            PrintPrecision->5]}], ",", 
        RowBox[{"-", 
          StyleBox["1.6950000000000001`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4]}], ",", 
        RowBox[{"-", 
          StyleBox["12.0690000000000008`",
            StyleBoxAutoDelete->True,
            PrintPrecision->5]}], ",", 
        StyleBox["27.4509999999999987`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5], ",", 
        RowBox[{"-", 
          StyleBox["21.5379999999999993`",
            StyleBoxAutoDelete->True,
            PrintPrecision->5]}], ",", 
        RowBox[{"-", 
          StyleBox["19.6080000000000005`",
            StyleBoxAutoDelete->True,
            PrintPrecision->5]}], ",", 
        StyleBox["48.7800000000000011`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5], ",", 
        StyleBox["19.6720000000000005`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5], ",", 
        StyleBox["1.3700000000000001`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["4.05400000000000027`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        RowBox[{"-", 
          StyleBox["15.5839999999999996`",
            StyleBoxAutoDelete->True,
            PrintPrecision->5]}], ",", 
        StyleBox["3.07699999999999995`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        RowBox[{"-", 
          StyleBox["4.47799999999999975`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4]}], ",", 
        StyleBox["4.68799999999999972`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        RowBox[{"-", 
          StyleBox["11.9399999999999995`",
            StyleBoxAutoDelete->True,
            PrintPrecision->5]}], ",", 
        RowBox[{"-", 
          StyleBox["1.6950000000000001`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4]}], ",", 
        StyleBox["15.5169999999999985`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5], ",", 
        StyleBox["5.96999999999999975`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], ",", 
        StyleBox["11.2680000000000002`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5]}], "}"}]], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[TextData[{
  "The built\[Hyphen]in function ",
  StyleBox["Fit", "MB"],
  " returns the formula for the regression line. "
}], "MathCaption",
  CellTags->{"S0.3", "3.16"}],

Cell[CellGroupData[{

Cell["\<\
regressionLine[x_] = Fit[Transpose[{ret[SP500],
   ret[AMR]}], {1, x}, x]\
\>", "Input",
  CellLabel->"In[57]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \(\(\(1.14131853172181729`\)\(\[InvisibleSpace]\)\) + 
      1.60713019996684529`\ x\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["\<\
This defines a function that computes the beta of a given asset. \
\
\>", "MathCaption",
  CellTags->{"S0.3", "3.17"}],

Cell["\<\
AssetBeta[marketreturns_List, assetreturns_List] :=
   CoefficientList[Fit[Transpose[{marketreturns,
      assetreturns}], {1, x}, x], x][[2]]\
\>", "Input",
  CellLabel->"In[58]:=",
  CellTags->"S0.3"],

Cell["Here is the calculation of the beta for the AMR stock. ", "MathCaption",
  CellTags->{"S0.3", "3.18"}],

Cell[CellGroupData[{

Cell["AssetBeta[ret[SP500], ret[AMR]]", "Input",
  CellLabel->"In[59]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \(1.60713019996684529`\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell["\<\
To perform a more sophisticated statistical analysis, load the \
standard statistics package. \
\>", "MathCaption",
  CellTags->{"S0.3", "3.19"}],

Cell["Needs[\"Statistics`LinearRegression`\"]", "Input",
  CellLabel->"In[60]:=",
  CellTags->"S0.3"],

Cell[TextData[{
  "You can use the function ",
  StyleBox["Regress", "MB"],
  " for linear regression analysis. "
}], "MathCaption",
  CellTags->{"S0.3", "3.20"}],

Cell[CellGroupData[{

Cell["Regress[Transpose[{ret[SP500], ret[AMR]}], {1, x}, x]", "Input",
  CellLabel->"In[61]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", "1.14131853172181685`", "2.46392680624918192`", 
                  "0.463211215863687897`", "0.647566254817226116`"},
                {"x", "1.60713019996684502`", "0.368405585297929816`", 
                  "4.36239368810643313`", "0.000228160762315798848`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            (
            TableForm[ #, TableHeadings -> {{1, x}, {"Estimate", "SE", 
              "TStat", "PValue"}}]&)]}], 
        ",", \(RSquared \[Rule] 0.452778062091038258`\), 
        ",", \(AdjustedRSquared \[Rule] 0.428985803921083341`\), 
        ",", \(EstimatedVariance \[Rule] 151.353426306535654`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>", "\<\"FRatio\"\>", "\<\"PValue\"\>"},
                {"\<\"Model\"\>", "1", "2880.328153989681`", 
                  "2880.328153989681`", "19.0304786900308471`", 
                  "0.000228160762315687826`"},
                {"\<\"Error\"\>", "23", "3481.12880505031929`", 
                  "151.353426306535654`", "\<\"\"\>", "\<\"\"\>"},
                {"\<\"Total\"\>", "24", 
                  "6361.45695903999985`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{1, 2880.3281539896807, 2880.3281539896807, 
              19.030478690030847, 0.00022816076231568783}, {23, 
              3481.1288050503199, 151.35342630653565}, {24, 
              6361.4569590400006}}, TableHeadings -> {{"Model", "Error", 
              "Total"}, {"DF", "SumOfSq", "MeanSq", "FRatio", 
              "PValue"}}]]}]}], "}"}]], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell["This explains the function. ", "MathCaption",
  CellTags->{"S0.3", "3.21"}],

Cell[CellGroupData[{

Cell["?Regress", "Input",
  CellLabel->"In[62]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \("Regress[data, funs, vars] finds a least-squares fit to a list of data \
as a linear combination of the functions funs of variables vars. The data can \
have the form {{x1, y1, ..., f1}, {x2, y2, ..., f2}, ...}, where the number \
of coordinates x, y, ... is equal to the number of variables in the list \
vars.  The data can also be of the form {f1, f2, ...}, with a single \
coordinate assumed to take values 1, 2, .... The argument funs can be any \
list of functions that depend only on the objects vars.  The result is a list \
of rules identifying summary statistics about the fit, or other statistics as \
specified by the option RegressionReport."\)], "Print"]
}, Open  ]],

Cell["This is the graph of AMR's returns. ", "MathCaption",
  CellTags->{"S0.3", "3.22"}],

Cell[CellGroupData[{

Cell["\<\
g1 = ListPlot[Transpose[{ret[SP500], ret[AMR]}],
   PlotStyle -> PointSize[0.02],
   PlotJoined->False,
   FrameLabel -> {\"Market Returns\", \"AMR's Returns\"}];\
\>", "Input",
  CellLabel->"In[63]:=",
  CellTags->"S0.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.426287 0.0337267 0.195001 0.0083706 [
[.08902 -0.0125 -9 -9 ]
[.08902 -0.0125 9 0 ]
[.25765 -0.0125 -6 -9 ]
[.25765 -0.0125 6 0 ]
[.42629 -0.0125 -3 -9 ]
[.42629 -0.0125 3 0 ]
[.59492 -0.0125 -3 -9 ]
[.59492 -0.0125 3 0 ]
[.76355 -0.0125 -6 -9 ]
[.76355 -0.0125 6 0 ]
[.93219 -0.0125 -6 -9 ]
[.93219 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -44 -24 ]
[.5 -0.0125 44 -9 ]
[-0.0125 .02759 -18 -4.5 ]
[-0.0125 .02759 0 4.5 ]
[-0.0125 .1113 -18 -4.5 ]
[-0.0125 .1113 0 4.5 ]
[-0.0125 .195 -6 -4.5 ]
[-0.0125 .195 0 4.5 ]
[-0.0125 .27871 -12 -4.5 ]
[-0.0125 .27871 0 4.5 ]
[-0.0125 .36241 -12 -4.5 ]
[-0.0125 .36241 0 4.5 ]
[-0.0125 .44612 -12 -4.5 ]
[-0.0125 .44612 0 4.5 ]
[-0.0125 .52983 -12 -4.5 ]
[-0.0125 .52983 0 4.5 ]
[-0.0125 .61353 -12 -4.5 ]
[-0.0125 .61353 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -33 -41 ]
[-0.01875 .30902 -18 41 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08902 0 m
.08902 .00625 L
s
[(-10)] .08902 -0.0125 0 1 Mshowa
.25765 0 m
.25765 .00625 L
s
[(-5)] .25765 -0.0125 0 1 Mshowa
.42629 0 m
.42629 .00625 L
s
[(0)] .42629 -0.0125 0 1 Mshowa
.59492 0 m
.59492 .00625 L
s
[(5)] .59492 -0.0125 0 1 Mshowa
.76355 0 m
.76355 .00625 L
s
[(10)] .76355 -0.0125 0 1 Mshowa
.93219 0 m
.93219 .00625 L
s
[(15)] .93219 -0.0125 0 1 Mshowa
.125 Mabswid
.12275 0 m
.12275 .00375 L
s
.15647 0 m
.15647 .00375 L
s
.1902 0 m
.1902 .00375 L
s
.22393 0 m
.22393 .00375 L
s
.29138 0 m
.29138 .00375 L
s
.32511 0 m
.32511 .00375 L
s
.35883 0 m
.35883 .00375 L
s
.39256 0 m
.39256 .00375 L
s
.46001 0 m
.46001 .00375 L
s
.49374 0 m
.49374 .00375 L
s
.52747 0 m
.52747 .00375 L
s
.56119 0 m
.56119 .00375 L
s
.62865 0 m
.62865 .00375 L
s
.66237 0 m
.66237 .00375 L
s
.6961 0 m
.6961 .00375 L
s
.72983 0 m
.72983 .00375 L
s
.79728 0 m
.79728 .00375 L
s
.83101 0 m
.83101 .00375 L
s
.86473 0 m
.86473 .00375 L
s
.89846 0 m
.89846 .00375 L
s
.05529 0 m
.05529 .00375 L
s
.02157 0 m
.02157 .00375 L
s
.96591 0 m
.96591 .00375 L
s
.99964 0 m
.99964 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -105 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Market) show
105.000000 15.000000 moveto
(Returns) show
147.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .02759 m
.00625 .02759 L
s
[(-20)] -0.0125 .02759 1 0 Mshowa
0 .1113 m
.00625 .1113 L
s
[(-10)] -0.0125 .1113 1 0 Mshowa
0 .195 m
.00625 .195 L
s
[(0)] -0.0125 .195 1 0 Mshowa
0 .27871 m
.00625 .27871 L
s
[(10)] -0.0125 .27871 1 0 Mshowa
0 .36241 m
.00625 .36241 L
s
[(20)] -0.0125 .36241 1 0 Mshowa
0 .44612 m
.00625 .44612 L
s
[(30)] -0.0125 .44612 1 0 Mshowa
0 .52983 m
.00625 .52983 L
s
[(40)] -0.0125 .52983 1 0 Mshowa
0 .61353 m
.00625 .61353 L
s
[(50)] -0.0125 .61353 1 0 Mshowa
.125 Mabswid
0 .04433 m
.00375 .04433 L
s
0 .06107 m
.00375 .06107 L
s
0 .07781 m
.00375 .07781 L
s
0 .09455 m
.00375 .09455 L
s
0 .12804 m
.00375 .12804 L
s
0 .14478 m
.00375 .14478 L
s
0 .16152 m
.00375 .16152 L
s
0 .17826 m
.00375 .17826 L
s
0 .21174 m
.00375 .21174 L
s
0 .22848 m
.00375 .22848 L
s
0 .24522 m
.00375 .24522 L
s
0 .26197 m
.00375 .26197 L
s
0 .29545 m
.00375 .29545 L
s
0 .31219 m
.00375 .31219 L
s
0 .32893 m
.00375 .32893 L
s
0 .34567 m
.00375 .34567 L
s
0 .37915 m
.00375 .37915 L
s
0 .3959 m
.00375 .3959 L
s
0 .41264 m
.00375 .41264 L
s
0 .42938 m
.00375 .42938 L
s
0 .46286 m
.00375 .46286 L
s
0 .4796 m
.00375 .4796 L
s
0 .49634 m
.00375 .49634 L
s
0 .51308 m
.00375 .51308 L
s
0 .54657 m
.00375 .54657 L
s
0 .56331 m
.00375 .56331 L
s
0 .58005 m
.00375 .58005 L
s
0 .59679 m
.00375 .59679 L
s
0 .01085 m
.00375 .01085 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
102 11.5 translate
90 rotate
-102 -11.5 translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(AMR) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(') show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
99.000000 15.000000 moveto
(Returns) show
141.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.08902 .61178 m
.08902 .61803 L
s
.25765 .61178 m
.25765 .61803 L
s
.42629 .61178 m
.42629 .61803 L
s
.59492 .61178 m
.59492 .61803 L
s
.76355 .61178 m
.76355 .61803 L
s
.93219 .61178 m
.93219 .61803 L
s
.125 Mabswid
.12275 .61428 m
.12275 .61803 L
s
.15647 .61428 m
.15647 .61803 L
s
.1902 .61428 m
.1902 .61803 L
s
.22393 .61428 m
.22393 .61803 L
s
.29138 .61428 m
.29138 .61803 L
s
.32511 .61428 m
.32511 .61803 L
s
.35883 .61428 m
.35883 .61803 L
s
.39256 .61428 m
.39256 .61803 L
s
.46001 .61428 m
.46001 .61803 L
s
.49374 .61428 m
.49374 .61803 L
s
.52747 .61428 m
.52747 .61803 L
s
.56119 .61428 m
.56119 .61803 L
s
.62865 .61428 m
.62865 .61803 L
s
.66237 .61428 m
.66237 .61803 L
s
.6961 .61428 m
.6961 .61803 L
s
.72983 .61428 m
.72983 .61803 L
s
.79728 .61428 m
.79728 .61803 L
s
.83101 .61428 m
.83101 .61803 L
s
.86473 .61428 m
.86473 .61803 L
s
.89846 .61428 m
.89846 .61803 L
s
.05529 .61428 m
.05529 .61803 L
s
.02157 .61428 m
.02157 .61803 L
s
.96591 .61428 m
.96591 .61803 L
s
.99964 .61428 m
.99964 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02759 m
1 .02759 L
s
.99375 .1113 m
1 .1113 L
s
.99375 .195 m
1 .195 L
s
.99375 .27871 m
1 .27871 L
s
.99375 .36241 m
1 .36241 L
s
.99375 .44612 m
1 .44612 L
s
.99375 .52983 m
1 .52983 L
s
.99375 .61353 m
1 .61353 L
s
.125 Mabswid
.99625 .04433 m
1 .04433 L
s
.99625 .06107 m
1 .06107 L
s
.99625 .07781 m
1 .07781 L
s
.99625 .09455 m
1 .09455 L
s
.99625 .12804 m
1 .12804 L
s
.99625 .14478 m
1 .14478 L
s
.99625 .16152 m
1 .16152 L
s
.99625 .17826 m
1 .17826 L
s
.99625 .21174 m
1 .21174 L
s
.99625 .22848 m
1 .22848 L
s
.99625 .24522 m
1 .24522 L
s
.99625 .26197 m
1 .26197 L
s
.99625 .29545 m
1 .29545 L
s
.99625 .31219 m
1 .31219 L
s
.99625 .32893 m
1 .32893 L
s
.99625 .34567 m
1 .34567 L
s
.99625 .37915 m
1 .37915 L
s
.99625 .3959 m
1 .3959 L
s
.99625 .41264 m
1 .41264 L
s
.99625 .42938 m
1 .42938 L
s
.99625 .46286 m
1 .46286 L
s
.99625 .4796 m
1 .4796 L
s
.99625 .49634 m
1 .49634 L
s
.99625 .51308 m
1 .51308 L
s
.99625 .54657 m
1 .54657 L
s
.99625 .56331 m
1 .56331 L
s
.99625 .58005 m
1 .58005 L
s
.99625 .59679 m
1 .59679 L
s
.99625 .01085 m
1 .01085 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.02 w
.3924 .29205 Mdot
.41406 .37981 Mdot
.34777 .12376 Mdot
.29458 .1658 Mdot
.31313 .11432 Mdot
.37682 .09455 Mdot
.16392 .10622 Mdot
.12181 .18081 Mdot
.02381 .09398 Mdot
.97619 .42478 Mdot
.24693 .01472 Mdot
.35832 .03087 Mdot
.84049 .60332 Mdot
.62826 .35967 Mdot
.49945 .20647 Mdot
.5857 .22894 Mdot
.57502 .06455 Mdot
.57577 .22076 Mdot
.19811 .15752 Mdot
.35522 .23424 Mdot
.30944 .09506 Mdot
.63419 .18081 Mdot
.50962 .32489 Mdot
.38747 .24497 Mdot
.82529 .28932 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[63]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool007Soo`800004ool00000ool400001Ooo00000000ool0
0P0000?oo`0000000_oo0P000ooo0P003Ooo0`0000Coo`00ooooo`8000?oo`8000?oo`<00005ool0
0000003oo`020002ool01000ool00000GOoo001hool01P00oooooooo003oo`<000?oo`07003ooooo
ool00?oo00000_oo00<00?ooool00_oo00@00?ooool000goo`06003ooooo003oo`001?oo00H00?oo
ool00?oo0002ool01000ooooo`000ooo00@00?ooool000?oo`03003ooooo05[oo`00N?oo00D00?oo
003oo`0000?oo`05003oooooool00003ool30002ool30002ool00`00ooooo`0>ool30002ool30002
ool00`00ooooo`02ool01000ooooo`000_oo00D00?ooooooo`0000;oo`04003ooooo001Mool007So
o`800003ool0000000;oo`8000;oo`@00003ool00?oo00800005ool00000003oo`04000>ool01@00
ooooo`00ool00`0000?oo`0000000P0000Coo`00003oo`800003ool0000000H000?oo`8005coo`00
N?oo0P0000?oo`0000002ooo00<00?ooool01ooo00<00?ooool03_oo00@00?ooool000Koo`03003o
oooo073oo`00N?oo0P0000?oo`0000002_oo0P006Ooo1000N_oo003ooolQool00?ooob7oo`00oooo
8Ooo003ooolQool00?ooob7oo`00?_oo1@000_oo00<00?ooool08_oo00<00?ooool08ooo00<00?oo
ool09Ooo00<00?ooool08?oo1@000_oo00<00?ooool07_oo1@000_oo00<00?ooool04ooo0010ool0
1`00oooooooo003oo`0002;oo`03003oo`0002?oo`03003oo`0002Goo`03003oo`0002?oo`07003o
ooooool00?oo00008Ooo00L00?ooooooo`00ool0000Dool003[oo`<000?oo`07003oooooool00?oo
00007Ooo0`001?oo00<00?ooool08Ooo00<00?oo00009ooo00<00?ooool08Ooo00L00?ooooooo`00
ool0000Qool00`00ooooo`03ool00`00ooooo`0Bool0043oo`07003oooooool00?oo00008_oo0P00
9?oo00<00?oo00009Ooo0P009?oo00L00?ooooooo`00ool0000Qool01000oooooooo0P005Ooo0010
ool01`00oooooooo003oo`0002;oo`03003ooooo02?oo`03003oo`0002Goo`03003ooooo02?oo`07
003oooooool00?oo00008Ooo00D00?ooooooo`0001Koo`00?ooo0P001?oo00<00?ooool08Ooo0`00
9?oo00<00?ooool09?oo0`008_oo0P001?oo00<00?ooool07ooo0P000ooo0`005?oo003ooolQool0
0?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00:oookP001ooo000[ool00`00ooooo`0Bool0
0`00ooooo`0Uool00`00ooooo`0Uool00`00ooooo`0Uool00`00ooooo`0Uool00`00ooooo`0Uool0
0`00ooooo`0=ool00`00ooooo`05ool002_oo`8003Soo`800;3oo`8000Ooo`00:ooo00<00?ooool0
=_oo1000/?oo00<00?ooool01Ooo000Oool30003ool00`00ooooo`03ool00`00ooooo`0fool4002`
ool00`00ooooo`05ool001ooo`03003ooooo00;oo`03003oo`0000Coo`03003ooooo03Ooo`800;7o
o`03003ooooo00Goo`006_oo0`000ooo00L00?ooooooo`00ool00004ool3001Aool2002Fool20007
ool0023oo`07003oooooool00?oo00001?oo00<00?ooool0D?oo1000U_oo00<00?ooool01Ooo000O
ool00`00ool00002ool00`00ool00004ool00`00ooooo`1@ool4002Fool00`00ooooo`05ool0023o
o`03003ooooo00;oo`03003ooooo00?oo`03003ooooo057oo`8009Ooo`03003ooooo00Goo`00:ooo
0P00j_oo0P001ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`03003ooooo0>[oo`03
003ooooo00Goo`00:ooo00<00?ooool0j_oo00<00?ooool01Ooo000[ool20026ool2001Rool20007
ool002_oo`03003ooooo08Coo`@006;oo`03003ooooo00Goo`00:ooo00<00?ooool0Q?oo1000H_oo
00<00?ooool01Ooo000[ool00`00ooooo`25ool2001Sool00`00ooooo`05ool002_oo`800>[oo`80
00Ooo`00:ooo00<00?ooool0j_oo00<00?ooool01Ooo000[ool00`00ooooo`3Zool00`00ooooo`05
ool002_oo`03003ooooo00;oo`8004;oo`8000koo`8009;oo`03003ooooo00Goo`00:ooo0P000_oo
1000@?oo10003?oo1000T?oo0P001ooo000[ool01000oooooooo1000@?oo10003?oo1000TOoo00<0
0?ooool01Ooo000Nool50002ool00`00ooooo`03ool00`00ooooo`02ool2000Oool2000Qool2000>
ool2002Bool00`00ooooo`05ool0023oo`07003oooooool00?oo00001?oo00<00?ooool08_oo1000
8Ooo0P00XOoo00<00?ooool01Ooo000Jool30003ool01`00oooooooo003oo`0000Coo`<002;oo`@0
023oo`@009ooo`8000Ooo`008?oo00L00?ooooooo`00ool00004ool00`00ooooo`0Sool2000Qool4
002Pool00`00ooooo`05ool0023oo`07003oooooool00?oo00001?oo00<00?ooool0Aooo0P001_oo
0P00VOoo00<00?ooool01Ooo000Oool20004ool00`00ooooo`03ool00`00ooooo`1>ool4002Hool0
0`00ooooo`05ool002_oo`8004ooo`@009Ooo`8000Ooo`00:ooo00<00?ooool0Cooo0P00VOoo00<0
0?ooool01Ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`03003ooooo0>[oo`03003o
oooo00Goo`00:ooo0P00j_oo0P001ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool000ooo`80
01[oo`03003ooooo02_oo`800;goo`03003ooooo00Goo`002ooo00H00?oo00000?oo000Jool00`00
ooooo`0Zool4002lool00`00ooooo`05ool000_oo`800003ool00?oo01_oo`8002_oo`@001Coo`80
0:Goo`8000Ooo`003Ooo0P0000?oo`00ool06Ooo00<00?ooool0:ooo0P005?oo1000YOoo00<00?oo
ool01Ooo000?ool2000Jool00`00ooooo`11ool4002Uool00`00ooooo`05ool000_oo`H001[oo`03
003ooooo01Woo`8002Ooo`8004ooo`8005Goo`03003ooooo00Goo`002ooo0`000_oo00<00?ooool0
6?oo0P006Ooo1000M_oo1000Dooo0P001ooo000>ool00`00ooooo`0Jool00`00ooooo`0Hool4001f
ool4001Dool00`00ooooo`05ool000_oo`<000;oo`03003ooooo01;oo`03003ooooo00?oo`03003o
oooo01Woo`8007Soo`8005Goo`03003ooooo00Goo`002ooo1P004ooo00<00?oo00001?oo00<00?oo
ool0j_oo00<00?ooool01Ooo000;ool00`00ooooo`02ool00`00ooooo`0Aool00`00ool00004ool3
003Yool20007ool000_oo`03003ooooo00;oo`03003ooooo017oo`03003oo`0000Coo`03003ooooo
07?oo`8007Goo`03003ooooo00Goo`002ooo1P004ooo00<00?oo00001?oo00<00?ooool0L_oo1000
M?oo00<00?ooool01Ooo000;ool01P00ooooo`00ool001Coo`03003ooooo00?oo`03003ooooo07;o
o`@007Coo`03003ooooo00Goo`002ooo00@00?ooool001coo`8007Coo`8007Coo`8000Ooo`003?oo
0P0000?oo`00ool06_oo00<00?ooool0QOoo0P00Hooo00<00?ooool01Ooo000@ool00`00ooooo`0H
ool00`00ooooo`24ool4001Rool00`00ooooo`05ool002_oo`03003ooooo08Coo`D0067oo`03003o
oooo00Goo`00:ooo0P00D_oo0P00<_oo1@00Gooo0P001ooo000[ool00`00ooooo`1@ool4000bool4
001Pool00`00ooooo`05ool000_oo`<001goo`03003ooooo053oo`@000Coo`8002goo`80067oo`03
003ooooo00Goo`00:ooo00<00?ooool0DOoo0P001?oo1000Sooo00<00?ooool01Ooo000[ool2001H
ool4002>ool20007ool002_oo`03003ooooo05Soo`80093oo`03003ooooo00Goo`003Ooo0P0000?o
o`00ool06Ooo00<00?ooool0j_oo00<00?ooool01Ooo000=ool200000ooo003oo`0Iool00`00oooo
o`3Zool00`00ooooo`05ool000goo`800003ool00?oo01Woo`800>[oo`8000Ooo`003Ooo00<00?oo
00006ooo00<00?ooool0j_oo00<00?ooool01Ooo000Nool50002ool00`00ooooo`03ool00`00oooo
o`3Zool00`00ooooo`05ool0023oo`07003oooooool00?oo00001?oo00<00?ooool0j_oo00<00?oo
ool01Ooo000Pool01`00oooooooo003oo`0000Coo`<00>Woo`8000Ooo`008?oo00L00?ooooooo`00
ool00004ool00`00ooooo`30ool2000Xool00`00ooooo`05ool0023oo`07003oooooool00?oo0000
1?oo00<00?ooool0FOoo0P00I?oo10009ooo00<00?ooool01Ooo000Oool20004ool00`00ooooo`03
ool00`00ooooo`1Hool4001Sool4000Wool00`00ooooo`05ool002_oo`8005Woo`@006Coo`8002Oo
o`8000Ooo`002ooo00<00?ooool00_oo00<00?ooool06?oo00<00?ooool0FOoo0P00Sooo00<00?oo
ool01Ooo000;ool6000Jool00`00ooooo`3Zool00`00ooooo`05ool000_oo`06003ooooo003oo`00
6_oo00<00?ooool0j_oo00<00?ooool01Ooo000;ool01000ooooo`007?oo0P00j_oo0P001ooo000<
ool200000ooo003oo`0Jool00`00ooooo`1eool2001cool00`00ooooo`05ool0013oo`03003ooooo
01Soo`03003ooooo07Coo`@007;oo`03003ooooo00Goo`00:ooo00<00?ooool0M?oo1000L_oo00<0
0?ooool01Ooo000>ool2000Kool2001fool2001bool20007ool000goo`800003ool00?oo01Woo`03
003ooooo0>[oo`03003ooooo00Goo`003Ooo0P0000?oo`00ool06Ooo00<00?ooool0j_oo00<00?oo
ool01Ooo000>ool00`00ool0000Jool2003Zool20007ool002_oo`03003ooooo0>[oo`03003ooooo
00Goo`003Ooo00<00?ooool03ooo0`000ooo00<00?ooool00ooo00<00?ooool0j_oo00<00?ooool0
1Ooo000<ool4000?ool00`00ooooo`02ool00`00ool00004ool00`00ooooo`2Aool2001Gool00`00
ooooo`05ool000goo`04003ooooo000?ool01`00oooooooo003oo`0000Coo`<0093oo`@005Goo`80
00Ooo`003Ooo00@00?ooool000ooo`07003oooooool00?oo00001?oo00<00?ooool0T?oo1000E_oo
00<00?ooool01Ooo000=ool00`00ool0000?ool00`00ool00002ool00`00ool00004ool00`00oooo
o`2Aool2001Gool00`00ooooo`05ool0023oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo
05koo`8008[oo`03003ooooo00Goo`003Ooo00<00?ooool06ooo0P00G_oo1000R?oo0P001ooo000=
ool3000Kool00`00ooooo`1Mool40029ool00`00ooooo`05ool0013oo`03003ooooo01Soo`03003o
oooo05koo`8008[oo`03003ooooo00Goo`003Ooo00<00?oo00006ooo00<00?ooool0j_oo00<00?oo
ool01Ooo000=ool4000Jool2003Zool20007ool0013oo`03003ooooo01Soo`03003ooooo0>[oo`03
003ooooo00Goo`00:ooo00<00?ooool0j_oo00<00?ooool01Ooo000=ool01000ooooo`006_oo00<0
0?ooool0j_oo00<00?ooool01Ooo000=ool4000Jool2003Zool20007ool000goo`04003ooooo000J
ool00`00ooooo`3Zool00`00ooooo`05ool000goo`04003ooooo000Jool00`00ooooo`3Tool20004
ool00`00ooooo`05ool002_oo`03003ooooo0>?oo`@000?oo`03003ooooo00Goo`003Ooo00@00?oo
ool001[oo`800>Coo`@000;oo`8000Ooo`003Ooo10006_oo00<00?ooool0i?oo0P001?oo00<00?oo
ool01Ooo000=ool00`00ooooo`0?ool20004ool00`00ooooo`03ool00`00ooooo`3Zool00`00oooo
o`05ool000goo`03003ooooo017oo`06003ooooo003oo`001?oo00<00?ooool0j_oo00<00?ooool0
1Ooo000>ool3000?ool01`00oooooooo003oo`0000Coo`<00>Woo`8000Ooo`004?oo00<00?ooool0
3_oo00H00?ooool00?oo0004ool00`00ooooo`3Zool00`00ooooo`05ool001ooo`03003oo`0000;o
o`03003oo`0000Coo`03003ooooo0>[oo`03003ooooo00Goo`003Ooo0P0000?oo`00ool03_oo00<0
0?ooool00_oo00<00?ooool00ooo00<00?ooool0j_oo00<00?ooool01Ooo000=ool200000ooo003o
o`0Iool2003Zool20007ool000goo`800003ool00?oo01Woo`03003ooooo0>[oo`03003ooooo00Go
o`003Ooo00<00?oo00006ooo00<00?ooool0j_oo00<00?ooool01Ooo000[ool00`00ooooo`3Zool0
0`00ooooo`05ool002_oo`800>[oo`8000Ooo`00:ooo00<00?ooool0j_oo00<00?ooool01Ooo000[
ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`03003ooooo0>[oo`03003ooooo00Goo`00:ooo
0P00j_oo0P001ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`03003ooooo0>[oo`03
003ooooo00Goo`00:ooo00<00?ooool0j_oo00<00?ooool01Ooo000[ool2003Zool20007ool002_o
o`03003ooooo0>[oo`03003ooooo00Goo`008?oo0`000_oo00<00?ooool00ooo00<00?ooool0j_oo
00<00?ooool01Ooo000Qool01P00ooooo`00ool000Coo`03003ooooo0>[oo`03003ooooo00Goo`00
7ooo100000Coo`00ool000Coo`<00>Woo`8000Ooo`007ooo00<00?oo00000_oo00<00?oo00001?oo
00<00?ooool0j_oo00<00?ooool01Ooo000Pool20002ool00`00ool00004ool00`00ooooo`3Zool0
0`00ooooo`05ool0027oo`05003oooooool00005ool00`00ooooo`3Zool00`00ooooo`05ool002_o
o`800>[oo`8000Ooo`00:ooo00<00?ooool0j_oo00<00?ooool01Ooo000[ool00`00ooooo`3Zool0
0`00ooooo`05ool002_oo`03003ooooo0>[oo`03003ooooo00Goo`00:ooo0P00j_oo0P001ooo000[
ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`03003ooooo0>[oo`03003ooooo00Goo`00:ooo
00<00?ooool0j_oo00<00?ooool01Ooo000[ool2003Zool20007ool002_oo`03003ooooo0>[oo`03
003ooooo00Goo`00:ooo00<00?ooool0j_oo00<00?ooool01Ooo000[ool00`00ooooo`3Zool00`00
ooooo`05ool002_oo`800<Goo`8002?oo`8000Ooo`00:ooo00<00?ooool0`ooo10008ooo00<00?oo
ool01Ooo000Pool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`33ool4000Sool00`00oooo
o`05ool001ooo`03003oo`0000;oo`03003oo`0000Coo`03003ooooo0<Coo`8002Coo`03003ooooo
00Goo`008Ooo00H00?ooool00?oo0004ool30002ool00`00ooooo`05ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00ooooo`05ool00`00
ooooo`05ool00`00ooooo`04ool20007ool001ooo`8000?oo`03003oo`0000Coonh000Ooo`007ooo
00<00?ooool00_oo00<00?oo0000nOoo000Oool30003ool00`00ooooo`3hool00?ooob7oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-18.0925, -36.882, 0.12505, \
0.503848}}]
}, Open  ]],

Cell[TextData[{
  "We generate a plot of the regression line, suppressing its display by \
setting the option ",
  StyleBox["DisplayFunction", "MB"],
  " to ",
  StyleBox["Identity", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.3", "3.23"}],

Cell["\<\
g2 = Plot[regressionLine[x], {x, -15, 20},
   DisplayFunction -> Identity];\
\>", "Input",
  CellLabel->"In[64]:=",
  CellTags->"S0.3"],

Cell["Now we display the data together with the regression line. ", \
"MathCaption",
  CellTags->{"S0.3", "3.24"}],

Cell[CellGroupData[{

Cell["Show[g1, g2, DisplayFunction -> $DisplayFunction];", "Input",
  CellLabel->"In[65]:=",
  CellTags->"S0.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.431973 0.0272109 0.203126 0.00820404 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.15986 -0.0125 -9 -9 ]
[.15986 -0.0125 9 0 ]
[.29592 -0.0125 -6 -9 ]
[.29592 -0.0125 6 0 ]
[.43197 -0.0125 -3 -9 ]
[.43197 -0.0125 3 0 ]
[.56803 -0.0125 -3 -9 ]
[.56803 -0.0125 3 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.84014 -0.0125 -6 -9 ]
[.84014 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -44 -24 ]
[.5 -0.0125 44 -9 ]
[-0.0125 .03905 -18 -4.5 ]
[-0.0125 .03905 0 4.5 ]
[-0.0125 .12109 -18 -4.5 ]
[-0.0125 .12109 0 4.5 ]
[-0.0125 .20313 -6 -4.5 ]
[-0.0125 .20313 0 4.5 ]
[-0.0125 .28517 -12 -4.5 ]
[-0.0125 .28517 0 4.5 ]
[-0.0125 .36721 -12 -4.5 ]
[-0.0125 .36721 0 4.5 ]
[-0.0125 .44925 -12 -4.5 ]
[-0.0125 .44925 0 4.5 ]
[-0.0125 .53129 -12 -4.5 ]
[-0.0125 .53129 0 4.5 ]
[-0.0125 .61333 -12 -4.5 ]
[-0.0125 .61333 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -33 -41 ]
[-0.01875 .30902 -18 41 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.15986 0 m
.15986 .00625 L
s
[(-10)] .15986 -0.0125 0 1 Mshowa
.29592 0 m
.29592 .00625 L
s
[(-5)] .29592 -0.0125 0 1 Mshowa
.43197 0 m
.43197 .00625 L
s
[(0)] .43197 -0.0125 0 1 Mshowa
.56803 0 m
.56803 .00625 L
s
[(5)] .56803 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(10)] .70408 -0.0125 0 1 Mshowa
.84014 0 m
.84014 .00625 L
s
[(15)] .84014 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -105 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Market) show
105.000000 15.000000 moveto
(Returns) show
147.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .03905 m
.00625 .03905 L
s
[(-20)] -0.0125 .03905 1 0 Mshowa
0 .12109 m
.00625 .12109 L
s
[(-10)] -0.0125 .12109 1 0 Mshowa
0 .20313 m
.00625 .20313 L
s
[(0)] -0.0125 .20313 1 0 Mshowa
0 .28517 m
.00625 .28517 L
s
[(10)] -0.0125 .28517 1 0 Mshowa
0 .36721 m
.00625 .36721 L
s
[(20)] -0.0125 .36721 1 0 Mshowa
0 .44925 m
.00625 .44925 L
s
[(30)] -0.0125 .44925 1 0 Mshowa
0 .53129 m
.00625 .53129 L
s
[(40)] -0.0125 .53129 1 0 Mshowa
0 .61333 m
.00625 .61333 L
s
[(50)] -0.0125 .61333 1 0 Mshowa
.125 Mabswid
0 .05545 m
.00375 .05545 L
s
0 .07186 m
.00375 .07186 L
s
0 .08827 m
.00375 .08827 L
s
0 .10468 m
.00375 .10468 L
s
0 .13749 m
.00375 .13749 L
s
0 .1539 m
.00375 .1539 L
s
0 .17031 m
.00375 .17031 L
s
0 .18672 m
.00375 .18672 L
s
0 .21953 m
.00375 .21953 L
s
0 .23594 m
.00375 .23594 L
s
0 .25235 m
.00375 .25235 L
s
0 .26876 m
.00375 .26876 L
s
0 .30157 m
.00375 .30157 L
s
0 .31798 m
.00375 .31798 L
s
0 .33439 m
.00375 .33439 L
s
0 .3508 m
.00375 .3508 L
s
0 .38361 m
.00375 .38361 L
s
0 .40002 m
.00375 .40002 L
s
0 .41643 m
.00375 .41643 L
s
0 .43284 m
.00375 .43284 L
s
0 .46566 m
.00375 .46566 L
s
0 .48206 m
.00375 .48206 L
s
0 .49847 m
.00375 .49847 L
s
0 .51488 m
.00375 .51488 L
s
0 .5477 m
.00375 .5477 L
s
0 .5641 m
.00375 .5641 L
s
0 .58051 m
.00375 .58051 L
s
0 .59692 m
.00375 .59692 L
s
0 .02264 m
.00375 .02264 L
s
0 .00623 m
.00375 .00623 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
102 11.5 translate
90 rotate
-102 -11.5 translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(AMR) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(') show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
99.000000 15.000000 moveto
(Returns) show
141.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.15986 .61178 m
.15986 .61803 L
s
.29592 .61178 m
.29592 .61803 L
s
.43197 .61178 m
.43197 .61803 L
s
.56803 .61178 m
.56803 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.84014 .61178 m
.84014 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05102 .61428 m
.05102 .61803 L
s
.07823 .61428 m
.07823 .61803 L
s
.10544 .61428 m
.10544 .61803 L
s
.13265 .61428 m
.13265 .61803 L
s
.18707 .61428 m
.18707 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2415 .61428 m
.2415 .61803 L
s
.26871 .61428 m
.26871 .61803 L
s
.32313 .61428 m
.32313 .61803 L
s
.35034 .61428 m
.35034 .61803 L
s
.37755 .61428 m
.37755 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45918 .61428 m
.45918 .61803 L
s
.48639 .61428 m
.48639 .61803 L
s
.51361 .61428 m
.51361 .61803 L
s
.54082 .61428 m
.54082 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62245 .61428 m
.62245 .61803 L
s
.64966 .61428 m
.64966 .61803 L
s
.67687 .61428 m
.67687 .61803 L
s
.73129 .61428 m
.73129 .61803 L
s
.7585 .61428 m
.7585 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81293 .61428 m
.81293 .61803 L
s
.86735 .61428 m
.86735 .61803 L
s
.89456 .61428 m
.89456 .61803 L
s
.92177 .61428 m
.92177 .61803 L
s
.94898 .61428 m
.94898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03905 m
1 .03905 L
s
.99375 .12109 m
1 .12109 L
s
.99375 .20313 m
1 .20313 L
s
.99375 .28517 m
1 .28517 L
s
.99375 .36721 m
1 .36721 L
s
.99375 .44925 m
1 .44925 L
s
.99375 .53129 m
1 .53129 L
s
.99375 .61333 m
1 .61333 L
s
.125 Mabswid
.99625 .05545 m
1 .05545 L
s
.99625 .07186 m
1 .07186 L
s
.99625 .08827 m
1 .08827 L
s
.99625 .10468 m
1 .10468 L
s
.99625 .13749 m
1 .13749 L
s
.99625 .1539 m
1 .1539 L
s
.99625 .17031 m
1 .17031 L
s
.99625 .18672 m
1 .18672 L
s
.99625 .21953 m
1 .21953 L
s
.99625 .23594 m
1 .23594 L
s
.99625 .25235 m
1 .25235 L
s
.99625 .26876 m
1 .26876 L
s
.99625 .30157 m
1 .30157 L
s
.99625 .31798 m
1 .31798 L
s
.99625 .33439 m
1 .33439 L
s
.99625 .3508 m
1 .3508 L
s
.99625 .38361 m
1 .38361 L
s
.99625 .40002 m
1 .40002 L
s
.99625 .41643 m
1 .41643 L
s
.99625 .43284 m
1 .43284 L
s
.99625 .46566 m
1 .46566 L
s
.99625 .48206 m
1 .48206 L
s
.99625 .49847 m
1 .49847 L
s
.99625 .51488 m
1 .51488 L
s
.99625 .5477 m
1 .5477 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .58051 m
1 .58051 L
s
.99625 .59692 m
1 .59692 L
s
.99625 .02264 m
1 .02264 L
s
.99625 .00623 m
1 .00623 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.02 w
.40464 .29824 Mdot
.42211 .38425 Mdot
.36863 .1333 Mdot
.32571 .17451 Mdot
.34068 .12405 Mdot
.39207 .10468 Mdot
.2203 .11611 Mdot
.18632 .18922 Mdot
.10725 .10411 Mdot
.87564 .42833 Mdot
.28727 .02643 Mdot
.37714 .04226 Mdot
.76616 .60332 Mdot
.59493 .36452 Mdot
.491 .21437 Mdot
.56058 .23639 Mdot
.55197 .07527 Mdot
.55258 .22837 Mdot
.24788 .16639 Mdot
.37464 .24159 Mdot
.3377 .10517 Mdot
.59971 .18922 Mdot
.49921 .33043 Mdot
.40066 .2521 Mdot
.75389 .29557 Mdot
.5 Mabswid
.02381 .01472 m
.06244 .03344 L
.10458 .05385 L
.14415 .07303 L
.18221 .09147 L
.22272 .11109 L
.26171 .12999 L
.30316 .15007 L
.34309 .16942 L
.3815 .18803 L
.42237 .20783 L
.46172 .2269 L
.49955 .24523 L
.53984 .26476 L
.57861 .28354 L
.61984 .30352 L
.65954 .32276 L
.69774 .34126 L
.73838 .36096 L
.77751 .37992 L
.81909 .40007 L
.85916 .41948 L
.89771 .43816 L
.93871 .45803 L
.97619 .47619 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool007Soo`800004ool00000ool400001Ooo00000000ool0
0P0000?oo`0000000_oo0P000ooo0P003Ooo0`0000Coo`00ooooo`8000?oo`8000?oo`<00005ool0
0000003oo`020002ool01000ool00000GOoo001hool01P00oooooooo003oo`<000?oo`07003ooooo
ool00?oo00000_oo00<00?ooool00_oo00@00?ooool000goo`06003ooooo003oo`001?oo00H00?oo
ool00?oo0002ool01000ooooo`000ooo00@00?ooool000?oo`03003ooooo05[oo`00N?oo00D00?oo
003oo`0000?oo`05003oooooool00003ool30002ool30002ool00`00ooooo`0>ool30002ool30002
ool00`00ooooo`02ool01000ooooo`000_oo00D00?ooooooo`0000;oo`04003ooooo001Mool007So
o`800003ool0000000;oo`8000;oo`@00003ool00?oo00800005ool00000003oo`04000>ool01@00
ooooo`00ool00`0000?oo`0000000P0000Coo`00003oo`800003ool0000000H000?oo`8005coo`00
N?oo0P0000?oo`0000002ooo00<00?ooool01ooo00<00?ooool03_oo00@00?ooool000Koo`03003o
oooo073oo`00N?oo0P0000?oo`0000002_oo0P006Ooo1000N_oo003ooolQool00?ooob7oo`00oooo
8Ooo003ooolQool00?ooob7oo`00;_oo1@000_oo00<00?ooool05_oo1@000_oo00<00?ooool06ooo
00<00?ooool06ooo00<00?ooool07Ooo00<00?ooool06Ooo1@000_oo00<00?ooool05_oo1@000_oo
00<00?ooool05ooo0`000ooo00<00?ooool02Ooo000`ool01`00oooooooo003oo`0001Woo`07003o
ooooool00?oo00006ooo00<00?oo00006ooo00<00?oo00007Ooo00<00?oo00007?oo00L00?oooooo
o`00ool0000Iool01`00oooooooo003oo`0001Soo`03003ooooo00;oo`03003oo`0000[oo`00:_oo
0`000ooo00<00?ooool00ooo00<00?ooool04Ooo0`000ooo00L00?ooooooo`00ool0000Fool30004
ool00`00ooooo`0Iool00`00ool0000Oool00`00ooooo`0Jool01`00oooooooo003oo`0001Woo`03
003ooooo00?oo`03003ooooo01Ooo`07003oooooool00?oo00002_oo000`ool01000oooooooo0P00
6_oo00L00?ooooooo`00ool0000Kool2000Lool00`00ool0000Mool2000Mool01`00oooooooo003o
o`0001Woo`04003oooooool2000Jool01`00oooooooo003oo`0000[oo`00<?oo00D00?ooooooo`00
01_oo`07003oooooool00?oo00006ooo00<00?ooool06ooo00<00?oo00007Ooo00<00?ooool07?oo
00L00?ooooooo`00ool0000Iool01@00oooooooo00006_oo00<00?oo00000_oo00<00?oo00002_oo
000_ool20003ool3000Hool20004ool00`00ooooo`0Jool3000Lool00`00ooooo`0Lool3000Kool2
0004ool00`00ooooo`0Gool20003ool3000Iool00`00ooooo`02ool00`00ooooo`09ool00?ooob7o
o`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo000[ooo^0007ool002_oo`8000Coo`03003o
oooo01goo`03003ooooo01goo`03003ooooo01goo`03003ooooo01koo`03003ooooo01goo`03003o
oooo01goo`03003ooooo01goo`03003ooooo00;oo`8000Ooo`00:ooo00<00?ooool0j_oo00<00?oo
ool01Ooo000[ool00`00ooooo`03ool2003Uool00`00ooooo`05ool002_oo`03003ooooo00Goo`80
0>?oo`03003ooooo00Goo`00:ooo0P002?oo0P00=ooo0P00Yooo0P001ooo000[ool00`00ooooo`09
ool2000dool4002Wool00`00ooooo`05ool001ooo`<000?oo`03003ooooo00?oo`03003ooooo00_o
o`8003;oo`@00:Ooo`03003ooooo00Goo`007ooo00<00?ooool00_oo00<00?oo00001?oo00<00?oo
ool03Ooo0P00<Ooo0P005?oo0P00T_oo00<00?ooool01Ooo000Jool30003ool01`00oooooooo003o
o`0000Coo`80013oo`8004Coo`@0093oo`8000Ooo`008?oo00L00?ooooooo`00ool00004ool00`00
ooooo`0Aool20012ool4002Aool00`00ooooo`05ool001ooo`03003oo`0000;oo`03003oo`0000Co
o`03003ooooo01?oo`80047oo`8009;oo`03003ooooo00Goo`008?oo00<00?ooool00_oo00<00?oo
ool00ooo00<00?ooool05Ooo0P00dooo00<00?ooool01Ooo000[ool2000Hool2003@ool20007ool0
02_oo`03003ooooo01Woo`800<ooo`03003ooooo00Goo`00:ooo00<00?ooool06ooo0P00cOoo00<0
0?ooool01Ooo000[ool00`00ooooo`0Mool2001Pool2001Yool00`00ooooo`05ool002_oo`80023o
o`8005goo`@006Ooo`8000Ooo`00:ooo00<00?ooool08Ooo0P00Fooo1000J?oo00<00?ooool01Ooo
000[ool00`00ooooo`0Sool2001Jool2001Yool00`00ooooo`05ool002_oo`8002Koo`800<;oo`80
00Ooo`00:ooo00<00?ooool09ooo0P00`Ooo00<00?ooool01Ooo000[ool00`00ooooo`0Yool2002o
ool00`00ooooo`05ool002_oo`03003ooooo01Koo`8001?oo`8001ooo`8000_oo`8008ooo`03003o
oooo00Goo`00:ooo0P005_oo10005?oo0P007?oo10002Ooo1000SOoo0P001ooo000[ool00`00oooo
o`0Eool4000Fool2000Jool40009ool4002>ool00`00ooooo`05ool001koo`D000;oo`03003ooooo
00?oo`03003ooooo01Koo`8001Soo`@001Soo`8000_oo`8008ooo`03003ooooo00Goo`008?oo00L0
0?ooooooo`00ool00004ool00`00ooooo`0_ool400000ooo0000002dool00`00ooooo`05ool001[o
o`<000?oo`07003oooooool00?oo00001?oo0P00<?oo10000ooo0P005Ooo0P00V_oo0P001ooo000P
ool01`00oooooooo003oo`0000Coo`03003ooooo033oo`8000Koo`8001;oo`@009[oo`03003ooooo
00Goo`008?oo00L00?ooooooo`00ool00004ool00`00ooooo`0jool2000@ool40004ool2002Dool0
0`00ooooo`05ool001ooo`8000Coo`03003ooooo00?oo`03003ooooo03coo`8000ooo`8000Coo`@0
09?oo`03003ooooo00Goo`00:ooo0P00?ooo0P004ooo1000T_oo0P001ooo000[ool00`00ooooo`10
ool2000Bool2002Dool00`00ooooo`05ool002_oo`03003ooooo04;oo`800:Koo`03003ooooo00Go
o`00:ooo00<00?ooool0A?oo0P00Y?oo00<00?ooool01Ooo000?ool2000Jool20017ool2002Qool2
0007ool000_oo`06003oo`00003oo`006_oo00<00?ooool0B?oo0P00X?oo00<00?ooool01Ooo000;
ool200000ooo003oo`0Kool00`00ooooo`0gool2000Aool2002Nool00`00ooooo`05ool000goo`80
0003ool00?oo01Woo`03003ooooo03Koo`@001;oo`8009coo`03003ooooo00Goo`003ooo0P006_oo
0P00=ooo10003ooo0P000ooo0P00VOoo0P001ooo000;ool6000Jool00`00ooooo`0gool2000?ool4
0004ool2002Hool00`00ooooo`05ool000_oo`<000;oo`03003ooooo01Soo`03003ooooo04Soo`@0
00Koo`8009Koo`03003ooooo00Goo`003_oo00<00?ooool06_oo00<00?ooool0:?oo0P007ooo0P00
2Ooo0P00=?oo0P00G_oo00<00?ooool01Ooo000;ool30002ool00`00ooooo`0Hool2000Xool4000[
ool2000aool4001Lool20007ool000_oo`H001[oo`03003ooooo02Ooo`@002goo`8002ooo`@005go
o`03003ooooo00Goo`002ooo00<00?ooool00_oo00<00?ooool04_oo00<00?ooool00ooo00<00?oo
ool0:?oo0P00<?oo0P00;_oo0P00G_oo00<00?ooool01Ooo000;ool00`00ooooo`02ool00`00oooo
o`0Aool00`00ool00004ool00`00ooooo`1Lool2002<ool00`00ooooo`05ool000_oo`H001?oo`03
003oo`0000Coo`8005ooo`8008Woo`8000Ooo`002ooo00H00?ooool00?oo000Cool00`00ool00004
ool00`00ooooo`1Pool3000>ool2001gool00`00ooooo`05ool000_oo`04003ooooo000Eool00`00
ool00004ool00`00ooooo`1Sool2000;ool4001fool00`00ooooo`05ool000coo`800003ool00?oo
01Coo`03003ooooo00?oo`03003ooooo06Goo`8000Woo`@007Koo`03003ooooo00Goo`004?oo00<0
0?ooool06?oo0P00J?oo0P002?oo0P00M_oo0P001ooo000[ool00`00ooooo`1Yool2000Dool2001Y
ool00`00ooooo`05ool002_oo`03003ooooo06_oo`80017oo`D006Ooo`03003ooooo00Goo`00:ooo
0P00K_oo0P003ooo1P00IOoo0P001ooo000;ool3000Mool00`00ooooo`1Eool2000Hool2000>ool5
001Vool00`00ooooo`05ool002_oo`03003ooooo05Coo`@001Woo`8000koo`8006Ooo`03003ooooo
00Goo`00:ooo00<00?ooool0E?oo10000ooo0P005_oo0P00MOoo00<00?ooool01Ooo000[ool2001F
ool20003ool4000Gool2001bool20007ool000goo`800003ool00?oo01Woo`03003ooooo05[oo`@0
01Woo`<0073oo`03003ooooo00Goo`003Ooo0P0000?oo`00ool06Ooo00<00?ooool0Fooo0P007Ooo
0P00K_oo00<00?ooool01Ooo000=ool200000ooo003oo`0Iool00`00ooooo`1lool2001/ool00`00
ooooo`05ool000goo`03003oo`0001_oo`8007ooo`8006Woo`8000Ooo`00:ooo00<00?ooool0P?oo
0P00J?oo00<00?ooool01Ooo000Nool50002ool00`00ooooo`03ool00`00ooooo`22ool2001Vool0
0`00ooooo`05ool0023oo`07003oooooool00?oo00001?oo00<00?ooool0Q?oo0P00I?oo00<00?oo
ool01Ooo000Pool01`00oooooooo003oo`0000Coo`8008Ooo`03003ooooo063oo`8000Ooo`008?oo
00L00?ooooooo`00ool00004ool00`00ooooo`27ool2000Vool2000iool00`00ooooo`05ool0023o
o`07003oooooool00?oo00001?oo00<00?ooool0G?oo0P00:ooo0P008ooo1000>?oo00<00?ooool0
1Ooo000Oool20004ool00`00ooooo`03ool00`00ooooo`1Kool4000/ool2000Qool4000hool00`00
ooooo`05ool000_oo`03003ooooo00;oo`03003ooooo01Soo`8005coo`@002koo`80023oo`8003So
o`8000Ooo`002ooo1P006_oo00<00?ooool0G?oo0P00<Ooo0`00F?oo00<00?ooool01Ooo000;ool0
1P00ooooo`00ool001[oo`03003ooooo09;oo`8005Koo`03003ooooo00Goo`002ooo00@00?ooool0
01coo`03003ooooo09Coo`8005Coo`03003ooooo00Goo`003?oo0P0000?oo`00ool06_oo0P00Uooo
0P00DOoo0P001ooo000@ool00`00ooooo`0Hool00`00ooooo`2Hool3001?ool00`00ooooo`05ool0
02_oo`03003ooooo07?oo`8002Koo`8004goo`03003ooooo00Goo`003_oo0P006ooo00<00?ooool0
L_oo10009ooo0P00Booo00<00?ooool01Ooo000=ool200000ooo003oo`0Iool2001cool4000Yool2
0018ool20007ool000goo`800003ool00?oo01Woo`03003ooooo07?oo`8002coo`8004Ooo`03003o
oooo00Goo`003_oo00<00?oo00006_oo00<00?ooool0Xooo0P00AOoo00<00?ooool01Ooo000[ool0
0`00ooooo`2Uool20013ool00`00ooooo`05ool000goo`03003ooooo01_oo`800:Soo`80043oo`80
00Ooo`003?oo10006ooo00<00?ooool0ZOoo0P00?ooo00<00?ooool01Ooo000=ool01000ooooo`00
3_oo0`000ooo00<00?ooool00ooo00<00?ooool0ROoo0P008?oo0P00?Ooo00<00?ooool01Ooo000=
ool01000ooooo`003_oo00<00?ooool00_oo00<00?oo00001?oo00<00?ooool0R?oo10008Ooo0P00
>ooo00<00?ooool01Ooo000=ool00`00ool0000@ool01`00oooooooo003oo`0000Coo`8008Woo`@0
02?oo`8003Soo`8000Ooo`008?oo00L00?ooooooo`00ool00004ool00`00ooooo`29ool2000Vool2
000gool00`00ooooo`05ool000goo`03003ooooo00ooo`03003oo`0000;oo`03003oo`0000Coo`03
003ooooo063oo`80057oo`8003Goo`03003ooooo00Goo`003Ooo0`004?oo00<00?ooool00_oo00<0
0?ooool00ooo00<00?ooool0Gooo1000D_oo0P00<ooo00<00?ooool01Ooo000@ool00`00ooooo`0H
ool2001Pool4001Dool2000`ool20007ool000goo`03003oo`0001_oo`03003ooooo063oo`8005Oo
o`<002koo`03003ooooo00Goo`003Ooo10006_oo00<00?ooool0_?oo0P00;?oo00<00?ooool01Ooo
000@ool00`00ooooo`0Hool2002oool2000Yool20007ool002_oo`03003ooooo0<3oo`8002Soo`03
003ooooo00Goo`003Ooo00@00?ooool001[oo`03003ooooo0<;oo`8002Koo`03003ooooo00Goo`00
3Ooo10006_oo00<00?ooool0a?oo0P009?oo00<00?ooool01Ooo000=ool01000ooooo`006_oo0P00
aooo0P008Ooo0P001ooo000=ool01000ooooo`006_oo00<00?ooool0b?oo0`007ooo00<00?ooool0
1Ooo000[ool00`00ooooo`3;ool3000Lool00`00ooooo`05ool000goo`04003ooooo000Jool00`00
ooooo`3;ool4000Kool00`00ooooo`05ool000goo`@001[oo`800<coo`H001Soo`8000Ooo`003Ooo
00<00?ooool06ooo00<00?ooool0c?oo0P000ooo0P005ooo00<00?ooool01Ooo000=ool00`00oooo
o`0?ool20004ool00`00ooooo`03ool00`00ooooo`3Cool2000Eool00`00ooooo`05ool000koo`<0
013oo`06003ooooo003oo`001?oo00<00?ooool0eOoo0P004ooo00<00?ooool01Ooo000@ool00`00
ooooo`0=ool01`00oooooooo003oo`0000Coo`800=Soo`80013oo`8000Ooo`008Ooo00H00?ooool0
0?oo0004ool00`00ooooo`3Iool2000?ool00`00ooooo`05ool000goo`800003ool00?oo00goo`03
003oo`0000;oo`03003oo`0000Coo`03003ooooo0=_oo`8000goo`03003ooooo00Goo`003Ooo0P00
00?oo`00ool03_oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool0gOoo0P002ooo00<00?oo
ool01Ooo000=ool200000ooo003oo`0Iool2003Pool20008ool20007ool000goo`03003oo`0001_o
o`03003ooooo0>7oo`8000Ooo`03003ooooo00Goo`00:ooo00<00?ooool0hooo0P001Ooo00<00?oo
ool01Ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`800>[oo`8000Ooo`00:ooo00<0
0?ooool0j_oo00<00?ooool01Ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`03003o
oooo0>[oo`03003ooooo00Goo`00:ooo0P00j_oo0P001ooo000[ool00`00ooooo`3Zool00`00oooo
o`05ool002_oo`03003ooooo0>[oo`03003ooooo00Goo`00:ooo00<00?ooool0j_oo00<00?ooool0
1Ooo000[ool2003Zool20007ool002_oo`03003ooooo0>[oo`03003ooooo00Goo`008?oo0`000_oo
00<00?ooool00ooo00<00?ooool0j_oo00<00?ooool01Ooo000Qool01P00ooooo`00ool000Coo`03
003ooooo0>[oo`03003ooooo00Goo`007ooo100000Coo`00ool000Coo`800>[oo`8000Ooo`007ooo
00<00?oo00000_oo00<00?oo00001?oo00<00?ooool0j_oo00<00?ooool01Ooo000Pool20002ool0
0`00ool00004ool00`00ooooo`3Zool00`00ooooo`05ool0027oo`05003oooooool00005ool2003Z
ool20007ool002_oo`03003ooooo0>[oo`03003ooooo00Goo`00:ooo00<00?ooool0j_oo00<00?oo
ool01Ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`800>[oo`8000Ooo`00:ooo00<0
0?ooool0j_oo00<00?ooool01Ooo000[ool00`00ooooo`3Zool00`00ooooo`05ool002_oo`03003o
oooo0>[oo`03003ooooo00Goo`00:ooo0P00j_oo0P001ooo000[ool00`00ooooo`3Zool00`00oooo
o`05ool002_oo`03003ooooo0>[oo`03003ooooo00Goo`00:ooo00<00?ooool0j_oo00<00?ooool0
1Ooo000[ool2002cool2000eool20007ool002_oo`03003ooooo0;7oo`@003Goo`03003ooooo00Go
o`008?oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool0/Ooo1000=Ooo00<00?ooool01Ooo
000Oool00`00ool00002ool00`00ool00004ool00`00ooooo`2bool2000fool00`00ooooo`05ool0
027oo`06003ooooo003oo`001?oo0P001?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool0
0ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool0
0ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool0
1?oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool0
1?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool0
0ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool0
0ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool0
1?oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00_oo0P001ooo000Oool20003ool00`00
ool00004ooo^0007ool001ooo`03003ooooo00;oo`03003oo`000?Woo`007ooo0`000ooo00<00?oo
ool0n?oo003ooolQool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-22.6082, -38.6172, \
0.154944, 0.513913}}]
}, Open  ]],

Cell["\<\
To compute the Security\[Hyphen]Market Line we need the vector of \
average returns and the betas for all the stocks. \
\>", "MathCaption",
  CellTags->{"S0.3", "3.25"}],

Cell[CellGroupData[{

Cell["means = MeanVector[returns]", "Input",
  CellLabel->"In[66]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \({1.70671999999999997`, 1.58512000000000004`, 0.288479999999999847`, 
      1.76839999999999974`, 0.512480000000000046`, 
      1.27487999999999979`, \(-0.529320000000000057`\), 1.10583999999999993`, 
      2.17032000000000024`, 4.2713599999999996`, \(-0.635840000000000138`\), 
      2.56159999999999987`}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
betas = Map[ AssetBeta[ret[#], ret[SP500]]&,
   ToExpression[tickers]]\
\>", "Input",
  CellLabel->"In[67]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \({0.281730790760063332`, 0.381004056098630439`, 0.220273044254782579`, 
      0.585250262789031783`, 0.716211029538091903`, 0.402816846109283499`, 
      0.145035729046096362`, 1.00702272488460353`, 0.432112361922119525`, 
      0.317500197961270869`, 0.311362548057070043`, 
      0.36465162278199048`}\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell["This is the regression data. ", "MathCaption",
  CellTags->{"S0.3", "3.26"}],

Cell[CellGroupData[{

Cell["data1 = Transpose[{betas, means}]", "Input",
  CellLabel->"In[68]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \({{0.281730790760063332`, 1.70671999999999997`}, {0.381004056098630439`, 
        1.58512000000000004`}, {0.220273044254782579`, 
        0.288479999999999847`}, {0.585250262789031783`, 
        1.76839999999999974`}, {0.716211029538091903`, 
        0.512480000000000046`}, {0.402816846109283499`, 
        1.27487999999999979`}, {0.145035729046096362`, \
\(-0.529320000000000057`\)}, {1.00702272488460353`, 
        1.10583999999999993`}, {0.432112361922119525`, 
        2.17032000000000024`}, {0.317500197961270869`, 
        4.2713599999999996`}, {0.311362548057070043`, \
\(-0.635840000000000138`\)}, {0.36465162278199048`, 
        2.56159999999999987`}}\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell["Here is the plot of the average returns versus the betas. ", \
"MathCaption",
  CellTags->{"S0.3", "3.27"}],

Cell[CellGroupData[{

Cell["g3 = ListPlot[data1, PlotStyle -> PointSize[.02]];", "Input",
  CellLabel->"In[69]:=",
  CellTags->"S0.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.136436 1.10487 0.0909822 0.119947 [
[.08454 -0.0125 -9 -9 ]
[.08454 -0.0125 9 0 ]
[.30551 -0.0125 -9 -9 ]
[.30551 -0.0125 9 0 ]
[.52648 -0.0125 -9 -9 ]
[.52648 -0.0125 9 0 ]
[.74746 -0.0125 -9 -9 ]
[.74746 -0.0125 9 0 ]
[.96843 -0.0125 -3 -9 ]
[.96843 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09098 -6 -4.5 ]
[-0.0125 .09098 0 4.5 ]
[-0.0125 .21093 -6 -4.5 ]
[-0.0125 .21093 0 4.5 ]
[-0.0125 .33088 -6 -4.5 ]
[-0.0125 .33088 0 4.5 ]
[-0.0125 .45082 -6 -4.5 ]
[-0.0125 .45082 0 4.5 ]
[-0.0125 .57077 -6 -4.5 ]
[-0.0125 .57077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08454 0 m
.08454 .00625 L
s
[(0.2)] .08454 -0.0125 0 1 Mshowa
.30551 0 m
.30551 .00625 L
s
[(0.4)] .30551 -0.0125 0 1 Mshowa
.52648 0 m
.52648 .00625 L
s
[(0.6)] .52648 -0.0125 0 1 Mshowa
.74746 0 m
.74746 .00625 L
s
[(0.8)] .74746 -0.0125 0 1 Mshowa
.96843 0 m
.96843 .00625 L
s
[(1)] .96843 -0.0125 0 1 Mshowa
.125 Mabswid
.13978 0 m
.13978 .00375 L
s
.19502 0 m
.19502 .00375 L
s
.25027 0 m
.25027 .00375 L
s
.36075 0 m
.36075 .00375 L
s
.416 0 m
.416 .00375 L
s
.47124 0 m
.47124 .00375 L
s
.58173 0 m
.58173 .00375 L
s
.63697 0 m
.63697 .00375 L
s
.69221 0 m
.69221 .00375 L
s
.8027 0 m
.8027 .00375 L
s
.85794 0 m
.85794 .00375 L
s
.91319 0 m
.91319 .00375 L
s
.02929 0 m
.02929 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09098 m
.00625 .09098 L
s
[(0)] -0.0125 .09098 1 0 Mshowa
0 .21093 m
.00625 .21093 L
s
[(1)] -0.0125 .21093 1 0 Mshowa
0 .33088 m
.00625 .33088 L
s
[(2)] -0.0125 .33088 1 0 Mshowa
0 .45082 m
.00625 .45082 L
s
[(3)] -0.0125 .45082 1 0 Mshowa
0 .57077 m
.00625 .57077 L
s
[(4)] -0.0125 .57077 1 0 Mshowa
.125 Mabswid
0 .11497 m
.00375 .11497 L
s
0 .13896 m
.00375 .13896 L
s
0 .16295 m
.00375 .16295 L
s
0 .18694 m
.00375 .18694 L
s
0 .23492 m
.00375 .23492 L
s
0 .25891 m
.00375 .25891 L
s
0 .2829 m
.00375 .2829 L
s
0 .30689 m
.00375 .30689 L
s
0 .35487 m
.00375 .35487 L
s
0 .37885 m
.00375 .37885 L
s
0 .40284 m
.00375 .40284 L
s
0 .42683 m
.00375 .42683 L
s
0 .47481 m
.00375 .47481 L
s
0 .4988 m
.00375 .4988 L
s
0 .52279 m
.00375 .52279 L
s
0 .54678 m
.00375 .54678 L
s
0 .06699 m
.00375 .06699 L
s
0 .043 m
.00375 .043 L
s
0 .01901 m
.00375 .01901 L
s
0 .59476 m
.00375 .59476 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08454 .61178 m
.08454 .61803 L
s
.30551 .61178 m
.30551 .61803 L
s
.52648 .61178 m
.52648 .61803 L
s
.74746 .61178 m
.74746 .61803 L
s
.96843 .61178 m
.96843 .61803 L
s
.125 Mabswid
.13978 .61428 m
.13978 .61803 L
s
.19502 .61428 m
.19502 .61803 L
s
.25027 .61428 m
.25027 .61803 L
s
.36075 .61428 m
.36075 .61803 L
s
.416 .61428 m
.416 .61803 L
s
.47124 .61428 m
.47124 .61803 L
s
.58173 .61428 m
.58173 .61803 L
s
.63697 .61428 m
.63697 .61803 L
s
.69221 .61428 m
.69221 .61803 L
s
.8027 .61428 m
.8027 .61803 L
s
.85794 .61428 m
.85794 .61803 L
s
.91319 .61428 m
.91319 .61803 L
s
.02929 .61428 m
.02929 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09098 m
1 .09098 L
s
.99375 .21093 m
1 .21093 L
s
.99375 .33088 m
1 .33088 L
s
.99375 .45082 m
1 .45082 L
s
.99375 .57077 m
1 .57077 L
s
.125 Mabswid
.99625 .11497 m
1 .11497 L
s
.99625 .13896 m
1 .13896 L
s
.99625 .16295 m
1 .16295 L
s
.99625 .18694 m
1 .18694 L
s
.99625 .23492 m
1 .23492 L
s
.99625 .25891 m
1 .25891 L
s
.99625 .2829 m
1 .2829 L
s
.99625 .30689 m
1 .30689 L
s
.99625 .35487 m
1 .35487 L
s
.99625 .37885 m
1 .37885 L
s
.99625 .40284 m
1 .40284 L
s
.99625 .42683 m
1 .42683 L
s
.99625 .47481 m
1 .47481 L
s
.99625 .4988 m
1 .4988 L
s
.99625 .52279 m
1 .52279 L
s
.99625 .54678 m
1 .54678 L
s
.99625 .06699 m
1 .06699 L
s
.99625 .043 m
1 .043 L
s
.99625 .01901 m
1 .01901 L
s
.99625 .59476 m
1 .59476 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.02 w
.17484 .2957 Mdot
.28452 .28111 Mdot
.10694 .12558 Mdot
.51019 .3031 Mdot
.65488 .15245 Mdot
.30862 .2439 Mdot
.02381 .02749 Mdot
.97619 .22362 Mdot
.34099 .35131 Mdot
.21436 .60332 Mdot
.20758 .01472 Mdot
.26646 .39824 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[69]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000Pool0
0`00ooooo`02ool01000oooooooo0`00<Ooo00<00?ooool00_oo00<00?ooool00_oo0`00;ooo00<0
0?ooool00_oo00@00?ooooooo`8003;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo03;o
o`D000goo`007ooo00<00?oo00001ooo00<00?ooool0<?oo00<00?oo00002Ooo00<00?ooool0;Ooo
00<00?oo00001ooo00<00?oo0000<?oo00<00?oo00001ooo00<00?oo0000=Ooo00<00?ooool03Ooo
000Oool00`00ool00008ool00`00ooooo`0_ool00`00ool00007ool4000^ool00`00ool00007ool0
0`00ool0000`ool00`00ool00007ool00`00ool0000eool00`00ooooo`0=ool001ooo`03003oo`00
00Soo`03003ooooo02ooo`03003oo`0000Ooo`03003oo`0002ooo`03003oo`0000Ooo`80037oo`03
003oo`0000Soo`03003ooooo03Coo`03003ooooo00goo`007ooo00<00?oo00001ooo00<00?oo0000
<?oo00<00?oo00002?oo0P00;ooo00<00?oo00001ooo00<00?ooool0<?oo00<00?oo00001ooo00<0
0?oo0000=Ooo00<00?ooool03Ooo000Pool00`00ooooo`07ool00`00ooooo`0`ool00`00ooooo`08
ool00`00ooooo`0^ool00`00ooooo`07ool2000aool00`00ooooo`07ool00`00ooooo`0cool2000?
ool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo000?oooo000C0006ool000oo
o`03003ooooo00Goo`03003ooooo00coo`03003ooooo00coo`03003ooooo00coo`03003ooooo00co
o`03003ooooo00coo`03003ooooo00coo`03003ooooo00coo`03003ooooo00goo`03003ooooo00co
o`03003ooooo00coo`03003ooooo00coo`03003ooooo00coo`03003ooooo00coo`03003ooooo00co
o`03003ooooo00coo`03003ooooo00goo`03003ooooo00coo`03003ooooo00Goo`03003ooooo00Co
o`003ooo00<00?ooool05?oo00<00?ooool0>Ooo00<00?ooool0>_oo00<00?ooool0>Ooo00<00?oo
ool0>_oo00<00?ooool01Ooo00<00?ooool01?oo000?ool00`00ooooo`0dool3003Gool00`00oooo
o`04ool000ooo`03003ooooo03?oo`D00=Koo`03003ooooo00Coo`003ooo00<00?ooool0<ooo1@00
e_oo00<00?ooool01?oo000?ool20003ool3000^ool5003Eool20006ool000ooo`04003oooooool5
000^ool3003Gool00`00ooooo`04ool000ooo`04003oooooool5003oool9ool00`00ooooo`04ool0
00ooo`04003oooooool5003oool9ool00`00ooooo`04ool000ooo`03003ooooo00;oo`<00?ooo`[o
o`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool2003oool?ool2
0006ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<0
0?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`oo
o`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3o
ool?ool00`00ooooo`04ool000ooo`800?ooo`ooo`8000Koo`003ooo00<00?ooool0oooo3ooo00<0
0?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`oo
o`03003ooooo00Coo`002?oo00<00?ooool01?oo00<00?ooool0oooo3ooo00<00?ooool01?oo0007
ool00`00ool00005ool00`00ooooo`3oool?ool00`00ooooo`04ool000Ooo`03003oo`0000Goo`80
0?ooo`ooo`8000Koo`001ooo00<00?oo00001Ooo00<00?ooool0oooo3ooo00<00?ooool01?oo0007
ool00`00ool00005ool00`00ooooo`3oool?ool00`00ooooo`04ool000Soo`03003ooooo00Coo`03
003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?
ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Co
o`003ooo0P00oooo3ooo0P001_oo000?ool00`00ooooo`0Iool3003bool00`00ooooo`04ool000oo
o`03003ooooo01Soo`D00?7oo`03003ooooo00Coo`003ooo00<00?ooool06?oo1@00lOoo00<00?oo
ool01?oo000?ool00`00ooooo`0Hool5003aool00`00ooooo`04ool000ooo`03003ooooo01Woo`<0
0?;oo`03003ooooo00Coo`003ooo0P00oooo3ooo0P001_oo000?ool00`00ooooo`3oool?ool00`00
ooooo`04ool000ooo`03003ooooo0:ooo`<005coo`03003ooooo00Coo`003ooo00<00?ooool0[_oo
1@00Fooo00<00?ooool01?oo000?ool00`00ooooo`2^ool5001Kool00`00ooooo`04ool000ooo`03
003ooooo0:koo`D005_oo`03003ooooo00Coo`003ooo00<00?ooool0[ooo0`00G?oo00<00?ooool0
1?oo000?ool2003oool?ool20006ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo
00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool0
00ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool0
1?oo000?ool2003oool?ool20006ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo
00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool0
00ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`001_oo1@001?oo00<00?ooool0oooo3ooo00<0
0?ooool01?oo0008ool00`00ooooo`04ool00`00ooooo`3oool?ool00`00ooooo`04ool000Soo`03
003ooooo00Coo`800?ooo`ooo`8000Koo`002?oo00<00?ooool01?oo00<00?ooool0oooo3ooo00<0
0?ooool01?oo0008ool00`00ooooo`04ool00`00ooooo`3oool8ool30004ool00`00ooooo`04ool0
00Ooo`8000Koo`03003ooooo0?ooo`Ooo`D000?oo`03003ooooo00Coo`003ooo00<00?ooool0oooo
1ooo1@000ooo00<00?ooool01?oo000?ool00`00ooooo`3oool7ool50003ool00`00ooooo`04ool0
00ooo`03003ooooo0?ooo`Soo`<000Coo`03003ooooo00Coo`003ooo0P00DOoo0`00^_oo0P001_oo
000?ool00`00ooooo`1?ool5002jool00`00ooooo`04ool000ooo`03003ooooo04ooo`D00;[oo`03
003ooooo00Coo`003ooo00<00?ooool0Cooo1@00^_oo00<00?ooool01?oo000?ool00`00ooooo`1@
ool3002kool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo0P00
oooo3ooo0P001_oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`19ool30032ool00`00ooooo`04ool000ooo`03003ooooo04Soo`D00<7oo`03003ooooo00Coo`00
3ooo00<00?ooool0B?oo1@00`Ooo00<00?ooool01?oo000?ool20019ool50030ool20006ool000oo
o`03003ooooo02_oo`<001_oo`<00<;oo`03003ooooo00Coo`003ooo00<00?ooool0:_oo1@00gooo
00<00?ooool01?oo000?ool00`00ooooo`0Zool5001Hool30024ool00`00ooooo`04ool000ooo`03
003ooooo02[oo`D005Ooo`D008?oo`03003ooooo00Coo`003ooo00<00?ooool0:ooo0`00F?oo1@00
Pooo00<00?ooool01?oo000?ool20027ool50022ool20006ool000ooo`03003ooooo08Ooo`<008Co
o`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3o
ool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`001ooo0`001Ooo
00<00?ooool0oooo3ooo00<00?ooool01?oo0007ool00`00ooooo`05ool00`00ooooo`3oool?ool0
0`00ooooo`04ool000Soo`03003ooooo00Coo`800?ooo`ooo`8000Koo`002?oo00<00?ooool01?oo
00<00?ooool0oooo3ooo00<00?ooool01?oo0007ool00`00ool00005ool00`00ooooo`3oool?ool0
0`00ooooo`04ool000Soo`03003ooooo00Coo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo
00<00?ooool0FOoo0`00/_oo00<00?ooool01?oo000?ool00`00ooooo`1Hool5002aool00`00oooo
o`04ool000ooo`8005Woo`D00;3oo`8000Koo`003ooo00<00?ooool0F?oo1@00/Ooo00<00?ooool0
1?oo000?ool00`00ooooo`1Iool3002bool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03
003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?
ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo0P00oooo3ooo
0P001_oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03
003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`14ool3
0037ool00`00ooooo`04ool000ooo`03003ooooo04?oo`D00<Koo`03003ooooo00Coo`003ooo00<0
0?ooool0@ooo1@00a_oo00<00?ooool01?oo000?ool20014ool50035ool20006ool000ooo`03003o
oooo04Coo`<00<Ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?
ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Co
o`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool2003oool?ool20006ool000ooo`03
003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?
ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Co
o`001ooo0P001_oo00<00?ooool0oooo3ooo00<00?ooool01?oo0009ool00`00ooooo`03ool00`00
ooooo`3oool?ool00`00ooooo`04ool000Soo`03003ooooo00Coo`800?ooo`ooo`8000Koo`002Ooo
00<00?ooool00ooo00<00?ooool0oooo3ooo00<00?ooool01?oo0007ool00`00ool00005ool00`00
ooooo`3oool?ool00`00ooooo`04ool000Soo`03003ooooo00Coo`03003ooooo0?ooo`ooo`03003o
oooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool0
0`00ooooo`04ool000ooo`800?ooo`ooo`8000Koo`003ooo00<00?ooool0oooo3ooo00<00?ooool0
1?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003o
oooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool0
0`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo0P00oooo3ooo0P00
1_oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003o
oooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool0
0`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo0P00oooo3ooo0P00
1_oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003o
oooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool0
0`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo
3ooo00<00?ooool01?oo000?ool2003oool?ool20006ool000ooo`03003ooooo0?ooo`ooo`03003o
oooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool0
0`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`002?oo0`001?oo00<00?oo
ool0oooo3ooo00<00?ooool01?oo0009ool00`00ooooo`03ool00`00ooooo`3oool?ool00`00oooo
o`04ool000Ooo`@000Coo`800?ooo`ooo`8000Koo`001ooo00<00?oo00001Ooo00<00?ooool0oooo
3ooo00<00?ooool01?oo0008ool20005ool00`00ooooo`3oool?ool00`00ooooo`04ool000Woo`03
003ooooo00?oo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<0
0?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`800?ooo`ooo`8000Ko
o`003ooo00<00?ooool0=_oo0`00eOoo00<00?ooool01?oo000?ool00`00ooooo`0eool5003Dool0
0`00ooooo`04ool000ooo`03003ooooo03Goo`D00=Coo`03003ooooo00Coo`003ooo00<00?ooool0
=Ooo1@00e?oo00<00?ooool01?oo000?ool00`00ooooo`05ool00`00ooooo`0<ool00`00ooooo`0<
ool00`00ooooo`0<ool01000oooooooo0`002?oo00<00?ooool03?oo00<00?ooool03?oo00<00?oo
ool03?oo00<00?ooool03Ooo00<00?ooool03?oo00<00?ooool03?oo00<00?ooool03?oo00<00?oo
ool03?oo00<00?ooool03?oo00<00?ooool03?oo00<00?ooool03?oo00<00?ooool03Ooo00<00?oo
ool03?oo00<00?ooool01Ooo00<00?ooool01?oo000?oooo000C0006ool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {0.0737567, -1.13683, \
0.00330594, 0.0304521}}]
}, Open  ]],

Cell["This is the equation of the Security\[Hyphen]Market Line. ", \
"MathCaption",
  CellTags->{"S0.3", "3.28"}],

Cell[CellGroupData[{

Cell["securityMarketLine[x_] = Fit[data1, {1, x}, x]", "Input",
  CellLabel->"In[70]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \(\(\(1.19448609561263596`\)\(\[InvisibleSpace]\)\) + 
      0.338086463646983226`\ x\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell["\<\
We generate a plot of the regression line, again suppressing its \
display. \
\>", "MathCaption",
  CellTags->{"S0.3", "3.29"}],

Cell["\<\
g4 = Plot[securityMarketLine[x], {x, .0, 1.1},
   DisplayFunction -> Identity];\
\>", "Input",
  CellLabel->"In[71]:=",
  CellTags->"S0.3"],

Cell["Now we display the data together with the regression line. ", \
"MathCaption",
  CellTags->{"S0.3", "3.30"}],

Cell[CellGroupData[{

Cell["Show[g3, g4, DisplayFunction -> $DisplayFunction];", "Input",
  CellLabel->"In[72]:=",
  CellTags->"S0.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.865801 0.0909822 0.119947 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.19697 -0.0125 -9 -9 ]
[.19697 -0.0125 9 0 ]
[.37013 -0.0125 -9 -9 ]
[.37013 -0.0125 9 0 ]
[.54329 -0.0125 -9 -9 ]
[.54329 -0.0125 9 0 ]
[.71645 -0.0125 -9 -9 ]
[.71645 -0.0125 9 0 ]
[.88961 -0.0125 -3 -9 ]
[.88961 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09098 -6 -4.5 ]
[-0.0125 .09098 0 4.5 ]
[-0.0125 .21093 -6 -4.5 ]
[-0.0125 .21093 0 4.5 ]
[-0.0125 .33088 -6 -4.5 ]
[-0.0125 .33088 0 4.5 ]
[-0.0125 .45082 -6 -4.5 ]
[-0.0125 .45082 0 4.5 ]
[-0.0125 .57077 -6 -4.5 ]
[-0.0125 .57077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.19697 0 m
.19697 .00625 L
s
[(0.2)] .19697 -0.0125 0 1 Mshowa
.37013 0 m
.37013 .00625 L
s
[(0.4)] .37013 -0.0125 0 1 Mshowa
.54329 0 m
.54329 .00625 L
s
[(0.6)] .54329 -0.0125 0 1 Mshowa
.71645 0 m
.71645 .00625 L
s
[(0.8)] .71645 -0.0125 0 1 Mshowa
.88961 0 m
.88961 .00625 L
s
[(1)] .88961 -0.0125 0 1 Mshowa
.125 Mabswid
.0671 0 m
.0671 .00375 L
s
.11039 0 m
.11039 .00375 L
s
.15368 0 m
.15368 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.32684 0 m
.32684 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.75974 0 m
.75974 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09098 m
.00625 .09098 L
s
[(0)] -0.0125 .09098 1 0 Mshowa
0 .21093 m
.00625 .21093 L
s
[(1)] -0.0125 .21093 1 0 Mshowa
0 .33088 m
.00625 .33088 L
s
[(2)] -0.0125 .33088 1 0 Mshowa
0 .45082 m
.00625 .45082 L
s
[(3)] -0.0125 .45082 1 0 Mshowa
0 .57077 m
.00625 .57077 L
s
[(4)] -0.0125 .57077 1 0 Mshowa
.125 Mabswid
0 .11497 m
.00375 .11497 L
s
0 .13896 m
.00375 .13896 L
s
0 .16295 m
.00375 .16295 L
s
0 .18694 m
.00375 .18694 L
s
0 .23492 m
.00375 .23492 L
s
0 .25891 m
.00375 .25891 L
s
0 .2829 m
.00375 .2829 L
s
0 .30689 m
.00375 .30689 L
s
0 .35487 m
.00375 .35487 L
s
0 .37885 m
.00375 .37885 L
s
0 .40284 m
.00375 .40284 L
s
0 .42683 m
.00375 .42683 L
s
0 .47481 m
.00375 .47481 L
s
0 .4988 m
.00375 .4988 L
s
0 .52279 m
.00375 .52279 L
s
0 .54678 m
.00375 .54678 L
s
0 .06699 m
.00375 .06699 L
s
0 .043 m
.00375 .043 L
s
0 .01901 m
.00375 .01901 L
s
0 .59476 m
.00375 .59476 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.19697 .61178 m
.19697 .61803 L
s
.37013 .61178 m
.37013 .61803 L
s
.54329 .61178 m
.54329 .61803 L
s
.71645 .61178 m
.71645 .61803 L
s
.88961 .61178 m
.88961 .61803 L
s
.125 Mabswid
.0671 .61428 m
.0671 .61803 L
s
.11039 .61428 m
.11039 .61803 L
s
.15368 .61428 m
.15368 .61803 L
s
.24026 .61428 m
.24026 .61803 L
s
.28355 .61428 m
.28355 .61803 L
s
.32684 .61428 m
.32684 .61803 L
s
.41342 .61428 m
.41342 .61803 L
s
.45671 .61428 m
.45671 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.58658 .61428 m
.58658 .61803 L
s
.62987 .61428 m
.62987 .61803 L
s
.67316 .61428 m
.67316 .61803 L
s
.75974 .61428 m
.75974 .61803 L
s
.80303 .61428 m
.80303 .61803 L
s
.84632 .61428 m
.84632 .61803 L
s
.9329 .61428 m
.9329 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09098 m
1 .09098 L
s
.99375 .21093 m
1 .21093 L
s
.99375 .33088 m
1 .33088 L
s
.99375 .45082 m
1 .45082 L
s
.99375 .57077 m
1 .57077 L
s
.125 Mabswid
.99625 .11497 m
1 .11497 L
s
.99625 .13896 m
1 .13896 L
s
.99625 .16295 m
1 .16295 L
s
.99625 .18694 m
1 .18694 L
s
.99625 .23492 m
1 .23492 L
s
.99625 .25891 m
1 .25891 L
s
.99625 .2829 m
1 .2829 L
s
.99625 .30689 m
1 .30689 L
s
.99625 .35487 m
1 .35487 L
s
.99625 .37885 m
1 .37885 L
s
.99625 .40284 m
1 .40284 L
s
.99625 .42683 m
1 .42683 L
s
.99625 .47481 m
1 .47481 L
s
.99625 .4988 m
1 .4988 L
s
.99625 .52279 m
1 .52279 L
s
.99625 .54678 m
1 .54678 L
s
.99625 .06699 m
1 .06699 L
s
.99625 .043 m
1 .043 L
s
.99625 .01901 m
1 .01901 L
s
.99625 .59476 m
1 .59476 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.02 w
.26773 .2957 Mdot
.35368 .28111 Mdot
.21452 .12558 Mdot
.53052 .3031 Mdot
.64391 .15245 Mdot
.37257 .2439 Mdot
.14938 .02749 Mdot
.89569 .22362 Mdot
.39793 .35131 Mdot
.2987 .60332 Mdot
.29339 .01472 Mdot
.33953 .39824 Mdot
.5 Mabswid
.02381 .23426 m
.06244 .23607 L
.10458 .23804 L
.14415 .23989 L
.18221 .24168 L
.22272 .24357 L
.26171 .2454 L
.30316 .24734 L
.34309 .24921 L
.3815 .25101 L
.42237 .25292 L
.46172 .25477 L
.49955 .25654 L
.53984 .25843 L
.57861 .26024 L
.61984 .26217 L
.65954 .26403 L
.69774 .26582 L
.73838 .26773 L
.77751 .26956 L
.81909 .27151 L
.85916 .27338 L
.89771 .27519 L
.93871 .27711 L
.97619 .27886 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000Eool0
0`00ooooo`0Wool00`00ooooo`02ool01000oooooooo0`008ooo00<00?ooool00_oo00<00?ooool0
0_oo0`008ooo00<00?ooool00_oo00@00?ooooooo`8002Coo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo02Koo`D002;oo`005?oo00<00?oo00009ooo00<00?oo00001ooo00<00?ooool08_oo
00<00?oo00002Ooo00<00?ooool08Ooo00<00?oo00001ooo00<00?oo00008_oo00<00?oo00001ooo
00<00?oo0000:Ooo00<00?ooool08_oo000Dool00`00ool0000Wool00`00ool00008ool00`00oooo
o`0Qool00`00ool00007ool4000Rool00`00ool00007ool00`00ool0000Rool00`00ool00007ool0
0`00ool0000Yool00`00ooooo`0Rool001Coo`03003oo`0002Ooo`03003oo`0000Soo`03003ooooo
027oo`03003oo`0000Ooo`03003oo`0002?oo`03003oo`0000Ooo`8002?oo`03003oo`0000Soo`03
003ooooo02Soo`03003ooooo02;oo`005?oo00<00?oo00009ooo00<00?oo00001ooo00<00?oo0000
8_oo00<00?oo00002?oo0P008ooo00<00?oo00001ooo00<00?ooool08_oo00<00?oo00001ooo00<0
0?oo0000:Ooo00<00?ooool08_oo000Eool00`00ooooo`0Wool00`00ooooo`07ool00`00ooooo`0R
ool00`00ooooo`08ool00`00ooooo`0Rool00`00ooooo`07ool2000Sool00`00ooooo`07ool00`00
ooooo`0Wool2000Tool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo000?oooo
000C0006ool000ooo`03003ooooo00?oo`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Wo
o`03003ooooo00Soo`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Wo
o`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Soo`03003ooooo00Woo`03003ooooo00Wo
o`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00So
o`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00Woo`03003ooooo00?o
o`03003ooooo00Coo`003ooo00<00?ooool00ooo00<00?ooool0;?oo00<00?ooool0;Ooo00<00?oo
ool0;?oo00<00?ooool0;Ooo00<00?ooool0;?oo00<00?ooool06ooo00<00?ooool01?oo000?ool0
0`00ooooo`1<ool3002oool00`00ooooo`04ool000ooo`03003ooooo04_oo`D00;koo`03003ooooo
00Coo`003ooo00<00?ooool0Booo1@00__oo00<00?ooool01?oo000?ool2000Uool3000Tool5002m
ool20006ool000ooo`03003ooooo02?oo`D002Coo`<00;ooo`03003ooooo00Coo`003ooo00<00?oo
ool08ooo1@00i_oo00<00?ooool01?oo000?ool00`00ooooo`0Sool5003Vool00`00ooooo`04ool0
00ooo`03003ooooo02Coo`<00>Ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?oo
ool01?oo000?ool2003oool?ool20006ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`00
3ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04
ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?oo
ool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`800?ooo`ooo`8000Koo`00
3ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04
ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`002?oo00<00?ooool01?oo00<00?ooool0
oooo3ooo00<00?ooool01?oo0007ool00`00ool00005ool00`00ooooo`3oool?ool00`00ooooo`04
ool000Ooo`03003oo`0000Goo`800?ooo`ooo`8000Koo`001ooo00<00?oo00001Ooo00<00?ooool0
oooo3ooo00<00?ooool01?oo0007ool00`00ool00005ool00`00ooooo`3oool?ool00`00ooooo`04
ool000Soo`03003ooooo00Coo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0
oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003o
oooo0?ooo`ooo`03003ooooo00Coo`003ooo0P00oooo3ooo0P001_oo000?ool00`00ooooo`0fool3
003Eool00`00ooooo`04ool000ooo`03003ooooo03Goo`D00=Coo`03003ooooo00Coo`003ooo00<0
0?ooool0=Ooo1@00e?oo00<00?ooool01?oo000?ool00`00ooooo`0eool5003Dool00`00ooooo`04
ool000ooo`03003ooooo03Koo`<00=Goo`03003ooooo00Coo`003ooo0P00oooo3ooo0P001_oo000?
ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0:coo`<005ooo`03003ooooo
00Coo`003ooo00<00?ooool0Zooo1@00G_oo00<00?ooool01?oo000?ool00`00ooooo`2[ool5001N
ool00`00ooooo`04ool000ooo`03003ooooo0:_oo`D005koo`03003ooooo00Coo`003ooo00<00?oo
ool0[?oo0`00Gooo00<00?ooool01?oo000?ool2003oool?ool20006ool000ooo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<0
0?ooool0oooo3ooo00<00?ooool01?oo000?ool2003oool?ool20006ool000ooo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`001_oo1@00
1?oo00<00?ooool0oooo3ooo00<00?ooool01?oo0008ool00`00ooooo`04ool00`00ooooo`3oool?
ool00`00ooooo`04ool000Soo`03003ooooo00Coo`800?ooo`ooo`8000Koo`002?oo00<00?ooool0
1?oo00<00?ooool0oooo3ooo00<00?ooool01?oo0008ool00`00ooooo`04ool00`00ooooo`3aool3
000Jool00`00ooooo`04ool000Ooo`8000Koo`03003ooooo0?3oo`D001Woo`03003ooooo00Coo`00
3ooo00<00?ooool0l?oo1@006Ooo00<00?ooool01?oo000?ool00`00ooooo`3`ool5000Iool00`00
ooooo`04ool000ooo`03003ooooo00?oo`H00>Soo`<001[oo`03003ooooo00Coo`003ooo0P002_oo
5P00@_oo0`00ZOoo0P001_oo000?ool00`00ooooo`0OoolE000/ool5002Yool00`00ooooo`04ool0
00ooo`03003ooooo03CooaH001Koo`D00:Woo`03003ooooo00Coo`003ooo00<00?ooool0B_oo2`00
2ooo1@00ZOoo00<00?ooool01?oo000?ool00`00ooooo`1EoolF002Sool00`00ooooo`04ool000oo
o`03003ooooo06_ooaD008koo`03003ooooo00Coo`003ooo0P00POoo5P00Mooo0P001_oo000?ool0
0`00ooooo`2FoolF001Rool00`00ooooo`04ool000ooo`03003ooooo0:cooaH004coo`03003ooooo
00Coo`003ooo00<00?ooool0`_oo5@00=ooo00<00?ooool01?oo000?ool00`00ooooo`1Lool3001h
oolF000Qool00`00ooooo`04ool000ooo`03003ooooo05_oo`D008gooaH000_oo`03003ooooo00Co
o`003ooo00<00?ooool0Fooo1@00Xooo1P001Ooo00<00?ooool01?oo000?ool2001Lool5002]ool2
0006ool000ooo`03003ooooo04Goo`<001Coo`<00:ooo`03003ooooo00Coo`003ooo00<00?ooool0
A?oo1@00aOoo00<00?ooool01?oo000?ool00`00ooooo`14ool50014ool3001nool00`00ooooo`04
ool000ooo`03003ooooo04Coo`D004?oo`D007goo`03003ooooo00Coo`003ooo00<00?ooool0AOoo
0`00A?oo1@00OOoo00<00?ooool01?oo000?ool2002=ool5001lool20006ool000ooo`03003ooooo
08goo`<007koo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool0
0`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`00
1ooo0`001Ooo00<00?ooool0oooo3ooo00<00?ooool01?oo0007ool00`00ooooo`05ool00`00oooo
o`3oool?ool00`00ooooo`04ool000Soo`03003ooooo00Coo`800?ooo`ooo`8000Koo`002?oo00<0
0?ooool01?oo00<00?ooool0oooo3ooo00<00?ooool01?oo0007ool00`00ool00005ool00`00oooo
o`3oool?ool00`00ooooo`04ool000Soo`03003ooooo00Coo`03003ooooo0?ooo`ooo`03003ooooo
00Coo`003ooo00<00?ooool0J?oo0`00Xooo00<00?ooool01?oo000?ool00`00ooooo`1Wool5002R
ool00`00ooooo`04ool000ooo`8006Soo`D00:7oo`8000Koo`003ooo00<00?ooool0Iooo1@00X_oo
00<00?ooool01?oo000?ool00`00ooooo`1Xool3002Sool00`00ooooo`04ool000ooo`03003ooooo
0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00
ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo
0P00oooo3ooo0P001_oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo
0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00
ooooo`1Hool3002cool00`00ooooo`04ool000ooo`03003ooooo05Ooo`D00;;oo`03003ooooo00Co
o`003ooo00<00?ooool0Eooo1@00/_oo00<00?ooool01?oo000?ool2001Hool5002aool20006ool0
00ooo`03003ooooo05Soo`<00;?oo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?oo
ool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03
003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool2003oool?ool20006
ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?oo
ool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03
003ooooo00Coo`001ooo0P001_oo00<00?ooool0oooo3ooo00<00?ooool01?oo0009ool00`00oooo
o`03ool00`00ooooo`3oool?ool00`00ooooo`04ool000Soo`03003ooooo00Coo`800?ooo`ooo`80
00Koo`002Ooo00<00?ooool00ooo00<00?ooool0oooo3ooo00<00?ooool01?oo0007ool00`00ool0
0005ool00`00ooooo`3oool?ool00`00ooooo`04ool000Soo`03003ooooo00Coo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`3oool?ool00`00ooooo`04ool000ooo`800?ooo`ooo`8000Koo`003ooo00<00?ooool0oooo3ooo
00<00?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo0P00
oooo3ooo0P001_oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo0P00
oooo3ooo0P001_oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<0
0?ooool0oooo3ooo00<00?ooool01?oo000?ool2003oool?ool20006ool000ooo`03003ooooo0?oo
o`ooo`03003ooooo00Coo`003ooo00<00?ooool0oooo3ooo00<00?ooool01?oo000?ool00`00oooo
o`3oool?ool00`00ooooo`04ool000ooo`03003ooooo0?ooo`ooo`03003ooooo00Coo`002?oo0`00
1?oo00<00?ooool0oooo3ooo00<00?ooool01?oo0009ool00`00ooooo`03ool00`00ooooo`3oool?
ool00`00ooooo`04ool000Ooo`@000Coo`800?ooo`ooo`8000Koo`001ooo00<00?oo00001Ooo00<0
0?ooool0oooo3ooo00<00?ooool01?oo0008ool20005ool00`00ooooo`3oool?ool00`00ooooo`04
ool000Woo`03003ooooo00?oo`03003ooooo0?ooo`ooo`03003ooooo00Coo`003ooo00<00?ooool0
oooo3ooo00<00?ooool01?oo000?ool00`00ooooo`3oool?ool00`00ooooo`04ool000ooo`800?oo
o`ooo`8000Koo`003ooo00<00?ooool0COoo0`00__oo00<00?ooool01?oo000?ool00`00ooooo`1<
ool5002mool00`00ooooo`04ool000ooo`03003ooooo04coo`D00;goo`03003ooooo00Coo`003ooo
00<00?ooool0C?oo1@00_Ooo00<00?ooool01?oo000?ool00`00ooooo`03ool00`00ooooo`09ool0
0`00ooooo`09ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`09ool0
0`00ooooo`030006ool00`00ooooo`09ool00`00ooooo`09ool00`00ooooo`09ool00`00ooooo`08
ool00`00ooooo`09ool00`00ooooo`09ool00`00ooooo`09ool00`00ooooo`09ool00`00ooooo`09
ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`09ool00`00ooooo`09
ool00`00ooooo`09ool00`00ooooo`03ool00`00ooooo`04ool000ooool001<000Koo`00\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-0.0909608, -1.13683, \
0.00421879, 0.0304521}}]
}, Open  ]],

Cell["Moving Averages", "Subsection",
  CellTags->{"S0.4", "4.1"}],

Cell["\<\
Some traders identify buy\[Hyphen]sell opportunities by analyzing \
the moving averages of finance series.   \
\>", "Text",
  CellTags->{"S0.4", "4.2"}],

Cell["First we load prices of IBM stock. ", "MathCaption",
  CellTags->{"S0.4", "4.3"}],

Cell["\<\
prices[IBM] ^= Last[Transpose[
   ReadList[ToFileName[{\"Finance\", \"Data\"}, \"IBM.prc\"],
      {Number, Number}]]];\
\>", "Input",
  CellLabel->"In[73]:=",
  CellTags->"S0.4"],

Cell[TextData[{
  "The function ",
  StyleBox["MovingAverage", "MB"],
  " is defined in the package ",
  StyleBox["Statistics`MovingAverage`", "MB"],
  ". We compute the 15\[Hyphen]day moving average for the last 1000 days. "
}], "MathCaption",
  CellTags->{"S0.4", "4.4"}],

Cell[BoxData[
    \(<< \ Statistics`DataSmoothing`\)], "Input",
  CellLabel->"In[74]:="],

Cell["mavg[15] = Take[MovingAverage[prices[IBM], 15], -1000];", "Input",
  CellLabel->"In[75]:=",
  CellTags->"S0.4"],

Cell["\<\
Here we compute the 75\[Hyphen]day moving average for the last 1000 \
days. \
\>", "MathCaption",
  CellTags->{"S0.4", "4.5"}],

Cell["mavg[75] = Take[MovingAverage[prices[IBM], 75], -1000];", "Input",
  CellLabel->"In[76]:=",
  CellTags->"S0.4"],

Cell["We create the graph of the 15\[Hyphen]day moving average. ", \
"MathCaption",
  CellTags->{"S0.4", "4.6"}],

Cell["\<\
g[15] = ListPlot[mavg[15],
   PlotJoined -> True, DisplayFunction -> Identity];\
\>", "Input",
  CellLabel->"In[77]:=",
  CellTags->"S0.4"],

Cell["We create the graph of the 75\[Hyphen]day moving average. ", \
"MathCaption",
  CellTags->{"S0.4", "4.7"}],

Cell["\<\
g[75] = ListPlot[mavg[75],
   PlotJoined -> True, DisplayFunction -> Identity];\
\>", "Input",
  CellLabel->"In[78]:=",
  CellTags->"S0.4"],

Cell["\<\
The intersection points of the moving averages identify trading \
opportunities. \
\>", "MathCaption",
  CellTags->{"S0.4", "4.8"}],

Cell[CellGroupData[{

Cell["Show[{g[15], g[75]}, DisplayFunction -> $DisplayFunction];", "Input",
  CellLabel->"In[79]:=",
  CellTags->"S0.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228562 0.000953334 -0.719416 0.00771686 [
[.02286 -0.0125 -3 -9 ]
[.02286 -0.0125 3 0 ]
[.21352 -0.0125 -9 -9 ]
[.21352 -0.0125 9 0 ]
[.40419 -0.0125 -9 -9 ]
[.40419 -0.0125 9 0 ]
[.59486 -0.0125 -9 -9 ]
[.59486 -0.0125 9 0 ]
[.78552 -0.0125 -9 -9 ]
[.78552 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05227 -18 -4.5 ]
[-0.0125 .05227 0 4.5 ]
[-0.0125 .20661 -18 -4.5 ]
[-0.0125 .20661 0 4.5 ]
[-0.0125 .36095 -18 -4.5 ]
[-0.0125 .36095 0 4.5 ]
[-0.0125 .51528 -18 -4.5 ]
[-0.0125 .51528 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02286 0 m
.02286 .00625 L
s
[(0)] .02286 -0.0125 0 1 Mshowa
.21352 0 m
.21352 .00625 L
s
[(200)] .21352 -0.0125 0 1 Mshowa
.40419 0 m
.40419 .00625 L
s
[(400)] .40419 -0.0125 0 1 Mshowa
.59486 0 m
.59486 .00625 L
s
[(600)] .59486 -0.0125 0 1 Mshowa
.78552 0 m
.78552 .00625 L
s
[(800)] .78552 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07052 0 m
.07052 .00375 L
s
.11819 0 m
.11819 .00375 L
s
.16586 0 m
.16586 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.30886 0 m
.30886 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.49952 0 m
.49952 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.69019 0 m
.69019 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.88086 0 m
.88086 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05227 m
.00625 .05227 L
s
[(100)] -0.0125 .05227 1 0 Mshowa
0 .20661 m
.00625 .20661 L
s
[(120)] -0.0125 .20661 1 0 Mshowa
0 .36095 m
.00625 .36095 L
s
[(140)] -0.0125 .36095 1 0 Mshowa
0 .51528 m
.00625 .51528 L
s
[(160)] -0.0125 .51528 1 0 Mshowa
.125 Mabswid
0 .09085 m
.00375 .09085 L
s
0 .12944 m
.00375 .12944 L
s
0 .16802 m
.00375 .16802 L
s
0 .24519 m
.00375 .24519 L
s
0 .28378 m
.00375 .28378 L
s
0 .32236 m
.00375 .32236 L
s
0 .39953 m
.00375 .39953 L
s
0 .43811 m
.00375 .43811 L
s
0 .4767 m
.00375 .4767 L
s
0 .01369 m
.00375 .01369 L
s
0 .55387 m
.00375 .55387 L
s
0 .59245 m
.00375 .59245 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02286 .61178 m
.02286 .61803 L
s
.21352 .61178 m
.21352 .61803 L
s
.40419 .61178 m
.40419 .61803 L
s
.59486 .61178 m
.59486 .61803 L
s
.78552 .61178 m
.78552 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07052 .61428 m
.07052 .61803 L
s
.11819 .61428 m
.11819 .61803 L
s
.16586 .61428 m
.16586 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.30886 .61428 m
.30886 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.49952 .61428 m
.49952 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.69019 .61428 m
.69019 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.88086 .61428 m
.88086 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05227 m
1 .05227 L
s
.99375 .20661 m
1 .20661 L
s
.99375 .36095 m
1 .36095 L
s
.99375 .51528 m
1 .51528 L
s
.125 Mabswid
.99625 .09085 m
1 .09085 L
s
.99625 .12944 m
1 .12944 L
s
.99625 .16802 m
1 .16802 L
s
.99625 .24519 m
1 .24519 L
s
.99625 .28378 m
1 .28378 L
s
.99625 .32236 m
1 .32236 L
s
.99625 .39953 m
1 .39953 L
s
.99625 .43811 m
1 .43811 L
s
.99625 .4767 m
1 .4767 L
s
.99625 .01369 m
1 .01369 L
s
.99625 .55387 m
1 .55387 L
s
.99625 .59245 m
1 .59245 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .216 m
.02476 .21497 L
.02572 .21664 L
.02667 .21773 L
.02762 .2187 L
.02858 .22249 L
.02953 .22468 L
.03048 .22654 L
.03144 .22982 L
.03239 .23317 L
.03334 .23612 L
.0343 .23947 L
.03525 .24558 L
.0362 .25407 L
.03716 .26256 L
.03811 .27124 L
.03906 .27934 L
.04002 .28371 L
.04097 .28918 L
.04192 .29497 L
.04288 .29767 L
.04383 .30191 L
.04478 .30763 L
.04574 .31207 L
.04669 .31677 L
.04764 .32243 L
.0486 .32995 L
.04955 .33548 L
.0505 .33998 L
.05146 .34217 L
.05241 .34352 L
.05336 .34493 L
.05432 .34718 L
.05527 .35053 L
.05622 .35381 L
.05718 .35728 L
.05813 .35953 L
.05908 .36185 L
.06004 .36377 L
.06099 .36641 L
.06194 .36911 L
.0629 .36976 L
.06385 .37188 L
.0648 .37419 L
.06576 .37812 L
.06671 .38281 L
.06766 .3886 L
.06862 .39619 L
.06957 .40429 L
.07052 .4113 L
Mistroke
.07148 .41715 L
.07243 .42409 L
.07338 .42782 L
.07434 .43265 L
.07529 .43458 L
.07624 .43696 L
.0772 .4394 L
.07815 .43908 L
.0791 .43979 L
.08006 .43824 L
.08101 .43638 L
.08196 .43528 L
.08292 .43284 L
.08387 .4304 L
.08482 .42834 L
.08578 .42795 L
.08673 .43033 L
.08768 .43245 L
.08864 .43406 L
.08959 .43599 L
.09054 .43844 L
.0915 .44146 L
.09245 .4477 L
.0934 .45413 L
.09436 .46268 L
.09531 .47194 L
.09626 .48184 L
.09722 .49142 L
.09817 .49863 L
.09912 .5057 L
.10008 .51239 L
.10103 .5167 L
.10198 .52287 L
.10294 .52847 L
.10389 .53303 L
.10484 .5365 L
.1058 .53728 L
.10675 .53625 L
.1077 .53477 L
.10866 .53271 L
.10961 .53149 L
.11056 .52847 L
.11152 .52634 L
.11247 .52384 L
.11342 .52171 L
.11438 .51875 L
.11533 .51612 L
.11628 .51361 L
.11724 .51097 L
.11819 .5113 L
Mistroke
.11914 .51072 L
.1201 .51123 L
.12105 .51175 L
.122 .51142 L
.12296 .51297 L
.12391 .51367 L
.12486 .51387 L
.12582 .51297 L
.12677 .51367 L
.12772 .51554 L
.12868 .51946 L
.12963 .52248 L
.13058 .52583 L
.13154 .52917 L
.13249 .53129 L
.13344 .53265 L
.1344 .53586 L
.13535 .53927 L
.1363 .54364 L
.13726 .54583 L
.13821 .54827 L
.13916 .55078 L
.14012 .55393 L
.14107 .5583 L
.14202 .56049 L
.14298 .5621 L
.14393 .56313 L
.14488 .56268 L
.14584 .56171 L
.14679 .56036 L
.14774 .55978 L
.1487 .55779 L
.14965 .55625 L
.1506 .5547 L
.15156 .55335 L
.15251 .55065 L
.15346 .54866 L
.15442 .54557 L
.15537 .5401 L
.15632 .53592 L
.15728 .53194 L
.15823 .5293 L
.15918 .52795 L
.16014 .52904 L
.16109 .53226 L
.16204 .53689 L
.163 .54371 L
.16395 .54988 L
.1649 .55625 L
.16586 .56223 L
Mistroke
.16681 .56795 L
.16776 .57432 L
.16872 .58139 L
.16967 .5893 L
.17062 .59579 L
.17158 .59972 L
.17253 .60139 L
.17348 .60248 L
.17444 .60332 L
.17539 .60017 L
.17634 .59612 L
.1773 .59007 L
.17825 .58364 L
.1792 .57502 L
.18016 .56699 L
.18111 .55933 L
.18206 .55232 L
.18302 .54576 L
.18397 .53695 L
.18492 .52904 L
.18588 .5239 L
.18683 .5183 L
.18778 .51007 L
.18874 .50358 L
.18969 .49914 L
.19064 .49573 L
.1916 .49284 L
.19255 .48872 L
.1935 .48499 L
.19446 .48165 L
.19541 .48004 L
.19636 .47702 L
.19732 .47419 L
.19827 .47085 L
.19922 .46885 L
.20018 .46557 L
.20113 .46146 L
.20208 .46094 L
.20304 .45734 L
.20399 .45271 L
.20494 .44461 L
.2059 .43381 L
.20685 .40821 L
.2078 .38995 L
.20876 .37554 L
.20971 .35773 L
.21066 .33998 L
.21162 .31709 L
.21257 .30011 L
.21352 .28223 L
Mistroke
.21448 .26616 L
.21543 .25336 L
.21638 .2405 L
.21734 .22667 L
.21829 .214 L
.21924 .20558 L
.2202 .1976 L
.22115 .20539 L
.2221 .2068 L
.22306 .205 L
.22401 .20616 L
.22496 .20661 L
.22592 .21072 L
.22687 .21059 L
.22782 .21079 L
.22878 .20841 L
.22973 .20596 L
.23068 .20236 L
.23164 .20063 L
.23259 .19908 L
.23354 .19452 L
.2345 .19002 L
.23545 .18648 L
.2364 .18275 L
.23736 .17619 L
.23831 .16873 L
.23926 .16249 L
.24022 .15812 L
.24117 .15619 L
.24212 .1524 L
.24308 .14957 L
.24403 .14822 L
.24498 .14745 L
.24594 .14764 L
.24689 .14654 L
.24784 .14777 L
.2488 .15163 L
.24975 .15523 L
.2507 .15986 L
.25166 .16674 L
.25261 .17085 L
.25356 .1742 L
.25452 .17703 L
.25547 .1778 L
.25642 .18281 L
.25738 .18886 L
.25833 .19285 L
.25928 .19664 L
.26024 .19458 L
.26119 .19574 L
Mistroke
.26214 .19471 L
.2631 .19362 L
.26405 .1924 L
.265 .19214 L
.26596 .19105 L
.26691 .18899 L
.26786 .18609 L
.26882 .18301 L
.26977 .18043 L
.27072 .17658 L
.27168 .17143 L
.27263 .16622 L
.27358 .16127 L
.27454 .15999 L
.27549 .156 L
.27644 .15323 L
.2774 .14957 L
.27835 .14584 L
.2793 .14018 L
.28026 .13503 L
.28121 .13368 L
.28216 .13433 L
.28312 .13446 L
.28407 .13523 L
.28502 .13548 L
.28598 .13593 L
.28693 .13581 L
.28788 .13561 L
.28884 .13709 L
.28979 .13986 L
.29074 .14307 L
.2917 .1459 L
.29265 .14957 L
.2936 .15445 L
.29456 .15921 L
.29551 .16339 L
.29646 .1659 L
.29742 .1688 L
.29837 .1715 L
.29932 .17349 L
.30028 .17548 L
.30123 .17613 L
.30218 .17722 L
.30314 .17735 L
.30409 .17664 L
.30504 .17619 L
.306 .17638 L
.30695 .17561 L
.3079 .17368 L
.30886 .17169 L
Mistroke
.30981 .1688 L
.31076 .16532 L
.31172 .16024 L
.31267 .15555 L
.31362 .1495 L
.31458 .14359 L
.31553 .14044 L
.31648 .13632 L
.31744 .1322 L
.31839 .12995 L
.31934 .12687 L
.3203 .12519 L
.32125 .12474 L
.3222 .12468 L
.32316 .12622 L
.32411 .1261 L
.32506 .12835 L
.32602 .13195 L
.32697 .13452 L
.32792 .13812 L
.32888 .14185 L
.32983 .145 L
.33078 .14828 L
.33174 .15175 L
.33269 .154 L
.33364 .156 L
.3346 .1569 L
.33555 .15728 L
.3365 .1578 L
.33746 .15632 L
.33841 .15626 L
.33936 .15439 L
.34032 .15259 L
.34127 .15143 L
.34222 .14931 L
.34318 .14745 L
.34413 .14571 L
.34508 .14455 L
.34604 .14243 L
.34699 .13979 L
.34794 .13844 L
.3489 .13645 L
.34985 .13368 L
.3508 .13092 L
.35176 .12847 L
.35271 .12693 L
.35366 .12565 L
.35462 .12667 L
.35557 .12783 L
.35652 .12982 L
Mistroke
.35748 .13214 L
.35843 .1342 L
.35938 .13529 L
.36034 .13864 L
.36129 .14198 L
.36224 .14481 L
.3632 .14867 L
.36415 .15381 L
.3651 .15876 L
.36606 .1632 L
.36701 .16796 L
.36796 .17265 L
.36892 .17664 L
.36987 .18172 L
.37082 .18847 L
.37178 .19458 L
.37273 .20005 L
.37368 .20687 L
.37464 .2122 L
.37559 .21838 L
.37654 .22384 L
.3775 .23014 L
.37845 .23432 L
.3794 .23883 L
.38036 .24358 L
.38131 .24834 L
.38226 .25252 L
.38322 .2551 L
.38417 .256 L
.38512 .25587 L
.38608 .25587 L
.38703 .25535 L
.38798 .25381 L
.38894 .25111 L
.38989 .24738 L
.39084 .24519 L
.3918 .24178 L
.39275 .23883 L
.3937 .23683 L
.39466 .23651 L
.39561 .23625 L
.39656 .23651 L
.39752 .23677 L
.39847 .23651 L
.39942 .23567 L
.40038 .23465 L
.40133 .23342 L
.40228 .23079 L
.40324 .22937 L
.40419 .22828 L
Mistroke
.40514 .22455 L
.4061 .22101 L
.40705 .21767 L
.408 .21297 L
.40896 .20629 L
.40991 .19831 L
.41086 .19066 L
.41182 .18397 L
.41277 .17748 L
.41372 .1715 L
.41468 .16648 L
.41563 .16198 L
.41658 .15818 L
.41754 .15368 L
.41849 .15163 L
.41944 .15047 L
.4204 .14841 L
.42135 .14712 L
.4223 .147 L
.42326 .14745 L
.42421 .14963 L
.42516 .15156 L
.42612 .15208 L
.42707 .15343 L
.42802 .15368 L
.42898 .15336 L
.42993 .15355 L
.43088 .15381 L
.43184 .15516 L
.43279 .15426 L
.43374 .15445 L
.4347 .15555 L
.43565 .15722 L
.4366 .15773 L
.43756 .15838 L
.43851 .15812 L
.43946 .15773 L
.44042 .15786 L
.44137 .15876 L
.44232 .1605 L
.44328 .16359 L
.44423 .16577 L
.44518 .16918 L
.44614 .17272 L
.44709 .17728 L
.44804 .18301 L
.449 .18738 L
.44995 .19227 L
.4509 .1969 L
.45186 .20114 L
Mistroke
.45281 .20545 L
.45376 .20944 L
.45472 .21265 L
.45567 .2151 L
.45662 .21844 L
.45758 .22114 L
.45853 .22391 L
.45948 .22577 L
.46044 .22603 L
.46139 .225 L
.46234 .22262 L
.4633 .22133 L
.46425 .2187 L
.4652 .21471 L
.46616 .21162 L
.46711 .20886 L
.46806 .20571 L
.46902 .20326 L
.46997 .20069 L
.47092 .19709 L
.47188 .19349 L
.47283 .19098 L
.47378 .18777 L
.47474 .18706 L
.47569 .18719 L
.47664 .18654 L
.4776 .18571 L
.47855 .18545 L
.4795 .18764 L
.48046 .19021 L
.48141 .19201 L
.48236 .194 L
.48332 .19651 L
.48427 .19896 L
.48522 .20159 L
.48618 .20339 L
.48713 .20494 L
.48808 .20764 L
.48904 .20963 L
.48999 .21162 L
.49094 .21394 L
.4919 .21613 L
.49285 .21825 L
.4938 .2194 L
.49476 .2196 L
.49571 .22076 L
.49666 .22204 L
.49762 .22236 L
.49857 .22339 L
.49952 .22416 L
Mistroke
.50048 .22487 L
.50143 .22539 L
.50238 .22532 L
.50334 .22506 L
.50429 .225 L
.50524 .22519 L
.5062 .22609 L
.50715 .22635 L
.5081 .22731 L
.50906 .22821 L
.51001 .22841 L
.51096 .22867 L
.51192 .23034 L
.51287 .23072 L
.51382 .23265 L
.51478 .23522 L
.51573 .2387 L
.51668 .24358 L
.51764 .24738 L
.51859 .25008 L
.51954 .25233 L
.5205 .25355 L
.52145 .25548 L
.5224 .25651 L
.52336 .2576 L
.52431 .25831 L
.52526 .26018 L
.52622 .26043 L
.52717 .26236 L
.52812 .2623 L
.52908 .26146 L
.53003 .25979 L
.53098 .25606 L
.53194 .25284 L
.53289 .24911 L
.53384 .24596 L
.5348 .24333 L
.53575 .23934 L
.5367 .236 L
.53766 .23317 L
.53861 .23137 L
.53956 .22821 L
.54052 .22558 L
.54147 .22127 L
.54242 .21735 L
.54338 .21407 L
.54433 .21014 L
.54528 .20687 L
.54624 .20416 L
.54719 .19973 L
Mistroke
.54814 .19349 L
.5491 .18764 L
.55005 .18217 L
.551 .17658 L
.55196 .17105 L
.55291 .16513 L
.55386 .15986 L
.55482 .15426 L
.55577 .14937 L
.55672 .14436 L
.55768 .13831 L
.55863 .1331 L
.55958 .12847 L
.56054 .12417 L
.56149 .12288 L
.56244 .12372 L
.5634 .12423 L
.56435 .12423 L
.5653 .12487 L
.56626 .12552 L
.56721 .12706 L
.56816 .12847 L
.56912 .13034 L
.57007 .13259 L
.57102 .13516 L
.57198 .13896 L
.57293 .14243 L
.57388 .14584 L
.57484 .14809 L
.57579 .14982 L
.57674 .15047 L
.5777 .15066 L
.57865 .15137 L
.5796 .1506 L
.58056 .14963 L
.58151 .14796 L
.58246 .14654 L
.58342 .14487 L
.58437 .14346 L
.58532 .14307 L
.58628 .14146 L
.58723 .13992 L
.58818 .13857 L
.58914 .13703 L
.59009 .13523 L
.59104 .13375 L
.592 .13285 L
.59295 .13233 L
.5939 .1324 L
.59486 .13175 L
Mistroke
.59581 .13169 L
.59676 .13188 L
.59772 .1324 L
.59867 .1315 L
.59962 .12989 L
.60058 .12892 L
.60153 .12777 L
.60248 .1259 L
.60344 .12474 L
.60439 .12532 L
.60534 .12577 L
.6063 .12558 L
.60725 .12552 L
.6082 .12597 L
.60916 .12661 L
.61011 .12667 L
.61106 .12622 L
.61202 .12661 L
.61297 .12815 L
.61392 .1306 L
.61488 .13285 L
.61583 .134 L
.61678 .13581 L
.61774 .13754 L
.61869 .13806 L
.61964 .1387 L
.6206 .14011 L
.62155 .14275 L
.6225 .14455 L
.62346 .14725 L
.62441 .14989 L
.62536 .15278 L
.62632 .15542 L
.62727 .15683 L
.62822 .15683 L
.62918 .15626 L
.63013 .15761 L
.63108 .15844 L
.63204 .1587 L
.63299 .15896 L
.63394 .15966 L
.6349 .16031 L
.63585 .1605 L
.6368 .16089 L
.63776 .1605 L
.63871 .15992 L
.63966 .16031 L
.64062 .16101 L
.64157 .16281 L
.64252 .16423 L
Mistroke
.64348 .16667 L
.64443 .16738 L
.64538 .16873 L
.64634 .17053 L
.64729 .17207 L
.64824 .17298 L
.6492 .17388 L
.65015 .17285 L
.6511 .17233 L
.65206 .17233 L
.65301 .17349 L
.65396 .17381 L
.65492 .17413 L
.65587 .17317 L
.65682 .17304 L
.65778 .17285 L
.65873 .17381 L
.65968 .17465 L
.66064 .1749 L
.66159 .17529 L
.66254 .17593 L
.6635 .17651 L
.66445 .17851 L
.6654 .17941 L
.66636 .18031 L
.66731 .18005 L
.66826 .18005 L
.66922 .17902 L
.67017 .17883 L
.67112 .17844 L
.67208 .17812 L
.67303 .17754 L
.67398 .17741 L
.67494 .17471 L
.67589 .17098 L
.67684 .16751 L
.6778 .16359 L
.67875 .15799 L
.6797 .15433 L
.68066 .15008 L
.68161 .14597 L
.68256 .14243 L
.68352 .13844 L
.68447 .1342 L
.68542 .12982 L
.68638 .12237 L
.68733 .11555 L
.68828 .1077 L
.68924 .10269 L
.69019 .10018 L
Mistroke
.69114 .09761 L
.6921 .09497 L
.69305 .09343 L
.694 .09015 L
.69496 .08667 L
.69591 .08275 L
.69686 .07774 L
.69782 .07362 L
.69877 .06963 L
.69972 .06462 L
.70068 .06282 L
.70163 .05954 L
.70258 .05703 L
.70354 .05446 L
.70449 .05098 L
.70544 .04783 L
.7064 .04513 L
.70735 .04256 L
.7083 .0405 L
.70926 .03864 L
.71021 .03825 L
.71116 .03787 L
.71212 .03748 L
.71307 .03754 L
.71402 .03883 L
.71498 .03928 L
.71593 .04044 L
.71688 .04063 L
.71784 .04108 L
.71879 .04095 L
.71974 .04153 L
.7207 .04224 L
.72165 .04256 L
.7226 .04262 L
.72356 .0425 L
.72451 .04095 L
.72546 .04005 L
.72642 .03819 L
.72737 .03561 L
.72832 .03285 L
.72928 .02989 L
.73023 .02777 L
.73118 .02616 L
.73214 .02488 L
.73309 .02398 L
.73404 .02153 L
.735 .01902 L
.73595 .01671 L
.7369 .01472 L
.73786 .01529 L
Mistroke
.73881 .01671 L
.73976 .01825 L
.74072 .02025 L
.74167 .02295 L
.74262 .0252 L
.74358 .02796 L
.74453 .0306 L
.74548 .03227 L
.74644 .03381 L
.74739 .03626 L
.74834 .03851 L
.7493 .04095 L
.75025 .04327 L
.7512 .04455 L
.75216 .04391 L
.75311 .0432 L
.75406 .04108 L
.75502 .0396 L
.75597 .03799 L
.75692 .0369 L
.75788 .03671 L
.75883 .03561 L
.75978 .03587 L
.76074 .03664 L
.76169 .03709 L
.76264 .03928 L
.7636 .04095 L
.76455 .04295 L
.7655 .04526 L
.76646 .0486 L
.76741 .05182 L
.76836 .05587 L
.76932 .05928 L
.77027 .06217 L
.77122 .0661 L
.77218 .06848 L
.77313 .07098 L
.77408 .07388 L
.77504 .076 L
.77599 .07748 L
.77694 .07793 L
.7779 .07902 L
.77885 .08031 L
.7798 .08269 L
.78076 .08385 L
.78171 .08552 L
.78266 .08693 L
.78362 .08912 L
.78457 .09085 L
.78552 .09156 L
Mistroke
.78648 .09349 L
.78743 .09658 L
.78838 .09915 L
.78934 .10134 L
.79029 .10307 L
.79124 .10436 L
.7922 .10442 L
.79315 .10397 L
.7941 .10333 L
.79506 .10352 L
.79601 .10301 L
.79696 .10282 L
.79792 .10185 L
.79887 .10204 L
.79982 .10217 L
.80078 .10172 L
.80173 .10031 L
.80268 .09851 L
.80364 .09741 L
.80459 .09696 L
.80554 .09729 L
.8065 .10031 L
.80745 .10391 L
.8084 .10667 L
.80936 .10835 L
.81031 .11008 L
.81126 .11175 L
.81222 .1133 L
.81317 .11471 L
.81412 .11587 L
.81508 .11651 L
.81603 .11812 L
.81698 .11941 L
.81794 .12108 L
.81889 .12256 L
.81984 .12429 L
.8208 .1241 L
.82175 .12391 L
.8227 .12462 L
.82366 .12629 L
.82461 .12867 L
.82556 .13118 L
.82652 .13465 L
.82747 .13773 L
.82842 .14153 L
.82938 .14564 L
.83033 .14976 L
.83128 .15478 L
.83224 .15973 L
.83319 .16462 L
Mistroke
.83414 .16757 L
.8351 .17233 L
.83605 .17754 L
.837 .18204 L
.83796 .18571 L
.83891 .18899 L
.83986 .19233 L
.84082 .1949 L
.84177 .1976 L
.84272 .19896 L
.84368 .20127 L
.84463 .20294 L
.84558 .20481 L
.84654 .2059 L
.84749 .20674 L
.84844 .20802 L
.8494 .20751 L
.85035 .20603 L
.8513 .20558 L
.85226 .20391 L
.85321 .20198 L
.85416 .19992 L
.85512 .19857 L
.85607 .19703 L
.85702 .19638 L
.85798 .19568 L
.85893 .19433 L
.85988 .19227 L
.86084 .19079 L
.86179 .19008 L
.86274 .18957 L
.8637 .18976 L
.86465 .19079 L
.8656 .19175 L
.86656 .1949 L
.86751 .19703 L
.86846 .19863 L
.86942 .19966 L
.87037 .19966 L
.87132 .19883 L
.87228 .1969 L
.87323 .19542 L
.87418 .19323 L
.87514 .18982 L
.87609 .18629 L
.87704 .18307 L
.878 .17921 L
.87895 .17394 L
.8799 .16732 L
.88086 .1578 L
Mistroke
.88181 .14867 L
.88276 .14005 L
.88372 .13143 L
.88467 .12339 L
.88562 .11716 L
.88658 .11182 L
.88753 .1068 L
.88848 .10198 L
.88944 .09684 L
.89039 .09176 L
.89134 .0861 L
.8923 .0796 L
.89325 .07298 L
.8942 .06899 L
.89516 .06925 L
.89611 .06957 L
.89706 .06995 L
.89802 .06918 L
.89897 .06912 L
.89992 .06848 L
.90088 .06745 L
.90183 .0661 L
.90278 .067 L
.90374 .06931 L
.90469 .07201 L
.90564 .07581 L
.9066 .07889 L
.90755 .08275 L
.9085 .0852 L
.90946 .08667 L
.91041 .08912 L
.91136 .09118 L
.91232 .09375 L
.91327 .09536 L
.91422 .09735 L
.91518 .09889 L
.91613 .09992 L
.91708 .10037 L
.91804 .10198 L
.91899 .10237 L
.91994 .10211 L
.9209 .10359 L
.92185 .10558 L
.9228 .10783 L
.92376 .10687 L
.92471 .10436 L
.92566 .10082 L
.92662 .09748 L
.92757 .09452 L
.92852 .09092 L
Mistroke
.92948 .08854 L
.93043 .08905 L
.93138 .0897 L
.93234 .08905 L
.93329 .08828 L
.93424 .08893 L
.9352 .08905 L
.93615 .08822 L
.9371 .08642 L
.93806 .08693 L
.93901 .08796 L
.93996 .09118 L
.94092 .09536 L
.94187 .09979 L
.94282 .10417 L
.94378 .10712 L
.94473 .10822 L
.94568 .10957 L
.94664 .11227 L
.94759 .11497 L
.94854 .11748 L
.9495 .11979 L
.95045 .12339 L
.9514 .1279 L
.95236 .13111 L
.95331 .13555 L
.95426 .13831 L
.95522 .14114 L
.95617 .14404 L
.95712 .14635 L
.95808 .14989 L
.95903 .15362 L
.95998 .15587 L
.96094 .1551 L
.96189 .15535 L
.96284 .15529 L
.9638 .15542 L
.96475 .15581 L
.9657 .15484 L
.96666 .15413 L
.96761 .15278 L
.96856 .15323 L
.96952 .15265 L
.97047 .15278 L
.97142 .15355 L
.97238 .15381 L
.97333 .15317 L
.97428 .15265 L
.97524 .15362 L
.97619 .15388 L
Mistroke
Mfstroke
.02381 .23836 m
.02476 .23687 L
.02572 .23607 L
.02667 .23502 L
.02762 .23418 L
.02858 .23355 L
.02953 .23336 L
.03048 .23333 L
.03144 .23409 L
.03239 .23472 L
.03334 .2354 L
.0343 .23624 L
.03525 .23719 L
.0362 .23841 L
.03716 .23975 L
.03811 .24146 L
.03906 .24295 L
.04002 .24432 L
.04097 .24554 L
.04192 .24684 L
.04288 .24793 L
.04383 .24935 L
.04478 .25112 L
.04574 .25277 L
.04669 .25436 L
.04764 .25575 L
.0486 .25755 L
.04955 .25962 L
.0505 .26172 L
.05146 .26357 L
.05241 .26524 L
.05336 .26677 L
.05432 .26834 L
.05527 .2704 L
.05622 .27236 L
.05718 .27413 L
.05813 .27603 L
.05908 .27808 L
.06004 .27996 L
.06099 .28208 L
.06194 .28416 L
.0629 .28598 L
.06385 .28807 L
.0648 .29004 L
.06576 .29206 L
.06671 .29399 L
.06766 .29616 L
.06862 .29875 L
.06957 .30173 L
.07052 .30443 L
Mistroke
.07148 .30689 L
.07243 .3094 L
.07338 .31167 L
.07434 .31421 L
.07529 .3163 L
.07624 .3185 L
.0772 .32083 L
.07815 .323 L
.0791 .32532 L
.08006 .32747 L
.08101 .32999 L
.08196 .33262 L
.08292 .33531 L
.08387 .33842 L
.08482 .34142 L
.08578 .34451 L
.08673 .34811 L
.08768 .35126 L
.08864 .35448 L
.08959 .35738 L
.09054 .36061 L
.0915 .36401 L
.09245 .36794 L
.0934 .37243 L
.09436 .37675 L
.09531 .38118 L
.09626 .386 L
.09722 .39027 L
.09817 .3946 L
.09912 .39882 L
.10008 .40249 L
.10103 .40651 L
.10198 .41053 L
.10294 .4142 L
.10389 .41736 L
.10484 .42069 L
.1058 .42357 L
.10675 .42608 L
.1077 .42857 L
.10866 .43078 L
.10961 .43323 L
.11056 .43582 L
.11152 .4388 L
.11247 .44153 L
.11342 .44417 L
.11438 .44671 L
.11533 .44935 L
.11628 .45172 L
.11724 .45398 L
.11819 .45626 L
Mistroke
.11914 .45834 L
.1201 .45982 L
.12105 .46133 L
.122 .46286 L
.12296 .46494 L
.12391 .46726 L
.12486 .46961 L
.12582 .47195 L
.12677 .47416 L
.12772 .47652 L
.12868 .47914 L
.12963 .48195 L
.13058 .48452 L
.13154 .48706 L
.13249 .48924 L
.13344 .49105 L
.1344 .49304 L
.13535 .49481 L
.1363 .49675 L
.13726 .49849 L
.13821 .50035 L
.13916 .50205 L
.14012 .5035 L
.14107 .50497 L
.14202 .50636 L
.14298 .50813 L
.14393 .50975 L
.14488 .51149 L
.14584 .51288 L
.14679 .51439 L
.14774 .51562 L
.1487 .51672 L
.14965 .51824 L
.1506 .51973 L
.15156 .52151 L
.15251 .5232 L
.15346 .52472 L
.15442 .52605 L
.15537 .52691 L
.15632 .52787 L
.15728 .52893 L
.15823 .52955 L
.15918 .53059 L
.16014 .53187 L
.16109 .53365 L
.16204 .53531 L
.163 .53717 L
.16395 .53868 L
.1649 .54016 L
.16586 .54142 L
Mistroke
.16681 .54241 L
.16776 .54322 L
.16872 .54404 L
.16967 .54504 L
.17062 .54589 L
.17158 .54639 L
.17253 .54648 L
.17348 .54651 L
.17444 .54684 L
.17539 .54708 L
.17634 .54723 L
.1773 .54773 L
.17825 .54816 L
.1792 .54821 L
.18016 .54827 L
.18111 .54798 L
.18206 .54799 L
.18302 .54792 L
.18397 .54767 L
.18492 .54736 L
.18588 .54742 L
.18683 .54692 L
.18778 .5458 L
.18874 .54537 L
.18969 .54465 L
.19064 .54423 L
.1916 .54405 L
.19255 .54355 L
.1935 .54292 L
.19446 .54201 L
.19541 .54125 L
.19636 .54062 L
.19732 .54017 L
.19827 .5391 L
.19922 .53802 L
.20018 .53665 L
.20113 .53472 L
.20208 .53283 L
.20304 .531 L
.20399 .52893 L
.20494 .52663 L
.2059 .52364 L
.20685 .51734 L
.2078 .51218 L
.20876 .50795 L
.20971 .50314 L
.21066 .49846 L
.21162 .4928 L
.21257 .48746 L
.21352 .48237 L
Mistroke
.21448 .47746 L
.21543 .47276 L
.21638 .46839 L
.21734 .46399 L
.21829 .45966 L
.21924 .45579 L
.2202 .45161 L
.22115 .44717 L
.2221 .4426 L
.22306 .43828 L
.22401 .43424 L
.22496 .43005 L
.22592 .42583 L
.22687 .42156 L
.22782 .41734 L
.22878 .41275 L
.22973 .4081 L
.23068 .40327 L
.23164 .39831 L
.23259 .39302 L
.23354 .38731 L
.2345 .38087 L
.23545 .37449 L
.2364 .3679 L
.23736 .36107 L
.23831 .3544 L
.23926 .34768 L
.24022 .34118 L
.24117 .33494 L
.24212 .32866 L
.24308 .32272 L
.24403 .31746 L
.24498 .31226 L
.24594 .30717 L
.24689 .3023 L
.24784 .29764 L
.2488 .29318 L
.24975 .28881 L
.2507 .28487 L
.25166 .28102 L
.25261 .2767 L
.25356 .27206 L
.25452 .26743 L
.25547 .26311 L
.25642 .25942 L
.25738 .25571 L
.25833 .25237 L
.25928 .24958 L
.26024 .24537 L
.26119 .24162 L
Mistroke
.26214 .23744 L
.2631 .23333 L
.26405 .22954 L
.265 .2263 L
.26596 .2229 L
.26691 .21849 L
.26786 .21387 L
.26882 .20919 L
.26977 .20503 L
.27072 .20096 L
.27168 .19688 L
.27263 .19332 L
.27358 .18964 L
.27454 .1859 L
.27549 .18227 L
.27644 .17916 L
.2774 .17649 L
.27835 .17707 L
.2793 .17634 L
.28026 .1748 L
.28121 .17368 L
.28216 .17274 L
.28312 .17267 L
.28407 .17205 L
.28502 .17161 L
.28598 .17084 L
.28693 .16981 L
.28788 .16867 L
.28884 .16798 L
.28979 .16744 L
.29074 .16666 L
.2917 .16615 L
.29265 .1659 L
.2936 .16588 L
.29456 .16564 L
.29551 .16513 L
.29646 .1646 L
.29742 .16428 L
.29837 .16423 L
.29932 .16415 L
.30028 .16426 L
.30123 .16384 L
.30218 .16364 L
.30314 .16333 L
.30409 .16296 L
.30504 .16299 L
.306 .16342 L
.30695 .16373 L
.3079 .16406 L
.30886 .16474 L
Mistroke
.30981 .16514 L
.31076 .16517 L
.31172 .16471 L
.31267 .1641 L
.31362 .16357 L
.31458 .16306 L
.31553 .16229 L
.31648 .16141 L
.31744 .16024 L
.31839 .15964 L
.31934 .15881 L
.3203 .15813 L
.32125 .15763 L
.3222 .15703 L
.32316 .15664 L
.32411 .15619 L
.32506 .156 L
.32602 .15569 L
.32697 .15544 L
.32792 .15463 L
.32888 .15366 L
.32983 .15272 L
.33078 .15174 L
.33174 .15168 L
.33269 .15129 L
.33364 .15107 L
.3346 .15079 L
.33555 .15061 L
.3365 .15016 L
.33746 .1497 L
.33841 .14964 L
.33936 .14966 L
.34032 .14961 L
.34127 .14964 L
.34222 .14918 L
.34318 .14886 L
.34413 .14862 L
.34508 .1484 L
.34604 .14817 L
.34699 .14805 L
.34794 .14811 L
.3489 .14817 L
.34985 .14818 L
.3508 .14831 L
.35176 .14838 L
.35271 .14829 L
.35366 .14792 L
.35462 .14805 L
.35557 .14817 L
.35652 .14805 L
Mistroke
.35748 .1481 L
.35843 .14829 L
.35938 .14833 L
.36034 .14847 L
.36129 .14847 L
.36224 .14846 L
.3632 .14872 L
.36415 .14903 L
.3651 .14917 L
.36606 .14918 L
.36701 .14921 L
.36796 .14927 L
.36892 .14962 L
.36987 .15021 L
.37082 .15105 L
.37178 .15192 L
.37273 .15308 L
.37368 .15426 L
.37464 .15544 L
.37559 .15682 L
.37654 .15799 L
.3775 .15947 L
.37845 .16077 L
.3794 .1622 L
.38036 .16356 L
.38131 .16512 L
.38226 .16671 L
.38322 .16859 L
.38417 .1703 L
.38512 .17232 L
.38608 .17438 L
.38703 .17606 L
.38798 .17776 L
.38894 .17923 L
.38989 .18031 L
.39084 .18166 L
.3918 .18279 L
.39275 .18359 L
.3937 .18463 L
.39466 .18562 L
.39561 .18715 L
.39656 .18834 L
.39752 .18955 L
.39847 .1907 L
.39942 .19183 L
.40038 .19294 L
.40133 .19375 L
.40228 .19426 L
.40324 .19475 L
.40419 .19516 L
Mistroke
.40514 .19537 L
.4061 .19561 L
.40705 .19566 L
.408 .19566 L
.40896 .19561 L
.40991 .19556 L
.41086 .1956 L
.41182 .19583 L
.41277 .19591 L
.41372 .19627 L
.41468 .19674 L
.41563 .197 L
.41658 .19699 L
.41754 .197 L
.41849 .19753 L
.41944 .19777 L
.4204 .198 L
.42135 .19835 L
.4223 .19888 L
.42326 .19941 L
.42421 .2001 L
.42516 .20078 L
.42612 .20091 L
.42707 .20103 L
.42802 .20104 L
.42898 .20099 L
.42993 .20087 L
.43088 .20069 L
.43184 .20031 L
.43279 .19998 L
.43374 .1997 L
.4347 .19938 L
.43565 .19903 L
.4366 .19867 L
.43756 .19844 L
.43851 .19813 L
.43946 .1978 L
.44042 .19715 L
.44137 .19643 L
.44232 .19544 L
.44328 .19479 L
.44423 .19402 L
.44518 .19315 L
.44614 .19241 L
.44709 .19177 L
.44804 .19153 L
.449 .19083 L
.44995 .19062 L
.4509 .19029 L
.45186 .18995 L
Mistroke
.45281 .18955 L
.45376 .18918 L
.45472 .18867 L
.45567 .18825 L
.45662 .18796 L
.45758 .18784 L
.45853 .18773 L
.45948 .18755 L
.46044 .18739 L
.46139 .18729 L
.46234 .18702 L
.4633 .18674 L
.46425 .1866 L
.4652 .18586 L
.46616 .18497 L
.46711 .18407 L
.46806 .18302 L
.46902 .18197 L
.46997 .18109 L
.47092 .18024 L
.47188 .17961 L
.47283 .17924 L
.47378 .17894 L
.47474 .17893 L
.47569 .17907 L
.47664 .17942 L
.4776 .17968 L
.47855 .18015 L
.4795 .18079 L
.48046 .18176 L
.48141 .18281 L
.48236 .18369 L
.48332 .18447 L
.48427 .18539 L
.48522 .18626 L
.48618 .18699 L
.48713 .18783 L
.48808 .18883 L
.48904 .19012 L
.48999 .19107 L
.49094 .19211 L
.4919 .19322 L
.49285 .19438 L
.4938 .19528 L
.49476 .19619 L
.49571 .19704 L
.49666 .19778 L
.49762 .19853 L
.49857 .19938 L
.49952 .20036 L
Mistroke
.50048 .2013 L
.50143 .2022 L
.50238 .20314 L
.50334 .2041 L
.50429 .20522 L
.50524 .20626 L
.5062 .20733 L
.50715 .2082 L
.5081 .20919 L
.50906 .21016 L
.51001 .2111 L
.51096 .21197 L
.51192 .21303 L
.51287 .21377 L
.51382 .21479 L
.51478 .21562 L
.51573 .21678 L
.51668 .21802 L
.51764 .21903 L
.51859 .21978 L
.51954 .22013 L
.5205 .22056 L
.52145 .22085 L
.5224 .22112 L
.52336 .22145 L
.52431 .22167 L
.52526 .22212 L
.52622 .22258 L
.52717 .22322 L
.52812 .22356 L
.52908 .22369 L
.53003 .22396 L
.53098 .22407 L
.53194 .2244 L
.53289 .2246 L
.53384 .22479 L
.5348 .22496 L
.53575 .22497 L
.5367 .22537 L
.53766 .22576 L
.53861 .22617 L
.53956 .22662 L
.54052 .22704 L
.54147 .22734 L
.54242 .22761 L
.54338 .2278 L
.54433 .22779 L
.54528 .22789 L
.54624 .22782 L
.54719 .22711 L
Mistroke
.54814 .22618 L
.5491 .22535 L
.55005 .22432 L
.551 .22316 L
.55196 .22193 L
.55291 .22079 L
.55386 .21979 L
.55482 .21859 L
.55577 .21742 L
.55672 .21616 L
.55768 .21479 L
.55863 .21342 L
.55958 .21206 L
.56054 .21072 L
.56149 .20936 L
.56244 .20814 L
.5634 .20697 L
.56435 .20551 L
.5653 .20425 L
.56626 .20311 L
.56721 .20205 L
.56816 .20108 L
.56912 .20019 L
.57007 .19926 L
.57102 .19836 L
.57198 .1976 L
.57293 .19683 L
.57388 .19616 L
.57484 .19533 L
.57579 .19433 L
.57674 .19319 L
.5777 .19188 L
.57865 .19052 L
.5796 .18891 L
.58056 .18739 L
.58151 .18597 L
.58246 .18465 L
.58342 .1831 L
.58437 .18181 L
.58532 .18045 L
.58628 .17885 L
.58723 .17708 L
.58818 .17516 L
.58914 .17326 L
.59009 .17135 L
.59104 .16948 L
.592 .16774 L
.59295 .16589 L
.5939 .16409 L
.59486 .16222 L
Mistroke
.59581 .16064 L
.59676 .15899 L
.59772 .15749 L
.59867 .15564 L
.59962 .15397 L
.60058 .15235 L
.60153 .15067 L
.60248 .14913 L
.60344 .14764 L
.60439 .1466 L
.60534 .14544 L
.6063 .14419 L
.60725 .14312 L
.6082 .14208 L
.60916 .14091 L
.61011 .1397 L
.61106 .1386 L
.61202 .1377 L
.61297 .13701 L
.61392 .13662 L
.61488 .1361 L
.61583 .13545 L
.61678 .13492 L
.61774 .13431 L
.61869 .13426 L
.61964 .13448 L
.6206 .13469 L
.62155 .13524 L
.6225 .13568 L
.62346 .13615 L
.62441 .13665 L
.62536 .13718 L
.62632 .13793 L
.62727 .13851 L
.62822 .13911 L
.62918 .13969 L
.63013 .14035 L
.63108 .14091 L
.63204 .14122 L
.63299 .14148 L
.63394 .14167 L
.6349 .1419 L
.63585 .14249 L
.6368 .14288 L
.63776 .14315 L
.63871 .14323 L
.63966 .14355 L
.64062 .14406 L
.64157 .14455 L
.64252 .14492 L
Mistroke
.64348 .14523 L
.64443 .14534 L
.64538 .14549 L
.64634 .14571 L
.64729 .14593 L
.64824 .14617 L
.6492 .14654 L
.65015 .14679 L
.6511 .14723 L
.65206 .14769 L
.65301 .14833 L
.65396 .149 L
.65492 .14991 L
.65587 .15049 L
.65682 .15092 L
.65778 .15151 L
.65873 .15211 L
.65968 .15271 L
.66064 .15328 L
.66159 .15394 L
.66254 .15461 L
.6635 .15528 L
.66445 .15602 L
.6654 .15663 L
.66636 .1574 L
.66731 .158 L
.66826 .15863 L
.66922 .15924 L
.67017 .15996 L
.67112 .16063 L
.67208 .16135 L
.67303 .16207 L
.67398 .16301 L
.67494 .16328 L
.67589 .16307 L
.67684 .16296 L
.6778 .16288 L
.67875 .16252 L
.6797 .1623 L
.68066 .16209 L
.68161 .16186 L
.68256 .16188 L
.68352 .16161 L
.68447 .16117 L
.68542 .16047 L
.68638 .15925 L
.68733 .15838 L
.68828 .15739 L
.68924 .15631 L
.69019 .1555 L
Mistroke
.69114 .15474 L
.6921 .15385 L
.69305 .15265 L
.694 .15142 L
.69496 .14998 L
.69591 .14844 L
.69686 .14687 L
.69782 .14525 L
.69877 .14373 L
.69972 .14203 L
.70068 .14056 L
.70163 .13876 L
.70258 .1371 L
.70354 .13546 L
.70449 .1339 L
.70544 .13237 L
.7064 .13082 L
.70735 .12907 L
.7083 .12734 L
.70926 .12561 L
.71021 .1241 L
.71116 .12238 L
.71212 .12054 L
.71307 .11867 L
.71402 .11695 L
.71498 .11509 L
.71593 .11338 L
.71688 .11148 L
.71784 .10957 L
.71879 .10768 L
.71974 .10608 L
.7207 .10449 L
.72165 .10301 L
.7226 .1014 L
.72356 .09964 L
.72451 .09759 L
.72546 .09563 L
.72642 .09335 L
.72737 .09116 L
.72832 .08891 L
.72928 .08649 L
.73023 .08417 L
.73118 .08179 L
.73214 .07956 L
.73309 .07741 L
.73404 .0752 L
.735 .07299 L
.73595 .07065 L
.7369 .06846 L
.73786 .06664 L
Mistroke
.73881 .06493 L
.73976 .06327 L
.74072 .0616 L
.74167 .05999 L
.74262 .05826 L
.74358 .05646 L
.74453 .05478 L
.74548 .05276 L
.74644 .05138 L
.74739 .05047 L
.74834 .0494 L
.7493 .04846 L
.75025 .0477 L
.7512 .04651 L
.75216 .0454 L
.75311 .04437 L
.75406 .043 L
.75502 .04183 L
.75597 .04075 L
.75692 .03968 L
.75788 .03933 L
.75883 .03879 L
.75978 .03839 L
.76074 .03817 L
.76169 .03785 L
.76264 .03774 L
.7636 .03766 L
.76455 .03761 L
.7655 .03753 L
.76646 .03779 L
.76741 .03819 L
.76836 .03862 L
.76932 .03896 L
.77027 .03925 L
.77122 .03997 L
.77218 .04046 L
.77313 .04108 L
.77408 .04176 L
.77504 .04248 L
.77599 .04315 L
.77694 .04376 L
.7779 .04444 L
.77885 .04516 L
.7798 .04597 L
.78076 .04683 L
.78171 .04764 L
.78266 .04844 L
.78362 .04929 L
.78457 .04992 L
.78552 .05052 L
Mistroke
.78648 .05131 L
.78743 .05231 L
.78838 .05347 L
.78934 .05453 L
.79029 .05558 L
.79124 .05632 L
.7922 .05687 L
.79315 .05744 L
.7941 .05811 L
.79506 .05904 L
.79601 .06005 L
.79696 .06099 L
.79792 .06202 L
.79887 .0632 L
.79982 .06439 L
.80078 .06567 L
.80173 .06682 L
.80268 .06794 L
.80364 .06904 L
.80459 .07017 L
.80554 .07147 L
.8065 .07313 L
.80745 .07488 L
.8084 .0765 L
.80936 .07765 L
.81031 .07873 L
.81126 .07969 L
.81222 .08063 L
.81317 .08156 L
.81412 .08252 L
.81508 .08338 L
.81603 .08432 L
.81698 .08536 L
.81794 .08649 L
.81889 .08743 L
.81984 .08863 L
.8208 .08976 L
.82175 .09101 L
.8227 .09251 L
.82366 .09412 L
.82461 .09582 L
.82556 .09771 L
.82652 .09964 L
.82747 .1015 L
.82842 .10345 L
.82938 .10517 L
.83033 .10715 L
.83128 .10914 L
.83224 .11111 L
.83319 .11294 L
Mistroke
.83414 .11429 L
.8351 .11604 L
.83605 .11793 L
.837 .11987 L
.83796 .12154 L
.83891 .12325 L
.83986 .125 L
.84082 .12676 L
.84177 .12859 L
.84272 .13002 L
.84368 .13173 L
.84463 .13354 L
.84558 .13533 L
.84654 .13709 L
.84749 .13879 L
.84844 .14031 L
.8494 .14173 L
.85035 .14307 L
.8513 .14445 L
.85226 .14555 L
.85321 .14654 L
.85416 .1476 L
.85512 .14865 L
.85607 .14982 L
.85702 .15098 L
.85798 .15217 L
.85893 .15309 L
.85988 .15395 L
.86084 .15498 L
.86179 .15619 L
.86274 .15735 L
.8637 .1588 L
.86465 .16044 L
.8656 .16213 L
.86656 .16383 L
.86751 .16535 L
.86846 .16676 L
.86942 .16822 L
.87037 .16935 L
.87132 .17031 L
.87228 .1712 L
.87323 .17211 L
.87418 .1729 L
.87514 .17346 L
.87609 .17406 L
.87704 .17451 L
.878 .17458 L
.87895 .17444 L
.8799 .17426 L
.88086 .17372 L
Mistroke
.88181 .17307 L
.88276 .17242 L
.88372 .17184 L
.88467 .17108 L
.88562 .17057 L
.88658 .17026 L
.88753 .16985 L
.88848 .16941 L
.88944 .16862 L
.89039 .16789 L
.89134 .16687 L
.8923 .16568 L
.89325 .16426 L
.8942 .16314 L
.89516 .16231 L
.89611 .16125 L
.89706 .16018 L
.89802 .15875 L
.89897 .15736 L
.89992 .15596 L
.90088 .15462 L
.90183 .15312 L
.90278 .15186 L
.90374 .15053 L
.90469 .14937 L
.90564 .14851 L
.9066 .147 L
.90755 .1453 L
.9085 .14377 L
.90946 .14251 L
.91041 .14127 L
.91136 .13995 L
.91232 .13852 L
.91327 .13691 L
.91422 .13564 L
.91518 .13415 L
.91613 .13251 L
.91708 .13097 L
.91804 .12975 L
.91899 .1285 L
.91994 .12733 L
.9209 .12621 L
.92185 .12521 L
.9228 .12422 L
.92376 .1231 L
.92471 .12175 L
.92566 .12013 L
.92662 .1183 L
.92757 .11641 L
.92852 .11455 L
Mistroke
.92948 .11272 L
.93043 .11146 L
.93138 .11046 L
.93234 .1094 L
.93329 .10814 L
.93424 .1072 L
.9352 .10607 L
.93615 .10469 L
.9371 .10315 L
.93806 .1015 L
.93901 .09993 L
.93996 .09864 L
.94092 .09744 L
.94187 .09644 L
.94282 .09561 L
.94378 .09476 L
.94473 .09402 L
.94568 .09372 L
.94664 .09389 L
.94759 .09388 L
.94854 .09408 L
.9495 .09419 L
.95045 .09458 L
.9514 .09527 L
.95236 .09617 L
.95331 .09731 L
.95426 .09829 L
.95522 .09938 L
.95617 .10057 L
.95712 .10145 L
.95808 .10238 L
.95903 .10338 L
.95998 .1045 L
.96094 .10554 L
.96189 .1066 L
.96284 .10792 L
.9638 .10935 L
.96475 .11115 L
.9657 .11244 L
.96666 .11314 L
.96761 .11395 L
.96856 .11494 L
.96952 .11608 L
.97047 .1173 L
.97142 .11847 L
.97238 .11965 L
.97333 .1208 L
.97428 .12163 L
.97524 .1224 L
.97619 .12297 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[79]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`006_oo00<00?ooool0:Ooo0`000ooo00<00?ooool00_oo00<00?ooool09?oo0`00
0_oo00<00?ooool00_oo00<00?ooool09?oo0P001?oo00<00?ooool00_oo00<00?ooool09?oo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool08Ooo1@000_oo00<00?ooool00_oo00<00?ooool0
0_oo00<00?ooool00ooo000Iool00`00ool0000Zool00`00ooooo`02ool00`00ool00002ool00`00
ool0000Vool01P00ooooo`00ool000;oo`03003oo`0002Goo`03003oo`0000;oo`03003oo`0000;o
o`03003oo`0002Coo`03003oo`0000;oo`03003oo`0000;oo`03003oo`0002Coo`07003oooooool0
0?oo00000_oo00<00?oo00000_oo00<00?oo00001?oo000Iool00`00ool0000[ool01`00oooooooo
003oo`0000;oo`03003oo`0002Coo`@00004ool00?oo0002ool00`00ool0000Uool00`00ool00002
ool00`00ool00002ool00`00ool0000Tool00`00ool00002ool00`00ool00002ool00`00ool0000T
ool01`00oooooooo003oo`0000;oo`03003oo`0000;oo`03003oo`0000Coo`006Ooo00<00?oo0000
:ooo00L00?ooooooo`00ool00002ool00`00ool0000Tool00`00ool00002ool00`00ool00002ool0
0`00ool0000Uool20003ool00`00ool00002ool00`00ool0000Uool01`00oooooooo003oo`0000;o
o`03003oo`0002Coo`07003oooooool00?oo00000_oo00<00?oo00000_oo00<00?oo00001?oo000I
ool00`00ool0000Zool00`00ool00002ool00`00ool00002ool00`00ool0000Uool20002ool00`00
ool00002ool00`00ool0000Uool00`00ooooo`02ool00`00ool00002ool00`00ool0000Tool00`00
ool00002ool00`00ool00002ool00`00ool0000Tool01`00oooooooo003oo`0000;oo`03003oo`00
00;oo`03003oo`0000Coo`006_oo00<00?ooool0:_oo00<00?ooool00_oo00<00?ooool00_oo00<0
0?ooool09Ooo00D00?ooooooo`0000Coo`03003ooooo02Goo`8000?oo`03003ooooo00;oo`03003o
oooo02Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo02;oo`8000Coo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00?oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool001Goool000H000Koo`005Ooo00<00?ooool00ooo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool00ooo00<00?ooool01?oo
000Eool00`00ooooo`3oool2ool00`00ooooo`04ool001Goo`800?ooo`;oo`8000Koo`005Ooo00<0
0?ooool0_?oo0P00@ooo00<00?ooool01?oo000Eool00`00ooooo`2lool20013ool00`00ooooo`04
ool001Goo`03003ooooo0;_oo`04003ooooo0012ool00`00ooooo`04ool001Goo`03003ooooo0;_o
o`04003ooooo0012ool00`00ooooo`04ool001Goo`03003ooooo0;[oo`04003oooooool20011ool0
0`00ooooo`04ool001Goo`03003ooooo0;[oo`03003ooooo00;oo`03003ooooo008003goo`03003o
oooo00Coo`005Ooo00<00?ooool0]Ooo1P001?oo1`00>ooo00<00?ooool01?oo0003ool50002ool0
0`00ooooo`02ool00`00ooooo`03ool00`00ooooo`2eool00`00ool000020006ool200001?oo003o
oooo0P00>Ooo00<00?ooool01?oo0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Coo`03
003ooooo0;Coo`03003ooooo00Woo`05003oooooool00002ool2000hool00`00ooooo`04ool000Go
o`07003oooooool00?oo00000_oo00<00?oo00001?oo0P00]Ooo00<00?ooool02?oo00<00?ooool0
0_oo00@00?ooooooo`8003Goo`<000Koo`001Ooo00L00?ooooooo`00ool00002ool00`00ool00004
ool00`00ooooo`2dool00`00ooooo`07ool20004ool00`00ooooo`03ool00`00ooooo`0dool00`00
ooooo`04ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo00<00?ooool0/ooo00<0
0?ooool02?oo00<00?ooool01?oo00<00?ooool00ooo0P00=?oo00<00?ooool01?oo0004ool20004
ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`2cool00`00ooooo`07ool00`00ooooo`05
ool00`00ooooo`04ool00`00ooooo`0bool00`00ooooo`04ool001Goo`03003ooooo0;?oo`03003o
oooo00Ooo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo01Ooo`03003ooooo01Ooo`03003o
oooo00Coo`005Ooo00<00?ooool0/_oo00<00?ooool01ooo00<00?ooool01_oo0P001ooo00<00?oo
ool05?oo10006?oo00<00?ooool01?oo000Eool00`00ooooo`2bool00`00ooooo`07ool00`00oooo
o`07ool00`00ooooo`05ool2000Eool01000ooooo`006?oo00<00?ooool01?oo000Eool00`00oooo
o`2bool00`00ooooo`06ool00`00ooooo`08ool20007ool00`00ooooo`0Cool01000ooooo`006?oo
00<00?ooool01?oo000Eool00`00ooooo`2bool00`00ooooo`06ool00`00ooooo`09ool00`00oooo
o`06ool00`00ooooo`0Bool01@00oooooooo00005ooo00<00?ooool01?oo000Eool00`00ooooo`2a
ool00`00ooooo`06ool2000<ool00`00ooooo`06ool00`00ooooo`0@ool00`00ooooo`02ool00`00
ooooo`04ool2000?ool00`00ooooo`04ool001Goo`800;;oo`03003ooooo00Koo`03003ooooo00_o
o`8000Soo`03003ooooo00ooo`03003ooooo00;oo`03003ooooo00;oo`@000koo`8000Koo`005Ooo
00<00?ooool0/Ooo00<00?ooool01_oo00<00?ooool03?oo00<00?ooool01ooo00<00?ooool03_oo
00<00?ooool00ooo00D00?ooooooo`0000;oo`@000coo`03003ooooo00Coo`005Ooo00<00?ooool0
/?oo0P001ooo00<00?ooool03Ooo00@00?ooooooo`8000Coo`03003ooooo00koo`03003ooooo00?o
o`05003oooooool00002ool200000ooo0000000;ool00`00ooooo`04ool001Goo`03003ooooo0;3o
o`03003ooooo00Koo`03003ooooo00koo`03003oo`00008000Goo`03003ooooo00goo`03003ooooo
00Coo`<000?oo`8000;oo`8000[oo`03003ooooo00Coo`005Ooo00<00?ooool0/?oo00<00?ooool0
1Ooo00<00?ooool03ooo0`000_oo00<00?ooool00_oo00<00?ooool03?oo00<00?ooool01_oo0P00
0_oo00<00?oo00000ooo0P002Ooo00<00?ooool01?oo000Eool00`00ooooo`2`ool00`00ooooo`04
ool2000Fool00`00ooooo`03ool00`00ooooo`0;ool00`00ooooo`07ool01@00ool00000ool00P00
0ooo00<00?ooool01ooo00<00?ooool01?oo000Eool00`00ooooo`2_ool00`00ooooo`05ool00`00
ooooo`0Fool00`00ooooo`02ool00`00ooooo`0;ool00`00ooooo`08ool20003ool00`00ooooo`02
ool00`00ooooo`06ool00`00ooooo`04ool001Goo`03003ooooo0:ooo`03003ooooo00Coo`8001So
o`8000Coo`03003ooooo00[oo`03003ooooo00Soo`03003ooooo00;oo`03003ooooo00?oo`03003o
oooo00Goo`03003ooooo00Coo`005Ooo00<00?ooool0[ooo00<00?ooool01?oo00<00?ooool06?oo
00<00?ooool00_oo0P002ooo00<00?ooool01ooo0P001Ooo00<00?ooool00_oo0P001_oo00<00?oo
ool01?oo000Eool00`00ooooo`1@ool20007ool00`00ooooo`0bool30009ool2000Cool00`00oooo
o`03ool2000Kool20003ool00`00ooooo`09ool00`00ooooo`06ool20006ool00`00ooooo`03ool2
0005ool00`00ooooo`04ool001Goo`80057oo`8000Koo`8003Coo`03003oo`0000Soo`@001;oo`03
003ooooo00?oo`03003ooooo01_oo`04003oooooool20009ool00`00ooooo`07ool00`00ooooo`05
ool00`00ooooo`09ool20006ool001Goo`03003ooooo04ooo`<000Koo`<003?oo`04003ooooo0005
ool30002ool2000Aool00`00ooooo`02ool00`00ooooo`0Lool00`00ooooo`02ool00`00ooooo`07
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`04ool001Goo`03003o
oooo04Koo`<000Koo`04003ooooo0004ool200000ooo003oo`0bool01000ooooo`001?oo00<00?oo
ool00ooo10003ooo00@00?ooooooo`8001ooo`04003oooooool20008ool00`00ooooo`05ool20009
ool00`00ooooo`09ool00`00ooooo`04ool001Goo`03003ooooo04Goo`04003ooooo0006ool01000
ooooo`001?oo00@00?ooool003?oo`04003ooooo0003ool20004ool400000ooo0000000<ool00`00
ooooo`02ool00`00ooooo`0Nool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`05ool00`00
ooooo`08ool00`00ooooo`09ool00`00ooooo`04ool001Goo`03003ooooo04Goo`04003ooooo0006
ool01000ooooo`000ooo0P000ooo00<00?ooool0;ooo00<00?ooool00_oo00@00?oo000000Coo`80
00;oo`800003ool00000008000Woo`04003oooooool2000Pool00`00ooooo`03ool00`00ooooo`05
ool00`00ooooo`04ool00`00ooooo`09ool00`00ooooo`09ool00`00ooooo`04ool001Goo`03003o
oooo03coo`8000Ooo`05003oooooool00004ool01000oooooooo0P000_oo1P003_oo0P008Ooo00<0
0?ooool00_oo00<00?oo00001Ooo00<00?ooool00_oo00<00?ooool00_oo0`001ooo00D00?oooooo
o`00027oo`03003ooooo00?oo`8000Koo`03003ooooo00?oo`8000coo`03003ooooo00Soo`03003o
oooo00Coo`005Ooo00<00?ooool0??oo0P001ooo00D00?ooooooo`0000Coo`03003ooooo00;oo`@0
00Coo`<000coo`<0023oo`03003ooooo00;oo`<000Coo`03003ooooo00?oo`03003ooooo00Goo`80
00Goo`04003ooooo000Sool00`00ooooo`03ool20005ool00`00ooooo`02ool2000=ool00`00oooo
o`08ool00`00ooooo`04ool001Goo`03003ooooo03_oo`04003ooooo0005ool20003ool00`00oooo
o`02ool00`00ooooo`050005ool01000ooooo`002_oo00<00?ooool00`007_oo00<00?ooool02?oo
0P001Ooo0P001ooo0P000ooo00<00?ooool00P008ooo00<00?ooool01?oo0P001?oo00<00?ooool0
0_oo00<00?ooool03?oo1P001Ooo00<00?ooool01?oo000Eool00`00ooooo`0kool01000ooooo`00
1Ooo00<00?ooool00_oo00<00?ooool00_oo10000_oo00<00?ooool01Ooo00@00?oo000000Woo`03
003ooooo00;oo`8001goo`03003ooooo00Soo`03003ooooo00Goo`@000Koo`800003ool00?oo0080
02Coo`03003ooooo00Goo`03003ooooo00;oo`05003oooooool0000Jool00`00ooooo`04ool001Go
o`03003ooooo03_oo`04003ooooo0005ool00`00ooooo`03ool6000<ool00`00ooooo`020008ool0
0`00ooooo`04ool00`00ooooo`0Iool00`00ooooo`08ool20009ool30006ool5000Uool00`00oooo
o`06ool01000ooooo`000ooo0P006_oo00<00?ooool01?oo000Eool00`00ooooo`0kool01000oooo
o`001Ooo00@00?ooooooo`@00003ool0000000goo`05003oooooool00008ool00`00ooooo`04ool0
0`00ooooo`0Iool00`00ooooo`08ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`0Uool2
0007ool01000ooooo`000_oo0P006ooo00<00?ooool01?oo000Eool2000lool01000ooooo`001?oo
00@00?ooooooo`800005ool00?ooool0000>ool01000oooooooo0P001_oo00<00?ooool01Ooo00<0
0?ooool06Ooo00<00?ooool01ooo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool09ooo00<0
0?ooool01_oo00<00?oo00000`006ooo0P001_oo000Eool00`00ooooo`0jool00`00ooooo`02ool0
1@00oooooooo00000_oo0P000ooo00<00?oo00003_oo00<00?ooool00_oo00<00?ooool01?oo00<0
0?ooool01_oo00<00?ooool06?oo00<00?ooool01ooo00<00?ooool03?oo1@000_oo00<00?ooool0
9ooo00<00?ooool01ooo0`007_oo00<00?ooool01?oo000Eool00`00ooooo`0jool00`00ooooo`02
ool01`00oooooooo003oo`0000Goo`80013oo`04003oooooool20005ool00`00ooooo`06ool00`00
ooooo`04ool2000Bool00`00ooooo`06ool00`00ooooo`0Aool4000Yool00`00ooooo`08ool00`00
ooooo`0Mool00`00ooooo`04ool001Goo`03003ooooo03[oo`03003ooooo00;oo`04003oooooool2
000Hool00`00ooooo`02ool20004ool00`00ooooo`06ool00`00ooooo`02ool200000ooo0000000A
ool00`00ooooo`05ool2000Dool00`00ooooo`0Yool00`00ooooo`08ool00`00ooooo`0Mool00`00
ooooo`04ool001Goo`03003ooooo03[oo`03003ooooo00?oo`05003oo`00ool0000Hool00`00oooo
o`03ool20003ool00`00ooooo`06ool01000oooooooo0P0000?oo`0000000P003ooo00<00?ooool0
1_oo00<00?ooool0@?oo00<00?ooool01_oo00<00?ooool07_oo00<00?ooool01?oo000Eool00`00
ooooo`0jool00`00ooooo`03ool01@00ool00?oo00006?oo00<00?ooool01?oo00D00?ooooooo`00
00Soo`D000;oo`D000koo`03003ooooo00Goo`8004;oo`03003ooooo00?oo`800003ool00?oo01oo
o`03003ooooo00Coo`005Ooo00<00?ooool0>Ooo00<00?ooool01?oo0`0000?oo`00ool05ooo00<0
0?ooool01Ooo0`002?oo0`001?oo00D00?ooool00?oo008000goo`03003ooooo00Coo`8004?oo`03
003ooooo00;oo`05003oo`00ool0000Pool00`00ooooo`04ool001Goo`03003ooooo03Koo`04003o
oooo0006ool200000ooo003oo`0Iool00`00ooooo`05ool50003ool300000ooo003oo`03ool01000
ooooo`000_oo0P003?oo00<00?ooool00ooo0P00AOoo00<00?ooool00P0000Coo`000000023oo`03
003ooooo00Coo`000ooo1@0000Coo`00000000?oo`03003ooooo00?oo`03003ooooo03Koo`04003o
oooo0009ool00`00ooooo`0Hool00`00ooooo`06ool01000oooooooo10000ooo00<00?ooool00_oo
00D00?ooooooo`0000;oo`8000_oo`03003ooooo00;oo`8004Koo`04003ooooo0003ool00`00oooo
o`0Oool00`00ooooo`04ool000Goo`05003oooooool00004ool00`00ool00004ool00`00ooooo`0f
ool3000:ool00`00ooooo`0Hool00`00ooooo`06ool00`00ooooo`08ool01000oooooooo0P000ooo
00@00?ooooooo`8000[oo`04003oooooool20017ool3000Vool00`00ooooo`04ool000Goo`03003o
oooo00;oo`07003oooooool00?oo00001?oo0P00=_oo10002_oo00<00?ooool06?oo00<00?ooool0
1_oo00<00?ooool02Ooo00@00?ooool000Goo`04003oooooool20008ool00`00ooooo`02ool00`00
ooooo`17ool2000Tool30006ool000Goo`03003ooooo00;oo`07003oooooool00?oo00001?oo00<0
0?ooool0=Ooo00@00?oo000000Woo`03003ooooo01Woo`03003ooooo00Koo`03003ooooo00Woo`04
003ooooo0005ool00`00ooooo`02ool20007ool01@00oooooooo0000L_oo00<00?ooool01?oo0005
ool01`00oooooooo003oo`0000;oo`03003oo`0000Coo`03003ooooo00?oo`80033oo`03003ooooo
00[oo`03003ooooo01Woo`03003ooooo00Koo`03003ooooo00Woo`04003ooooo0006ool00`00oooo
o`02ool20006ool00`00ooooo`02001bool00`00ooooo`04ool000Coo`8000Coo`03003ooooo00;o
o`03003ooooo00?oo`03003ooooo00Coo`03003ooooo02koo`03003ooooo00[oo`03003ooooo01Wo
o`03003ooooo00Goo`03003ooooo00[oo`<000Ooo`8000Coo`<000Coo`04003oo`00001cool00`00
ooooo`04ool001Goo`03003ooooo00Coo`03003ooooo02koo`03003ooooo00[oo`03003ooooo01[o
o`03003ooooo00Coo`03003ooooo00_oo`8000Soo`<000Coo`D00003ool0000007Coo`03003ooooo
00Coo`005Ooo00<00?ooool01Ooo00<00?ooool0;Ooo00<00?ooool02Ooo0P007?oo00<00?ooool0
1?oo00<00?ooool02ooo00<00?ooool02Ooo0`001_oo0`00MOoo00<00?ooool01?oo000Eool00`00
ooooo`04ool2000_ool00`00ooooo`09ool00`00ooooo`0Kool00`00ooooo`03ool00`00ooooo`0J
ool00`00ooooo`04ool00`00ooooo`1eool00`00ooooo`04ool001Goo`03003ooooo00?oo`@002ko
o`03003ooooo00Woo`03003ooooo01_oo`04003oooooool3000Mool00`00ooooo`02ool00`00oooo
o`1fool00`00ooooo`04ool001Goo`03003ooooo00?oo`04003ooooo000^ool00`00ooooo`09ool0
0`00ooooo`0Kool01@00oooooooo00007ooo00<00?ooool00_oo00<00?ooool0M_oo00<00?ooool0
1?oo000Eool00`00ooooo`06ool2000]ool00`00ooooo`09ool00`00ooooo`0Lool01000ooooo`00
7ooo00<00?ooool00_oo00<00?ooool0M_oo00<00?ooool01?oo000Eool20007ool3000/ool00`00
ooooo`08ool00`00ooooo`0Mool00`00ool0000Pool00`00ooooo`02ool00`00ooooo`1eool20006
ool001Goo`03003ooooo00Koo`03003oo`0002coo`03003ooooo00Soo`03003ooooo01goo`03003o
o`00027oo`04003ooooo001iool00`00ooooo`04ool001Goo`03003ooooo00Koo`04003ooooo000[
ool00`00ooooo`08ool00`00ooooo`0Mool3000Qool01000ooooo`00NOoo00<00?ooool01?oo000E
ool00`00ooooo`06ool00`00ooooo`02000Zool00`00ooooo`07ool00`00ooooo`13ool00`00ool0
001iool00`00ooooo`04ool001Goo`03003ooooo00Koo`05003oooooool0000Zool00`00ooooo`07
ool00`00ooooo`14ool00`00ooooo`1hool00`00ooooo`04ool001Goo`03003ooooo00Ooo`03003o
oooo008002Woo`03003ooooo00Ooo`03003ooooo0;ooo`03003ooooo00Coo`005Ooo00<00?ooool0
1ooo00D00?ooooooo`0002Woo`03003ooooo00Ooo`03003ooooo0;ooo`03003ooooo00Coo`005Ooo
00<00?ooool01ooo00@00?ooooooo`8002Ooo`03003ooooo00Soo`03003ooooo0;ooo`03003ooooo
00Coo`005Ooo00<00?ooool01ooo00<00?ooool00_oo00<00?ooool09Ooo00<00?ooool01ooo00<0
0?ooool0`?oo00<00?ooool01?oo000Eool00`00ooooo`07ool00`00ooooo`02ool2000Vool00`00
ooooo`07ool00`00ooooo`30ool00`00ooooo`04ool001Goo`8000Soo`03003ooooo00?oo`03003o
oooo02Coo`03003ooooo00Ooo`03003ooooo0;ooo`8000Koo`005Ooo00<00?ooool01ooo00<00?oo
ool00ooo0P009Ooo00<00?ooool01ooo00<00?ooool0`?oo00<00?ooool01?oo000Eool00`00oooo
o`08ool00`00ooooo`03ool00`00ooooo`0Sool00`00ooooo`06ool00`00ooooo`31ool00`00oooo
o`04ool001Goo`03003ooooo00Soo`03003ooooo00?oo`8002Coo`03003ooooo00Koo`03003ooooo
0<7oo`03003ooooo00Coo`005Ooo00<00?ooool02?oo00<00?ooool01?oo00<00?ooool08_oo00<0
0?ooool01_oo00<00?ooool0`Ooo00<00?ooool01?oo000Eool00`00ooooo`08ool00`00ooooo`04
ool00`00ooooo`0Rool00`00ooooo`06ool00`00ooooo`31ool00`00ooooo`04ool001Goo`03003o
oooo00Soo`03003ooooo00Coo`8002?oo`03003ooooo00Koo`03003ooooo0<7oo`03003ooooo00Co
o`005Ooo00<00?ooool02Ooo00<00?ooool01?oo00<00?ooool08Ooo00<00?ooool01Ooo00<00?oo
ool0`_oo00<00?ooool01?oo000Eool00`00ooooo`09ool00`00ooooo`04ool00`00ooooo`0Qool0
0`00ooooo`05ool00`00ooooo`32ool00`00ooooo`04ool001Goo`03003ooooo00Woo`03003ooooo
00Goo`03003ooooo023oo`03003ooooo00Goo`03003ooooo0<;oo`03003ooooo00Coo`005Ooo0P00
2_oo00<00?ooool01Ooo00<00?ooool08?oo00<00?ooool01Ooo00<00?ooool0`Ooo0P001_oo000E
ool00`00ooooo`09ool00`00ooooo`06ool00`00ooooo`0Oool00`00ooooo`05ool00`00ooooo`32
ool00`00ooooo`04ool001Goo`03003ooooo00Woo`03003ooooo00Koo`03003ooooo01ooo`03003o
oooo00Coo`03003ooooo0<?oo`03003ooooo00Coo`005Ooo00<00?ooool02_oo00<00?ooool01Ooo
00<00?ooool07ooo00<00?ooool01?oo00<00?ooool0`ooo00<00?ooool01?oo000Eool00`00oooo
o`0:ool00`00ooooo`06ool00`00ooooo`0Nool00`00ooooo`04ool00`00ooooo`33ool00`00oooo
o`04ool001Goo`03003ooooo00[oo`8000Ooo`03003ooooo01koo`03003ooooo00Coo`03003ooooo
0<?oo`03003ooooo00Coo`005Ooo00<00?ooool02ooo00<00?ooool01Ooo00<00?ooool07_oo00<0
0?ooool01?oo00<00?ooool0`ooo00<00?ooool01?oo000Eool00`00ooooo`0;ool00`00ooooo`06
ool00`00ooooo`0Lool00`00ooooo`05ool00`00ooooo`33ool00`00ooooo`04ool000?oo`D000;o
o`<000;oo`03003ooooo00?oo`03003ooooo00_oo`03003ooooo00Koo`03003ooooo01coo`03003o
oooo00Goo`03003ooooo0<?oo`03003ooooo00Coo`001Ooo00<00?ooool00ooo00H00?ooool00?oo
0004ool00`00ooooo`0<ool00`00ooooo`05ool00`00ooooo`0Lool00`00ooooo`04ool00`00oooo
o`34ool00`00ooooo`04ool000Goo`04003oooooool400001?oo003oo`001?oo0P003Ooo00<00?oo
ool01Ooo0P007Ooo00<00?ooool01?oo00<00?ooool0`_oo0`001_oo0005ool01`00oooooooo003o
o`0000;oo`03003oo`0000Coo`03003ooooo00goo`03003ooooo00Goo`03003ooooo01_oo`03003o
oooo00Coo`03003ooooo0<Coo`03003ooooo00Coo`001Ooo00<00?ooool00_oo0P000_oo00<00?oo
00001?oo00<00?ooool03Ooo00<00?ooool01Ooo00<00?ooool06ooo00<00?ooool01?oo00<00?oo
ool0a?oo00<00?ooool01?oo0004ool20005ool01@00oooooooo00001Ooo00<00?ooool03_oo00<0
0?ooool01?oo00<00?ooool06ooo00<00?ooool01?oo00<00?ooool0a?oo00<00?ooool01?oo000E
ool00`00ooooo`0>ool00`00ooooo`04ool00`00ooooo`0Kool00`00ooooo`04ool00`00ooooo`34
ool00`00ooooo`04ool001Goo`03003ooooo00koo`03003ooooo00Goo`03003ooooo01[oo`03003o
oooo00Coo`03003ooooo0<Coo`03003ooooo00Coo`005Ooo00<00?ooool03_oo00<00?ooool01Ooo
00<00?ooool06_oo00<00?ooool00ooo00<00?ooool0aOoo00<00?ooool01?oo000Eool00`00oooo
o`0>ool00`00ooooo`05ool00`00ooooo`0Jool00`00ooooo`03ool00`00ooooo`35ool00`00oooo
o`04ool001Goo`03003ooooo00ooo`03003ooooo00Coo`03003ooooo01[oo`03003ooooo00?oo`03
003ooooo0<Goo`03003ooooo00Coo`005Ooo00<00?ooool03ooo00<00?ooool01Ooo00<00?ooool0
6Ooo00<00?ooool00ooo00<00?ooool0aOoo00<00?ooool01?oo000Eool2000@ool00`00ooooo`05
ool00`00ooooo`0Iool00`00ooooo`03ool00`00ooooo`34ool20006ool001Goo`03003ooooo00oo
o`03003ooooo00Goo`03003ooooo01Woo`03003ooooo00?oo`03003ooooo0<Goo`03003ooooo00Co
o`005Ooo00<00?ooool03ooo00<00?ooool01Ooo00<00?ooool06Ooo00<00?ooool00_oo00<00?oo
ool0a_oo00<00?ooool01?oo000Eool00`00ooooo`0?ool00`00ooooo`05ool2000Jool00`00oooo
o`02ool00`00ooooo`36ool00`00ooooo`04ool001Goo`03003ooooo00ooo`03003ooooo00Koo`03
003ooooo01Soo`03003ooooo00;oo`03003ooooo0<Koo`03003ooooo00Coo`005Ooo00<00?ooool0
4?oo00<00?ooool01Ooo00<00?ooool06?oo00<00?ooool00_oo00<00?ooool0a_oo00<00?ooool0
1?oo000Eool00`00ooooo`0@ool00`00ooooo`05ool00`00ooooo`0Gool00`00ooooo`02ool00`00
ooooo`37ool00`00ooooo`04ool001Goo`03003ooooo013oo`04003ooooo0005ool00`00ooooo`0F
ool00`00ooooo`02ool00`00ooooo`37ool00`00ooooo`04ool001Goo`03003ooooo013oo`03003o
o`00008000Coo`03003ooooo01Koo`03003ooooo00;oo`03003ooooo0<Ooo`03003ooooo00Coo`00
5Ooo00<00?ooool04?oo0`0000?oo`00ool00ooo00<00?ooool05_oo00<00?ooool00_oo00<00?oo
ool0aooo00<00?ooool01?oo000Eool2000Bool200000ooo003oo`04ool00`00ooooo`0Eool00`00
ooooo`02ool00`00ooooo`36ool20006ool001Goo`03003ooooo01Goo`03003ooooo00;oo`03003o
oooo01Goo`05003oooooool0003:ool00`00ooooo`04ool001Goo`03003ooooo01Goo`03003ooooo
00;oo`03003ooooo01Goo`05003oooooool0003:ool00`00ooooo`04ool001Goo`03003ooooo01Go
o`03003ooooo00?oo`03003ooooo01Coo`05003oooooool0003:ool00`00ooooo`04ool001Goo`03
003ooooo01Goo`03003ooooo00?oo`03003ooooo01Coo`05003oooooool0003:ool00`00ooooo`04
ool001Goo`03003ooooo01Goo`03003ooooo00Coo`03003ooooo01?oo`04003ooooo003;ool00`00
ooooo`04ool001Goo`03003ooooo01Goo`03003ooooo00Coo`03003ooooo01;oo`05003oooooool0
003;ool00`00ooooo`04ool001Goo`03003ooooo01Goo`03003ooooo00Goo`03003ooooo017oo`05
003oooooool0003;ool00`00ooooo`04ool001Goo`03003ooooo01Koo`03003ooooo00Coo`03003o
oooo013oo`8000?oo`03003ooooo0<Woo`03003ooooo00Coo`005Ooo00<00?ooool05_oo00<00?oo
ool01?oo0P004Ooo00<00?ooool00_oo00<00?ooool0bOoo00<00?ooool01?oo000Eool2000Gool0
0`00ooooo`05ool00`00ooooo`0?ool00`00ooooo`02ool00`00ooooo`38ool20006ool001Goo`03
003ooooo01Koo`03003ooooo00Goo`03003ooooo00koo`8000?oo`03003ooooo0<[oo`03003ooooo
00Coo`005Ooo00<00?ooool05_oo00<00?ooool01_oo00<00?ooool03Ooo00<00?ooool00_oo00<0
0?ooool0b_oo00<00?ooool01?oo000Eool00`00ooooo`0Fool00`00ooooo`06ool00`00ooooo`0=
ool00`00ooooo`02ool00`00ooooo`3:ool00`00ooooo`04ool001Goo`03003ooooo01Koo`03003o
oooo00Ooo`03003ooooo00coo`03003ooooo00;oo`03003ooooo0<[oo`03003ooooo00Coo`005Ooo
00<00?ooool05_oo00<00?ooool01ooo00<00?ooool02ooo00<00?ooool00ooo00<00?ooool0b_oo
00<00?ooool01?oo000Eool00`00ooooo`0Gool00`00ooooo`07ool00`00ooooo`0:ool00`00oooo
o`02ool00`00ooooo`3;ool00`00ooooo`04ool001Goo`03003ooooo01Ooo`03003ooooo00Ooo`80
00_oo`03003ooooo00;oo`03003ooooo0<_oo`03003ooooo00Coo`000ooo1@0000?oo`0000001?oo
00<00?ooool00ooo00<00?ooool05ooo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool00_oo
00<00?ooool0booo00<00?ooool01?oo0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Co
o`03003ooooo01Ooo`04003oooooool40003ool2000:ool00`00ooooo`02ool00`00ooooo`3;ool0
0`00ooooo`04ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo0P006?oo00D00?oo
ooooo`0000;oo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo0<Woo`<0
00Koo`001Ooo00@00?ooooooo`8000?oo`03003oo`0000Coo`03003ooooo01Ooo`04003ooooo0003
ool00`00ooooo`03ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`3<ool00`00ooooo`04
ool000Goo`05003oooooool00004ool00`00ool00004ool00`00ooooo`0Gool01000ooooo`000ooo
00<00?ooool00ooo0P001ooo00<00?ooool00_oo00<00?ooool0c?oo00<00?ooool01?oo0004ool2
0004ool20003ool00`00ooooo`03ool00`00ooooo`0Hool30004ool00`00ooooo`03ool20006ool0
0`00ooooo`02ool00`00ooooo`3<ool00`00ooooo`04ool001Goo`03003ooooo01Soo`8000Goo`03
003ooooo00Coo`8000Goo`04003oooooool2003>ool00`00ooooo`04ool001Goo`03003ooooo01So
o`8000Koo`03003ooooo00;oo`03003oo`0000Goo`05003oooooool0003?ool00`00ooooo`04ool0
01Goo`03003ooooo023oo`03003ooooo00;oo`04003oo`000004ool00`00ooooo`02003?ool00`00
ooooo`04ool001Goo`03003ooooo023oo`03003ooooo00;oo`03003oo`00008000;oo`03003oo`00
00800=3oo`03003ooooo00Coo`005Ooo00<00?ooool08?oo0P000ooo00@00?oo003oo`H00=;oo`03
003ooooo00Coo`005Ooo00<00?ooool08Ooo00@00?ooool000;oo`03003ooooo00;oo`03003ooooo
0=;oo`03003ooooo00Coo`005Ooo0P008_oo00@00?ooool000?oo`05003oooooool0003Cool20006
ool001Goo`03003ooooo027oo`03003oo`0000Coo`05003oooooool0003Dool00`00ooooo`04ool0
01Goo`03003ooooo02;oo`8000Coo`05003oooooool0003Dool00`00ooooo`04ool001Goo`03003o
oooo02Soo`05003oooooool0003Dool00`00ooooo`04ool001Goo`03003ooooo02Soo`04003ooooo
003Eool00`00ooooo`04ool001Goo`03003ooooo02Soo`04003ooooo003Eool00`00ooooo`04ool0
01Goo`03003ooooo02Woo`03003oo`000=Goo`03003ooooo00Coo`005Ooo00<00?ooool0:Ooo00<0
0?oo0000eOoo00<00?ooool01?oo000Eool00`00ooooo`0Yool00`00ool0003Eool00`00ooooo`04
ool001Goo`03003ooooo02Woo`03003oo`000=Goo`03003ooooo00Coo`005Ooo0P00:_oo00<00?oo
0000e?oo0P001_oo000Eool00`00ooooo`0Yool00`00ool0003Eool00`00ooooo`04ool001Goo`03
003ooooo02Woo`800=Koo`03003ooooo00Coo`005Ooo00<00?ooool0:_oo00<00?ooool0e?oo00<0
0?ooool01?oo000Eool00`00ooooo`3oool2ool00`00ooooo`04ool001Goo`03003ooooo00?oo`03
003ooooo02koo`03003ooooo02ooo`03003ooooo02koo`03003ooooo02ooo`03003ooooo02ooo`03
003ooooo00?oo`03003ooooo00Coo`005Oooo`001P001_oo003ooolQool00?ooob7oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-109.729, 86.1131, 4.0354, \
0.498529}}]
}, Open  ]],

Cell["We create the graph of the prices. ", "MathCaption",
  CellTags->{"S0.4", "4.9"}],

Cell[CellGroupData[{

Cell["g[0] = ListPlot[Take[prices[IBM], -1000]];", "Input",
  CellLabel->"In[80]:=",
  CellTags->"S0.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228562 0.000953334 -0.664583 0.00725552 [
[.02286 -0.0125 -3 -9 ]
[.02286 -0.0125 3 0 ]
[.21352 -0.0125 -9 -9 ]
[.21352 -0.0125 9 0 ]
[.40419 -0.0125 -9 -9 ]
[.40419 -0.0125 9 0 ]
[.59486 -0.0125 -9 -9 ]
[.59486 -0.0125 9 0 ]
[.78552 -0.0125 -9 -9 ]
[.78552 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06097 -18 -4.5 ]
[-0.0125 .06097 0 4.5 ]
[-0.0125 .20608 -18 -4.5 ]
[-0.0125 .20608 0 4.5 ]
[-0.0125 .35119 -18 -4.5 ]
[-0.0125 .35119 0 4.5 ]
[-0.0125 .4963 -18 -4.5 ]
[-0.0125 .4963 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02286 0 m
.02286 .00625 L
s
[(0)] .02286 -0.0125 0 1 Mshowa
.21352 0 m
.21352 .00625 L
s
[(200)] .21352 -0.0125 0 1 Mshowa
.40419 0 m
.40419 .00625 L
s
[(400)] .40419 -0.0125 0 1 Mshowa
.59486 0 m
.59486 .00625 L
s
[(600)] .59486 -0.0125 0 1 Mshowa
.78552 0 m
.78552 .00625 L
s
[(800)] .78552 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07052 0 m
.07052 .00375 L
s
.11819 0 m
.11819 .00375 L
s
.16586 0 m
.16586 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.30886 0 m
.30886 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.49952 0 m
.49952 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.69019 0 m
.69019 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.88086 0 m
.88086 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06097 m
.00625 .06097 L
s
[(100)] -0.0125 .06097 1 0 Mshowa
0 .20608 m
.00625 .20608 L
s
[(120)] -0.0125 .20608 1 0 Mshowa
0 .35119 m
.00625 .35119 L
s
[(140)] -0.0125 .35119 1 0 Mshowa
0 .4963 m
.00625 .4963 L
s
[(160)] -0.0125 .4963 1 0 Mshowa
.125 Mabswid
0 .09725 m
.00375 .09725 L
s
0 .13352 m
.00375 .13352 L
s
0 .1698 m
.00375 .1698 L
s
0 .24236 m
.00375 .24236 L
s
0 .27863 m
.00375 .27863 L
s
0 .31491 m
.00375 .31491 L
s
0 .38747 m
.00375 .38747 L
s
0 .42374 m
.00375 .42374 L
s
0 .46002 m
.00375 .46002 L
s
0 .02469 m
.00375 .02469 L
s
0 .53258 m
.00375 .53258 L
s
0 .56886 m
.00375 .56886 L
s
0 .60513 m
.00375 .60513 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02286 .61178 m
.02286 .61803 L
s
.21352 .61178 m
.21352 .61803 L
s
.40419 .61178 m
.40419 .61803 L
s
.59486 .61178 m
.59486 .61803 L
s
.78552 .61178 m
.78552 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07052 .61428 m
.07052 .61803 L
s
.11819 .61428 m
.11819 .61803 L
s
.16586 .61428 m
.16586 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.30886 .61428 m
.30886 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.49952 .61428 m
.49952 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.69019 .61428 m
.69019 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.88086 .61428 m
.88086 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06097 m
1 .06097 L
s
.99375 .20608 m
1 .20608 L
s
.99375 .35119 m
1 .35119 L
s
.99375 .4963 m
1 .4963 L
s
.125 Mabswid
.99625 .09725 m
1 .09725 L
s
.99625 .13352 m
1 .13352 L
s
.99625 .1698 m
1 .1698 L
s
.99625 .24236 m
1 .24236 L
s
.99625 .27863 m
1 .27863 L
s
.99625 .31491 m
1 .31491 L
s
.99625 .38747 m
1 .38747 L
s
.99625 .42374 m
1 .42374 L
s
.99625 .46002 m
1 .46002 L
s
.99625 .02469 m
1 .02469 L
s
.99625 .53258 m
1 .53258 L
s
.99625 .56886 m
1 .56886 L
s
.99625 .60513 m
1 .60513 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.02381 .20608 Mdot
.02476 .20608 Mdot
.02572 .24417 Mdot
.02667 .22603 Mdot
.02762 .22603 Mdot
.02858 .25959 Mdot
.02953 .25143 Mdot
.03048 .25868 Mdot
.03144 .2741 Mdot
.03239 .27863 Mdot
.03334 .26866 Mdot
.0343 .26957 Mdot
.03525 .29496 Mdot
.0362 .3004 Mdot
.03716 .31582 Mdot
.03811 .32852 Mdot
.03906 .32035 Mdot
.04002 .30584 Mdot
.04097 .30312 Mdot
.04192 .30766 Mdot
.04288 .29768 Mdot
.04383 .31128 Mdot
.04478 .3394 Mdot
.04574 .33668 Mdot
.04669 .34484 Mdot
.04764 .34847 Mdot
.0486 .37568 Mdot
.04955 .37296 Mdot
.0505 .36389 Mdot
.05146 .34665 Mdot
.05241 .34756 Mdot
.05336 .34031 Mdot
.05432 .33759 Mdot
.05527 .35028 Mdot
.05622 .35391 Mdot
.05718 .34665 Mdot
.05813 .34303 Mdot
.05908 .37205 Mdot
.06004 .36389 Mdot
.06099 .38203 Mdot
.06194 .38656 Mdot
.0629 .38475 Mdot
.06385 .40289 Mdot
.0648 .39654 Mdot
.06576 .40198 Mdot
.06671 .41377 Mdot
.06766 .42193 Mdot
.06862 .4446 Mdot
.06957 .46456 Mdot
.07052 .45277 Mdot
.07148 .42919 Mdot
.07243 .44098 Mdot
.07338 .42465 Mdot
.07434 .43191 Mdot
.07529 .40923 Mdot
.07624 .42012 Mdot
.0772 .41921 Mdot
.07815 .39835 Mdot
.0791 .40651 Mdot
.08006 .38021 Mdot
.08101 .38747 Mdot
.08196 .40651 Mdot
.08292 .41014 Mdot
.08387 .43009 Mdot
.08482 .42374 Mdot
.08578 .42374 Mdot
.08673 .47453 Mdot
.08768 .45458 Mdot
.08864 .45458 Mdot
.08959 .43644 Mdot
.09054 .45458 Mdot
.0915 .46184 Mdot
.09245 .48632 Mdot
.0934 .49721 Mdot
.09436 .50083 Mdot
.09531 .51807 Mdot
.09626 .54618 Mdot
.09722 .54527 Mdot
.09817 .53167 Mdot
.09912 .52351 Mdot
.10008 .51807 Mdot
.10103 .5353 Mdot
.10198 .54165 Mdot
.10294 .53348 Mdot
.10389 .50083 Mdot
.10484 .50356 Mdot
.1058 .47272 Mdot
.10675 .47181 Mdot
.1077 .47635 Mdot
.10866 .47181 Mdot
.10961 .50083 Mdot
.11056 .50356 Mdot
.11152 .51535 Mdot
.11247 .4963 Mdot
.11342 .49358 Mdot
.11438 .47635 Mdot
.11533 .49811 Mdot
.11628 .50628 Mdot
.11724 .4963 Mdot
.11819 .50537 Mdot
.11914 .49539 Mdot
.1201 .47998 Mdot
.12105 .47907 Mdot
.122 .47181 Mdot
.12296 .49358 Mdot
.12391 .51081 Mdot
.12486 .50628 Mdot
.12582 .50265 Mdot
.12677 .50628 Mdot
.12772 .51988 Mdot
.12868 .53167 Mdot
.12963 .54074 Mdot
.13058 .55344 Mdot
.13154 .54346 Mdot
.13249 .5353 Mdot
.13344 .51444 Mdot
.1344 .52532 Mdot
.13535 .52714 Mdot
.1363 .53348 Mdot
.13726 .52442 Mdot
.13821 .54527 Mdot
.13916 .54165 Mdot
.14012 .54709 Mdot
.14107 .56795 Mdot
.14202 .55072 Mdot
.14298 .55434 Mdot
.14393 .55525 Mdot
.14488 .54709 Mdot
.14584 .52986 Mdot
.14679 .51625 Mdot
.14774 .50628 Mdot
.1487 .49721 Mdot
.14965 .50537 Mdot
.1506 .51172 Mdot
.15156 .50537 Mdot
.15251 .50718 Mdot
.15346 .51353 Mdot
.15442 .50356 Mdot
.15537 .49086 Mdot
.15632 .49177 Mdot
.15728 .49811 Mdot
.15823 .51807 Mdot
.15918 .52804 Mdot
.16014 .54527 Mdot
.16109 .5616 Mdot
.16204 .57158 Mdot
.163 .59334 Mdot
.16395 .59244 Mdot
.1649 .60151 Mdot
.16586 .58971 Mdot
.16681 .5879 Mdot
.16776 .60332 Mdot
.16872 .60332 Mdot
.16967 .60241 Mdot
.17062 .58337 Mdot
.17158 .55344 Mdot
.17253 .54165 Mdot
.17348 .54346 Mdot
.17444 .55706 Mdot
.17539 .51716 Mdot
.17634 .51444 Mdot
.1773 .50809 Mdot
.17825 .50174 Mdot
.1792 .47998 Mdot
.18016 .47635 Mdot
.18111 .47998 Mdot
.18206 .50446 Mdot
.18302 .51081 Mdot
.18397 .47816 Mdot
.18492 .47181 Mdot
.18588 .48088 Mdot
.18683 .46274 Mdot
.18778 .42737 Mdot
.18874 .46546 Mdot
.18969 .45458 Mdot
.19064 .46637 Mdot
.1916 .46728 Mdot
.19255 .4437 Mdot
.1935 .42737 Mdot
.19446 .42919 Mdot
.19541 .4573 Mdot
.19636 .46184 Mdot
.19732 .47091 Mdot
.19827 .431 Mdot
.19922 .4437 Mdot
.20018 .43463 Mdot
.20113 .4047 Mdot
.20208 .42012 Mdot
.20304 .41468 Mdot
.20399 .38928 Mdot
.20494 .3521 Mdot
.2059 .31491 Mdot
.20685 .08274 Mdot
.2078 .1698 Mdot
.20876 .22603 Mdot
.20971 .20608 Mdot
.21066 .21152 Mdot
.21162 .14804 Mdot
.21257 .19157 Mdot
.21352 .19157 Mdot
.21448 .20789 Mdot
.21543 .22422 Mdot
.21638 .23873 Mdot
.21734 .21968 Mdot
.21829 .21061 Mdot
.21924 .23329 Mdot
.2202 .20245 Mdot
.22115 .19248 Mdot
.2221 .18975 Mdot
.22306 .20064 Mdot
.22401 .2224 Mdot
.22496 .21787 Mdot
.22592 .20608 Mdot
.22687 .18975 Mdot
.22782 .19429 Mdot
.22878 .17434 Mdot
.22973 .18975 Mdot
.23068 .18794 Mdot
.23164 .1952 Mdot
.23259 .18885 Mdot
.23354 .16889 Mdot
.2345 .13897 Mdot
.23545 .14259 Mdot
.2364 .13715 Mdot
.23736 .10813 Mdot
.23831 .1172 Mdot
.23926 .1299 Mdot
.24022 .14441 Mdot
.24117 .16255 Mdot
.24212 .14078 Mdot
.24308 .13443 Mdot
.24403 .17071 Mdot
.24498 .17706 Mdot
.24594 .19792 Mdot
.24689 .17343 Mdot
.24784 .18613 Mdot
.2488 .19338 Mdot
.24975 .19338 Mdot
.2507 .20245 Mdot
.25166 .20517 Mdot
.25261 .17524 Mdot
.25356 .17706 Mdot
.25452 .18431 Mdot
.25547 .17343 Mdot
.25642 .21152 Mdot
.25738 .21968 Mdot
.25833 .22694 Mdot
.25928 .23057 Mdot
.26024 .16889 Mdot
.26119 .18975 Mdot
.26214 .17162 Mdot
.2631 .17796 Mdot
.26405 .17615 Mdot
.265 .19882 Mdot
.26596 .18975 Mdot
.26691 .14622 Mdot
.26786 .13625 Mdot
.26882 .14078 Mdot
.26977 .13715 Mdot
.27072 .1571 Mdot
.27168 .14713 Mdot
.27263 .15348 Mdot
.27358 .16073 Mdot
.27454 .15076 Mdot
.27549 .13352 Mdot
.27644 .13262 Mdot
.2774 .12627 Mdot
.27835 .12355 Mdot
.2793 .11901 Mdot
.28026 .1172 Mdot
.28121 .12718 Mdot
.28216 .14531 Mdot
.28312 .14259 Mdot
.28407 .14804 Mdot
.28502 .16073 Mdot
.28598 .15348 Mdot
.28693 .15166 Mdot
.28788 .15801 Mdot
.28884 .17162 Mdot
.28979 .17252 Mdot
.29074 .17796 Mdot
.2917 .16617 Mdot
.29265 .17524 Mdot
.2936 .18794 Mdot
.29456 .18431 Mdot
.29551 .18613 Mdot
.29646 .18069 Mdot
.29742 .18341 Mdot
.29837 .18613 Mdot
.29932 .18885 Mdot
.30028 .18159 Mdot
.30123 .16073 Mdot
.30218 .17343 Mdot
.30314 .17343 Mdot
.30409 .16255 Mdot
.30504 .17162 Mdot
.306 .16889 Mdot
.30695 .16436 Mdot
.3079 .16073 Mdot
.30886 .1562 Mdot
.30981 .14531 Mdot
.31076 .13171 Mdot
.31172 .11176 Mdot
.31267 .11992 Mdot
.31362 .1036 Mdot
.31458 .09815 Mdot
.31553 .11629 Mdot
.31648 .11539 Mdot
.31744 .11539 Mdot
.31839 .1308 Mdot
.31934 .12808 Mdot
.3203 .14531 Mdot
.32125 .15801 Mdot
.3222 .15983 Mdot
.32316 .17796 Mdot
.32411 .1435 Mdot
.32506 .16345 Mdot
.32602 .16255 Mdot
.32697 .1562 Mdot
.32792 .15438 Mdot
.32888 .15076 Mdot
.32983 .16073 Mdot
.33078 .16164 Mdot
.33174 .16436 Mdot
.33269 .16255 Mdot
.33364 .1562 Mdot
.3346 .15801 Mdot
.33555 .16345 Mdot
.3365 .16708 Mdot
.33746 .1571 Mdot
.33841 .14259 Mdot
.33936 .13715 Mdot
.34032 .13715 Mdot
.34127 .13987 Mdot
.34222 .12445 Mdot
.34318 .12445 Mdot
.34413 .13625 Mdot
.34508 .14531 Mdot
.34604 .13443 Mdot
.34699 .12536 Mdot
.34794 .13715 Mdot
.3489 .1299 Mdot
.34985 .12445 Mdot
.3508 .12808 Mdot
.35176 .12264 Mdot
.35271 .12083 Mdot
.35366 .11901 Mdot
.35462 .15166 Mdot
.35557 .1562 Mdot
.35652 .15257 Mdot
.35748 .1571 Mdot
.35843 .16527 Mdot
.35938 .16073 Mdot
.36034 .18159 Mdot
.36129 .17252 Mdot
.36224 .17706 Mdot
.3632 .18431 Mdot
.36415 .19701 Mdot
.3651 .19792 Mdot
.36606 .18522 Mdot
.36701 .18794 Mdot
.36796 .18522 Mdot
.36892 .20789 Mdot
.36987 .22785 Mdot
.37082 .2478 Mdot
.37178 .24326 Mdot
.37273 .24236 Mdot
.37368 .25687 Mdot
.37464 .25687 Mdot
.37559 .25959 Mdot
.37654 .25415 Mdot
.3775 .27319 Mdot
.37845 .25596 Mdot
.3794 .2614 Mdot
.38036 .25233 Mdot
.38131 .25505 Mdot
.38226 .24417 Mdot
.38322 .24417 Mdot
.38417 .24054 Mdot
.38512 .24598 Mdot
.38608 .24326 Mdot
.38703 .2351 Mdot
.38798 .2351 Mdot
.38894 .21878 Mdot
.38989 .20699 Mdot
.39084 .22331 Mdot
.3918 .22513 Mdot
.39275 .21424 Mdot
.3937 .23329 Mdot
.39466 .2478 Mdot
.39561 .25143 Mdot
.39656 .2478 Mdot
.39752 .2478 Mdot
.39847 .23692 Mdot
.39942 .23419 Mdot
.40038 .22875 Mdot
.40133 .21787 Mdot
.40228 .19792 Mdot
.40324 .19882 Mdot
.40419 .19157 Mdot
.40514 .17071 Mdot
.4061 .17524 Mdot
.40705 .16708 Mdot
.408 .16708 Mdot
.40896 .15348 Mdot
.40991 .13897 Mdot
.41086 .13987 Mdot
.41182 .15348 Mdot
.41277 .14531 Mdot
.41372 .14985 Mdot
.41468 .15801 Mdot
.41563 .15438 Mdot
.41658 .14441 Mdot
.41754 .13534 Mdot
.41849 .16255 Mdot
.41944 .15438 Mdot
.4204 .14622 Mdot
.42135 .14894 Mdot
.4223 .16527 Mdot
.42326 .15983 Mdot
.42421 .1698 Mdot
.42516 .16708 Mdot
.42612 .16073 Mdot
.42707 .16436 Mdot
.42802 .15348 Mdot
.42898 .15348 Mdot
.42993 .1571 Mdot
.43088 .14804 Mdot
.43184 .15438 Mdot
.43279 .14985 Mdot
.43374 .1571 Mdot
.4347 .16164 Mdot
.43565 .17252 Mdot
.4366 .17252 Mdot
.43756 .16889 Mdot
.43851 .16617 Mdot
.43946 .16164 Mdot
.44042 .16255 Mdot
.44137 .17706 Mdot
.44232 .17796 Mdot
.44328 .19701 Mdot
.44423 .18794 Mdot
.44518 .1961 Mdot
.44614 .20427 Mdot
.44709 .21424 Mdot
.44804 .23782 Mdot
.449 .22331 Mdot
.44995 .24145 Mdot
.4509 .23782 Mdot
.45186 .22875 Mdot
.45281 .22694 Mdot
.45376 .21787 Mdot
.45472 .20789 Mdot
.45567 .21152 Mdot
.45662 .22513 Mdot
.45758 .2351 Mdot
.45853 .22694 Mdot
.45948 .2224 Mdot
.46044 .20789 Mdot
.46139 .19973 Mdot
.46234 .20427 Mdot
.4633 .20517 Mdot
.46425 .20427 Mdot
.4652 .18159 Mdot
.46616 .18522 Mdot
.46711 .18794 Mdot
.46806 .17343 Mdot
.46902 .17343 Mdot
.46997 .17524 Mdot
.47092 .17434 Mdot
.47188 .18431 Mdot
.47283 .19157 Mdot
.47378 .17706 Mdot
.47474 .19792 Mdot
.47569 .20154 Mdot
.47664 .1952 Mdot
.4776 .19338 Mdot
.47855 .20064 Mdot
.4795 .21243 Mdot
.48046 .2215 Mdot
.48141 .21333 Mdot
.48236 .20154 Mdot
.48332 .2088 Mdot
.48427 .20971 Mdot
.48522 .21152 Mdot
.48618 .20971 Mdot
.48713 .21333 Mdot
.48808 .21515 Mdot
.48904 .22603 Mdot
.48999 .22966 Mdot
.49094 .22785 Mdot
.4919 .22422 Mdot
.49285 .23057 Mdot
.4938 .22875 Mdot
.49476 .22422 Mdot
.49571 .22966 Mdot
.49666 .21968 Mdot
.49762 .21333 Mdot
.49857 .22422 Mdot
.49952 .2224 Mdot
.50048 .21968 Mdot
.50143 .22059 Mdot
.50238 .21424 Mdot
.50334 .2224 Mdot
.50429 .22875 Mdot
.50524 .23057 Mdot
.5062 .23692 Mdot
.50715 .23419 Mdot
.5081 .24236 Mdot
.50906 .23692 Mdot
.51001 .23238 Mdot
.51096 .22331 Mdot
.51192 .23692 Mdot
.51287 .22966 Mdot
.51382 .24961 Mdot
.51478 .25596 Mdot
.51573 .26957 Mdot
.51668 .28317 Mdot
.51764 .27591 Mdot
.51859 .26684 Mdot
.51954 .26231 Mdot
.5205 .25415 Mdot
.52145 .2614 Mdot
.5224 .25687 Mdot
.52336 .25233 Mdot
.52431 .24236 Mdot
.52526 .24961 Mdot
.52622 .24054 Mdot
.52717 .25687 Mdot
.52812 .24871 Mdot
.52908 .24417 Mdot
.53003 .24598 Mdot
.53098 .23057 Mdot
.53194 .23057 Mdot
.53289 .21424 Mdot
.53384 .21787 Mdot
.5348 .21696 Mdot
.53575 .20517 Mdot
.5367 .20971 Mdot
.53766 .21243 Mdot
.53861 .21696 Mdot
.53956 .20517 Mdot
.54052 .20336 Mdot
.54147 .1961 Mdot
.54242 .19338 Mdot
.54338 .19792 Mdot
.54433 .19066 Mdot
.54528 .18431 Mdot
.54624 .19248 Mdot
.54719 .15166 Mdot
.54814 .1299 Mdot
.5491 .13443 Mdot
.55005 .12808 Mdot
.551 .1308 Mdot
.55196 .13443 Mdot
.55291 .13352 Mdot
.55386 .1308 Mdot
.55482 .12445 Mdot
.55577 .12718 Mdot
.55672 .12264 Mdot
.55768 .11266 Mdot
.55863 .1172 Mdot
.55958 .11901 Mdot
.56054 .13171 Mdot
.56149 .13352 Mdot
.56244 .14169 Mdot
.5634 .14169 Mdot
.56435 .12808 Mdot
.5653 .13987 Mdot
.56626 .1435 Mdot
.56721 .15529 Mdot
.56816 .15076 Mdot
.56912 .15076 Mdot
.57007 .15892 Mdot
.57102 .15892 Mdot
.57198 .16617 Mdot
.57293 .16617 Mdot
.57388 .16708 Mdot
.57484 .16345 Mdot
.57579 .15801 Mdot
.57674 .15076 Mdot
.5777 .14441 Mdot
.57865 .13806 Mdot
.5796 .12899 Mdot
.58056 .1299 Mdot
.58151 .13171 Mdot
.58246 .1308 Mdot
.58342 .12718 Mdot
.58437 .13897 Mdot
.58532 .15348 Mdot
.58628 .1435 Mdot
.58723 .14441 Mdot
.58818 .14804 Mdot
.58914 .14169 Mdot
.59009 .13262 Mdot
.59104 .1299 Mdot
.592 .13171 Mdot
.59295 .1308 Mdot
.5939 .1299 Mdot
.59486 .12083 Mdot
.59581 .1308 Mdot
.59676 .13352 Mdot
.59772 .13443 Mdot
.59867 .12627 Mdot
.59962 .1308 Mdot
.60058 .1299 Mdot
.60153 .12808 Mdot
.60248 .12173 Mdot
.60344 .12536 Mdot
.60439 .14078 Mdot
.60534 .13625 Mdot
.6063 .12899 Mdot
.60725 .1299 Mdot
.6082 .13625 Mdot
.60916 .1299 Mdot
.61011 .13171 Mdot
.61106 .12718 Mdot
.61202 .13987 Mdot
.61297 .14804 Mdot
.61392 .16527 Mdot
.61488 .16164 Mdot
.61583 .14441 Mdot
.61678 .14713 Mdot
.61774 .14985 Mdot
.61869 .14804 Mdot
.61964 .14531 Mdot
.6206 .14894 Mdot
.62155 .16708 Mdot
.6225 .16164 Mdot
.62346 .16799 Mdot
.62441 .16889 Mdot
.62536 .16799 Mdot
.62632 .17706 Mdot
.62727 .16799 Mdot
.62822 .16527 Mdot
.62918 .15348 Mdot
.63013 .16345 Mdot
.63108 .15892 Mdot
.63204 .15348 Mdot
.63299 .15166 Mdot
.63394 .15529 Mdot
.6349 .15801 Mdot
.63585 .1698 Mdot
.6368 .16708 Mdot
.63776 .16255 Mdot
.63871 .16073 Mdot
.63966 .17343 Mdot
.64062 .18703 Mdot
.64157 .19338 Mdot
.64252 .18522 Mdot
.64348 .18794 Mdot
.64443 .17343 Mdot
.64538 .17796 Mdot
.64634 .17887 Mdot
.64729 .17343 Mdot
.64824 .16799 Mdot
.6492 .17071 Mdot
.65015 .15529 Mdot
.6511 .15983 Mdot
.65206 .16255 Mdot
.65301 .17706 Mdot
.65396 .17796 Mdot
.65492 .19157 Mdot
.65587 .17978 Mdot
.65682 .18341 Mdot
.65778 .18522 Mdot
.65873 .18703 Mdot
.65968 .18975 Mdot
.66064 .1825 Mdot
.66159 .17887 Mdot
.66254 .17706 Mdot
.6635 .17887 Mdot
.66445 .18341 Mdot
.6654 .17252 Mdot
.66636 .17524 Mdot
.66731 .17343 Mdot
.66826 .17796 Mdot
.66922 .17706 Mdot
.67017 .17706 Mdot
.67112 .17796 Mdot
.67208 .18069 Mdot
.67303 .17887 Mdot
.67398 .18794 Mdot
.67494 .14441 Mdot
.67589 .12627 Mdot
.67684 .12808 Mdot
.6778 .12355 Mdot
.67875 .1045 Mdot
.6797 .12083 Mdot
.68066 .11539 Mdot
.68161 .11539 Mdot
.68256 .12808 Mdot
.68352 .12083 Mdot
.68447 .1172 Mdot
.68542 .11629 Mdot
.68638 .07548 Mdot
.68733 .08274 Mdot
.68828 .07729 Mdot
.68924 .07367 Mdot
.69019 .0909 Mdot
.69114 .0918 Mdot
.6921 .08636 Mdot
.69305 .08274 Mdot
.694 .07457 Mdot
.69496 .06641 Mdot
.69591 .06006 Mdot
.69686 .05734 Mdot
.69782 .06278 Mdot
.69877 .06097 Mdot
.69972 .04555 Mdot
.70068 .05009 Mdot
.70163 .03648 Mdot
.70258 .04192 Mdot
.70354 .03739 Mdot
.70449 .04192 Mdot
.70544 .04736 Mdot
.7064 .04827 Mdot
.70735 .04646 Mdot
.7083 .04555 Mdot
.70926 .04011 Mdot
.71021 .05462 Mdot
.71116 .0519 Mdot
.71212 .05734 Mdot
.71307 .06188 Mdot
.71402 .06369 Mdot
.71498 .05643 Mdot
.71593 .05281 Mdot
.71688 .04464 Mdot
.71784 .04374 Mdot
.71879 .04011 Mdot
.71974 .05553 Mdot
.7207 .05825 Mdot
.72165 .05099 Mdot
.7226 .04646 Mdot
.72356 .0383 Mdot
.72451 .03285 Mdot
.72546 .0392 Mdot
.72642 .03104 Mdot
.72737 .0256 Mdot
.72832 .02469 Mdot
.72928 .01472 Mdot
.73023 .02288 Mdot
.73118 .02197 Mdot
.73214 .0256 Mdot
.73309 .02741 Mdot
.73404 .02106 Mdot
.735 .02288 Mdot
.73595 .01834 Mdot
.7369 .01834 Mdot
.73786 .04646 Mdot
.73881 .05281 Mdot
.73976 .06097 Mdot
.74072 .05916 Mdot
.74167 .06369 Mdot
.74262 .05643 Mdot
.74358 .05371 Mdot
.74453 .06006 Mdot
.74548 .04555 Mdot
.74644 .04736 Mdot
.74739 .06188 Mdot
.74834 .05281 Mdot
.7493 .05734 Mdot
.75025 .05099 Mdot
.7512 .03648 Mdot
.75216 .03739 Mdot
.75311 .04283 Mdot
.75406 .03104 Mdot
.75502 .0383 Mdot
.75597 .04102 Mdot
.75692 .04102 Mdot
.75788 .05099 Mdot
.75883 .04464 Mdot
.75978 .04918 Mdot
.76074 .05825 Mdot
.76169 .06822 Mdot
.76264 .08364 Mdot
.7636 .08092 Mdot
.76455 .07911 Mdot
.7655 .06913 Mdot
.76646 .08455 Mdot
.76741 .08818 Mdot
.76836 .08818 Mdot
.76932 .08636 Mdot
.77027 .08183 Mdot
.77122 .09634 Mdot
.77218 .08455 Mdot
.77313 .08001 Mdot
.77408 .08999 Mdot
.77504 .08818 Mdot
.77599 .08908 Mdot
.77694 .08999 Mdot
.7779 .09634 Mdot
.77885 .09725 Mdot
.7798 .10269 Mdot
.78076 .10087 Mdot
.78171 .11176 Mdot
.78266 .10813 Mdot
.78362 .1172 Mdot
.78457 .10632 Mdot
.78552 .10632 Mdot
.78648 .11176 Mdot
.78743 .12355 Mdot
.78838 .12627 Mdot
.78934 .11901 Mdot
.79029 .11357 Mdot
.79124 .10813 Mdot
.7922 .09725 Mdot
.79315 .0909 Mdot
.7941 .09362 Mdot
.79506 .1036 Mdot
.79601 .1045 Mdot
.79696 .10541 Mdot
.79792 .1036 Mdot
.79887 .10904 Mdot
.79982 .10813 Mdot
.80078 .10541 Mdot
.80173 .1036 Mdot
.80268 .10087 Mdot
.80364 .1036 Mdot
.80459 .10722 Mdot
.80554 .11266 Mdot
.8065 .13987 Mdot
.80745 .14169 Mdot
.8084 .13262 Mdot
.80936 .12718 Mdot
.81031 .12899 Mdot
.81126 .12899 Mdot
.81222 .12536 Mdot
.81317 .12899 Mdot
.81412 .12445 Mdot
.81508 .11448 Mdot
.81603 .12627 Mdot
.81698 .11901 Mdot
.81794 .12718 Mdot
.81889 .12808 Mdot
.81984 .13715 Mdot
.8208 .13715 Mdot
.82175 .13897 Mdot
.8227 .14259 Mdot
.82366 .15076 Mdot
.82461 .16255 Mdot
.82556 .16436 Mdot
.82652 .17434 Mdot
.82747 .17252 Mdot
.82842 .17796 Mdot
.82938 .17252 Mdot
.83033 .18431 Mdot
.83128 .18975 Mdot
.83224 .19701 Mdot
.83319 .19701 Mdot
.83414 .17887 Mdot
.8351 .20427 Mdot
.83605 .21243 Mdot
.837 .20608 Mdot
.83796 .20245 Mdot
.83891 .2088 Mdot
.83986 .21152 Mdot
.84082 .21061 Mdot
.84177 .21061 Mdot
.84272 .19701 Mdot
.84368 .20517 Mdot
.84463 .20789 Mdot
.84558 .21606 Mdot
.84654 .21243 Mdot
.84749 .2088 Mdot
.84844 .19701 Mdot
.8494 .19701 Mdot
.85035 .19157 Mdot
.8513 .19973 Mdot
.85226 .17887 Mdot
.85321 .18159 Mdot
.85416 .1825 Mdot
.85512 .19157 Mdot
.85607 .18885 Mdot
.85702 .18794 Mdot
.85798 .1952 Mdot
.85893 .18885 Mdot
.85988 .18703 Mdot
.86084 .19157 Mdot
.86179 .19882 Mdot
.86274 .18975 Mdot
.8637 .19973 Mdot
.86465 .20608 Mdot
.8656 .21333 Mdot
.86656 .22331 Mdot
.86751 .21152 Mdot
.86846 .20517 Mdot
.86942 .20608 Mdot
.87037 .18885 Mdot
.87132 .17615 Mdot
.87228 .16799 Mdot
.87323 .16799 Mdot
.87418 .1562 Mdot
.87514 .1435 Mdot
.87609 .14894 Mdot
.87704 .14441 Mdot
.878 .14531 Mdot
.87895 .13171 Mdot
.8799 .11992 Mdot
.88086 .08908 Mdot
.88181 .08274 Mdot
.88276 .08364 Mdot
.88372 .08455 Mdot
.88467 .07548 Mdot
.88562 .08818 Mdot
.88658 .09271 Mdot
.88753 .09725 Mdot
.88848 .08818 Mdot
.88944 .07095 Mdot
.89039 .07729 Mdot
.89134 .0646 Mdot
.8923 .05371 Mdot
.89325 .0383 Mdot
.8942 .06369 Mdot
.89516 .09271 Mdot
.89611 .08727 Mdot
.89706 .08908 Mdot
.89802 .07367 Mdot
.89897 .07457 Mdot
.89992 .07911 Mdot
.90088 .0782 Mdot
.90183 .0782 Mdot
.90278 .10087 Mdot
.90374 .1036 Mdot
.90469 .11539 Mdot
.90564 .11811 Mdot
.9066 .09725 Mdot
.90755 .09271 Mdot
.9085 .09815 Mdot
.90946 .11357 Mdot
.91041 .12173 Mdot
.91136 .11811 Mdot
.91232 .10994 Mdot
.91327 .09725 Mdot
.91422 .10722 Mdot
.91518 .09997 Mdot
.91613 .09271 Mdot
.91708 .10722 Mdot
.91804 .12627 Mdot
.91899 .12083 Mdot
.91994 .11448 Mdot
.9209 .11811 Mdot
.92185 .12083 Mdot
.9228 .1299 Mdot
.92376 .09997 Mdot
.92471 .08636 Mdot
.92566 .06822 Mdot
.92662 .06278 Mdot
.92757 .05553 Mdot
.92852 .05643 Mdot
.92948 .06641 Mdot
.93043 .09997 Mdot
.93138 .11629 Mdot
.93234 .1172 Mdot
.93329 .10994 Mdot
.93424 .12355 Mdot
.9352 .11992 Mdot
.93615 .10904 Mdot
.9371 .1045 Mdot
.93806 .10722 Mdot
.93901 .10087 Mdot
.93996 .11357 Mdot
.94092 .12173 Mdot
.94187 .11811 Mdot
.94282 .11811 Mdot
.94378 .10813 Mdot
.94473 .11539 Mdot
.94568 .13534 Mdot
.94664 .15529 Mdot
.94759 .14804 Mdot
.94854 .15892 Mdot
.9495 .15257 Mdot
.95045 .15983 Mdot
.9514 .16799 Mdot
.95236 .15257 Mdot
.95331 .16345 Mdot
.95426 .15257 Mdot
.95522 .16164 Mdot
.95617 .15892 Mdot
.95712 .15076 Mdot
.95808 .15801 Mdot
.95903 .16799 Mdot
.95998 .16708 Mdot
.96094 .14441 Mdot
.96189 .15166 Mdot
.96284 .15801 Mdot
.9638 .15438 Mdot
.96475 .16527 Mdot
.9657 .15438 Mdot
.96666 .14259 Mdot
.96761 .14441 Mdot
.96856 .15892 Mdot
.96952 .15348 Mdot
.97047 .16073 Mdot
.97142 .16164 Mdot
.97238 .16164 Mdot
.97333 .15892 Mdot
.97428 .15983 Mdot
.97524 .15801 Mdot
.97619 .15529 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`006_oo00<00?ooool0:Ooo0`000ooo00<00?ooool00_oo00<00?ooool09?oo0`00
0_oo00<00?ooool00_oo00<00?ooool09?oo0P001?oo00<00?ooool00_oo00<00?ooool09?oo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool08Ooo1@000_oo00<00?ooool00_oo00<00?ooool0
0_oo00<00?ooool00ooo000Iool00`00ool0000Zool00`00ooooo`02ool00`00ool00002ool00`00
ool0000Vool01P00ooooo`00ool000;oo`03003oo`0002Goo`03003oo`0000;oo`03003oo`0000;o
o`03003oo`0002Coo`03003oo`0000;oo`03003oo`0000;oo`03003oo`0002Coo`07003oooooool0
0?oo00000_oo00<00?oo00000_oo00<00?oo00001?oo000Iool00`00ool0000[ool01`00oooooooo
003oo`0000;oo`03003oo`0002Coo`@00004ool00?oo0002ool00`00ool0000Uool00`00ool00002
ool00`00ool00002ool00`00ool0000Tool00`00ool00002ool00`00ool00002ool00`00ool0000T
ool01`00oooooooo003oo`0000;oo`03003oo`0000;oo`03003oo`0000Coo`006Ooo00<00?oo0000
:ooo00L00?ooooooo`00ool00002ool00`00ool0000Tool00`00ool00002ool00`00ool00002ool0
0`00ool0000Uool20003ool00`00ool00002ool00`00ool0000Uool01`00oooooooo003oo`0000;o
o`03003oo`0002Coo`07003oooooool00?oo00000_oo00<00?oo00000_oo00<00?oo00001?oo000I
ool00`00ool0000Zool00`00ool00002ool00`00ool00002ool00`00ool0000Uool20002ool00`00
ool00002ool00`00ool0000Uool00`00ooooo`02ool00`00ool00002ool00`00ool0000Tool00`00
ool00002ool00`00ool00002ool00`00ool0000Tool01`00oooooooo003oo`0000;oo`03003oo`00
00;oo`03003oo`0000Coo`006_oo00<00?ooool0:_oo00<00?ooool00_oo00<00?ooool00_oo00<0
0?ooool09Ooo00D00?ooooooo`0000Coo`03003ooooo02Goo`8000?oo`03003ooooo00;oo`03003o
oooo02Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo02;oo`8000Coo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00?oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool001Goool000H000Koo`005Ooo00<00?ooool00ooo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool00ooo00<00?ooool01?oo
000Eool00`00ooooo`3oool2ool00`00ooooo`04ool001Goo`03003ooooo0;[oo`8004Goo`03003o
oooo00Coo`005Ooo00<00?ooool0^_oo1000@ooo00<00?ooool01?oo000Eool00`00ooooo`2jool4
0013ool00`00ooooo`04ool001Goo`800;[oo`@004?oo`8000Koo`005Ooo00<00?ooool0^Ooo1000
A?oo00<00?ooool01?oo000Eool00`00ooooo`2hool50003ool2000oool00`00ooooo`04ool001Go
o`03003ooooo0;;oo`<000?oo`<000Coo`<003ooo`03003ooooo00Coo`005Ooo00<00?ooool0/_oo
100000?oo`0000000P001?oo10008Ooo0P006ooo00<00?ooool01?oo000Eool00`00ooooo`2bool9
0003ool5000Qool2000Kool00`00ooooo`04ool001Goo`03003ooooo0;;oo`P000;oo`L003koo`03
003ooooo00Coo`005Ooo00<00?ooool0/_oo20000_oo1`00?_oo00<00?ooool01?oo0003ool50002
ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`2aool300000ooo000000030002ool7000Q
ool20007ool2000Bool00`00ooooo`04ool000Goo`07003oooooool00?oo00000_oo00<00?oo0000
1?oo00<00?ooool0/Ooo0`0000?oo`0000000P000ooo1@0000?oo`0000008?oo0P001ooo0P004_oo
00<00?ooool01?oo0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Coo`800;;oo`<00003
ool00000008000?oo`@000;oo`80023oo`8000Ooo`80013oo`<000Koo`001Ooo00L00?ooooooo`00
ool00002ool00`00ool00004ool00`00ooooo`2aool20002ool30005ool30002ool2000Pool20007
ool3000Aool00`00ooooo`04ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo00<0
0?ooool0/Ooo0P003ooo0`007_oo0P002?oo0`004Ooo00<00?ooool01?oo0004ool20004ool00`00
ooooo`02ool00`00ooooo`03ool00`00ooooo`2^ool4000Aool2000Mool6000Iool00`00ooooo`04
ool001Goo`03003ooooo0:koo`@0017oo`@001_oo`H001Woo`03003ooooo00Coo`005Ooo00<00?oo
ool0<_oo0P00Nooo0`004?oo1@006_oo100000?oo`0000006Ooo00<00?ooool01?oo000Eool00`00
ooooo`0bool2001kool3000@ool5000Jool300000ooo00000005ool2000Cool00`00ooooo`04ool0
01Goo`03003ooooo0:ooo`<0017oo`D000;oo`8001Goo`H000Goo`8001?oo`03003ooooo00Coo`00
5Ooo00<00?ooool0[ooo0`004Ooo1@000_oo0P005Ooo1P0000?oo`0000000P005Ooo00<00?ooool0
1?oo000Eool2001?ool2001dool40002ool2000Fool500000ooo00000002000Dool20006ool001Go
o`03003ooooo04koo`8007Coo`D00004ool00000ool2000Dool20002ool;000?ool00`00ooooo`04
ool001Goo`03003ooooo04koo`8005coo`8001Woo`<00003ool00000008001Soo`800003ool00000
00H000ooo`03003ooooo00Coo`005Ooo00<00?ooool0>_oo0P004_oo0P00G?oo0P006Ooo20006?oo
1@000ooo10003_oo00<00?ooool01?oo000Eool00`00ooooo`0jool2000Aool2000nool2000hool8
00000ooo0000000Fool50002ool4000>ool00`00ooooo`04ool001Goo`03003ooooo03[oo`8000Wo
o`8000Koo`@003coo`8001koo`<001Ooo`@000;oo`800003ool0000001Goo`H00003ool0000000@0
00goo`03003ooooo00Coo`005Ooo00<00?ooool0>_oo0P002Ooo0P001_oo10001_oo0`00<ooo0P00
2?oo10004_oo0`006?oo0`001Ooo0P003ooo0P001?oo3@003Ooo00<00?ooool01?oo000Eool00`00
ooooo`14ool30006ool20006ool5000bool30008ool4000Aool4000Iool20004ool3000?ool20006
ool500000ooo00000002000>ool00`00ooooo`04ool001Goo`03003ooooo03[oo`8000Soo`<000So
o`8000Coo`@0037oo`@00003ool0000000;oo`X000ooo`<001[oo`8000?oo`D001Soo`<00003ool0
0000013oo`03003ooooo00Coo`005Ooo00<00?ooool0>_oo0P002?oo0`001_oo10001_oo0P00<Ooo
1`000_oo2P003ooo0`007ooo1@003Ooo0P002_oo0P004ooo00<00?ooool01?oo000Eool2000jool4
0005ool40007ool40003ool4000Aool2000Pool50002ool;000aool200000ooo0000000=ool2000@
ool2000<ool20006ool001Goo`03003ooooo03Woo`@000Goo`80013oo`@000ooo`@0023oo`800005
ool00000003oo`0;000aool200001?oo000000007_oo0P003Ooo00<00?ooool01?oo000Eool00`00
ooooo`0iool40005ool200001?oo000000001Ooo1@000_oo10003ooo0`009?oo0`0000?oo`000000
0`000_oo1P003?oo0P008Ooo0P000_oo0P002ooo0`005?oo10001ooo00<00?ooool01?oo000Eool0
0`00ooooo`0cool20004ool30005ool70005ool50002ool4000?ool7000Qool200000ooo00000003
0004ool4000<ool2000Uool2000;ool3000@ool20002ool40007ool00`00ooooo`04ool001Goo`03
003ooooo03?oo`8000coo`@00004ool000000008ool20005ool3000;ool9000Kool20004ool70004
ool400001?oo00000000;ooo0P003?oo0P004?oo20001ooo00<00?ooool01?oo000Eool00`00oooo
o`12ool300001?oo000000000ooo0P000ooo1@000_oo0`002ooo2@006ooo0P000ooo1`001ooo0P00
00Coo`00000000;oo`8002_oo`8000_oo`80017oo`X000Goo`03003ooooo00Coo`005Ooo00<00?oo
ool0@_oo0`0000Goo`0000000?oo00@000;oo`H000;oo`<000goo`L0023oo`D000coo`@00003ool0
000003Soo`80017oo`X000Goo`03003ooooo00Coo`005Ooo00<00?ooool0>ooo0P001_oo0P0000Go
o`0000000?oo00@000;oo`D000Coo`8000goo`P0023oo`@000Soo`P00003ool0000002_oo`<001ko
o`T000Goo`03003ooooo00Coo`005Ooo00<00?ooool0>Ooo10000ooo0P001_oo0P0000Coo`000000
00;oo`D000Coo`8000_oo`800003ool0000000D0027oo`8000Woo`P00003ool0000002_oo`<000[o
o`8001;oo`P000Koo`03003ooooo00Coo`005Ooo0P00<ooo0P001Ooo10000ooo0P001Ooo0`0000Co
o`00000000Goo`8000Coo`<000Woo`<000;oo`H0027oo`8000Woo`P00003ool0000000;oo`8002So
o`<000Woo`8001;oo`H000Ooo`8000Koo`005Ooo00<00?ooool0<_oo0P000ooo0P000_oo20001?oo
0`0000?oo`0000003Ooo0P002Ooo0`000_oo0P0000?oo`0000001ooo0P00:Ooo1P000_oo0P00:?oo
0`002?oo0P008Ooo00<00?ooool01?oo000Eool00`00ooooo`0gool20003ool70005ool200000ooo
00000003ool20008ool2000:ool20007ool20005ool3000Vool200000ooo00000009000Vool40003
ool20002ool2000Qool00`00ooooo`04ool001Goo`03003ooooo03coo`H000Koo`@000Coo`8000So
o`8001?oo`8000Coo`@0017oo`8001?oo`8000?oo`T002Koo`@000?oo`8002Goo`03003ooooo00Co
o`005Ooo00<00?ooool0>?oo0P000_oo10002?oo10003_oo10004Ooo0P001?oo10004Ooo0P005ooo
0P000_oo1P009ooo0P001?oo10008ooo00<00?ooool01?oo000Eool00`00ooooo`0cool70002ool2
0002ool30005ool4000?ool30007ool20008ool20004ool4000@ool2000Hool200001?oo00000000
0_oo0P009ooo0P000ooo1`008Ooo00<00?ooool01?oo000Eool00`00ooooo`0cool70003ool20000
1?oo000000001ooo0P006Ooo0P004?oo0`003ooo0`005ooo0P0000Coo`00000002_oo`8000?oo`L0
027oo`03003ooooo00Coo`000ooo1@0000Coo`00000000?oo`03003ooooo00?oo`03003ooooo03Go
o`D000;oo`<000;oo`8001Soo`8000Soo`8000Soo`<000;oo`800004ool00000000?ool3000Gool2
000_ool;000Rool00`00ooooo`04ool000Goo`05003oooooool00004ool00`00ool00004ool00`00
ooooo`0eool30004ool30002ool2000Hool20008ool20008ool30002ool200000ooo00000002000>
ool20019ool700001?oo000000008_oo00<00?ooool01?oo0005ool00`00ooooo`02ool01`00oooo
oooo003oo`0000Coo`8000?oo`8002ooo`H000Coo`8002;oo`8000goo`8000;oo`<00004ool00000
000<ool4001:ool40004ool3000Oool30006ool000Goo`03003ooooo00;oo`07003oooooool00?oo
00001?oo00<00?ooool00_oo0P00;ooo1P001?oo0P007Ooo0P000ooo0P003Ooo1`000ooo0P002ooo
0`00Booo1@000ooo0`008Ooo00<00?ooool01?oo0005ool01`00oooooooo003oo`0000;oo`03003o
o`0000Coo`03003ooooo03?oo`@000Soo`8001_oo`8000Coo`8000coo`H000?oo`P000Koo`<004_o
o`D000?oo`<0027oo`03003ooooo00Coo`001?oo0P001?oo00<00?ooool00_oo00<00?ooool00ooo
00<00?ooool0<ooo0P0000?oo`0000001ooo0P008?oo1@002_oo10001Ooo20001_oo0`00Booo1@00
0ooo0`008Ooo00<00?ooool01?oo000Eool00`00ooooo`0dool40007ool2000Pool200000ooo0000
000<ool30004ool80006ool3001>ool2000Wool00`00ooooo`04ool001Goo`03003ooooo00?oo`80
02goo`H000Ooo`80027oo`8000goo`@000Coo`X005[oo`8002;oo`03003ooooo00Coo`005Ooo00<0
0?ooool00ooo0P00;Ooo10002Ooo0P006ooo0P001?oo10002ooo10001_oo2000F_oo0P008_oo00<0
0?ooool01?oo000Eool00`00ooooo`0eool20008ool2000Kool20004ool4000;ool40006ool80003
ool2001iool00`00ooooo`04ool001Goo`03003ooooo03Goo`8000Soo`80023oo`D000[oo`D000Oo
o`800003ool00000008000?oo`8007Woo`03003ooooo00Coo`005Ooo00<00?ooool0=?oo0P00:_oo
0`0000?oo`0000002_oo1@002ooo0`000_oo0P00N_oo00<00?ooool01?oo000Eool20004ool2000_
ool2000Wool5000?ool2000=ool20002ool4001hool20006ool001Goo`03003ooooo00?oo`8005Oo
o`H00003ool0000001_oo`P007Woo`03003ooooo00Coo`005Ooo00<00?ooool01?oo0P00E_oo0P00
00Goo`0000000?oo008001goo`H007Woo`03003ooooo00Coo`005Ooo00<00?ooool01?oo0P00Eooo
10000_oo0P007Ooo1@00N_oo00<00?ooool01?oo000Eool00`00ooooo`03ool3001Gool4000Qool5
001jool00`00ooooo`04ool001Goo`03003ooooo00?oo`<005Soo`<002;oo`<007_oo`03003ooooo
00Coo`005Ooo00<00?ooool01Ooo0P00F?oo0P008_oo0`00Nooo00<00?ooool01?oo000Eool00`00
ooooo`05ool2001kool3001lool00`00ooooo`04ool001Goo`03003ooooo00Coo`<005Ooo`8002;o
o`<007coo`03003ooooo00Coo`005Ooo0P001Ooo0P00F?oo0P008ooo0P00Nooo0P001_oo000Eool0
0`00ooooo`04ool2001lool2001mool00`00ooooo`04ool001Goo`03003ooooo08;oo`8007goo`03
003ooooo00Coo`005Ooo00<00?ooool0oooo0_oo00<00?ooool01?oo000Eool00`00ooooo`05ool2
003jool00`00ooooo`04ool001Goo`03003ooooo00Goo`@00?Soo`03003ooooo00Coo`005Ooo00<0
0?ooool01Ooo1000n?oo00<00?ooool01?oo000Eool00`00ooooo`05ool4003hool00`00ooooo`04
ool001Goo`03003ooooo00Koo`<00?Soo`03003ooooo00Coo`005Ooo00<00?ooool01ooo0P00:Ooo
0P00cOoo00<00?ooool01?oo000Eool20007ool2000Zool2003<ool20006ool001Goo`03003ooooo
00Koo`800?Woo`03003ooooo00Coo`005Ooo00<00?ooool01_oo0P00nOoo00<00?ooool01?oo000E
ool00`00ooooo`06ool2003iool00`00ooooo`04ool001Goo`03003ooooo00Koo`800?Woo`03003o
oooo00Coo`005Ooo00<00?ooool02?oo1000mOoo00<00?ooool01?oo000Eool00`00ooooo`08ool4
003eool00`00ooooo`04ool000?oo`D000;oo`<000;oo`03003ooooo00?oo`03003ooooo00Soo`D0
0?Coo`03003ooooo00Coo`001Ooo00<00?ooool00ooo00H00?ooool00?oo0004ool00`00ooooo`08
ool5003dool00`00ooooo`04ool000Goo`04003oooooool400001?oo003oo`001?oo0P002Ooo1@00
9?oo0P00c?oo0`001_oo0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Coo`03003ooooo
00[oo`<002Coo`800<koo`03003ooooo00Coo`001Ooo00<00?ooool00_oo0P000_oo00<00?oo0000
1?oo00<00?ooool02ooo0P00m?oo00<00?ooool01?oo0004ool20005ool01@00oooooooo00001Ooo
00<00?ooool02Ooo0P0000?oo`000000looo00<00?ooool01?oo000Eool00`00ooooo`09ool20000
0ooo0000003cool00`00ooooo`04ool001Goo`03003ooooo00_oo`800?Coo`03003ooooo00Coo`00
5Ooo00<00?ooool02Ooo1000m?oo00<00?ooool01?oo000Eool00`00ooooo`09ool20006ool2003^
ool00`00ooooo`04ool001Goo`03003ooooo00coo`8000?oo`800>koo`03003ooooo00Coo`005Ooo
00<00?ooool03?oo0P000ooo0P00k_oo00<00?ooool01?oo000Eool2000=ool20003ool2000Nool2
003=ool20006ool001Goo`03003ooooo037oo`800<koo`03003ooooo00Coo`005Ooo00<00?ooool0
3Ooo0P0000?oo`000000kooo00<00?ooool01?oo000Eool00`00ooooo`0=ool200000ooo0000003_
ool00`00ooooo`04ool001Goo`03003ooooo00goo`8000;oo`8001goo`800<ooo`03003ooooo00Co
o`005Ooo00<00?ooool04?oo10007?oo0P00cooo00<00?ooool01?oo000Eool00`00ooooo`0=ool2
00000ooo00000002000Mool2003>ool00`00ooooo`04ool001Goo`03003ooooo00goo`8002;oo`80
0<koo`03003ooooo00Coo`005Ooo00<00?ooool03_oo10007ooo0P00c_oo00<00?ooool01?oo000E
ool2000?ool6000Mool2003=ool20006ool001Goo`03003ooooo00ooo`800003ool0000001Woo`@0
0=3oo`03003ooooo00Coo`005Ooo00<00?ooool03ooo0P0000?oo`0000006Ooo1@00cooo00<00?oo
ool01?oo000Eool00`00ooooo`0?ool20002ool2000Kool2003?ool00`00ooooo`04ool001Goo`03
003ooooo00ooo`8000;oo`8001_oo`800<ooo`03003ooooo00Coo`005Ooo00<00?ooool03_oo0`00
7Ooo1000cooo00<00?ooool01?oo000Eool00`00ooooo`0>ool2000Nool4003?ool00`00ooooo`04
ool001Goo`03003ooooo00koo`800?7oo`03003ooooo00Coo`005Ooo00<00?ooool03_oo0P000ooo
0`005ooo1000d?oo00<00?ooool01?oo000Eool2000Dool3000Gool4003?ool20006ool001Goo`03
003ooooo00koo`8000Coo`8001Ooo`@00=3oo`03003ooooo00Coo`005Ooo00<00?ooool03_oo0P00
1?oo0P005ooo1000d?oo00<00?ooool01?oo000Eool00`00ooooo`0Hool20002ool2000>ool5003@
ool00`00ooooo`04ool001Goo`03003ooooo01?oo`8000?oo`H000goo`<00003ool000000=3oo`03
003ooooo00Coo`005Ooo00<00?ooool04ooo0P000ooo1@003_oo0`00dooo00<00?ooool01?oo000E
ool00`00ooooo`0Kool2000>ool3003Cool00`00ooooo`04ool001Goo`03003ooooo01Coo`8001Ko
o`800=?oo`03003ooooo00Coo`000ooo1@0000?oo`0000001?oo00<00?ooool00ooo00<00?ooool0
5?oo0P003_oo0`00f_oo00<00?ooool01?oo0005ool01`00oooooooo003oo`0000;oo`03003oo`00
00Coo`03003ooooo01Woo`D000Koo`<00=[oo`03003ooooo00Coo`001Ooo00L00?ooooooo`00ool0
0002ool00`00ool00004ool2000Eool20003ool50005ool4003Hool30006ool000Goo`04003ooooo
ool20003ool00`00ool00004ool00`00ooooo`0Dool800000ooo00000004ool40003ool2003Eool0
0`00ooooo`04ool000Goo`05003oooooool00004ool00`00ool00004ool00`00ooooo`0Eool:0003
ool40004ool3003Dool00`00ooooo`04ool000Coo`8000Coo`8000?oo`03003ooooo00?oo`03003o
oooo01[oo`D000?oo`@000Coo`@00=?oo`03003ooooo00Coo`005Ooo00<00?ooool07?oo0P0000?o
o`0000000_oo0`001?oo1000dooo00<00?ooool01?oo000Eool00`00ooooo`0Eool300000ooo0000
0004ool200000ooo000000030003ool2003Eool00`00ooooo`04ool001Goo`03003ooooo01Goo`<0
0003ool0000000;oo`8000?oo`800003ool0000000?oo`800=Goo`03003ooooo00Coo`005Ooo00<0
0?ooool05_oo0P001Ooo1@00gooo00<00?ooool01?oo000Eool00`00ooooo`0Fool20007ool50000
0ooo0000003Jool00`00ooooo`04ool001Goo`8001Ooo`<000Coo`@00004ool00000ool2003Iool2
0006ool001Goo`03003ooooo01Koo`<000Coo`@00>3oo`03003ooooo00Coo`005Ooo00<00?ooool0
5_oo0`001Ooo10001ooo0P00e_oo00<00?ooool01?oo000Eool00`00ooooo`0Eool40005ool40004
ool200000ooo0000003Fool00`00ooooo`04ool001Goo`03003ooooo01Goo`8000Ooo`H000;oo`80
0003ool000000=Koo`03003ooooo00Coo`005Ooo00<00?ooool05Ooo0P001ooo1P001Ooo0P00e_oo
00<00?ooool01?oo000Eool00`00ooooo`0Nool200000ooo00000006ool2003Fool00`00ooooo`04
ool001Goo`03003ooooo027oo`8000Koo`800=Koo`03003ooooo00Coo`005Ooo00<00?ooool09_oo
0P00fOoo00<00?ooool01?oo000Eool00`00ooooo`0Qool20003ool2003Iool00`00ooooo`04ool0
01Goo`8002;oo`8000?oo`800=Soo`8000Koo`005Ooo00<00?ooool09_oo0P00fOoo00<00?ooool0
1?oo000Eool00`00ooooo`3oool2ool00`00ooooo`04ool001Goo`03003ooooo02Soo`800=Ooo`03
003ooooo00Coo`005Ooo00<00?ooool09ooo0`00eooo00<00?ooool01?oo000Eool00`00ooooo`0W
ool2003Hool00`00ooooo`04ool001Goo`03003ooooo02Koo`<00=Soo`03003ooooo00Coo`005Ooo
00<00?ooool09_oo0`00f?oo00<00?ooool01?oo000Eool00`00ooooo`0Wool3003Gool00`00oooo
o`04ool001Goo`8002Soo`<00=Koo`8000Koo`005Ooo00<00?ooool0oooo0_oo00<00?ooool01?oo
000Eool00`00ooooo`03ool00`00ooooo`0^ool00`00ooooo`0_ool00`00ooooo`0^ool00`00oooo
o`0_ool00`00ooooo`0_ool00`00ooooo`03ool00`00ooooo`04ool001Goool000H000Koo`00oooo
8Ooo003ooolQool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-109.729, 84.0312, 4.0354, \
0.530228}}]
}, Open  ]],

Cell["Finally we display all three graphs together. ", "MathCaption",
  CellTags->{"S0.4", "4.10"}],

Cell[CellGroupData[{

Cell["\<\
Show[{g[0], g[15], g[75]},
   DisplayFunction -> $DisplayFunction];\
\>", "Input",
  CellLabel->"In[81]:=",
  CellTags->"S0.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228562 0.000953334 -0.664583 0.00725552 [
[.02286 -0.0125 -3 -9 ]
[.02286 -0.0125 3 0 ]
[.21352 -0.0125 -9 -9 ]
[.21352 -0.0125 9 0 ]
[.40419 -0.0125 -9 -9 ]
[.40419 -0.0125 9 0 ]
[.59486 -0.0125 -9 -9 ]
[.59486 -0.0125 9 0 ]
[.78552 -0.0125 -9 -9 ]
[.78552 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06097 -18 -4.5 ]
[-0.0125 .06097 0 4.5 ]
[-0.0125 .20608 -18 -4.5 ]
[-0.0125 .20608 0 4.5 ]
[-0.0125 .35119 -18 -4.5 ]
[-0.0125 .35119 0 4.5 ]
[-0.0125 .4963 -18 -4.5 ]
[-0.0125 .4963 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02286 0 m
.02286 .00625 L
s
[(0)] .02286 -0.0125 0 1 Mshowa
.21352 0 m
.21352 .00625 L
s
[(200)] .21352 -0.0125 0 1 Mshowa
.40419 0 m
.40419 .00625 L
s
[(400)] .40419 -0.0125 0 1 Mshowa
.59486 0 m
.59486 .00625 L
s
[(600)] .59486 -0.0125 0 1 Mshowa
.78552 0 m
.78552 .00625 L
s
[(800)] .78552 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07052 0 m
.07052 .00375 L
s
.11819 0 m
.11819 .00375 L
s
.16586 0 m
.16586 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.30886 0 m
.30886 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.49952 0 m
.49952 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.69019 0 m
.69019 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.88086 0 m
.88086 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06097 m
.00625 .06097 L
s
[(100)] -0.0125 .06097 1 0 Mshowa
0 .20608 m
.00625 .20608 L
s
[(120)] -0.0125 .20608 1 0 Mshowa
0 .35119 m
.00625 .35119 L
s
[(140)] -0.0125 .35119 1 0 Mshowa
0 .4963 m
.00625 .4963 L
s
[(160)] -0.0125 .4963 1 0 Mshowa
.125 Mabswid
0 .09725 m
.00375 .09725 L
s
0 .13352 m
.00375 .13352 L
s
0 .1698 m
.00375 .1698 L
s
0 .24236 m
.00375 .24236 L
s
0 .27863 m
.00375 .27863 L
s
0 .31491 m
.00375 .31491 L
s
0 .38747 m
.00375 .38747 L
s
0 .42374 m
.00375 .42374 L
s
0 .46002 m
.00375 .46002 L
s
0 .02469 m
.00375 .02469 L
s
0 .53258 m
.00375 .53258 L
s
0 .56886 m
.00375 .56886 L
s
0 .60513 m
.00375 .60513 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02286 .61178 m
.02286 .61803 L
s
.21352 .61178 m
.21352 .61803 L
s
.40419 .61178 m
.40419 .61803 L
s
.59486 .61178 m
.59486 .61803 L
s
.78552 .61178 m
.78552 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07052 .61428 m
.07052 .61803 L
s
.11819 .61428 m
.11819 .61803 L
s
.16586 .61428 m
.16586 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.30886 .61428 m
.30886 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.49952 .61428 m
.49952 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.69019 .61428 m
.69019 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.88086 .61428 m
.88086 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06097 m
1 .06097 L
s
.99375 .20608 m
1 .20608 L
s
.99375 .35119 m
1 .35119 L
s
.99375 .4963 m
1 .4963 L
s
.125 Mabswid
.99625 .09725 m
1 .09725 L
s
.99625 .13352 m
1 .13352 L
s
.99625 .1698 m
1 .1698 L
s
.99625 .24236 m
1 .24236 L
s
.99625 .27863 m
1 .27863 L
s
.99625 .31491 m
1 .31491 L
s
.99625 .38747 m
1 .38747 L
s
.99625 .42374 m
1 .42374 L
s
.99625 .46002 m
1 .46002 L
s
.99625 .02469 m
1 .02469 L
s
.99625 .53258 m
1 .53258 L
s
.99625 .56886 m
1 .56886 L
s
.99625 .60513 m
1 .60513 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.02381 .20608 Mdot
.02476 .20608 Mdot
.02572 .24417 Mdot
.02667 .22603 Mdot
.02762 .22603 Mdot
.02858 .25959 Mdot
.02953 .25143 Mdot
.03048 .25868 Mdot
.03144 .2741 Mdot
.03239 .27863 Mdot
.03334 .26866 Mdot
.0343 .26957 Mdot
.03525 .29496 Mdot
.0362 .3004 Mdot
.03716 .31582 Mdot
.03811 .32852 Mdot
.03906 .32035 Mdot
.04002 .30584 Mdot
.04097 .30312 Mdot
.04192 .30766 Mdot
.04288 .29768 Mdot
.04383 .31128 Mdot
.04478 .3394 Mdot
.04574 .33668 Mdot
.04669 .34484 Mdot
.04764 .34847 Mdot
.0486 .37568 Mdot
.04955 .37296 Mdot
.0505 .36389 Mdot
.05146 .34665 Mdot
.05241 .34756 Mdot
.05336 .34031 Mdot
.05432 .33759 Mdot
.05527 .35028 Mdot
.05622 .35391 Mdot
.05718 .34665 Mdot
.05813 .34303 Mdot
.05908 .37205 Mdot
.06004 .36389 Mdot
.06099 .38203 Mdot
.06194 .38656 Mdot
.0629 .38475 Mdot
.06385 .40289 Mdot
.0648 .39654 Mdot
.06576 .40198 Mdot
.06671 .41377 Mdot
.06766 .42193 Mdot
.06862 .4446 Mdot
.06957 .46456 Mdot
.07052 .45277 Mdot
.07148 .42919 Mdot
.07243 .44098 Mdot
.07338 .42465 Mdot
.07434 .43191 Mdot
.07529 .40923 Mdot
.07624 .42012 Mdot
.0772 .41921 Mdot
.07815 .39835 Mdot
.0791 .40651 Mdot
.08006 .38021 Mdot
.08101 .38747 Mdot
.08196 .40651 Mdot
.08292 .41014 Mdot
.08387 .43009 Mdot
.08482 .42374 Mdot
.08578 .42374 Mdot
.08673 .47453 Mdot
.08768 .45458 Mdot
.08864 .45458 Mdot
.08959 .43644 Mdot
.09054 .45458 Mdot
.0915 .46184 Mdot
.09245 .48632 Mdot
.0934 .49721 Mdot
.09436 .50083 Mdot
.09531 .51807 Mdot
.09626 .54618 Mdot
.09722 .54527 Mdot
.09817 .53167 Mdot
.09912 .52351 Mdot
.10008 .51807 Mdot
.10103 .5353 Mdot
.10198 .54165 Mdot
.10294 .53348 Mdot
.10389 .50083 Mdot
.10484 .50356 Mdot
.1058 .47272 Mdot
.10675 .47181 Mdot
.1077 .47635 Mdot
.10866 .47181 Mdot
.10961 .50083 Mdot
.11056 .50356 Mdot
.11152 .51535 Mdot
.11247 .4963 Mdot
.11342 .49358 Mdot
.11438 .47635 Mdot
.11533 .49811 Mdot
.11628 .50628 Mdot
.11724 .4963 Mdot
.11819 .50537 Mdot
.11914 .49539 Mdot
.1201 .47998 Mdot
.12105 .47907 Mdot
.122 .47181 Mdot
.12296 .49358 Mdot
.12391 .51081 Mdot
.12486 .50628 Mdot
.12582 .50265 Mdot
.12677 .50628 Mdot
.12772 .51988 Mdot
.12868 .53167 Mdot
.12963 .54074 Mdot
.13058 .55344 Mdot
.13154 .54346 Mdot
.13249 .5353 Mdot
.13344 .51444 Mdot
.1344 .52532 Mdot
.13535 .52714 Mdot
.1363 .53348 Mdot
.13726 .52442 Mdot
.13821 .54527 Mdot
.13916 .54165 Mdot
.14012 .54709 Mdot
.14107 .56795 Mdot
.14202 .55072 Mdot
.14298 .55434 Mdot
.14393 .55525 Mdot
.14488 .54709 Mdot
.14584 .52986 Mdot
.14679 .51625 Mdot
.14774 .50628 Mdot
.1487 .49721 Mdot
.14965 .50537 Mdot
.1506 .51172 Mdot
.15156 .50537 Mdot
.15251 .50718 Mdot
.15346 .51353 Mdot
.15442 .50356 Mdot
.15537 .49086 Mdot
.15632 .49177 Mdot
.15728 .49811 Mdot
.15823 .51807 Mdot
.15918 .52804 Mdot
.16014 .54527 Mdot
.16109 .5616 Mdot
.16204 .57158 Mdot
.163 .59334 Mdot
.16395 .59244 Mdot
.1649 .60151 Mdot
.16586 .58971 Mdot
.16681 .5879 Mdot
.16776 .60332 Mdot
.16872 .60332 Mdot
.16967 .60241 Mdot
.17062 .58337 Mdot
.17158 .55344 Mdot
.17253 .54165 Mdot
.17348 .54346 Mdot
.17444 .55706 Mdot
.17539 .51716 Mdot
.17634 .51444 Mdot
.1773 .50809 Mdot
.17825 .50174 Mdot
.1792 .47998 Mdot
.18016 .47635 Mdot
.18111 .47998 Mdot
.18206 .50446 Mdot
.18302 .51081 Mdot
.18397 .47816 Mdot
.18492 .47181 Mdot
.18588 .48088 Mdot
.18683 .46274 Mdot
.18778 .42737 Mdot
.18874 .46546 Mdot
.18969 .45458 Mdot
.19064 .46637 Mdot
.1916 .46728 Mdot
.19255 .4437 Mdot
.1935 .42737 Mdot
.19446 .42919 Mdot
.19541 .4573 Mdot
.19636 .46184 Mdot
.19732 .47091 Mdot
.19827 .431 Mdot
.19922 .4437 Mdot
.20018 .43463 Mdot
.20113 .4047 Mdot
.20208 .42012 Mdot
.20304 .41468 Mdot
.20399 .38928 Mdot
.20494 .3521 Mdot
.2059 .31491 Mdot
.20685 .08274 Mdot
.2078 .1698 Mdot
.20876 .22603 Mdot
.20971 .20608 Mdot
.21066 .21152 Mdot
.21162 .14804 Mdot
.21257 .19157 Mdot
.21352 .19157 Mdot
.21448 .20789 Mdot
.21543 .22422 Mdot
.21638 .23873 Mdot
.21734 .21968 Mdot
.21829 .21061 Mdot
.21924 .23329 Mdot
.2202 .20245 Mdot
.22115 .19248 Mdot
.2221 .18975 Mdot
.22306 .20064 Mdot
.22401 .2224 Mdot
.22496 .21787 Mdot
.22592 .20608 Mdot
.22687 .18975 Mdot
.22782 .19429 Mdot
.22878 .17434 Mdot
.22973 .18975 Mdot
.23068 .18794 Mdot
.23164 .1952 Mdot
.23259 .18885 Mdot
.23354 .16889 Mdot
.2345 .13897 Mdot
.23545 .14259 Mdot
.2364 .13715 Mdot
.23736 .10813 Mdot
.23831 .1172 Mdot
.23926 .1299 Mdot
.24022 .14441 Mdot
.24117 .16255 Mdot
.24212 .14078 Mdot
.24308 .13443 Mdot
.24403 .17071 Mdot
.24498 .17706 Mdot
.24594 .19792 Mdot
.24689 .17343 Mdot
.24784 .18613 Mdot
.2488 .19338 Mdot
.24975 .19338 Mdot
.2507 .20245 Mdot
.25166 .20517 Mdot
.25261 .17524 Mdot
.25356 .17706 Mdot
.25452 .18431 Mdot
.25547 .17343 Mdot
.25642 .21152 Mdot
.25738 .21968 Mdot
.25833 .22694 Mdot
.25928 .23057 Mdot
.26024 .16889 Mdot
.26119 .18975 Mdot
.26214 .17162 Mdot
.2631 .17796 Mdot
.26405 .17615 Mdot
.265 .19882 Mdot
.26596 .18975 Mdot
.26691 .14622 Mdot
.26786 .13625 Mdot
.26882 .14078 Mdot
.26977 .13715 Mdot
.27072 .1571 Mdot
.27168 .14713 Mdot
.27263 .15348 Mdot
.27358 .16073 Mdot
.27454 .15076 Mdot
.27549 .13352 Mdot
.27644 .13262 Mdot
.2774 .12627 Mdot
.27835 .12355 Mdot
.2793 .11901 Mdot
.28026 .1172 Mdot
.28121 .12718 Mdot
.28216 .14531 Mdot
.28312 .14259 Mdot
.28407 .14804 Mdot
.28502 .16073 Mdot
.28598 .15348 Mdot
.28693 .15166 Mdot
.28788 .15801 Mdot
.28884 .17162 Mdot
.28979 .17252 Mdot
.29074 .17796 Mdot
.2917 .16617 Mdot
.29265 .17524 Mdot
.2936 .18794 Mdot
.29456 .18431 Mdot
.29551 .18613 Mdot
.29646 .18069 Mdot
.29742 .18341 Mdot
.29837 .18613 Mdot
.29932 .18885 Mdot
.30028 .18159 Mdot
.30123 .16073 Mdot
.30218 .17343 Mdot
.30314 .17343 Mdot
.30409 .16255 Mdot
.30504 .17162 Mdot
.306 .16889 Mdot
.30695 .16436 Mdot
.3079 .16073 Mdot
.30886 .1562 Mdot
.30981 .14531 Mdot
.31076 .13171 Mdot
.31172 .11176 Mdot
.31267 .11992 Mdot
.31362 .1036 Mdot
.31458 .09815 Mdot
.31553 .11629 Mdot
.31648 .11539 Mdot
.31744 .11539 Mdot
.31839 .1308 Mdot
.31934 .12808 Mdot
.3203 .14531 Mdot
.32125 .15801 Mdot
.3222 .15983 Mdot
.32316 .17796 Mdot
.32411 .1435 Mdot
.32506 .16345 Mdot
.32602 .16255 Mdot
.32697 .1562 Mdot
.32792 .15438 Mdot
.32888 .15076 Mdot
.32983 .16073 Mdot
.33078 .16164 Mdot
.33174 .16436 Mdot
.33269 .16255 Mdot
.33364 .1562 Mdot
.3346 .15801 Mdot
.33555 .16345 Mdot
.3365 .16708 Mdot
.33746 .1571 Mdot
.33841 .14259 Mdot
.33936 .13715 Mdot
.34032 .13715 Mdot
.34127 .13987 Mdot
.34222 .12445 Mdot
.34318 .12445 Mdot
.34413 .13625 Mdot
.34508 .14531 Mdot
.34604 .13443 Mdot
.34699 .12536 Mdot
.34794 .13715 Mdot
.3489 .1299 Mdot
.34985 .12445 Mdot
.3508 .12808 Mdot
.35176 .12264 Mdot
.35271 .12083 Mdot
.35366 .11901 Mdot
.35462 .15166 Mdot
.35557 .1562 Mdot
.35652 .15257 Mdot
.35748 .1571 Mdot
.35843 .16527 Mdot
.35938 .16073 Mdot
.36034 .18159 Mdot
.36129 .17252 Mdot
.36224 .17706 Mdot
.3632 .18431 Mdot
.36415 .19701 Mdot
.3651 .19792 Mdot
.36606 .18522 Mdot
.36701 .18794 Mdot
.36796 .18522 Mdot
.36892 .20789 Mdot
.36987 .22785 Mdot
.37082 .2478 Mdot
.37178 .24326 Mdot
.37273 .24236 Mdot
.37368 .25687 Mdot
.37464 .25687 Mdot
.37559 .25959 Mdot
.37654 .25415 Mdot
.3775 .27319 Mdot
.37845 .25596 Mdot
.3794 .2614 Mdot
.38036 .25233 Mdot
.38131 .25505 Mdot
.38226 .24417 Mdot
.38322 .24417 Mdot
.38417 .24054 Mdot
.38512 .24598 Mdot
.38608 .24326 Mdot
.38703 .2351 Mdot
.38798 .2351 Mdot
.38894 .21878 Mdot
.38989 .20699 Mdot
.39084 .22331 Mdot
.3918 .22513 Mdot
.39275 .21424 Mdot
.3937 .23329 Mdot
.39466 .2478 Mdot
.39561 .25143 Mdot
.39656 .2478 Mdot
.39752 .2478 Mdot
.39847 .23692 Mdot
.39942 .23419 Mdot
.40038 .22875 Mdot
.40133 .21787 Mdot
.40228 .19792 Mdot
.40324 .19882 Mdot
.40419 .19157 Mdot
.40514 .17071 Mdot
.4061 .17524 Mdot
.40705 .16708 Mdot
.408 .16708 Mdot
.40896 .15348 Mdot
.40991 .13897 Mdot
.41086 .13987 Mdot
.41182 .15348 Mdot
.41277 .14531 Mdot
.41372 .14985 Mdot
.41468 .15801 Mdot
.41563 .15438 Mdot
.41658 .14441 Mdot
.41754 .13534 Mdot
.41849 .16255 Mdot
.41944 .15438 Mdot
.4204 .14622 Mdot
.42135 .14894 Mdot
.4223 .16527 Mdot
.42326 .15983 Mdot
.42421 .1698 Mdot
.42516 .16708 Mdot
.42612 .16073 Mdot
.42707 .16436 Mdot
.42802 .15348 Mdot
.42898 .15348 Mdot
.42993 .1571 Mdot
.43088 .14804 Mdot
.43184 .15438 Mdot
.43279 .14985 Mdot
.43374 .1571 Mdot
.4347 .16164 Mdot
.43565 .17252 Mdot
.4366 .17252 Mdot
.43756 .16889 Mdot
.43851 .16617 Mdot
.43946 .16164 Mdot
.44042 .16255 Mdot
.44137 .17706 Mdot
.44232 .17796 Mdot
.44328 .19701 Mdot
.44423 .18794 Mdot
.44518 .1961 Mdot
.44614 .20427 Mdot
.44709 .21424 Mdot
.44804 .23782 Mdot
.449 .22331 Mdot
.44995 .24145 Mdot
.4509 .23782 Mdot
.45186 .22875 Mdot
.45281 .22694 Mdot
.45376 .21787 Mdot
.45472 .20789 Mdot
.45567 .21152 Mdot
.45662 .22513 Mdot
.45758 .2351 Mdot
.45853 .22694 Mdot
.45948 .2224 Mdot
.46044 .20789 Mdot
.46139 .19973 Mdot
.46234 .20427 Mdot
.4633 .20517 Mdot
.46425 .20427 Mdot
.4652 .18159 Mdot
.46616 .18522 Mdot
.46711 .18794 Mdot
.46806 .17343 Mdot
.46902 .17343 Mdot
.46997 .17524 Mdot
.47092 .17434 Mdot
.47188 .18431 Mdot
.47283 .19157 Mdot
.47378 .17706 Mdot
.47474 .19792 Mdot
.47569 .20154 Mdot
.47664 .1952 Mdot
.4776 .19338 Mdot
.47855 .20064 Mdot
.4795 .21243 Mdot
.48046 .2215 Mdot
.48141 .21333 Mdot
.48236 .20154 Mdot
.48332 .2088 Mdot
.48427 .20971 Mdot
.48522 .21152 Mdot
.48618 .20971 Mdot
.48713 .21333 Mdot
.48808 .21515 Mdot
.48904 .22603 Mdot
.48999 .22966 Mdot
.49094 .22785 Mdot
.4919 .22422 Mdot
.49285 .23057 Mdot
.4938 .22875 Mdot
.49476 .22422 Mdot
.49571 .22966 Mdot
.49666 .21968 Mdot
.49762 .21333 Mdot
.49857 .22422 Mdot
.49952 .2224 Mdot
.50048 .21968 Mdot
.50143 .22059 Mdot
.50238 .21424 Mdot
.50334 .2224 Mdot
.50429 .22875 Mdot
.50524 .23057 Mdot
.5062 .23692 Mdot
.50715 .23419 Mdot
.5081 .24236 Mdot
.50906 .23692 Mdot
.51001 .23238 Mdot
.51096 .22331 Mdot
.51192 .23692 Mdot
.51287 .22966 Mdot
.51382 .24961 Mdot
.51478 .25596 Mdot
.51573 .26957 Mdot
.51668 .28317 Mdot
.51764 .27591 Mdot
.51859 .26684 Mdot
.51954 .26231 Mdot
.5205 .25415 Mdot
.52145 .2614 Mdot
.5224 .25687 Mdot
.52336 .25233 Mdot
.52431 .24236 Mdot
.52526 .24961 Mdot
.52622 .24054 Mdot
.52717 .25687 Mdot
.52812 .24871 Mdot
.52908 .24417 Mdot
.53003 .24598 Mdot
.53098 .23057 Mdot
.53194 .23057 Mdot
.53289 .21424 Mdot
.53384 .21787 Mdot
.5348 .21696 Mdot
.53575 .20517 Mdot
.5367 .20971 Mdot
.53766 .21243 Mdot
.53861 .21696 Mdot
.53956 .20517 Mdot
.54052 .20336 Mdot
.54147 .1961 Mdot
.54242 .19338 Mdot
.54338 .19792 Mdot
.54433 .19066 Mdot
.54528 .18431 Mdot
.54624 .19248 Mdot
.54719 .15166 Mdot
.54814 .1299 Mdot
.5491 .13443 Mdot
.55005 .12808 Mdot
.551 .1308 Mdot
.55196 .13443 Mdot
.55291 .13352 Mdot
.55386 .1308 Mdot
.55482 .12445 Mdot
.55577 .12718 Mdot
.55672 .12264 Mdot
.55768 .11266 Mdot
.55863 .1172 Mdot
.55958 .11901 Mdot
.56054 .13171 Mdot
.56149 .13352 Mdot
.56244 .14169 Mdot
.5634 .14169 Mdot
.56435 .12808 Mdot
.5653 .13987 Mdot
.56626 .1435 Mdot
.56721 .15529 Mdot
.56816 .15076 Mdot
.56912 .15076 Mdot
.57007 .15892 Mdot
.57102 .15892 Mdot
.57198 .16617 Mdot
.57293 .16617 Mdot
.57388 .16708 Mdot
.57484 .16345 Mdot
.57579 .15801 Mdot
.57674 .15076 Mdot
.5777 .14441 Mdot
.57865 .13806 Mdot
.5796 .12899 Mdot
.58056 .1299 Mdot
.58151 .13171 Mdot
.58246 .1308 Mdot
.58342 .12718 Mdot
.58437 .13897 Mdot
.58532 .15348 Mdot
.58628 .1435 Mdot
.58723 .14441 Mdot
.58818 .14804 Mdot
.58914 .14169 Mdot
.59009 .13262 Mdot
.59104 .1299 Mdot
.592 .13171 Mdot
.59295 .1308 Mdot
.5939 .1299 Mdot
.59486 .12083 Mdot
.59581 .1308 Mdot
.59676 .13352 Mdot
.59772 .13443 Mdot
.59867 .12627 Mdot
.59962 .1308 Mdot
.60058 .1299 Mdot
.60153 .12808 Mdot
.60248 .12173 Mdot
.60344 .12536 Mdot
.60439 .14078 Mdot
.60534 .13625 Mdot
.6063 .12899 Mdot
.60725 .1299 Mdot
.6082 .13625 Mdot
.60916 .1299 Mdot
.61011 .13171 Mdot
.61106 .12718 Mdot
.61202 .13987 Mdot
.61297 .14804 Mdot
.61392 .16527 Mdot
.61488 .16164 Mdot
.61583 .14441 Mdot
.61678 .14713 Mdot
.61774 .14985 Mdot
.61869 .14804 Mdot
.61964 .14531 Mdot
.6206 .14894 Mdot
.62155 .16708 Mdot
.6225 .16164 Mdot
.62346 .16799 Mdot
.62441 .16889 Mdot
.62536 .16799 Mdot
.62632 .17706 Mdot
.62727 .16799 Mdot
.62822 .16527 Mdot
.62918 .15348 Mdot
.63013 .16345 Mdot
.63108 .15892 Mdot
.63204 .15348 Mdot
.63299 .15166 Mdot
.63394 .15529 Mdot
.6349 .15801 Mdot
.63585 .1698 Mdot
.6368 .16708 Mdot
.63776 .16255 Mdot
.63871 .16073 Mdot
.63966 .17343 Mdot
.64062 .18703 Mdot
.64157 .19338 Mdot
.64252 .18522 Mdot
.64348 .18794 Mdot
.64443 .17343 Mdot
.64538 .17796 Mdot
.64634 .17887 Mdot
.64729 .17343 Mdot
.64824 .16799 Mdot
.6492 .17071 Mdot
.65015 .15529 Mdot
.6511 .15983 Mdot
.65206 .16255 Mdot
.65301 .17706 Mdot
.65396 .17796 Mdot
.65492 .19157 Mdot
.65587 .17978 Mdot
.65682 .18341 Mdot
.65778 .18522 Mdot
.65873 .18703 Mdot
.65968 .18975 Mdot
.66064 .1825 Mdot
.66159 .17887 Mdot
.66254 .17706 Mdot
.6635 .17887 Mdot
.66445 .18341 Mdot
.6654 .17252 Mdot
.66636 .17524 Mdot
.66731 .17343 Mdot
.66826 .17796 Mdot
.66922 .17706 Mdot
.67017 .17706 Mdot
.67112 .17796 Mdot
.67208 .18069 Mdot
.67303 .17887 Mdot
.67398 .18794 Mdot
.67494 .14441 Mdot
.67589 .12627 Mdot
.67684 .12808 Mdot
.6778 .12355 Mdot
.67875 .1045 Mdot
.6797 .12083 Mdot
.68066 .11539 Mdot
.68161 .11539 Mdot
.68256 .12808 Mdot
.68352 .12083 Mdot
.68447 .1172 Mdot
.68542 .11629 Mdot
.68638 .07548 Mdot
.68733 .08274 Mdot
.68828 .07729 Mdot
.68924 .07367 Mdot
.69019 .0909 Mdot
.69114 .0918 Mdot
.6921 .08636 Mdot
.69305 .08274 Mdot
.694 .07457 Mdot
.69496 .06641 Mdot
.69591 .06006 Mdot
.69686 .05734 Mdot
.69782 .06278 Mdot
.69877 .06097 Mdot
.69972 .04555 Mdot
.70068 .05009 Mdot
.70163 .03648 Mdot
.70258 .04192 Mdot
.70354 .03739 Mdot
.70449 .04192 Mdot
.70544 .04736 Mdot
.7064 .04827 Mdot
.70735 .04646 Mdot
.7083 .04555 Mdot
.70926 .04011 Mdot
.71021 .05462 Mdot
.71116 .0519 Mdot
.71212 .05734 Mdot
.71307 .06188 Mdot
.71402 .06369 Mdot
.71498 .05643 Mdot
.71593 .05281 Mdot
.71688 .04464 Mdot
.71784 .04374 Mdot
.71879 .04011 Mdot
.71974 .05553 Mdot
.7207 .05825 Mdot
.72165 .05099 Mdot
.7226 .04646 Mdot
.72356 .0383 Mdot
.72451 .03285 Mdot
.72546 .0392 Mdot
.72642 .03104 Mdot
.72737 .0256 Mdot
.72832 .02469 Mdot
.72928 .01472 Mdot
.73023 .02288 Mdot
.73118 .02197 Mdot
.73214 .0256 Mdot
.73309 .02741 Mdot
.73404 .02106 Mdot
.735 .02288 Mdot
.73595 .01834 Mdot
.7369 .01834 Mdot
.73786 .04646 Mdot
.73881 .05281 Mdot
.73976 .06097 Mdot
.74072 .05916 Mdot
.74167 .06369 Mdot
.74262 .05643 Mdot
.74358 .05371 Mdot
.74453 .06006 Mdot
.74548 .04555 Mdot
.74644 .04736 Mdot
.74739 .06188 Mdot
.74834 .05281 Mdot
.7493 .05734 Mdot
.75025 .05099 Mdot
.7512 .03648 Mdot
.75216 .03739 Mdot
.75311 .04283 Mdot
.75406 .03104 Mdot
.75502 .0383 Mdot
.75597 .04102 Mdot
.75692 .04102 Mdot
.75788 .05099 Mdot
.75883 .04464 Mdot
.75978 .04918 Mdot
.76074 .05825 Mdot
.76169 .06822 Mdot
.76264 .08364 Mdot
.7636 .08092 Mdot
.76455 .07911 Mdot
.7655 .06913 Mdot
.76646 .08455 Mdot
.76741 .08818 Mdot
.76836 .08818 Mdot
.76932 .08636 Mdot
.77027 .08183 Mdot
.77122 .09634 Mdot
.77218 .08455 Mdot
.77313 .08001 Mdot
.77408 .08999 Mdot
.77504 .08818 Mdot
.77599 .08908 Mdot
.77694 .08999 Mdot
.7779 .09634 Mdot
.77885 .09725 Mdot
.7798 .10269 Mdot
.78076 .10087 Mdot
.78171 .11176 Mdot
.78266 .10813 Mdot
.78362 .1172 Mdot
.78457 .10632 Mdot
.78552 .10632 Mdot
.78648 .11176 Mdot
.78743 .12355 Mdot
.78838 .12627 Mdot
.78934 .11901 Mdot
.79029 .11357 Mdot
.79124 .10813 Mdot
.7922 .09725 Mdot
.79315 .0909 Mdot
.7941 .09362 Mdot
.79506 .1036 Mdot
.79601 .1045 Mdot
.79696 .10541 Mdot
.79792 .1036 Mdot
.79887 .10904 Mdot
.79982 .10813 Mdot
.80078 .10541 Mdot
.80173 .1036 Mdot
.80268 .10087 Mdot
.80364 .1036 Mdot
.80459 .10722 Mdot
.80554 .11266 Mdot
.8065 .13987 Mdot
.80745 .14169 Mdot
.8084 .13262 Mdot
.80936 .12718 Mdot
.81031 .12899 Mdot
.81126 .12899 Mdot
.81222 .12536 Mdot
.81317 .12899 Mdot
.81412 .12445 Mdot
.81508 .11448 Mdot
.81603 .12627 Mdot
.81698 .11901 Mdot
.81794 .12718 Mdot
.81889 .12808 Mdot
.81984 .13715 Mdot
.8208 .13715 Mdot
.82175 .13897 Mdot
.8227 .14259 Mdot
.82366 .15076 Mdot
.82461 .16255 Mdot
.82556 .16436 Mdot
.82652 .17434 Mdot
.82747 .17252 Mdot
.82842 .17796 Mdot
.82938 .17252 Mdot
.83033 .18431 Mdot
.83128 .18975 Mdot
.83224 .19701 Mdot
.83319 .19701 Mdot
.83414 .17887 Mdot
.8351 .20427 Mdot
.83605 .21243 Mdot
.837 .20608 Mdot
.83796 .20245 Mdot
.83891 .2088 Mdot
.83986 .21152 Mdot
.84082 .21061 Mdot
.84177 .21061 Mdot
.84272 .19701 Mdot
.84368 .20517 Mdot
.84463 .20789 Mdot
.84558 .21606 Mdot
.84654 .21243 Mdot
.84749 .2088 Mdot
.84844 .19701 Mdot
.8494 .19701 Mdot
.85035 .19157 Mdot
.8513 .19973 Mdot
.85226 .17887 Mdot
.85321 .18159 Mdot
.85416 .1825 Mdot
.85512 .19157 Mdot
.85607 .18885 Mdot
.85702 .18794 Mdot
.85798 .1952 Mdot
.85893 .18885 Mdot
.85988 .18703 Mdot
.86084 .19157 Mdot
.86179 .19882 Mdot
.86274 .18975 Mdot
.8637 .19973 Mdot
.86465 .20608 Mdot
.8656 .21333 Mdot
.86656 .22331 Mdot
.86751 .21152 Mdot
.86846 .20517 Mdot
.86942 .20608 Mdot
.87037 .18885 Mdot
.87132 .17615 Mdot
.87228 .16799 Mdot
.87323 .16799 Mdot
.87418 .1562 Mdot
.87514 .1435 Mdot
.87609 .14894 Mdot
.87704 .14441 Mdot
.878 .14531 Mdot
.87895 .13171 Mdot
.8799 .11992 Mdot
.88086 .08908 Mdot
.88181 .08274 Mdot
.88276 .08364 Mdot
.88372 .08455 Mdot
.88467 .07548 Mdot
.88562 .08818 Mdot
.88658 .09271 Mdot
.88753 .09725 Mdot
.88848 .08818 Mdot
.88944 .07095 Mdot
.89039 .07729 Mdot
.89134 .0646 Mdot
.8923 .05371 Mdot
.89325 .0383 Mdot
.8942 .06369 Mdot
.89516 .09271 Mdot
.89611 .08727 Mdot
.89706 .08908 Mdot
.89802 .07367 Mdot
.89897 .07457 Mdot
.89992 .07911 Mdot
.90088 .0782 Mdot
.90183 .0782 Mdot
.90278 .10087 Mdot
.90374 .1036 Mdot
.90469 .11539 Mdot
.90564 .11811 Mdot
.9066 .09725 Mdot
.90755 .09271 Mdot
.9085 .09815 Mdot
.90946 .11357 Mdot
.91041 .12173 Mdot
.91136 .11811 Mdot
.91232 .10994 Mdot
.91327 .09725 Mdot
.91422 .10722 Mdot
.91518 .09997 Mdot
.91613 .09271 Mdot
.91708 .10722 Mdot
.91804 .12627 Mdot
.91899 .12083 Mdot
.91994 .11448 Mdot
.9209 .11811 Mdot
.92185 .12083 Mdot
.9228 .1299 Mdot
.92376 .09997 Mdot
.92471 .08636 Mdot
.92566 .06822 Mdot
.92662 .06278 Mdot
.92757 .05553 Mdot
.92852 .05643 Mdot
.92948 .06641 Mdot
.93043 .09997 Mdot
.93138 .11629 Mdot
.93234 .1172 Mdot
.93329 .10994 Mdot
.93424 .12355 Mdot
.9352 .11992 Mdot
.93615 .10904 Mdot
.9371 .1045 Mdot
.93806 .10722 Mdot
.93901 .10087 Mdot
.93996 .11357 Mdot
.94092 .12173 Mdot
.94187 .11811 Mdot
.94282 .11811 Mdot
.94378 .10813 Mdot
.94473 .11539 Mdot
.94568 .13534 Mdot
.94664 .15529 Mdot
.94759 .14804 Mdot
.94854 .15892 Mdot
.9495 .15257 Mdot
.95045 .15983 Mdot
.9514 .16799 Mdot
.95236 .15257 Mdot
.95331 .16345 Mdot
.95426 .15257 Mdot
.95522 .16164 Mdot
.95617 .15892 Mdot
.95712 .15076 Mdot
.95808 .15801 Mdot
.95903 .16799 Mdot
.95998 .16708 Mdot
.96094 .14441 Mdot
.96189 .15166 Mdot
.96284 .15801 Mdot
.9638 .15438 Mdot
.96475 .16527 Mdot
.9657 .15438 Mdot
.96666 .14259 Mdot
.96761 .14441 Mdot
.96856 .15892 Mdot
.96952 .15348 Mdot
.97047 .16073 Mdot
.97142 .16164 Mdot
.97238 .16164 Mdot
.97333 .15892 Mdot
.97428 .15983 Mdot
.97524 .15801 Mdot
.97619 .15529 Mdot
.5 Mabswid
.02381 .21491 m
.02476 .21394 L
.02572 .21551 L
.02667 .21654 L
.02762 .21745 L
.02858 .22101 L
.02953 .22307 L
.03048 .22482 L
.03144 .22791 L
.03239 .23105 L
.03334 .23383 L
.0343 .23698 L
.03525 .24272 L
.0362 .2507 L
.03716 .25868 L
.03811 .26684 L
.03906 .27446 L
.04002 .27857 L
.04097 .28371 L
.04192 .28916 L
.04288 .29169 L
.04383 .29568 L
.04478 .30107 L
.04574 .30524 L
.04669 .30965 L
.04764 .31497 L
.0486 .32205 L
.04955 .32725 L
.0505 .33148 L
.05146 .33353 L
.05241 .3348 L
.05336 .33613 L
.05432 .33825 L
.05527 .34139 L
.05622 .34448 L
.05718 .34774 L
.05813 .34986 L
.05908 .35204 L
.06004 .35385 L
.06099 .35633 L
.06194 .35887 L
.0629 .35947 L
.06385 .36147 L
.0648 .36364 L
.06576 .36733 L
.06671 .37175 L
.06766 .37719 L
.06862 .38432 L
.06957 .39194 L
.07052 .39853 L
Mistroke
.07148 .40403 L
.07243 .41056 L
.07338 .41407 L
.07434 .41861 L
.07529 .42042 L
.07624 .42266 L
.0772 .42495 L
.07815 .42465 L
.0791 .42532 L
.08006 .42387 L
.08101 .42211 L
.08196 .42108 L
.08292 .41879 L
.08387 .41649 L
.08482 .41455 L
.08578 .41419 L
.08673 .41643 L
.08768 .41842 L
.08864 .41994 L
.08959 .42175 L
.09054 .42405 L
.0915 .42689 L
.09245 .43275 L
.0934 .4388 L
.09436 .44684 L
.09531 .45555 L
.09626 .46486 L
.09722 .47387 L
.09817 .48064 L
.09912 .48729 L
.10008 .49358 L
.10103 .49763 L
.10198 .50343 L
.10294 .50869 L
.10389 .51299 L
.10484 .51625 L
.1058 .51698 L
.10675 .51601 L
.1077 .51462 L
.10866 .51269 L
.10961 .51154 L
.11056 .50869 L
.11152 .5067 L
.11247 .50434 L
.11342 .50235 L
.11438 .49957 L
.11533 .49709 L
.11628 .49473 L
.11724 .49225 L
.11819 .49255 L
Mistroke
.11914 .49201 L
.1201 .49249 L
.12105 .49297 L
.122 .49267 L
.12296 .49412 L
.12391 .49479 L
.12486 .49497 L
.12582 .49412 L
.12677 .49479 L
.12772 .49654 L
.12868 .50023 L
.12963 .50307 L
.13058 .50622 L
.13154 .50936 L
.13249 .51136 L
.13344 .51262 L
.1344 .51565 L
.13535 .51885 L
.1363 .52296 L
.13726 .52502 L
.13821 .52732 L
.13916 .52968 L
.14012 .53264 L
.14107 .53675 L
.14202 .53881 L
.14298 .54032 L
.14393 .54128 L
.14488 .54086 L
.14584 .53995 L
.14679 .53868 L
.14774 .53814 L
.1487 .53627 L
.14965 .53481 L
.1506 .53336 L
.15156 .53209 L
.15251 .52955 L
.15346 .52768 L
.15442 .52478 L
.15537 .51964 L
.15632 .51571 L
.15728 .51196 L
.15823 .50948 L
.15918 .50821 L
.16014 .50924 L
.16109 .51226 L
.16204 .51662 L
.163 .52302 L
.16395 .52883 L
.1649 .53481 L
.16586 .54044 L
Mistroke
.16681 .54582 L
.16776 .5518 L
.16872 .55846 L
.16967 .56589 L
.17062 .572 L
.17158 .57569 L
.17253 .57726 L
.17348 .57829 L
.17444 .57907 L
.17539 .57611 L
.17634 .5723 L
.1773 .56662 L
.17825 .56057 L
.1792 .55247 L
.18016 .54491 L
.18111 .53772 L
.18206 .53113 L
.18302 .52496 L
.18397 .51668 L
.18492 .50924 L
.18588 .5044 L
.18683 .49914 L
.18778 .4914 L
.18874 .4853 L
.18969 .48112 L
.19064 .47792 L
.1916 .4752 L
.19255 .47133 L
.1935 .46782 L
.19446 .46468 L
.19541 .46317 L
.19636 .46032 L
.19732 .45766 L
.19827 .45452 L
.19922 .45265 L
.20018 .44956 L
.20113 .44569 L
.20208 .44521 L
.20304 .44182 L
.20399 .43747 L
.20494 .42985 L
.2059 .41969 L
.20685 .39563 L
.2078 .37846 L
.20876 .36491 L
.20971 .34817 L
.21066 .33148 L
.21162 .30995 L
.21257 .29399 L
.21352 .27718 L
Mistroke
.21448 .26207 L
.21543 .25004 L
.21638 .23794 L
.21734 .22494 L
.21829 .21303 L
.21924 .20511 L
.2202 .19761 L
.22115 .20493 L
.2221 .20626 L
.22306 .20457 L
.22401 .20566 L
.22496 .20608 L
.22592 .20995 L
.22687 .20983 L
.22782 .21001 L
.22878 .20777 L
.22973 .20547 L
.23068 .20209 L
.23164 .20046 L
.23259 .19901 L
.23354 .19471 L
.2345 .19048 L
.23545 .18715 L
.2364 .18365 L
.23736 .17748 L
.23831 .17047 L
.23926 .1646 L
.24022 .16049 L
.24117 .15868 L
.24212 .15511 L
.24308 .15245 L
.24403 .15118 L
.24498 .15045 L
.24594 .15064 L
.24689 .14961 L
.24784 .15076 L
.2488 .15438 L
.24975 .15777 L
.2507 .16212 L
.25166 .16859 L
.25261 .17246 L
.25356 .17561 L
.25452 .17827 L
.25547 .17899 L
.25642 .18371 L
.25738 .18939 L
.25833 .19314 L
.25928 .19671 L
.26024 .19477 L
.26119 .19586 L
Mistroke
.26214 .19489 L
.2631 .19387 L
.26405 .19272 L
.265 .19248 L
.26596 .19145 L
.26691 .18951 L
.26786 .18679 L
.26882 .18389 L
.26977 .18147 L
.27072 .17784 L
.27168 .17301 L
.27263 .16811 L
.27358 .16345 L
.27454 .16224 L
.27549 .1585 L
.27644 .1559 L
.2774 .15245 L
.27835 .14894 L
.2793 .14362 L
.28026 .13878 L
.28121 .13751 L
.28216 .13812 L
.28312 .13824 L
.28407 .13897 L
.28502 .13921 L
.28598 .13963 L
.28693 .13951 L
.28788 .13933 L
.28884 .14072 L
.28979 .14332 L
.29074 .14634 L
.2917 .149 L
.29265 .15245 L
.2936 .15704 L
.29456 .16152 L
.29551 .16545 L
.29646 .16781 L
.29742 .17053 L
.29837 .17307 L
.29932 .17494 L
.30028 .17682 L
.30123 .17742 L
.30218 .17845 L
.30314 .17857 L
.30409 .1779 L
.30504 .17748 L
.306 .17766 L
.30695 .17694 L
.3079 .17512 L
.30886 .17325 L
Mistroke
.30981 .17053 L
.31076 .16726 L
.31172 .16249 L
.31267 .15807 L
.31362 .15239 L
.31458 .14683 L
.31553 .14386 L
.31648 .13999 L
.31744 .13612 L
.31839 .13401 L
.31934 .13111 L
.3203 .12953 L
.32125 .12911 L
.3222 .12905 L
.32316 .1305 L
.32411 .13038 L
.32506 .1325 L
.32602 .13588 L
.32697 .1383 L
.32792 .14169 L
.32888 .14519 L
.32983 .14816 L
.33078 .15124 L
.33174 .1545 L
.33269 .15662 L
.33364 .1585 L
.3346 .15934 L
.33555 .1597 L
.3365 .16019 L
.33746 .1588 L
.33841 .15874 L
.33936 .15698 L
.34032 .15529 L
.34127 .1542 L
.34222 .15221 L
.34318 .15045 L
.34413 .14882 L
.34508 .14773 L
.34604 .14574 L
.34699 .14326 L
.34794 .14199 L
.3489 .14011 L
.34985 .13751 L
.3508 .13491 L
.35176 .13262 L
.35271 .13117 L
.35366 .12996 L
.35462 .13092 L
.35557 .13201 L
.35652 .13389 L
Mistroke
.35748 .13606 L
.35843 .138 L
.35938 .13903 L
.36034 .14217 L
.36129 .14531 L
.36224 .14797 L
.3632 .1516 L
.36415 .15644 L
.3651 .1611 L
.36606 .16527 L
.36701 .16974 L
.36796 .17416 L
.36892 .1779 L
.36987 .18268 L
.37082 .18903 L
.37178 .19477 L
.37273 .19991 L
.37368 .20632 L
.37464 .21134 L
.37559 .21714 L
.37654 .22228 L
.3775 .22821 L
.37845 .23214 L
.3794 .23637 L
.38036 .24085 L
.38131 .24532 L
.38226 .24925 L
.38322 .25167 L
.38417 .25251 L
.38512 .25239 L
.38608 .25239 L
.38703 .25191 L
.38798 .25046 L
.38894 .24792 L
.38989 .24441 L
.39084 .24236 L
.3918 .23915 L
.39275 .23637 L
.3937 .2345 L
.39466 .23419 L
.39561 .23395 L
.39656 .23419 L
.39752 .23444 L
.39847 .23419 L
.39942 .23341 L
.40038 .23244 L
.40133 .23129 L
.40228 .22881 L
.40324 .22748 L
.40419 .22646 L
Mistroke
.40514 .22295 L
.4061 .21962 L
.40705 .21648 L
.408 .21207 L
.40896 .20578 L
.40991 .19828 L
.41086 .19108 L
.41182 .1848 L
.41277 .17869 L
.41372 .17307 L
.41468 .16835 L
.41563 .16412 L
.41658 .16055 L
.41754 .15632 L
.41849 .15438 L
.41944 .1533 L
.4204 .15136 L
.42135 .15015 L
.4223 .15003 L
.42326 .15045 L
.42421 .15251 L
.42516 .15432 L
.42612 .15481 L
.42707 .15608 L
.42802 .15632 L
.42898 .15602 L
.42993 .1562 L
.43088 .15644 L
.43184 .15771 L
.43279 .15686 L
.43374 .15704 L
.4347 .15807 L
.43565 .15964 L
.4366 .16013 L
.43756 .16073 L
.43851 .16049 L
.43946 .16013 L
.44042 .16025 L
.44137 .1611 L
.44232 .16273 L
.44328 .16563 L
.44423 .16769 L
.44518 .17089 L
.44614 .17422 L
.44709 .17851 L
.44804 .18389 L
.449 .188 L
.44995 .1926 L
.4509 .19695 L
.45186 .20094 L
Mistroke
.45281 .20499 L
.45376 .20874 L
.45472 .21176 L
.45567 .21406 L
.45662 .2172 L
.45758 .21974 L
.45853 .22234 L
.45948 .2241 L
.46044 .22434 L
.46139 .22337 L
.46234 .22113 L
.4633 .21993 L
.46425 .21745 L
.4652 .2137 L
.46616 .2108 L
.46711 .2082 L
.46806 .20523 L
.46902 .20294 L
.46997 .20052 L
.47092 .19713 L
.47188 .19374 L
.47283 .19139 L
.47378 .18836 L
.47474 .1877 L
.47569 .18782 L
.47664 .18722 L
.4776 .18643 L
.47855 .18619 L
.4795 .18824 L
.48046 .19066 L
.48141 .19235 L
.48236 .19423 L
.48332 .19659 L
.48427 .19888 L
.48522 .20136 L
.48618 .20306 L
.48713 .20451 L
.48808 .20705 L
.48904 .20892 L
.48999 .2108 L
.49094 .21297 L
.4919 .21503 L
.49285 .21702 L
.4938 .21811 L
.49476 .21829 L
.49571 .21938 L
.49666 .22059 L
.49762 .22089 L
.49857 .22186 L
.49952 .22259 L
Mistroke
.50048 .22325 L
.50143 .22373 L
.50238 .22367 L
.50334 .22343 L
.50429 .22337 L
.50524 .22355 L
.5062 .2244 L
.50715 .22464 L
.5081 .22555 L
.50906 .22639 L
.51001 .22658 L
.51096 .22682 L
.51192 .22839 L
.51287 .22875 L
.51382 .23057 L
.51478 .23299 L
.51573 .23625 L
.51668 .24085 L
.51764 .24441 L
.51859 .24695 L
.51954 .24907 L
.5205 .25022 L
.52145 .25203 L
.5224 .253 L
.52336 .25403 L
.52431 .25469 L
.52526 .25644 L
.52622 .25669 L
.52717 .2585 L
.52812 .25844 L
.52908 .25765 L
.53003 .25608 L
.53098 .25258 L
.53194 .24955 L
.53289 .24605 L
.53384 .24308 L
.5348 .2406 L
.53575 .23685 L
.5367 .23371 L
.53766 .23105 L
.53861 .22936 L
.53956 .22639 L
.54052 .22392 L
.54147 .21986 L
.54242 .21618 L
.54338 .21309 L
.54433 .2094 L
.54528 .20632 L
.54624 .20378 L
.54719 .19961 L
Mistroke
.54814 .19374 L
.5491 .18824 L
.55005 .1831 L
.551 .17784 L
.55196 .17264 L
.55291 .16708 L
.55386 .16212 L
.55482 .15686 L
.55577 .15227 L
.55672 .14755 L
.55768 .14187 L
.55863 .13697 L
.55958 .13262 L
.56054 .12857 L
.56149 .12736 L
.56244 .12814 L
.5634 .12863 L
.56435 .12863 L
.5653 .12923 L
.56626 .12984 L
.56721 .13129 L
.56816 .13262 L
.56912 .13437 L
.57007 .13649 L
.57102 .13891 L
.57198 .14247 L
.57293 .14574 L
.57388 .14894 L
.57484 .15106 L
.57579 .15269 L
.57674 .1533 L
.5777 .15348 L
.57865 .15414 L
.5796 .15342 L
.58056 .15251 L
.58151 .15094 L
.58246 .14961 L
.58342 .14804 L
.58437 .14671 L
.58532 .14634 L
.58628 .14483 L
.58723 .14338 L
.58818 .14211 L
.58914 .14066 L
.59009 .13897 L
.59104 .13758 L
.592 .13673 L
.59295 .13625 L
.5939 .13631 L
.59486 .1357 L
Mistroke
.59581 .13564 L
.59676 .13582 L
.59772 .13631 L
.59867 .13546 L
.59962 .13395 L
.60058 .13304 L
.60153 .13195 L
.60248 .1302 L
.60344 .12911 L
.60439 .12965 L
.60534 .13008 L
.6063 .1299 L
.60725 .12984 L
.6082 .13026 L
.60916 .13086 L
.61011 .13092 L
.61106 .1305 L
.61202 .13086 L
.61297 .13231 L
.61392 .13461 L
.61488 .13673 L
.61583 .13782 L
.61678 .13951 L
.61774 .14114 L
.61869 .14163 L
.61964 .14223 L
.6206 .14356 L
.62155 .14604 L
.6225 .14773 L
.62346 .15027 L
.62441 .15275 L
.62536 .15547 L
.62632 .15795 L
.62727 .15928 L
.62822 .15928 L
.62918 .15874 L
.63013 .16001 L
.63108 .16079 L
.63204 .16103 L
.63299 .16128 L
.63394 .16194 L
.6349 .16255 L
.63585 .16273 L
.6368 .16309 L
.63776 .16273 L
.63871 .16218 L
.63966 .16255 L
.64062 .16321 L
.64157 .1649 L
.64252 .16623 L
Mistroke
.64348 .16853 L
.64443 .1692 L
.64538 .17047 L
.64634 .17216 L
.64729 .17361 L
.64824 .17446 L
.6492 .1753 L
.65015 .17434 L
.6511 .17385 L
.65206 .17385 L
.65301 .17494 L
.65396 .17524 L
.65492 .17555 L
.65587 .17464 L
.65682 .17452 L
.65778 .17434 L
.65873 .17524 L
.65968 .17603 L
.66064 .17627 L
.66159 .17663 L
.66254 .17724 L
.6635 .17778 L
.66445 .17966 L
.6654 .1805 L
.66636 .18135 L
.66731 .18111 L
.66826 .18111 L
.66922 .18014 L
.67017 .17996 L
.67112 .1796 L
.67208 .17929 L
.67303 .17875 L
.67398 .17863 L
.67494 .17609 L
.67589 .17258 L
.67684 .16932 L
.6778 .16563 L
.67875 .16037 L
.6797 .15692 L
.68066 .15293 L
.68161 .14906 L
.68256 .14574 L
.68352 .14199 L
.68447 .138 L
.68542 .13389 L
.68638 .12687 L
.68733 .12046 L
.68828 .11309 L
.68924 .10837 L
.69019 .10601 L
Mistroke
.69114 .1036 L
.6921 .10112 L
.69305 .09967 L
.694 .09658 L
.69496 .09332 L
.69591 .08963 L
.69686 .08491 L
.69782 .08104 L
.69877 .07729 L
.69972 .07258 L
.70068 .07088 L
.70163 .0678 L
.70258 .06544 L
.70354 .06302 L
.70449 .05976 L
.70544 .0568 L
.7064 .05426 L
.70735 .05184 L
.7083 .0499 L
.70926 .04815 L
.71021 .04779 L
.71116 .04743 L
.71212 .04706 L
.71307 .04712 L
.71402 .04833 L
.71498 .04876 L
.71593 .04984 L
.71688 .05003 L
.71784 .05045 L
.71879 .05033 L
.71974 .05087 L
.7207 .05154 L
.72165 .05184 L
.7226 .0519 L
.72356 .05178 L
.72451 .05033 L
.72546 .04948 L
.72642 .04773 L
.72737 .04531 L
.72832 .04271 L
.72928 .03993 L
.73023 .03793 L
.73118 .03642 L
.73214 .03521 L
.73309 .03437 L
.73404 .03207 L
.735 .02971 L
.73595 .02753 L
.7369 .02566 L
.73786 .0262 L
Mistroke
.73881 .02753 L
.73976 .02898 L
.74072 .03086 L
.74167 .0334 L
.74262 .03551 L
.74358 .03811 L
.74453 .04059 L
.74548 .04217 L
.74644 .04362 L
.74739 .04591 L
.74834 .04803 L
.7493 .05033 L
.75025 .0525 L
.7512 .05371 L
.75216 .05311 L
.75311 .05244 L
.75406 .05045 L
.75502 .04906 L
.75597 .04755 L
.75692 .04652 L
.75788 .04634 L
.75883 .04531 L
.75978 .04555 L
.76074 .04628 L
.76169 .0467 L
.76264 .04876 L
.7636 .05033 L
.76455 .0522 L
.7655 .05438 L
.76646 .05752 L
.76741 .06055 L
.76836 .06435 L
.76932 .06756 L
.77027 .07028 L
.77122 .07397 L
.77218 .07621 L
.77313 .07856 L
.77408 .08128 L
.77504 .08328 L
.77599 .08467 L
.77694 .08509 L
.7779 .08612 L
.77885 .08733 L
.7798 .08957 L
.78076 .09066 L
.78171 .09223 L
.78266 .09356 L
.78362 .09561 L
.78457 .09725 L
.78552 .09791 L
Mistroke
.78648 .09973 L
.78743 .10263 L
.78838 .10505 L
.78934 .1071 L
.79029 .10873 L
.79124 .10994 L
.7922 .11 L
.79315 .10958 L
.7941 .10898 L
.79506 .10916 L
.79601 .10867 L
.79696 .10849 L
.79792 .10759 L
.79887 .10777 L
.79982 .10789 L
.80078 .10746 L
.80173 .10613 L
.80268 .10444 L
.80364 .10341 L
.80459 .10299 L
.80554 .10329 L
.8065 .10613 L
.80745 .10952 L
.8084 .11212 L
.80936 .11369 L
.81031 .11532 L
.81126 .1169 L
.81222 .11835 L
.81317 .11968 L
.81412 .12077 L
.81508 .12137 L
.81603 .12288 L
.81698 .12409 L
.81794 .12566 L
.81889 .12705 L
.81984 .12869 L
.8208 .12851 L
.82175 .12832 L
.8227 .12899 L
.82366 .13056 L
.82461 .1328 L
.82556 .13516 L
.82652 .13842 L
.82747 .14132 L
.82842 .14489 L
.82938 .14876 L
.83033 .15263 L
.83128 .15735 L
.83224 .162 L
.83319 .1666 L
Mistroke
.83414 .16938 L
.8351 .17385 L
.83605 .17875 L
.837 .18298 L
.83796 .18643 L
.83891 .18951 L
.83986 .19266 L
.84082 .19508 L
.84177 .19761 L
.84272 .19888 L
.84368 .20106 L
.84463 .20263 L
.84558 .20439 L
.84654 .20541 L
.84749 .2062 L
.84844 .20741 L
.8494 .20693 L
.85035 .20554 L
.8513 .20511 L
.85226 .20354 L
.85321 .20173 L
.85416 .19979 L
.85512 .19852 L
.85607 .19707 L
.85702 .19647 L
.85798 .1958 L
.85893 .19453 L
.85988 .1926 L
.86084 .19121 L
.86179 .19054 L
.86274 .19006 L
.8637 .19024 L
.86465 .19121 L
.8656 .19211 L
.86656 .19508 L
.86751 .19707 L
.86846 .19858 L
.86942 .19955 L
.87037 .19955 L
.87132 .19876 L
.87228 .19695 L
.87323 .19556 L
.87418 .1935 L
.87514 .1903 L
.87609 .18697 L
.87704 .18395 L
.878 .18032 L
.87895 .17536 L
.8799 .16914 L
.88086 .16019 L
Mistroke
.88181 .1516 L
.88276 .1435 L
.88372 .1354 L
.88467 .12784 L
.88562 .12198 L
.88658 .11696 L
.88753 .11224 L
.88848 .10771 L
.88944 .10287 L
.89039 .09809 L
.89134 .09277 L
.8923 .08667 L
.89325 .08044 L
.8942 .07669 L
.89516 .07693 L
.89611 .07723 L
.89706 .0776 L
.89802 .07687 L
.89897 .07681 L
.89992 .07621 L
.90088 .07524 L
.90183 .07397 L
.90278 .07481 L
.90374 .07699 L
.90469 .07953 L
.90564 .0831 L
.9066 .086 L
.90755 .08963 L
.9085 .09193 L
.90946 .09332 L
.91041 .09561 L
.91136 .09755 L
.91232 .09997 L
.91327 .10148 L
.91422 .10335 L
.91518 .1048 L
.91613 .10577 L
.91708 .1062 L
.91804 .10771 L
.91899 .10807 L
.91994 .10783 L
.9209 .10922 L
.92185 .11109 L
.9228 .11321 L
.92376 .1123 L
.92471 .10994 L
.92566 .10662 L
.92662 .10347 L
.92757 .10069 L
.92852 .09731 L
Mistroke
.92948 .09507 L
.93043 .09555 L
.93138 .09616 L
.93234 .09555 L
.93329 .09483 L
.93424 .09543 L
.9352 .09555 L
.93615 .09477 L
.9371 .09307 L
.93806 .09356 L
.93901 .09453 L
.93996 .09755 L
.94092 .10148 L
.94187 .10565 L
.94282 .10976 L
.94378 .11254 L
.94473 .11357 L
.94568 .11484 L
.94664 .11738 L
.94759 .11992 L
.94854 .12228 L
.9495 .12445 L
.95045 .12784 L
.9514 .13207 L
.95236 .1351 L
.95331 .13927 L
.95426 .14187 L
.95522 .14453 L
.95617 .14725 L
.95712 .14943 L
.95808 .15275 L
.95903 .15626 L
.95998 .15837 L
.96094 .15765 L
.96189 .15789 L
.96284 .15783 L
.9638 .15795 L
.96475 .15831 L
.9657 .15741 L
.96666 .15674 L
.96761 .15547 L
.96856 .1559 L
.96952 .15535 L
.97047 .15547 L
.97142 .1562 L
.97238 .15644 L
.97333 .15583 L
.97428 .15535 L
.97524 .15626 L
.97619 .1565 L
Mistroke
Mfstroke
.02381 .23594 m
.02476 .23453 L
.02572 .23378 L
.02667 .23279 L
.02762 .23201 L
.02858 .23141 L
.02953 .23123 L
.03048 .23121 L
.03144 .23192 L
.03239 .23251 L
.03334 .23315 L
.0343 .23394 L
.03525 .23484 L
.0362 .23598 L
.03716 .23724 L
.03811 .23885 L
.03906 .24025 L
.04002 .24153 L
.04097 .24268 L
.04192 .2439 L
.04288 .24493 L
.04383 .24626 L
.04478 .24793 L
.04574 .24948 L
.04669 .25098 L
.04764 .25228 L
.0486 .25398 L
.04955 .25592 L
.0505 .2579 L
.05146 .25964 L
.05241 .26121 L
.05336 .26265 L
.05432 .26412 L
.05527 .26606 L
.05622 .2679 L
.05718 .26957 L
.05813 .27135 L
.05908 .27328 L
.06004 .27504 L
.06099 .27704 L
.06194 .279 L
.0629 .2807 L
.06385 .28267 L
.0648 .28452 L
.06576 .28642 L
.06671 .28824 L
.06766 .29028 L
.06862 .29271 L
.06957 .29552 L
.07052 .29806 L
Mistroke
.07148 .30036 L
.07243 .30272 L
.07338 .30486 L
.07434 .30725 L
.07529 .30922 L
.07624 .31128 L
.0772 .31347 L
.07815 .31552 L
.0791 .31769 L
.08006 .31971 L
.08101 .32208 L
.08196 .32456 L
.08292 .32709 L
.08387 .33002 L
.08482 .33283 L
.08578 .33574 L
.08673 .33912 L
.08768 .34208 L
.08864 .34511 L
.08959 .34784 L
.09054 .35088 L
.0915 .35407 L
.09245 .35777 L
.0934 .36199 L
.09436 .36605 L
.09531 .37021 L
.09626 .37475 L
.09722 .37876 L
.09817 .38284 L
.09912 .3868 L
.10008 .39025 L
.10103 .39403 L
.10198 .39781 L
.10294 .40126 L
.10389 .40423 L
.10484 .40736 L
.1058 .41007 L
.10675 .41243 L
.1077 .41477 L
.10866 .41685 L
.10961 .41915 L
.11056 .42159 L
.11152 .42439 L
.11247 .42696 L
.11342 .42944 L
.11438 .43182 L
.11533 .43431 L
.11628 .43654 L
.11724 .43867 L
.11819 .44081 L
Mistroke
.11914 .44277 L
.1201 .44416 L
.12105 .44557 L
.122 .44701 L
.12296 .44897 L
.12391 .45115 L
.12486 .45336 L
.12582 .45556 L
.12677 .45764 L
.12772 .45985 L
.12868 .46232 L
.12963 .46496 L
.13058 .46737 L
.13154 .46977 L
.13249 .47181 L
.13344 .47352 L
.1344 .47539 L
.13535 .47705 L
.1363 .47887 L
.13726 .48051 L
.13821 .48226 L
.13916 .48386 L
.14012 .48522 L
.14107 .4866 L
.14202 .48791 L
.14298 .48958 L
.14393 .4911 L
.14488 .49273 L
.14584 .49404 L
.14679 .49547 L
.14774 .49661 L
.1487 .49765 L
.14965 .49908 L
.1506 .50048 L
.15156 .50215 L
.15251 .50375 L
.15346 .50518 L
.15442 .50642 L
.15537 .50723 L
.15632 .50814 L
.15728 .50913 L
.15823 .50971 L
.15918 .51069 L
.16014 .5119 L
.16109 .51357 L
.16204 .51513 L
.163 .51688 L
.16395 .5183 L
.1649 .51969 L
.16586 .52087 L
Mistroke
.16681 .5218 L
.16776 .52256 L
.16872 .52334 L
.16967 .52428 L
.17062 .52508 L
.17158 .52555 L
.17253 .52564 L
.17348 .52566 L
.17444 .52598 L
.17539 .52619 L
.17634 .52634 L
.1773 .52681 L
.17825 .52721 L
.1792 .52726 L
.18016 .52732 L
.18111 .52704 L
.18206 .52705 L
.18302 .52699 L
.18397 .52675 L
.18492 .52646 L
.18588 .52652 L
.18683 .52605 L
.18778 .525 L
.18874 .52458 L
.18969 .52391 L
.19064 .52352 L
.1916 .52335 L
.19255 .52288 L
.1935 .52229 L
.19446 .52143 L
.19541 .52071 L
.19636 .52012 L
.19732 .5197 L
.19827 .5187 L
.19922 .51768 L
.20018 .51639 L
.20113 .51457 L
.20208 .51279 L
.20304 .51108 L
.20399 .50913 L
.20494 .50697 L
.2059 .50416 L
.20685 .49823 L
.2078 .49339 L
.20876 .48941 L
.20971 .48488 L
.21066 .48048 L
.21162 .47516 L
.21257 .47014 L
.21352 .46536 L
Mistroke
.21448 .46074 L
.21543 .45632 L
.21638 .45221 L
.21734 .44808 L
.21829 .444 L
.21924 .44036 L
.2202 .43643 L
.22115 .43226 L
.2221 .42797 L
.22306 .4239 L
.22401 .42011 L
.22496 .41616 L
.22592 .4122 L
.22687 .40818 L
.22782 .40422 L
.22878 .3999 L
.22973 .39552 L
.23068 .39099 L
.23164 .38632 L
.23259 .38135 L
.23354 .37598 L
.2345 .36992 L
.23545 .36392 L
.2364 .35773 L
.23736 .35131 L
.23831 .34503 L
.23926 .33872 L
.24022 .3326 L
.24117 .32674 L
.24212 .32084 L
.24308 .31525 L
.24403 .3103 L
.24498 .30542 L
.24594 .30063 L
.24689 .29605 L
.24784 .29167 L
.2488 .28747 L
.24975 .28336 L
.2507 .27966 L
.25166 .27605 L
.25261 .27198 L
.25356 .26762 L
.25452 .26326 L
.25547 .2592 L
.25642 .25573 L
.25738 .25225 L
.25833 .2491 L
.25928 .24648 L
.26024 .24253 L
.26119 .239 L
Mistroke
.26214 .23507 L
.2631 .23121 L
.26405 .22764 L
.265 .22459 L
.26596 .2214 L
.26691 .21725 L
.26786 .21291 L
.26882 .20851 L
.26977 .20459 L
.27072 .20077 L
.27168 .19694 L
.27263 .19359 L
.27358 .19013 L
.27454 .18661 L
.27549 .1832 L
.27644 .18027 L
.2774 .17776 L
.27835 .1783 L
.2793 .17763 L
.28026 .17617 L
.28121 .17512 L
.28216 .17424 L
.28312 .17417 L
.28407 .17359 L
.28502 .17318 L
.28598 .17245 L
.28693 .17148 L
.28788 .17041 L
.28884 .16977 L
.28979 .16926 L
.29074 .16852 L
.2917 .16804 L
.29265 .16781 L
.2936 .16778 L
.29456 .16756 L
.29551 .16708 L
.29646 .16659 L
.29742 .16628 L
.29837 .16623 L
.29932 .16616 L
.30028 .16626 L
.30123 .16587 L
.30218 .16568 L
.30314 .16539 L
.30409 .16504 L
.30504 .16507 L
.306 .16547 L
.30695 .16576 L
.3079 .16608 L
.30886 .16672 L
Mistroke
.30981 .16709 L
.31076 .16712 L
.31172 .16668 L
.31267 .16611 L
.31362 .16562 L
.31458 .16513 L
.31553 .16441 L
.31648 .16359 L
.31744 .16249 L
.31839 .16192 L
.31934 .16114 L
.3203 .1605 L
.32125 .16003 L
.3222 .15946 L
.32316 .1591 L
.32411 .15868 L
.32506 .1585 L
.32602 .15821 L
.32697 .15798 L
.32792 .15721 L
.32888 .15629 L
.32983 .15541 L
.33078 .15449 L
.33174 .15443 L
.33269 .15407 L
.33364 .15386 L
.3346 .1536 L
.33555 .15343 L
.3365 .15301 L
.33746 .15257 L
.33841 .15252 L
.33936 .15253 L
.34032 .15249 L
.34127 .15252 L
.34222 .15209 L
.34318 .15178 L
.34413 .15155 L
.34508 .15135 L
.34604 .15113 L
.34699 .15102 L
.34794 .15108 L
.3489 .15113 L
.34985 .15114 L
.3508 .15126 L
.35176 .15134 L
.35271 .15125 L
.35366 .1509 L
.35462 .15102 L
.35557 .15113 L
.35652 .15102 L
Mistroke
.35748 .15107 L
.35843 .15125 L
.35938 .15129 L
.36034 .15142 L
.36129 .15142 L
.36224 .15141 L
.3632 .15165 L
.36415 .15194 L
.3651 .15207 L
.36606 .15209 L
.36701 .15211 L
.36796 .15217 L
.36892 .1525 L
.36987 .15305 L
.37082 .15384 L
.37178 .15466 L
.37273 .15575 L
.37368 .15686 L
.37464 .15798 L
.37559 .15927 L
.37654 .16037 L
.3775 .16176 L
.37845 .16298 L
.3794 .16432 L
.38036 .16561 L
.38131 .16707 L
.38226 .16857 L
.38322 .17033 L
.38417 .17194 L
.38512 .17384 L
.38608 .17578 L
.38703 .17736 L
.38798 .17896 L
.38894 .18033 L
.38989 .18135 L
.39084 .18262 L
.3918 .18368 L
.39275 .18443 L
.3937 .18541 L
.39466 .18634 L
.39561 .18778 L
.39656 .18891 L
.39752 .19004 L
.39847 .19112 L
.39942 .19219 L
.40038 .19322 L
.40133 .19399 L
.40228 .19447 L
.40324 .19493 L
.40419 .19532 L
Mistroke
.40514 .19551 L
.4061 .19574 L
.40705 .19579 L
.408 .19579 L
.40896 .19574 L
.40991 .19569 L
.41086 .19573 L
.41182 .19595 L
.41277 .19602 L
.41372 .19636 L
.41468 .1968 L
.41563 .19705 L
.41658 .19703 L
.41754 .19705 L
.41849 .19754 L
.41944 .19777 L
.4204 .19799 L
.42135 .19832 L
.4223 .19881 L
.42326 .19931 L
.42421 .19996 L
.42516 .2006 L
.42612 .20072 L
.42707 .20083 L
.42802 .20084 L
.42898 .20079 L
.42993 .20069 L
.43088 .20052 L
.43184 .20015 L
.43279 .19985 L
.43374 .19959 L
.4347 .19928 L
.43565 .19896 L
.4366 .19862 L
.43756 .1984 L
.43851 .19811 L
.43946 .1978 L
.44042 .19719 L
.44137 .19651 L
.44232 .19558 L
.44328 .19497 L
.44423 .19424 L
.44518 .19343 L
.44614 .19273 L
.44709 .19212 L
.44804 .19191 L
.449 .19124 L
.44995 .19105 L
.4509 .19073 L
.45186 .19042 L
Mistroke
.45281 .19004 L
.45376 .18969 L
.45472 .18921 L
.45567 .18882 L
.45662 .18855 L
.45758 .18844 L
.45853 .18833 L
.45948 .18816 L
.46044 .18801 L
.46139 .18792 L
.46234 .18766 L
.4633 .1874 L
.46425 .18726 L
.4652 .18657 L
.46616 .18574 L
.46711 .18489 L
.46806 .1839 L
.46902 .18291 L
.46997 .18209 L
.47092 .18129 L
.47188 .1807 L
.47283 .18035 L
.47378 .18007 L
.47474 .18006 L
.47569 .18019 L
.47664 .18052 L
.4776 .18076 L
.47855 .18121 L
.4795 .18181 L
.48046 .18272 L
.48141 .18371 L
.48236 .18453 L
.48332 .18527 L
.48427 .18613 L
.48522 .18695 L
.48618 .18764 L
.48713 .18842 L
.48808 .18937 L
.48904 .19058 L
.48999 .19147 L
.49094 .19245 L
.4919 .19349 L
.49285 .19458 L
.4938 .19543 L
.49476 .19628 L
.49571 .19708 L
.49666 .19778 L
.49762 .19849 L
.49857 .19928 L
.49952 .2002 L
Mistroke
.50048 .20109 L
.50143 .20193 L
.50238 .20281 L
.50334 .20372 L
.50429 .20477 L
.50524 .20575 L
.5062 .20676 L
.50715 .20758 L
.5081 .20851 L
.50906 .20942 L
.51001 .2103 L
.51096 .21112 L
.51192 .21211 L
.51287 .21281 L
.51382 .21377 L
.51478 .21456 L
.51573 .21564 L
.51668 .21681 L
.51764 .21776 L
.51859 .21846 L
.51954 .21879 L
.5205 .2192 L
.52145 .21947 L
.5224 .21972 L
.52336 .22003 L
.52431 .22024 L
.52526 .22066 L
.52622 .2211 L
.52717 .2217 L
.52812 .22202 L
.52908 .22214 L
.53003 .22239 L
.53098 .2225 L
.53194 .2228 L
.53289 .223 L
.53384 .22318 L
.5348 .22334 L
.53575 .22335 L
.5367 .22372 L
.53766 .22409 L
.53861 .22447 L
.53956 .2249 L
.54052 .22529 L
.54147 .22557 L
.54242 .22583 L
.54338 .22601 L
.54433 .226 L
.54528 .22609 L
.54624 .22602 L
.54719 .22535 L
Mistroke
.54814 .22448 L
.5491 .2237 L
.55005 .22273 L
.551 .22164 L
.55196 .22048 L
.55291 .21942 L
.55386 .21847 L
.55482 .21735 L
.55577 .21625 L
.55672 .21506 L
.55768 .21377 L
.55863 .21249 L
.55958 .21121 L
.56054 .20995 L
.56149 .20867 L
.56244 .20752 L
.5634 .20642 L
.56435 .20505 L
.5653 .20387 L
.56626 .20279 L
.56721 .2018 L
.56816 .20088 L
.56912 .20005 L
.57007 .19917 L
.57102 .19833 L
.57198 .19761 L
.57293 .19689 L
.57388 .19626 L
.57484 .19547 L
.57579 .19453 L
.57674 .19347 L
.5777 .19223 L
.57865 .19095 L
.5796 .18944 L
.58056 .18801 L
.58151 .18667 L
.58246 .18544 L
.58342 .18397 L
.58437 .18276 L
.58532 .18148 L
.58628 .17998 L
.58723 .17831 L
.58818 .17651 L
.58914 .17472 L
.59009 .17293 L
.59104 .17117 L
.592 .16954 L
.59295 .16779 L
.5939 .1661 L
.59486 .16435 L
Mistroke
.59581 .16286 L
.59676 .16131 L
.59772 .1599 L
.59867 .15816 L
.59962 .15658 L
.60058 .15506 L
.60153 .15349 L
.60248 .15204 L
.60344 .15064 L
.60439 .14966 L
.60534 .14857 L
.6063 .14739 L
.60725 .14639 L
.6082 .14541 L
.60916 .14431 L
.61011 .14317 L
.61106 .14213 L
.61202 .14129 L
.61297 .14065 L
.61392 .14027 L
.61488 .13979 L
.61583 .13917 L
.61678 .13868 L
.61774 .13811 L
.61869 .13806 L
.61964 .13826 L
.6206 .13846 L
.62155 .13898 L
.6225 .13939 L
.62346 .13984 L
.62441 .14031 L
.62536 .1408 L
.62632 .14151 L
.62727 .14205 L
.62822 .14262 L
.62918 .14316 L
.63013 .14378 L
.63108 .14431 L
.63204 .1446 L
.63299 .14484 L
.63394 .14502 L
.6349 .14524 L
.63585 .1458 L
.6368 .14616 L
.63776 .14641 L
.63871 .14649 L
.63966 .14679 L
.64062 .14727 L
.64157 .14773 L
.64252 .14808 L
Mistroke
.64348 .14837 L
.64443 .14847 L
.64538 .14862 L
.64634 .14882 L
.64729 .14903 L
.64824 .14926 L
.6492 .14961 L
.65015 .14984 L
.6511 .15025 L
.65206 .15068 L
.65301 .15129 L
.65396 .15192 L
.65492 .15278 L
.65587 .15332 L
.65682 .15372 L
.65778 .15427 L
.65873 .15484 L
.65968 .1554 L
.66064 .15594 L
.66159 .15656 L
.66254 .15719 L
.6635 .15782 L
.66445 .15852 L
.6654 .15909 L
.66636 .15981 L
.66731 .16038 L
.66826 .16097 L
.66922 .16154 L
.67017 .16222 L
.67112 .16285 L
.67208 .16353 L
.67303 .1642 L
.67398 .16509 L
.67494 .16534 L
.67589 .16515 L
.67684 .16504 L
.6778 .16496 L
.67875 .16463 L
.6797 .16442 L
.68066 .16423 L
.68161 .16401 L
.68256 .16402 L
.68352 .16377 L
.68447 .16336 L
.68542 .1627 L
.68638 .16155 L
.68733 .16073 L
.68828 .1598 L
.68924 .15879 L
.69019 .15802 L
Mistroke
.69114 .15731 L
.6921 .15648 L
.69305 .15535 L
.694 .15419 L
.69496 .15284 L
.69591 .15138 L
.69686 .14991 L
.69782 .14839 L
.69877 .14696 L
.69972 .14536 L
.70068 .14398 L
.70163 .14229 L
.70258 .14073 L
.70354 .13918 L
.70449 .13772 L
.70544 .13628 L
.7064 .13482 L
.70735 .13317 L
.7083 .13155 L
.70926 .12992 L
.71021 .12851 L
.71116 .12689 L
.71212 .12516 L
.71307 .1234 L
.71402 .12178 L
.71498 .12003 L
.71593 .11842 L
.71688 .11664 L
.71784 .11484 L
.71879 .11306 L
.71974 .11156 L
.7207 .11006 L
.72165 .10867 L
.7226 .10716 L
.72356 .10551 L
.72451 .10358 L
.72546 .10173 L
.72642 .09959 L
.72737 .09754 L
.72832 .09542 L
.72928 .09315 L
.73023 .09096 L
.73118 .08872 L
.73214 .08663 L
.73309 .08461 L
.73404 .08253 L
.735 .08045 L
.73595 .07825 L
.7369 .07619 L
.73786 .07448 L
Mistroke
.73881 .07287 L
.73976 .07131 L
.74072 .06974 L
.74167 .06822 L
.74262 .0666 L
.74358 .06491 L
.74453 .06333 L
.74548 .06143 L
.74644 .06013 L
.74739 .05928 L
.74834 .05827 L
.7493 .05739 L
.75025 .05668 L
.7512 .05555 L
.75216 .05451 L
.75311 .05354 L
.75406 .05225 L
.75502 .05115 L
.75597 .05013 L
.75692 .04913 L
.75788 .0488 L
.75883 .0483 L
.75978 .04792 L
.76074 .04772 L
.76169 .04741 L
.76264 .0473 L
.7636 .04723 L
.76455 .04718 L
.7655 .04711 L
.76646 .04735 L
.76741 .04773 L
.76836 .04814 L
.76932 .04845 L
.77027 .04873 L
.77122 .04941 L
.77218 .04987 L
.77313 .05045 L
.77408 .05109 L
.77504 .05177 L
.77599 .0524 L
.77694 .05296 L
.7779 .0536 L
.77885 .05428 L
.7798 .05504 L
.78076 .05585 L
.78171 .05662 L
.78266 .05737 L
.78362 .05816 L
.78457 .05876 L
.78552 .05932 L
Mistroke
.78648 .06006 L
.78743 .06101 L
.78838 .06209 L
.78934 .0631 L
.79029 .06408 L
.79124 .06478 L
.7922 .0653 L
.79315 .06583 L
.7941 .06646 L
.79506 .06733 L
.79601 .06828 L
.79696 .06917 L
.79792 .07014 L
.79887 .07125 L
.79982 .07236 L
.80078 .07357 L
.80173 .07465 L
.80268 .0757 L
.80364 .07674 L
.80459 .0778 L
.80554 .07902 L
.8065 .08058 L
.80745 .08223 L
.8084 .08375 L
.80936 .08483 L
.81031 .08584 L
.81126 .08675 L
.81222 .08763 L
.81317 .0885 L
.81412 .08941 L
.81508 .09022 L
.81603 .0911 L
.81698 .09208 L
.81794 .09315 L
.81889 .09403 L
.81984 .09515 L
.8208 .09622 L
.82175 .09739 L
.8227 .09881 L
.82366 .10032 L
.82461 .10191 L
.82556 .10369 L
.82652 .10551 L
.82747 .10726 L
.82842 .10909 L
.82938 .11071 L
.83033 .11257 L
.83128 .11444 L
.83224 .11629 L
.83319 .11801 L
Mistroke
.83414 .11928 L
.8351 .12092 L
.83605 .1227 L
.837 .12453 L
.83796 .1261 L
.83891 .12771 L
.83986 .12935 L
.84082 .13101 L
.84177 .13273 L
.84272 .13407 L
.84368 .13568 L
.84463 .13738 L
.84558 .13906 L
.84654 .14072 L
.84749 .14232 L
.84844 .14374 L
.8494 .14508 L
.85035 .14634 L
.8513 .14764 L
.85226 .14868 L
.85321 .14961 L
.85416 .1506 L
.85512 .15159 L
.85607 .15269 L
.85702 .15378 L
.85798 .15489 L
.85893 .15576 L
.85988 .15657 L
.86084 .15754 L
.86179 .15868 L
.86274 .15976 L
.8637 .16113 L
.86465 .16267 L
.8656 .16426 L
.86656 .16586 L
.86751 .16729 L
.86846 .16862 L
.86942 .16998 L
.87037 .17105 L
.87132 .17195 L
.87228 .17279 L
.87323 .17365 L
.87418 .17438 L
.87514 .17492 L
.87609 .17547 L
.87704 .1759 L
.878 .17597 L
.87895 .17584 L
.8799 .17567 L
.88086 .17516 L
Mistroke
.88181 .17454 L
.88276 .17394 L
.88372 .17339 L
.88467 .17268 L
.88562 .1722 L
.88658 .17191 L
.88753 .17152 L
.88848 .17111 L
.88944 .17036 L
.89039 .16968 L
.89134 .16871 L
.8923 .1676 L
.89325 .16626 L
.8942 .16521 L
.89516 .16443 L
.89611 .16343 L
.89706 .16243 L
.89802 .16108 L
.89897 .15978 L
.89992 .15846 L
.90088 .1572 L
.90183 .15579 L
.90278 .1546 L
.90374 .15336 L
.90469 .15227 L
.90564 .15146 L
.9066 .15003 L
.90755 .14843 L
.9085 .147 L
.90946 .14581 L
.91041 .14465 L
.91136 .1434 L
.91232 .14206 L
.91327 .14055 L
.91422 .13935 L
.91518 .13795 L
.91613 .13641 L
.91708 .13496 L
.91804 .13381 L
.91899 .13264 L
.91994 .13154 L
.9209 .13049 L
.92185 .12955 L
.9228 .12861 L
.92376 .12756 L
.92471 .12629 L
.92566 .12477 L
.92662 .12305 L
.92757 .12127 L
.92852 .11952 L
Mistroke
.92948 .1178 L
.93043 .11662 L
.93138 .11568 L
.93234 .11468 L
.93329 .1135 L
.93424 .11262 L
.9352 .11155 L
.93615 .11026 L
.9371 .10881 L
.93806 .10726 L
.93901 .10578 L
.93996 .10456 L
.94092 .10344 L
.94187 .10249 L
.94282 .10172 L
.94378 .10092 L
.94473 .10022 L
.94568 .09994 L
.94664 .1001 L
.94759 .10009 L
.94854 .10028 L
.9495 .10038 L
.95045 .10075 L
.9514 .10139 L
.95236 .10224 L
.95331 .10332 L
.95426 .10424 L
.95522 .10526 L
.95617 .10638 L
.95712 .10721 L
.95808 .10808 L
.95903 .10902 L
.95998 .11008 L
.96094 .11106 L
.96189 .11205 L
.96284 .11329 L
.9638 .11464 L
.96475 .11633 L
.9657 .11754 L
.96666 .1182 L
.96761 .11896 L
.96856 .1199 L
.96952 .12096 L
.97047 .12211 L
.97142 .12321 L
.97238 .12432 L
.97333 .1254 L
.97428 .12618 L
.97524 .12691 L
.97619 .12744 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`006_oo00<00?ooool0:Ooo0`000ooo00<00?ooool00_oo00<00?ooool09?oo0`00
0_oo00<00?ooool00_oo00<00?ooool09?oo0P001?oo00<00?ooool00_oo00<00?ooool09?oo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool08Ooo1@000_oo00<00?ooool00_oo00<00?ooool0
0_oo00<00?ooool00ooo000Iool00`00ool0000Zool00`00ooooo`02ool00`00ool00002ool00`00
ool0000Vool01P00ooooo`00ool000;oo`03003oo`0002Goo`03003oo`0000;oo`03003oo`0000;o
o`03003oo`0002Coo`03003oo`0000;oo`03003oo`0000;oo`03003oo`0002Coo`07003oooooool0
0?oo00000_oo00<00?oo00000_oo00<00?oo00001?oo000Iool00`00ool0000[ool01`00oooooooo
003oo`0000;oo`03003oo`0002Coo`@00004ool00?oo0002ool00`00ool0000Uool00`00ool00002
ool00`00ool00002ool00`00ool0000Tool00`00ool00002ool00`00ool00002ool00`00ool0000T
ool01`00oooooooo003oo`0000;oo`03003oo`0000;oo`03003oo`0000Coo`006Ooo00<00?oo0000
:ooo00L00?ooooooo`00ool00002ool00`00ool0000Tool00`00ool00002ool00`00ool00002ool0
0`00ool0000Uool20003ool00`00ool00002ool00`00ool0000Uool01`00oooooooo003oo`0000;o
o`03003oo`0002Coo`07003oooooool00?oo00000_oo00<00?oo00000_oo00<00?oo00001?oo000I
ool00`00ool0000Zool00`00ool00002ool00`00ool00002ool00`00ool0000Uool20002ool00`00
ool00002ool00`00ool0000Uool00`00ooooo`02ool00`00ool00002ool00`00ool0000Tool00`00
ool00002ool00`00ool00002ool00`00ool0000Tool01`00oooooooo003oo`0000;oo`03003oo`00
00;oo`03003oo`0000Coo`006_oo00<00?ooool0:_oo00<00?ooool00_oo00<00?ooool00_oo00<0
0?ooool09Ooo00D00?ooooooo`0000Coo`03003ooooo02Goo`8000?oo`03003ooooo00;oo`03003o
oooo02Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo02;oo`8000Coo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00?oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool001Goool000H000Koo`005Ooo00<00?ooool00ooo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02Ooo
00<00?ooool02_oo00<00?ooool02Ooo00<00?ooool02_oo00<00?ooool00ooo00<00?ooool01?oo
000Eool00`00ooooo`3oool2ool00`00ooooo`04ool001Goo`03003ooooo0;[oo`8004Goo`03003o
oooo00Coo`005Ooo00<00?ooool0^_oo1000@ooo00<00?ooool01?oo000Eool00`00ooooo`2jool4
0013ool00`00ooooo`04ool001Goo`800;[oo`@004?oo`8000Koo`005Ooo00<00?ooool0^Ooo1@00
@ooo00<00?ooool01?oo000Eool00`00ooooo`2hool60002ool2000oool00`00ooooo`04ool001Go
o`03003ooooo0;;oo`<000?oo`@000;oo`@003ooo`03003ooooo00Coo`005Ooo00<00?ooool0/_oo
100000?oo`0000000`000_oo1@008Ooo0P006ooo00<00?ooool01?oo000Eool00`00ooooo`2bool9
0003ool5000Qool2000Kool00`00ooooo`04ool001Goo`03003ooooo0;;oo`T00003ool0000000P0
03_oo`03003ooooo00Coo`005Ooo00<00?ooool0/_oo20000_oo200000?oo`000000>_oo00<00?oo
ool01?oo0003ool50002ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`2aool90002ool7
00001?oo003ooooo0P006ooo0P001ooo0P004_oo00<00?ooool01?oo0005ool01`00oooooooo003o
o`0000;oo`03003oo`0000Coo`03003ooooo0;7oo`P000?oo`D00004ool000000003ool2000Jool2
0007ool2000Bool00`00ooooo`04ool000Goo`07003oooooool00?oo00000_oo00<00?oo00001?oo
0P00/_oo20000ooo10000_oo0`001?oo0P006Ooo0P001ooo0P004?oo0`001_oo0005ool01`00oooo
oooo003oo`0000;oo`03003oo`0000Coo`03003ooooo0;7oo`<00004ool000000005ool30002ool4
0004ool2000Hool20007ool3000Aool00`00ooooo`04ool000Goo`07003oooooool00?oo00000_oo
00<00?oo00001?oo00<00?ooool0/Ooo0`002Ooo0P000ooo10001_oo00<00?ooool05?oo0P002?oo
0`004Ooo00<00?ooool01?oo0004ool20004ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`2^ool400000ooo003oo`08ool00`00ooooo`03ool30007ool00`00ooooo`0Bool6000Iool00`00
ooooo`04ool001Goo`03003ooooo0:koo`D000Woo`03003ooooo00Coo`@000Koo`8001?oo`L001So
o`03003ooooo00Coo`005Ooo00<00?ooool0<_oo0P00Nooo10002Ooo00<00?ooool00ooo1@001ooo
0P004Ooo20006?oo00<00?ooool01?oo000Eool00`00ooooo`0bool2001kool40008ool00`00oooo
o`04ool60007ool2000@ool300001Ooo00000?oo00000ooo0P004ooo00<00?ooool01?oo000Eool0
0`00ooooo`2_ool40008ool00`00ooooo`05ool600000ooo00000004ool2000?ool60002ool00`00
ooooo`02000Cool00`00ooooo`04ool001Goo`03003ooooo0:ooo`<000Soo`03003ooooo00Koo`H0
0003ool0000000Goo`8000koo`H00003ool00000008000?oo`<000ooo`03003ooooo00Coo`005Ooo
0P00Cooo0P00HOoo00<00?ooool01_oo00<00?ooool01ooo20001_oo00<00?ooool03Ooo1@0000?o
o`0000000P000_oo10003_oo0P001_oo000Eool00`00ooooo`1>ool2001Qool00`00ooooo`05ool2
0009ool800000ooo00000004ool00`00ooooo`0=ool20002ool>000<ool00`00ooooo`04ool001Go
o`03003ooooo04koo`8005coo`8000;oo`03003ooooo00Koo`03003ooooo00_oo`P000Coo`8000oo
o`03003ooooo00800003ool0000000L000;oo`03003ooooo00Woo`03003ooooo00Coo`005Ooo00<0
0?ooool0>_oo0P004_oo0P00G?oo0P000_oo00<00?ooool01Ooo0P003Ooo2@001?oo00<00?ooool0
3Ooo00<00?ooool01`0000?oo`0000000P000ooo00<00?ooool02?oo00<00?ooool01?oo000Eool0
0`00ooooo`0jool2000Aool2000nool2000Qool00`00ooooo`05ool00`00ooooo`0<ool;0002ool2
000=ool00`00ooooo`02ool600000ooo000000020004ool00`00ooooo`07ool00`00ooooo`04ool0
01Goo`03003ooooo03[oo`8000Woo`8000Koo`@003coo`8001koo`<000Ooo`03003ooooo00goo`@0
00;oo`D000?oo`03003ooooo00_oo`04003oooooool600000ooo000000040003ool20008ool00`00
ooooo`04ool001Goo`03003ooooo03[oo`8000Woo`8000Koo`@000Koo`<003?oo`8000Soo`@001;o
o`<000Koo`80013oo`<000Goo`8000?oo`8000[oo`<000?oo`d000Coo`8000Ooo`03003ooooo00Co
o`005Ooo00<00?ooool0A?oo0`001_oo0P001_oo1@00<_oo0`002?oo10004Ooo10001_oo00<00?oo
ool04?oo0P001?oo0`001?oo00<00?ooool02?oo0`001Ooo30001?oo0P001_oo00<00?ooool01?oo
000Eool00`00ooooo`0jool20008ool30008ool30003ool4000aool70002ool:000?ool40005ool2
000Bool20003ool60003ool00`00ooooo`09ool00`00ooooo`05ool300000ooo00000003ool00`00
ooooo`03ool20005ool00`00ooooo`04ool001Goo`03003ooooo03[oo`8000Soo`<000Koo`D000Go
o`<0033oo`L000;oo`X000ooo`@000Goo`03003ooooo01Koo`H000?oo`8000Ooo`<000Woo`8000Ko
o`03003ooooo00[oo`03003ooooo00Coo`005Ooo0P00>_oo10001Ooo10001ooo1@000_oo1`003_oo
0P008?oo1@0000?oo`0000002`004Ooo00<00?ooool00_oo00<00?ooool05ooo0P0000Coo`000000
00Coo`03003ooooo00Goo`<000Soo`03003ooooo00Coo`<000_oo`8000Koo`005Ooo00<00?ooool0
>Ooo10001Ooo0P000_oo0`001_oo00D00?ooool00?oo00D00003ool00?oo00_oo`@0023oo`800003
ool00000010000ooo`04003oooooool2000Iool200000ooo000000020003ool20008ool00`00oooo
o`05ool20006ool200000ooo003oo`0:ool00`00ooooo`04ool001Goo`03003ooooo03Woo`@000Go
o`800003ool00000008000Coo`H00003ool00000008000;oo`03003ooooo00[oo`<002Coo`T000;o
o`H00003ool0000000Woo`800003ool00?oo00?oo`03003ooooo01Soo`8000;oo`<000Coo`03003o
oooo00?oo`@000Koo`8000[oo`D000Ooo`03003ooooo00Coo`005Ooo00<00?ooool0<ooo0P001?oo
0`001Ooo20001?oo1P0000?oo`0000000P000ooo00<00?ooool02Ooo1`007ooo00D00?oo00000?oo
00D000?oo`H000;oo`@000Goo`800003ool00?oo00;oo`8001koo`<000Goo`03003ooooo00;oo`@0
00Koo`03003ooooo00Koo`800003ool0000000<000Ooo`03003ooooo00Coo`005Ooo00<00?ooool0
<ooo0P001ooo0P000ooo2@001?oo00<00?ooool03@002?oo2@006ooo0P0000Coo`00ooooo`L000;o
o`X000;oo`<000Koo`05003oooooool0000Oool200000ooo003oo`04ool00`00ooooo`02ool30005
ool00`00ooooo`07ool80007ool00`00ooooo`04ool001Goo`03003ooooo03coo`8000Coo`P000;o
o`<000;oo`D000;oo`@00003ool0000000Ooo`T001_oo`800003ool00?oo00L000?oo`04003ooooo
ool60002ool40005ool01000ooooo`008?oo0P0000?oo`00ool01?oo0P000_oo0P0000?oo`00ool0
0ooo0P002Ooo2P001Ooo00<00?ooool01?oo000Eool00`00ooooo`0kool01000ooooo`000ooo0`00
00?oo`0000001`0000?oo`00000010000_oo0`0000Coo`00ool000Woo`P001goo`03003oo`0000@0
00Coo`8000Koo`@00003ool0000000;oo`8000;oo`03003ooooo008002?oo`03003ooooo00Coo`80
0005ool00000ool00003ool2000:ool:0005ool00`00ooooo`04ool001Goo`03003ooooo03_oo`80
0003ool00?oo00?oo`800003ool0000000d000Coo`800005ool00?ooool00008ool9000Lool00`00
ooooo`040004ool01000oooooooo200000?oo`0000000ooo0P0000Coo`00000002;oo`@000Ooo`80
00?oo`05003oooooool0000<ool90005ool00`00ooooo`04ool001Goo`03003ooooo03Woo`@00003
ool00?oo008000;oo`04003oooooool=0004ool200001?oo003ooooo0P001Ooo0P0000?oo`000000
1P006ooo00<00?ooool00_oo0P001?oo00<00?ooool00_oo2`001Ooo0`008ooo10002?oo10000ooo
00<00?ooool02ooo20001_oo00<00?ooool01?oo000Eool2000cool20005ool400000ooo003oo`02
0002ool00`00ooooo`070005ool20004ool40003ool00`00ooooo`02ool300000ooo00000006000K
ool00`00ooooo`02ool20003ool20004ool;0002ool20002ool00`00ooooo`0Sool40007ool40000
0ooo0000000>ool60007ool20006ool001Goo`03003ooooo03;oo`8000?oo`800003ool0000000P0
00;oo`P000coo`<000Coo`04003oooooool400001?oo00000?oo0P000_oo00<00?ooool00_oo0P00
5?oo00<00?ooool01ooo00<00?ooool02?oo2P0000?oo`00ool09Ooo10001ooo1P007Ooo00<00?oo
ool01?oo000Eool00`00ooooo`0gool200000ooo003oo`0800001?oo00000?oo0P0000Coo`000000
00;oo`8000Soo`800003ool00?oo00;oo`8000?oo`<000Koo`<000Coo`<001?oo`03003ooooo00Ko
o`8000Soo`800003ool0000000T002Koo`@000?oo`8000;oo`800003ool00?oo01koo`03003ooooo
00Coo`005Ooo00<00?ooool0>_oo00<00?oo00001@0000Coo`00000000;oo`@000Coo`8000Soo`80
0003ool00?oo00?oo`03003ooooo00?oo`03003ooooo00Coo`<000?oo`H000ooo`<000Soo`03003o
oooo00Ooo`8000?oo`T002Koo`@000?oo`8000Goo`03003ooooo01goo`03003ooooo00Coo`005Ooo
00<00?ooool0>?oo0`0000?oo`0000000P000_oo0`000ooo10003_oo10001Ooo00<00?ooool00_oo
00<00?ooool01?oo0`000ooo1`003_oo0P002?oo00<00?ooool03?oo0P000_oo1P009ooo0P0000Co
o`00ooooo`@000;oo`8001ooo`03003ooooo00Coo`005Ooo00<00?ooool0<ooo200000?oo`000000
0_oo0`0000?oo`00ool00_oo10003ooo0`001_oo0`0000?oo`00ool01Ooo3P003?oo0`001ooo0P00
3_oo0P0000Coo`00000000;oo`8002Ooo`800003ool00?oo00P0023oo`03003ooooo00Coo`005Ooo
00<00?ooool0<ooo1`000ooo0P0000Koo`0000000?oo0005ool2000Aool00`00ooooo`04ool40008
ool30004ool400000ooo0000000;ool30006ool2000?ool200001?oo00000000:ooo0P0000?oo`00
ool020008?oo00<00?ooool01?oo0003ool500001?oo000000000ooo00<00?ooool00ooo00<00?oo
ool0=Ooo1@000_oo0`0000?oo`0000000P005ooo0P0000?oo`00ool01Ooo1P000ooo1@0000Coo`00
003oo`@000;oo`8000[oo`<000Goo`80013oo`8002ooo`d0023oo`03003ooooo00Coo`001Ooo00D0
0?ooooooo`0000Coo`03003oo`0000Coo`03003ooooo03Goo`<00004ool00?ooool30002ool3000G
ool200000ooo003oo`05ool30003ool800001?oo00000?oo1@000_oo0P002Ooo0`001?oo0P00@_oo
30008Ooo00<00?ooool01?oo0005ool00`00ooooo`02ool01`00oooooooo003oo`0000Coo`8000?o
o`8002ooo`H000Coo`8000Coo`03003ooooo01Soo`03003ooooo008000Coo`03003ooooo00Koo`<0
0003ool0000000H000?oo`8000Koo`D000?oo`8004Coo`H000;oo`<001ooo`<000Koo`001Ooo00<0
0?ooool00_oo00L00?ooooooo`00ool00004ool00`00ooooo`02ool2000_ool60004ool20004ool0
0`00ooooo`0Fool30002ool20004ool00`00ooooo`06ool70003ool30003ool20005ool40003ool2
0015ool60002ool3000Qool00`00ooooo`04ool000Goo`07003oooooool00?oo00000_oo00<00?oo
00001?oo00<00?ooool00ooo00<00?ooool0;Ooo10002?oo0P0000?oo`00ool06?oo0`000ooo0P00
0ooo00<00?ooool01_oo1`000_oo200000?oo`00ool00ooo10000ooo00<00?ooool0A?oo1@000ooo
0`008Ooo00<00?ooool01?oo0004ool20004ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`03ool2000^ool50007ool200000ooo003oo`0Jool00`00ooooo`0500000ooo003oo`07ool40000
0ooo003oo`02ool80002ool01000oooooooo10000_oo00<00?ooool0AOoo1@000ooo0`008Ooo00<0
0?ooool01?oo000Eool00`00ooooo`04ool00`00ooooo`0]ool40007ool200000ooo003oo`0Kool0
1@00ool00000ool00`002ooo10000ooo20000ooo1`0000?oo`000000B_oo0P009ooo00<00?ooool0
1?oo000Eool00`00ooooo`03ool3000/ool60007ool200000ooo003oo`0Kool00`00ooooo`020002
ool00`00ooooo`08ool50003ool:0003ool7001@ool2000Rool00`00ooooo`04ool001Goo`03003o
oooo00?oo`<002coo`@000Woo`<001[oo`800004ool00?ooool5000:ool40006ool80006ool3001A
ool2000Rool00`00ooooo`04ool001Goo`03003ooooo00Coo`8002ooo`8000Soo`<001[oo`800004
ool00?ooool4000;ool40006ool90002ool200000ooo003oo`1fool00`00ooooo`04ool001Goo`03
003ooooo00?oo`04003oo`00000^ool20008ool3000Mool00`00ool00004000:ool50007ool20000
0ooo000000030002ool3001hool00`00ooooo`04ool001Goo`03003ooooo00Koo`8002coo`8000_o
o`03003ooooo01coo`H000[oo`D000_oo`@00005ool00000ool0001hool00`00ooooo`04ool001Go
o`8000Coo`800004ool00000000[ool2000:ool00`00ooooo`0Jool6000>ool2000=ool200000ooo
00000004001gool20006ool001Goo`03003ooooo00?oo`800004ool00?oo000/ool00`00ooooo`08
ool00`00ooooo`0Iool9000Kool8001iool00`00ooooo`04ool001Goo`03003ooooo00Coo`<000;o
o`03003ooooo02Woo`03003ooooo00Soo`03003ooooo01Woo`800003ool0000000@001goo`H007Wo
o`03003ooooo00Coo`005Ooo00<00?ooool01?oo0`000_oo0P00:_oo00<00?ooool01ooo00<00?oo
ool06ooo10000_oo0P007Ooo1P00NOoo00<00?ooool01?oo000Eool00`00ooooo`03ool40003ool0
0`00ooooo`0Xool00`00ooooo`07ool00`00ooooo`0Kool4000Qool5001jool00`00ooooo`04ool0
01Goo`03003ooooo00?oo`<00004ool00?ooool2000Yool00`00ooooo`07ool00`00ooooo`0Lool3
000Rool3001kool00`00ooooo`04ool001Goo`03003ooooo00Goo`<000?oo`03003ooooo02Ooo`03
003ooooo00Ooo`03003ooooo01goo`8002;oo`<007_oo`03003ooooo00Coo`005Ooo00<00?ooool0
1Ooo0`001?oo00<00?ooool09Ooo00<00?ooool01ooo00<00?ooool0@Ooo0`00O?oo00<00?ooool0
1?oo000Eool00`00ooooo`04ool40004ool00`00ooooo`0Uool00`00ooooo`07ool00`00ooooo`0M
ool2000Rool3001lool00`00ooooo`04ool001Goo`8000Goo`800003ool00?oo00Coo`03003ooooo
02Coo`03003ooooo00Ooo`03003ooooo01goo`8002?oo`8007_oo`8000Koo`005Ooo00<00?ooool0
1?oo0P0000?oo`00ool01?oo00<00?ooool09?oo00<00?ooool01ooo00<00?ooool0@Ooo0P00OOoo
00<00?ooool01?oo000Eool00`00ooooo`07ool00`00ooooo`04ool00`00ooooo`0Sool00`00oooo
o`06ool00`00ooooo`12ool2001mool00`00ooooo`04ool001Goo`03003ooooo00Soo`03003ooooo
00?oo`03003ooooo02?oo`03003ooooo00Koo`03003ooooo0<7oo`03003ooooo00Coo`005Ooo00<0
0?ooool01Ooo0P0000?oo`00ool01Ooo00<00?ooool08_oo00<00?ooool01_oo00<00?ooool0`Ooo
00<00?ooool01?oo000Eool00`00ooooo`05ool40006ool00`00ooooo`0Rool00`00ooooo`06ool0
0`00ooooo`31ool00`00ooooo`04ool001Goo`03003ooooo00Goo`@000Koo`03003ooooo02;oo`03
003ooooo00Koo`03003ooooo0<7oo`03003ooooo00Coo`005Ooo00<00?ooool01Ooo1@001_oo00<0
0?ooool08Ooo00<00?ooool01Ooo00<00?ooool0`_oo00<00?ooool01?oo000Eool00`00ooooo`06
ool40006ool00`00ooooo`0Qool00`00ooooo`05ool00`00ooooo`32ool00`00ooooo`04ool001Go
o`03003ooooo00Ooo`<000Ooo`03003ooooo01koo`<000Ooo`03003ooooo0<;oo`03003ooooo00Co
o`005Ooo0P001ooo0P0000?oo`00ool01_oo00<00?ooool07_oo0`001ooo00<00?ooool0`Ooo0P00
1_oo000Eool00`00ooooo`06ool200000ooo003oo`07ool00`00ooooo`0Oool00`00ooooo`05ool0
0`00ooooo`32ool00`00ooooo`04ool001Goo`03003ooooo00Koo`800003ool00?oo00Ooo`03003o
oooo01ooo`03003ooooo00Coo`03003ooooo0<?oo`03003ooooo00Coo`005Ooo00<00?ooool01_oo
0P000_oo00<00?ooool01Ooo00<00?ooool07ooo00<00?ooool01?oo00<00?ooool0`ooo00<00?oo
ool01?oo000Eool00`00ooooo`06ool20002ool00`00ooooo`06ool00`00ooooo`0Nool00`00oooo
o`04ool00`00ooooo`33ool00`00ooooo`04ool001Goo`03003ooooo00Soo`@000Ooo`03003ooooo
01koo`03003ooooo00Coo`03003ooooo0<?oo`03003ooooo00Coo`005Ooo00<00?ooool02?oo1000
1ooo00<00?ooool07Ooo00<00?ooool01Ooo00<00?ooool0`ooo00<00?ooool01?oo0003ool50002
ool30002ool00`00ooooo`03ool00`00ooooo`08ool50007ool00`00ooooo`0Lool00`00ooooo`05
ool00`00ooooo`33ool00`00ooooo`04ool000Goo`03003ooooo00?oo`06003ooooo003oo`001?oo
00<00?ooool02?oo1@001ooo00<00?ooool07?oo00<00?ooool01Ooo00<00?ooool0`ooo00<00?oo
ool01?oo0005ool01000oooooooo100000Coo`00ool000Coo`8000Woo`D000Ooo`03003ooooo01[o
o`<000Koo`03003ooooo0<;oo`<000Koo`001Ooo00L00?ooooooo`00ool00002ool00`00ool00004
ool00`00ooooo`0:ool40007ool00`00ooooo`0Iool30006ool00`00ooooo`34ool00`00ooooo`04
ool000Goo`03003ooooo00;oo`8000;oo`03003oo`0000Coo`03003ooooo00_oo`<000Ooo`03003o
oooo01_oo`03003ooooo00Coo`03003ooooo0<Coo`03003ooooo00Coo`001?oo0P001Ooo00D00?oo
ooooo`0000Goo`03003ooooo00Woo`800004ool000000006ool00`00ooooo`0Kool00`00ooooo`04
ool00`00ooooo`34ool00`00ooooo`04ool001Goo`03003ooooo00Woo`800004ool000000006ool0
0`00ooooo`0Kool00`00ooooo`04ool00`00ooooo`34ool00`00ooooo`04ool001Goo`03003ooooo
00_oo`800003ool00?oo00Koo`03003ooooo01[oo`03003ooooo00Coo`03003ooooo0<Coo`03003o
oooo00Coo`005Ooo00<00?ooool02Ooo100000?oo`00ool01_oo00<00?ooool06_oo00<00?ooool0
0ooo00<00?ooool0aOoo00<00?ooool01?oo000Eool00`00ooooo`09ool20003ool00`00ooooo`02
0003ool00`00ooooo`0Jool00`00ooooo`03ool00`00ooooo`35ool00`00ooooo`04ool001Goo`03
003ooooo00coo`800003ool00?oo008000?oo`03003ooooo01[oo`03003ooooo00?oo`03003ooooo
0<Goo`03003ooooo00Coo`005Ooo00<00?ooool03?oo0P0000?oo`00ool00P001?oo00<00?ooool0
6Ooo00<00?ooool00ooo00<00?ooool0aOoo00<00?ooool01?oo000Eool2000=ool200000ooo003o
o`020004ool00`00ooooo`0Gool30005ool00`00ooooo`34ool20006ool001Goo`03003ooooo00oo
o`03003ooooo00Goo`03003ooooo01Ooo`<000Coo`03003ooooo0<Koo`03003ooooo00Coo`005Ooo
00<00?ooool03Ooo1@001Ooo00<00?ooool06Ooo00<00?ooool00_oo00<00?ooool0a_oo00<00?oo
ool01?oo000Eool00`00ooooo`0=ool50006ool00`00ooooo`0Hool00`00ooooo`02ool00`00oooo
o`36ool00`00ooooo`04ool001Goo`03003ooooo00goo`<00003ool0000000Goo`03003ooooo01Go
o`800003ool00?oo00?oo`03003ooooo0<Koo`03003ooooo00Coo`005Ooo00<00?ooool04?oo1000
1?oo00<00?ooool05Ooo0`001Ooo00<00?ooool0a_oo00<00?ooool01?oo000Eool00`00ooooo`0=
ool200000ooo000000020005ool00`00ooooo`0Eool20004ool00`00ooooo`37ool00`00ooooo`04
ool001Goo`03003ooooo00goo`800005ool00?ooool00005ool00`00ooooo`0Eool20004ool00`00
ooooo`37ool00`00ooooo`04ool001Goo`03003ooooo00koo`D00003ool00?oo00?oo`03003ooooo
01Goo`8000Coo`03003ooooo0<Ooo`03003ooooo00Coo`005Ooo0P003ooo1`001Ooo00<00?ooool0
5?oo0P001?oo00<00?ooool0a_oo0P001_oo000Eool00`00ooooo`0?ool200001Ooo00000?oo0000
1?oo00<00?ooool04?oo100000?oo`00ool00_oo00<00?ooool0b?oo00<00?ooool01?oo000Eool0
0`00ooooo`0?ool200001Ooo00000?oo00001?oo00<00?ooool04?oo1P000ooo00<00?ooool0b?oo
00<00?ooool01?oo000Eool00`00ooooo`0?ool20002ool30005ool00`00ooooo`0Bool30003ool0
0`00ooooo`38ool00`00ooooo`04ool001Goo`03003ooooo00ooo`8000;oo`<000Goo`03003ooooo
01;oo`<000?oo`03003ooooo0<Soo`03003ooooo00Coo`005Ooo00<00?ooool03_oo0`001?oo00<0
0?ooool01?oo00<00?ooool03ooo1@000_oo00<00?ooool0bOoo00<00?ooool01?oo000Eool00`00
ooooo`0>ool20005ool00`00ooooo`04ool00`00ooooo`0?ool40003ool00`00ooooo`39ool00`00
ooooo`04ool001Goo`03003ooooo00koo`8000Koo`03003ooooo00Coo`03003ooooo017oo`05003o
ooooool0003;ool00`00ooooo`04ool001Goo`03003ooooo00koo`8000?oo`@000Koo`03003ooooo
00goo`@000Coo`03003ooooo0<Woo`03003ooooo00Coo`005Ooo0P005?oo10001ooo00<00?ooool0
3?oo10001?oo00<00?ooool0b?oo0P001_oo000Eool00`00ooooo`0>ool20004ool30007ool00`00
ooooo`0<ool40004ool00`00ooooo`39ool00`00ooooo`04ool001Goo`03003ooooo00koo`8000Co
o`<000Ooo`8000goo`@000?oo`03003ooooo0<[oo`03003ooooo00Coo`005Ooo00<00?ooool05_oo
00@00?oo000000;oo`800003ool00?oo00_oo`D000?oo`03003ooooo0<[oo`03003ooooo00Coo`00
5Ooo00<00?ooool04ooo0P0000?oo`00ool01P0000?oo`0000002_oo0`0000?oo`0000000ooo00<0
0?ooool0b_oo00<00?ooool01?oo000Eool00`00ooooo`0Cool200000ooo003oo`050003ool00`00
ooooo`08ool40005ool00`00ooooo`3:ool00`00ooooo`04ool001Goo`03003ooooo01Koo`03003o
oooo00;oo`8000?oo`8000Woo`@000Goo`03003ooooo0<[oo`03003ooooo00Coo`005Ooo00<00?oo
ool05?oo0P0000?oo`00ool02?oo00<00?ooool02?oo0`001?oo00<00?ooool0booo00<00?ooool0
1?oo0003ool500000ooo00000004ool00`00ooooo`03ool00`00ooooo`0Dool200000ooo003oo`09
ool00`00ool000020007ool00`00ooooo`02ool00`00ooooo`3;ool00`00ooooo`04ool000Goo`07
003oooooool00?oo00000_oo00<00?oo00001?oo00<00?ooool05ooo00<00?oo00001@000ooo1@00
1ooo00<00?ooool00_oo00<00?ooool0booo00<00?ooool01?oo0005ool01`00oooooooo003oo`00
00;oo`03003oo`0000Coo`8001Goo`800003ool00?oo00H000Coo`@000Koo`03003ooooo00?oo`03
003ooooo0<Woo`<000Koo`001Ooo00@00?ooooooo`8000?oo`03003oo`0000Coo`03003ooooo01Co
o`P00003ool0000000Coo`@000?oo`800003ool00?oo00?oo`03003ooooo0<coo`03003ooooo00Co
o`001Ooo00D00?ooooooo`0000Coo`03003oo`0000Coo`03003ooooo01Goo`/000;oo`@000Coo`@0
00Coo`03003ooooo0<coo`03003ooooo00Coo`001?oo0P001?oo0P000ooo00<00?ooool00ooo00<0
0?ooool06?oo20000_oo1@000ooo10001?oo00<00?ooool0c?oo00<00?ooool01?oo000Eool00`00
ooooo`0Hool20002ool200000ooo00000002ool50002ool40003ool2003>ool00`00ooooo`04ool0
01Goo`03003ooooo01Goo`H000Coo`800003ool0000000@000;oo`800003ool00?oo00;oo`03003o
oooo0<goo`03003ooooo00Coo`005Ooo00<00?ooool05Ooo0`0000?oo`0000000_oo0P0000?oo`00
ool00P0000?oo`0000000P0000Coo`00000000;oo`800=3oo`03003ooooo00Coo`005Ooo00<00?oo
ool05_oo0P001Ooo1@000ooo00<00?oo00000`0000?oo`00ool00P00dOoo00<00?ooool01?oo000E
ool00`00ooooo`0Fool20007ool90002ool4003Cool00`00ooooo`04ool001Goo`8001Ooo`<000Co
o`X00003ool00?oo00;oo`03003ooooo0=7oo`8000Koo`005Ooo00<00?ooool05_oo0`001?oo1@00
00?oo`0000000ooo00D00?ooooooo`000=Coo`03003ooooo00Coo`005Ooo00<00?ooool05_oo0`00
1Ooo1P001?oo0`0000?oo`00ool0dooo00<00?ooool01?oo000Eool00`00ooooo`0Eool40005ool5
0003ool500000ooo003oo`3Cool00`00ooooo`04ool001Goo`03003ooooo01Goo`8000Ooo`H000;o
o`H00=Goo`03003ooooo00Coo`005Ooo00<00?ooool05Ooo0P001ooo1P001?oo1000eOoo00<00?oo
ool01?oo000Eool00`00ooooo`0Nool200000ooo00000006ool3003Eool00`00ooooo`04ool001Go
o`03003ooooo027oo`8000Koo`<00=Goo`03003ooooo00Coo`005Ooo00<00?ooool09_oo0P0000Co
o`00ool00=Goo`03003ooooo00Coo`005Ooo00<00?ooool08Ooo0P000ooo0P0000Coo`00ool00=Go
o`03003ooooo00Coo`005Ooo0P008_oo0P000ooo0P0000Coo`00ool00=Coo`8000Koo`005Ooo00<0
0?ooool09_oo0P0000Coo`00ool00=Goo`03003ooooo00Coo`005Ooo00<00?ooool0:_oo00<00?oo
ool0e?oo00<00?ooool01?oo000Eool00`00ooooo`0Xool2003Gool00`00ooooo`04ool001Goo`03
003ooooo02Ooo`<00=Ooo`03003ooooo00Coo`005Ooo00<00?ooool09ooo0P00f?oo00<00?ooool0
1?oo000Eool00`00ooooo`0Vool3003Hool00`00ooooo`04ool001Goo`03003ooooo02Koo`<00=So
o`03003ooooo00Coo`005Ooo00<00?ooool09ooo0`00eooo00<00?ooool01?oo000Eool2000Xool3
003Fool20006ool001Goo`03003ooooo0?ooo`;oo`03003ooooo00Coo`005Ooo00<00?ooool00ooo
00<00?ooool0;_oo00<00?ooool0;ooo00<00?ooool0;_oo00<00?ooool0;ooo00<00?ooool0;ooo
00<00?ooool00ooo00<00?ooool01?oo000Eoooo00060006ool00?ooob7oo`00oooo8Ooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-109.729, 84.0312, 4.0354, \
0.530228}}]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
CellGrouping->Manual,
WindowSize->{500, 350},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "ApplicationManual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "0.1"->{
    Cell[1717, 49, 46, 1, 72, "Section",
      CellTags->"0.1"]},
  "S0.1"->{
    Cell[1766, 52, 79, 1, 56, "Subsection",
      CellTags->{"S0.1", "1.1"}],
    Cell[1848, 55, 82, 1, 49, "Subsubsection",
      CellTags->{"S0.1", "1.2"}],
    Cell[1933, 58, 239, 6, 52, "Text",
      CellTags->{"S0.1", "1.3"}],
    Cell[2175, 66, 165, 4, 48, "MathCaption",
      CellTags->{"S0.1", "1.4"}],
    Cell[2365, 74, 98, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[2590, 83, 143, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.5"}],
    Cell[2736, 89, 157, 8, 102, "Input",
      CellTags->"S0.1"],
    Cell[2896, 99, 108, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.6"}],
    Cell[3029, 104, 82, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[3236, 113, 75, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.7"}],
    Cell[3336, 118, 87, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[3524, 127, 149, 5, 32, "MathCaption",
      CellTags->{"S0.1", "1.8"}],
    Cell[3676, 134, 247, 11, 156, "Input",
      CellTags->"S0.1"],
    Cell[3926, 147, 143, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.9"}],
    Cell[4072, 153, 93, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[4168, 157, 231, 6, 50, "MathCaption",
      CellTags->{"S0.1", "1.10"}],
    Cell[4402, 165, 100, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[4505, 169, 154, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.11"}],
    Cell[4662, 175, 98, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[4763, 179, 132, 5, 70, "MathCaption",
      CellTags->{"S0.1", "1.12"}],
    Cell[4920, 188, 71, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[5464, 201, 91, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.13"}],
    Cell[5580, 206, 102, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[20146, 592, 182, 7, 70, "MathCaption",
      CellTags->{"S0.1", "1.14"}],
    Cell[20640, 616, 91, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.15"}],
    Cell[20734, 619, 137, 5, 70, "Input",
      CellTags->"S0.1"],
    Cell[20874, 626, 85, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.16"}],
    Cell[20984, 631, 106, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[39371, 1191, 114, 2, 70, "MathCaption",
      CellTags->{"S0.1", "1.17"}],
    Cell[39510, 1197, 75, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[53885, 1617, 95, 1, 70, "Subsubsection",
      CellTags->{"S0.1", "1.18"}],
    Cell[53983, 1620, 214, 6, 49, "MathCaption",
      CellTags->{"S0.1", "1.19"}],
    Cell[54200, 1628, 314, 12, 174, "Input",
      CellTags->"S0.1"],
    Cell[54517, 1642, 153, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.20"}],
    Cell[54673, 1648, 93, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[54769, 1652, 86, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.21"}],
    Cell[54880, 1657, 74, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[80542, 2796, 153, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.22"}],
    Cell[80698, 2802, 93, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[80794, 2806, 86, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.23"}],
    Cell[80905, 2811, 74, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[111798, 4004, 143, 4, 70, "MathCaption",
      CellTags->{"S0.1", "1.24"}],
    Cell[111944, 4010, 91, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[112038, 4014, 86, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.25"}],
    Cell[112149, 4019, 74, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[142567, 5158, 144, 4, 70, "MathCaption",
      CellTags->{"S0.1", "1.26"}],
    Cell[142714, 5164, 92, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[142809, 5168, 86, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.27"}],
    Cell[142920, 5173, 74, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[173465, 6354, 144, 4, 70, "MathCaption",
      CellTags->{"S0.1", "1.28"}],
    Cell[173612, 6360, 92, 2, 70, "Input",
      CellTags->"S0.1"],
    Cell[173707, 6364, 86, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.29"}],
    Cell[173818, 6369, 74, 2, 70, "Input",
      CellTags->"S0.1"]},
  "1.1"->{
    Cell[1766, 52, 79, 1, 56, "Subsection",
      CellTags->{"S0.1", "1.1"}]},
  "1.2"->{
    Cell[1848, 55, 82, 1, 49, "Subsubsection",
      CellTags->{"S0.1", "1.2"}]},
  "1.3"->{
    Cell[1933, 58, 239, 6, 52, "Text",
      CellTags->{"S0.1", "1.3"}]},
  "1.4"->{
    Cell[2175, 66, 165, 4, 48, "MathCaption",
      CellTags->{"S0.1", "1.4"}]},
  "1.5"->{
    Cell[2590, 83, 143, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.5"}]},
  "1.6"->{
    Cell[2896, 99, 108, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.6"}]},
  "1.7"->{
    Cell[3236, 113, 75, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.7"}]},
  "1.8"->{
    Cell[3524, 127, 149, 5, 32, "MathCaption",
      CellTags->{"S0.1", "1.8"}]},
  "1.9"->{
    Cell[3926, 147, 143, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.9"}]},
  "1.10"->{
    Cell[4168, 157, 231, 6, 50, "MathCaption",
      CellTags->{"S0.1", "1.10"}]},
  "1.11"->{
    Cell[4505, 169, 154, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.11"}]},
  "1.12"->{
    Cell[4763, 179, 132, 5, 70, "MathCaption",
      CellTags->{"S0.1", "1.12"}]},
  "1.13"->{
    Cell[5464, 201, 91, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.13"}]},
  "1.14"->{
    Cell[20146, 592, 182, 7, 70, "MathCaption",
      CellTags->{"S0.1", "1.14"}]},
  "1.15"->{
    Cell[20640, 616, 91, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.15"}]},
  "1.16"->{
    Cell[20874, 626, 85, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.16"}]},
  "1.17"->{
    Cell[39371, 1191, 114, 2, 70, "MathCaption",
      CellTags->{"S0.1", "1.17"}]},
  "1.18"->{
    Cell[53885, 1617, 95, 1, 70, "Subsubsection",
      CellTags->{"S0.1", "1.18"}]},
  "1.19"->{
    Cell[53983, 1620, 214, 6, 49, "MathCaption",
      CellTags->{"S0.1", "1.19"}]},
  "1.20"->{
    Cell[54517, 1642, 153, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.20"}]},
  "1.21"->{
    Cell[54769, 1652, 86, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.21"}]},
  "1.22"->{
    Cell[80542, 2796, 153, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.22"}]},
  "1.23"->{
    Cell[80794, 2806, 86, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.23"}]},
  "1.24"->{
    Cell[111798, 4004, 143, 4, 70, "MathCaption",
      CellTags->{"S0.1", "1.24"}]},
  "1.25"->{
    Cell[112038, 4014, 86, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.25"}]},
  "1.26"->{
    Cell[142567, 5158, 144, 4, 70, "MathCaption",
      CellTags->{"S0.1", "1.26"}]},
  "1.27"->{
    Cell[142809, 5168, 86, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.27"}]},
  "1.28"->{
    Cell[173465, 6354, 144, 4, 70, "MathCaption",
      CellTags->{"S0.1", "1.28"}]},
  "1.29"->{
    Cell[173707, 6364, 86, 1, 70, "MathCaption",
      CellTags->{"S0.1", "1.29"}]},
  "S0.2"->{
    Cell[199442, 7507, 80, 1, 70, "Subsection",
      CellTags->{"S0.2", "2.1"}],
    Cell[199525, 7510, 82, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.2"}],
    Cell[199610, 7513, 82, 2, 70, "Input",
      CellTags->"S0.2"],
    Cell[199695, 7517, 216, 5, 70, "MathCaption",
      CellTags->{"S0.2", "2.3"}],
    Cell[199936, 7526, 81, 2, 70, "Input",
      CellTags->"S0.2"],
    Cell[204631, 7689, 60, 1, 70, "Caption",
      CellTags->"S0.2"],
    Cell[204694, 7692, 380, 8, 70, "Text",
      CellTags->{"S0.2", "2.5"}],
    Cell[206458, 7722, 98, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.6"}],
    Cell[206559, 7725, 143, 5, 70, "Input",
      CellTags->"S0.2"],
    Cell[206705, 7732, 81, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.7"}],
    Cell[206811, 7737, 86, 2, 70, "Input",
      CellTags->"S0.2"],
    Cell[206975, 7746, 76, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.8"}],
    Cell[207076, 7751, 166, 5, 70, "Input",
      CellTags->"S0.2"],
    Cell[207350, 7763, 85, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.9"}],
    Cell[207438, 7766, 120, 2, 30, "Input",
      CellTags->"S0.2"],
    Cell[207561, 7770, 82, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.10"}],
    Cell[207646, 7773, 76, 2, 30, "Input",
      CellTags->"S0.2"],
    Cell[207725, 7777, 113, 2, 31, "MathCaption",
      CellTags->{"S0.2", "2.11"}],
    Cell[207841, 7781, 117, 2, 30, "Input",
      CellTags->"S0.2"],
    Cell[207961, 7785, 104, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.12"}],
    Cell[208090, 7790, 89, 2, 30, "Input",
      CellTags->"S0.2"],
    Cell[208385, 7801, 90, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.13"}],
    Cell[208500, 7806, 168, 6, 66, "Input",
      CellTags->"S0.2"],
    Cell[209948, 7850, 92, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.14"}],
    Cell[210043, 7853, 95, 2, 70, "Input",
      CellTags->"S0.2"],
    Cell[210369, 7868, 74, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.15"}],
    Cell[210468, 7873, 207, 6, 70, "Input",
      CellTags->"S0.2"],
    Cell[214400, 7977, 93, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.16"}],
    Cell[214496, 7980, 241, 7, 70, "Input",
      CellTags->"S0.2"],
    Cell[214740, 7989, 136, 4, 70, "MathCaption",
      CellTags->{"S0.2", "2.17"}],
    Cell[214901, 7997, 188, 5, 70, "Input",
      CellTags->"S0.2"],
    Cell[236653, 8743, 214, 7, 70, "Text",
      CellTags->{"S0.2", "2.18"}],
    Cell[236870, 8752, 141, 4, 70, "MathCaption",
      CellTags->{"S0.2", "2.19"}],
    Cell[237036, 8760, 79, 2, 70, "Input",
      CellTags->"S0.2"],
    Cell[237411, 8776, 234, 7, 70, "MathCaption",
      CellTags->{"S0.2", "2.20"}],
    Cell[237670, 8787, 116, 2, 70, "Input",
      CellTags->"S0.2"],
    Cell[237968, 8798, 371, 11, 68, "MathCaption",
      CellTags->{"S0.2", "2.21"}],
    Cell[238364, 8813, 258, 7, 84, "Input",
      CellTags->"S0.2"],
    Cell[283091, 10279, 141, 4, 31, "MathCaption",
      CellTags->{"S0.2", "2.22"}],
    Cell[283257, 10287, 267, 8, 102, "Input",
      CellTags->"S0.2"]},
  "2.1"->{
    Cell[199442, 7507, 80, 1, 70, "Subsection",
      CellTags->{"S0.2", "2.1"}]},
  "2.2"->{
    Cell[199525, 7510, 82, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.2"}]},
  "2.3"->{
    Cell[199695, 7517, 216, 5, 70, "MathCaption",
      CellTags->{"S0.2", "2.3"}]},
  "2.5"->{
    Cell[204694, 7692, 380, 8, 70, "Text",
      CellTags->{"S0.2", "2.5"}]},
  "2.6"->{
    Cell[206458, 7722, 98, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.6"}]},
  "2.7"->{
    Cell[206705, 7732, 81, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.7"}]},
  "2.8"->{
    Cell[206975, 7746, 76, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.8"}]},
  "2.9"->{
    Cell[207350, 7763, 85, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.9"}]},
  "2.10"->{
    Cell[207561, 7770, 82, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.10"}]},
  "2.11"->{
    Cell[207725, 7777, 113, 2, 31, "MathCaption",
      CellTags->{"S0.2", "2.11"}]},
  "2.12"->{
    Cell[207961, 7785, 104, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.12"}]},
  "2.13"->{
    Cell[208385, 7801, 90, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.13"}]},
  "2.14"->{
    Cell[209948, 7850, 92, 1, 31, "MathCaption",
      CellTags->{"S0.2", "2.14"}]},
  "2.15"->{
    Cell[210369, 7868, 74, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.15"}]},
  "2.16"->{
    Cell[214400, 7977, 93, 1, 70, "MathCaption",
      CellTags->{"S0.2", "2.16"}]},
  "2.17"->{
    Cell[214740, 7989, 136, 4, 70, "MathCaption",
      CellTags->{"S0.2", "2.17"}]},
  "2.18"->{
    Cell[236653, 8743, 214, 7, 70, "Text",
      CellTags->{"S0.2", "2.18"}]},
  "2.19"->{
    Cell[236870, 8752, 141, 4, 70, "MathCaption",
      CellTags->{"S0.2", "2.19"}]},
  "2.20"->{
    Cell[237411, 8776, 234, 7, 70, "MathCaption",
      CellTags->{"S0.2", "2.20"}]},
  "2.21"->{
    Cell[237968, 8798, 371, 11, 68, "MathCaption",
      CellTags->{"S0.2", "2.21"}]},
  "2.22"->{
    Cell[283091, 10279, 141, 4, 31, "MathCaption",
      CellTags->{"S0.2", "2.22"}]},
  "S0.3"->{
    Cell[329050, 11787, 89, 1, 56, "Subsection",
      CellTags->{"S0.3", "3.1"}],
    Cell[329142, 11790, 272, 6, 52, "Text",
      CellTags->{"S0.3", "3.2"}],
    Cell[329417, 11798, 133, 3, 31, "DisplayFormula",
      CellTags->"S0.3"],
    Cell[329553, 11803, 413, 15, 33, "Text",
      CellTags->{"S0.3", "3.3"}],
    Cell[329969, 11820, 171, 5, 31, "MathCaption",
      CellTags->{"S0.3", "3.4"}],
    Cell[330143, 11827, 143, 5, 30, "Input",
      CellTags->"S0.3"],
    Cell[330289, 11834, 85, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.5"}],
    Cell[330399, 11839, 86, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[330564, 11848, 76, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.6"}],
    Cell[330665, 11853, 168, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[330990, 11866, 82, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.7"}],
    Cell[331075, 11869, 132, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[331210, 11876, 81, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.8"}],
    Cell[331294, 11879, 76, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[331373, 11883, 105, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.9"}],
    Cell[331481, 11886, 117, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[331601, 11890, 355, 9, 71, "Text",
      CellTags->{"S0.3", "3.10"}],
    Cell[331959, 11901, 103, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.11"}],
    Cell[332087, 11906, 158, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[337158, 12049, 95, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.12"}],
    Cell[337278, 12054, 87, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[340390, 12142, 205, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.13"}],
    Cell[340620, 12151, 109, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[341475, 12170, 214, 6, 49, "MathCaption",
      CellTags->{"S0.3", "3.14"}],
    Cell[341692, 12178, 147, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[341842, 12185, 90, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.15"}],
    Cell[341957, 12190, 70, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[345342, 12288, 176, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.16"}],
    Cell[345543, 12297, 143, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[345845, 12310, 128, 4, 31, "MathCaption",
      CellTags->{"S0.3", "3.17"}],
    Cell[345976, 12316, 212, 6, 66, "Input",
      CellTags->"S0.3"],
    Cell[346191, 12324, 108, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.18"}],
    Cell[346324, 12329, 93, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[346514, 12338, 155, 4, 48, "MathCaption",
      CellTags->{"S0.3", "3.19"}],
    Cell[346672, 12344, 101, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[346776, 12348, 162, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.20"}],
    Cell[346963, 12357, 115, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[349289, 12409, 81, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.21"}],
    Cell[349395, 12414, 70, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[350171, 12430, 89, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.22"}],
    Cell[350285, 12435, 232, 7, 84, "Input",
      CellTags->"S0.3"],
    Cell[370263, 13207, 245, 8, 50, "MathCaption",
      CellTags->{"S0.3", "3.23"}],
    Cell[370511, 13217, 145, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[370659, 13224, 114, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.24"}],
    Cell[370798, 13230, 112, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[393000, 14089, 179, 4, 48, "MathCaption",
      CellTags->{"S0.3", "3.25"}],
    Cell[393204, 14097, 89, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[393697, 14112, 140, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[394216, 14128, 82, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.26"}],
    Cell[394323, 14133, 95, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[395155, 14153, 113, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.27"}],
    Cell[395293, 14159, 112, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[409414, 14651, 113, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.28"}],
    Cell[409552, 14657, 108, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[409820, 14667, 137, 4, 31, "MathCaption",
      CellTags->{"S0.3", "3.29"}],
    Cell[409960, 14673, 149, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[410112, 14680, 114, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.30"}],
    Cell[410251, 14686, 112, 2, 30, "Input",
      CellTags->"S0.3"]},
  "3.1"->{
    Cell[329050, 11787, 89, 1, 56, "Subsection",
      CellTags->{"S0.3", "3.1"}]},
  "3.2"->{
    Cell[329142, 11790, 272, 6, 52, "Text",
      CellTags->{"S0.3", "3.2"}]},
  "3.3"->{
    Cell[329553, 11803, 413, 15, 33, "Text",
      CellTags->{"S0.3", "3.3"}]},
  "3.4"->{
    Cell[329969, 11820, 171, 5, 31, "MathCaption",
      CellTags->{"S0.3", "3.4"}]},
  "3.5"->{
    Cell[330289, 11834, 85, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.5"}]},
  "3.6"->{
    Cell[330564, 11848, 76, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.6"}]},
  "3.7"->{
    Cell[330990, 11866, 82, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.7"}]},
  "3.8"->{
    Cell[331210, 11876, 81, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.8"}]},
  "3.9"->{
    Cell[331373, 11883, 105, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.9"}]},
  "3.10"->{
    Cell[331601, 11890, 355, 9, 71, "Text",
      CellTags->{"S0.3", "3.10"}]},
  "3.11"->{
    Cell[331959, 11901, 103, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.11"}]},
  "3.12"->{
    Cell[337158, 12049, 95, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.12"}]},
  "3.13"->{
    Cell[340390, 12142, 205, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.13"}]},
  "3.14"->{
    Cell[341475, 12170, 214, 6, 49, "MathCaption",
      CellTags->{"S0.3", "3.14"}]},
  "3.15"->{
    Cell[341842, 12185, 90, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.15"}]},
  "3.16"->{
    Cell[345342, 12288, 176, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.16"}]},
  "3.17"->{
    Cell[345845, 12310, 128, 4, 31, "MathCaption",
      CellTags->{"S0.3", "3.17"}]},
  "3.18"->{
    Cell[346191, 12324, 108, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.18"}]},
  "3.19"->{
    Cell[346514, 12338, 155, 4, 48, "MathCaption",
      CellTags->{"S0.3", "3.19"}]},
  "3.20"->{
    Cell[346776, 12348, 162, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.20"}]},
  "3.21"->{
    Cell[349289, 12409, 81, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.21"}]},
  "3.22"->{
    Cell[350171, 12430, 89, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.22"}]},
  "3.23"->{
    Cell[370263, 13207, 245, 8, 50, "MathCaption",
      CellTags->{"S0.3", "3.23"}]},
  "3.24"->{
    Cell[370659, 13224, 114, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.24"}]},
  "3.25"->{
    Cell[393000, 14089, 179, 4, 48, "MathCaption",
      CellTags->{"S0.3", "3.25"}]},
  "3.26"->{
    Cell[394216, 14128, 82, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.26"}]},
  "3.27"->{
    Cell[395155, 14153, 113, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.27"}]},
  "3.28"->{
    Cell[409414, 14651, 113, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.28"}]},
  "3.29"->{
    Cell[409820, 14667, 137, 4, 31, "MathCaption",
      CellTags->{"S0.3", "3.29"}]},
  "3.30"->{
    Cell[410112, 14680, 114, 2, 31, "MathCaption",
      CellTags->{"S0.3", "3.30"}]},
  "S0.4"->{
    Cell[425497, 15242, 66, 1, 56, "Subsection",
      CellTags->{"S0.4", "4.1"}],
    Cell[425566, 15245, 162, 4, 33, "Text",
      CellTags->{"S0.4", "4.2"}],
    Cell[425731, 15251, 87, 1, 31, "MathCaption",
      CellTags->{"S0.4", "4.3"}],
    Cell[425821, 15254, 189, 6, 66, "Input",
      CellTags->"S0.4"],
    Cell[426013, 15262, 273, 7, 67, "MathCaption",
      CellTags->{"S0.4", "4.4"}],
    Cell[426380, 15275, 117, 2, 30, "Input",
      CellTags->"S0.4"],
    Cell[426500, 15279, 136, 4, 31, "MathCaption",
      CellTags->{"S0.4", "4.5"}],
    Cell[426639, 15285, 117, 2, 30, "Input",
      CellTags->"S0.4"],
    Cell[426759, 15289, 112, 2, 31, "MathCaption",
      CellTags->{"S0.4", "4.6"}],
    Cell[426874, 15293, 149, 5, 48, "Input",
      CellTags->"S0.4"],
    Cell[427026, 15300, 112, 2, 31, "MathCaption",
      CellTags->{"S0.4", "4.7"}],
    Cell[427141, 15304, 149, 5, 48, "Input",
      CellTags->"S0.4"],
    Cell[427293, 15311, 141, 4, 31, "MathCaption",
      CellTags->{"S0.4", "4.8"}],
    Cell[427459, 15319, 120, 2, 30, "Input",
      CellTags->"S0.4"],
    Cell[485245, 17957, 87, 1, 31, "MathCaption",
      CellTags->{"S0.4", "4.9"}],
    Cell[485357, 17962, 104, 2, 30, "Input",
      CellTags->"S0.4"],
    Cell[523451, 19483, 99, 1, 70, "MathCaption",
      CellTags->{"S0.4", "4.10"}],
    Cell[523575, 19488, 137, 5, 70, "Input",
      CellTags->"S0.4"]},
  "4.1"->{
    Cell[425497, 15242, 66, 1, 56, "Subsection",
      CellTags->{"S0.4", "4.1"}]},
  "4.2"->{
    Cell[425566, 15245, 162, 4, 33, "Text",
      CellTags->{"S0.4", "4.2"}]},
  "4.3"->{
    Cell[425731, 15251, 87, 1, 31, "MathCaption",
      CellTags->{"S0.4", "4.3"}]},
  "4.4"->{
    Cell[426013, 15262, 273, 7, 67, "MathCaption",
      CellTags->{"S0.4", "4.4"}]},
  "4.5"->{
    Cell[426500, 15279, 136, 4, 31, "MathCaption",
      CellTags->{"S0.4", "4.5"}]},
  "4.6"->{
    Cell[426759, 15289, 112, 2, 31, "MathCaption",
      CellTags->{"S0.4", "4.6"}]},
  "4.7"->{
    Cell[427026, 15300, 112, 2, 31, "MathCaption",
      CellTags->{"S0.4", "4.7"}]},
  "4.8"->{
    Cell[427293, 15311, 141, 4, 31, "MathCaption",
      CellTags->{"S0.4", "4.8"}]},
  "4.9"->{
    Cell[485245, 17957, 87, 1, 31, "MathCaption",
      CellTags->{"S0.4", "4.9"}]},
  "4.10"->{
    Cell[523451, 19483, 99, 1, 70, "MathCaption",
      CellTags->{"S0.4", "4.10"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"0.1", 600110, 23145},
  {"S0.1", 600188, 23148},
  {"1.1", 604184, 23255},
  {"1.2", 604274, 23258},
  {"1.3", 604367, 23261},
  {"1.4", 604452, 23264},
  {"1.5", 604544, 23267},
  {"1.6", 604636, 23270},
  {"1.7", 604728, 23273},
  {"1.8", 604820, 23276},
  {"1.9", 604913, 23279},
  {"1.10", 605007, 23282},
  {"1.11", 605102, 23285},
  {"1.12", 605197, 23288},
  {"1.13", 605292, 23291},
  {"1.14", 605386, 23294},
  {"1.15", 605482, 23297},
  {"1.16", 605577, 23300},
  {"1.17", 605672, 23303},
  {"1.18", 605769, 23306},
  {"1.19", 605867, 23309},
  {"1.20", 605964, 23312},
  {"1.21", 606061, 23315},
  {"1.22", 606157, 23318},
  {"1.23", 606254, 23321},
  {"1.24", 606350, 23324},
  {"1.25", 606448, 23327},
  {"1.26", 606545, 23330},
  {"1.27", 606643, 23333},
  {"1.28", 606740, 23336},
  {"1.29", 606838, 23339},
  {"S0.2", 606935, 23342},
  {"2.1", 610007, 23423},
  {"2.2", 610101, 23426},
  {"2.3", 610196, 23429},
  {"2.5", 610292, 23432},
  {"2.6", 610381, 23435},
  {"2.7", 610476, 23438},
  {"2.8", 610571, 23441},
  {"2.9", 610666, 23444},
  {"2.10", 610762, 23447},
  {"2.11", 610859, 23450},
  {"2.12", 610957, 23453},
  {"2.13", 611055, 23456},
  {"2.14", 611152, 23459},
  {"2.15", 611249, 23462},
  {"2.16", 611346, 23465},
  {"2.17", 611443, 23468},
  {"2.18", 611541, 23471},
  {"2.19", 611632, 23474},
  {"2.20", 611730, 23477},
  {"2.21", 611828, 23480},
  {"2.22", 611927, 23483},
  {"S0.3", 612026, 23486},
  {"3.1", 616539, 23603},
  {"3.2", 616634, 23606},
  {"3.3", 616724, 23609},
  {"3.4", 616815, 23612},
  {"3.5", 616912, 23615},
  {"3.6", 617008, 23618},
  {"3.7", 617104, 23621},
  {"3.8", 617200, 23624},
  {"3.9", 617296, 23627},
  {"3.10", 617394, 23630},
  {"3.11", 617486, 23633},
  {"3.12", 617585, 23636},
  {"3.13", 617683, 23639},
  {"3.14", 617782, 23642},
  {"3.15", 617881, 23645},
  {"3.16", 617979, 23648},
  {"3.17", 618078, 23651},
  {"3.18", 618177, 23654},
  {"3.19", 618276, 23657},
  {"3.20", 618375, 23660},
  {"3.21", 618474, 23663},
  {"3.22", 618572, 23666},
  {"3.23", 618670, 23669},
  {"3.24", 618769, 23672},
  {"3.25", 618868, 23675},
  {"3.26", 618967, 23678},
  {"3.27", 619065, 23681},
  {"3.28", 619164, 23684},
  {"3.29", 619263, 23687},
  {"3.30", 619362, 23690},
  {"S0.4", 619461, 23693},
  {"4.1", 620872, 23730},
  {"4.2", 620967, 23733},
  {"4.3", 621057, 23736},
  {"4.4", 621153, 23739},
  {"4.5", 621250, 23742},
  {"4.6", 621347, 23745},
  {"4.7", 621444, 23748},
  {"4.8", 621541, 23751},
  {"4.9", 621638, 23754},
  {"4.10", 621735, 23757}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 46, 1, 72, "Section",
  CellTags->"0.1"],
Cell[1766, 52, 79, 1, 56, "Subsection",
  CellTags->{"S0.1", "1.1"}],
Cell[1848, 55, 82, 1, 49, "Subsubsection",
  CellTags->{"S0.1", "1.2"}],
Cell[1933, 58, 239, 6, 52, "Text",
  CellTags->{"S0.1", "1.3"}],
Cell[2175, 66, 165, 4, 48, "MathCaption",
  CellTags->{"S0.1", "1.4"}],

Cell[CellGroupData[{
Cell[2365, 74, 98, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[2466, 78, 109, 2, 29, "Output"]
}, Open  ]],
Cell[2590, 83, 143, 4, 31, "MathCaption",
  CellTags->{"S0.1", "1.5"}],
Cell[2736, 89, 157, 8, 102, "Input",
  CellTags->"S0.1"],
Cell[2896, 99, 108, 1, 31, "MathCaption",
  CellTags->{"S0.1", "1.6"}],

Cell[CellGroupData[{
Cell[3029, 104, 82, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[3114, 108, 107, 2, 29, "Output"]
}, Open  ]],
Cell[3236, 113, 75, 1, 31, "MathCaption",
  CellTags->{"S0.1", "1.7"}],

Cell[CellGroupData[{
Cell[3336, 118, 87, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[3426, 122, 83, 2, 29, "Output"]
}, Open  ]],
Cell[3524, 127, 149, 5, 32, "MathCaption",
  CellTags->{"S0.1", "1.8"}],
Cell[3676, 134, 247, 11, 156, "Input",
  CellTags->"S0.1"],
Cell[3926, 147, 143, 4, 31, "MathCaption",
  CellTags->{"S0.1", "1.9"}],
Cell[4072, 153, 93, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[4168, 157, 231, 6, 50, "MathCaption",
  CellTags->{"S0.1", "1.10"}],
Cell[4402, 165, 100, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[4505, 169, 154, 4, 31, "MathCaption",
  CellTags->{"S0.1", "1.11"}],
Cell[4662, 175, 98, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[4763, 179, 132, 5, 70, "MathCaption",
  CellTags->{"S0.1", "1.12"}],

Cell[CellGroupData[{
Cell[4920, 188, 71, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[4994, 192, 455, 6, 70, "Print"]
}, Open  ]],
Cell[5464, 201, 91, 1, 70, "MathCaption",
  CellTags->{"S0.1", "1.13"}],

Cell[CellGroupData[{
Cell[5580, 206, 102, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[5685, 210, 14446, 379, 70, 3296, 236, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[20146, 592, 182, 7, 70, "MathCaption",
  CellTags->{"S0.1", "1.14"}],
Cell[20331, 601, 87, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[20443, 607, 67, 2, 70, "Input"],
Cell[20513, 611, 112, 2, 70, "Print"]
}, Open  ]],
Cell[20640, 616, 91, 1, 70, "MathCaption",
  CellTags->{"S0.1", "1.15"}],
Cell[20734, 619, 137, 5, 70, "Input",
  CellTags->"S0.1"],
Cell[20874, 626, 85, 1, 70, "MathCaption",
  CellTags->{"S0.1", "1.16"}],

Cell[CellGroupData[{
Cell[20984, 631, 106, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[21093, 635, 18263, 553, 70, 4695, 380, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[39371, 1191, 114, 2, 70, "MathCaption",
  CellTags->{"S0.1", "1.17"}],

Cell[CellGroupData[{
Cell[39510, 1197, 75, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[39588, 1201, 14282, 413, 70, 4003, 281, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[53885, 1617, 95, 1, 70, "Subsubsection",
  CellTags->{"S0.1", "1.18"}],
Cell[53983, 1620, 214, 6, 49, "MathCaption",
  CellTags->{"S0.1", "1.19"}],
Cell[54200, 1628, 314, 12, 174, "Input",
  CellTags->"S0.1"],
Cell[54517, 1642, 153, 4, 31, "MathCaption",
  CellTags->{"S0.1", "1.20"}],
Cell[54673, 1648, 93, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[54769, 1652, 86, 1, 31, "MathCaption",
  CellTags->{"S0.1", "1.21"}],

Cell[CellGroupData[{
Cell[54880, 1657, 74, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[54957, 1661, 25570, 1132, 191, 15313, 1000, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[80542, 2796, 153, 4, 31, "MathCaption",
  CellTags->{"S0.1", "1.22"}],
Cell[80698, 2802, 93, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[80794, 2806, 86, 1, 31, "MathCaption",
  CellTags->{"S0.1", "1.23"}],

Cell[CellGroupData[{
Cell[80905, 2811, 74, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[80982, 2815, 30801, 1186, 191, 15205, 988, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[111798, 4004, 143, 4, 70, "MathCaption",
  CellTags->{"S0.1", "1.24"}],
Cell[111944, 4010, 91, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[112038, 4014, 86, 1, 70, "MathCaption",
  CellTags->{"S0.1", "1.25"}],

Cell[CellGroupData[{
Cell[112149, 4019, 74, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[112226, 4023, 30326, 1132, 70, 14447, 931, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[142567, 5158, 144, 4, 70, "MathCaption",
  CellTags->{"S0.1", "1.26"}],
Cell[142714, 5164, 92, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[142809, 5168, 86, 1, 70, "MathCaption",
  CellTags->{"S0.1", "1.27"}],

Cell[CellGroupData[{
Cell[142920, 5173, 74, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[142997, 5177, 30453, 1174, 70, 15048, 979, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[173465, 6354, 144, 4, 70, "MathCaption",
  CellTags->{"S0.1", "1.28"}],
Cell[173612, 6360, 92, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[173707, 6364, 86, 1, 70, "MathCaption",
  CellTags->{"S0.1", "1.29"}],

Cell[CellGroupData[{
Cell[173818, 6369, 74, 2, 70, "Input",
  CellTags->"S0.1"],
Cell[173895, 6373, 25532, 1131, 70, 15335, 1000, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[199442, 7507, 80, 1, 70, "Subsection",
  CellTags->{"S0.2", "2.1"}],
Cell[199525, 7510, 82, 1, 70, "MathCaption",
  CellTags->{"S0.2", "2.2"}],
Cell[199610, 7513, 82, 2, 70, "Input",
  CellTags->"S0.2"],
Cell[199695, 7517, 216, 5, 70, "MathCaption",
  CellTags->{"S0.2", "2.3"}],

Cell[CellGroupData[{
Cell[199936, 7526, 81, 2, 70, "Input",
  CellTags->"S0.2"],
Cell[200020, 7530, 156, 4, 70, "Print"]
}, Open  ]],
Cell[200191, 7537, 1423, 45, 70, InheritFromParent],
Cell[201617, 7584, 405, 14, 70, InheritFromParent],
Cell[202025, 7600, 1219, 38, 70, InheritFromParent],
Cell[203247, 7640, 413, 14, 70, InheritFromParent],
Cell[203663, 7656, 240, 7, 70, InheritFromParent],
Cell[203906, 7665, 370, 12, 70, InheritFromParent],
Cell[204279, 7679, 349, 8, 70, InheritFromParent],
Cell[204631, 7689, 60, 1, 70, "Caption",
  CellTags->"S0.2"],
Cell[204694, 7692, 380, 8, 70, "Text",
  CellTags->{"S0.2", "2.5"}],
Cell[205077, 7702, 1378, 18, 70, "Print"],
Cell[206458, 7722, 98, 1, 70, "MathCaption",
  CellTags->{"S0.2", "2.6"}],
Cell[206559, 7725, 143, 5, 70, "Input",
  CellTags->"S0.2"],
Cell[206705, 7732, 81, 1, 70, "MathCaption",
  CellTags->{"S0.2", "2.7"}],

Cell[CellGroupData[{
Cell[206811, 7737, 86, 2, 70, "Input",
  CellTags->"S0.2"],
Cell[206900, 7741, 60, 2, 70, "Output"]
}, Open  ]],
Cell[206975, 7746, 76, 1, 70, "MathCaption",
  CellTags->{"S0.2", "2.8"}],

Cell[CellGroupData[{
Cell[207076, 7751, 166, 5, 70, "Input",
  CellTags->"S0.2"],
Cell[207245, 7758, 90, 2, 70, "Output"]
}, Open  ]],
Cell[207350, 7763, 85, 1, 31, "MathCaption",
  CellTags->{"S0.2", "2.9"}],
Cell[207438, 7766, 120, 2, 30, "Input",
  CellTags->"S0.2"],
Cell[207561, 7770, 82, 1, 31, "MathCaption",
  CellTags->{"S0.2", "2.10"}],
Cell[207646, 7773, 76, 2, 30, "Input",
  CellTags->"S0.2"],
Cell[207725, 7777, 113, 2, 31, "MathCaption",
  CellTags->{"S0.2", "2.11"}],
Cell[207841, 7781, 117, 2, 30, "Input",
  CellTags->"S0.2"],
Cell[207961, 7785, 104, 1, 31, "MathCaption",
  CellTags->{"S0.2", "2.12"}],

Cell[CellGroupData[{
Cell[208090, 7790, 89, 2, 30, "Input",
  CellTags->"S0.2"],
Cell[208182, 7794, 188, 4, 29, "Output"]
}, Open  ]],
Cell[208385, 7801, 90, 1, 31, "MathCaption",
  CellTags->{"S0.2", "2.13"}],

Cell[CellGroupData[{
Cell[208500, 7806, 168, 6, 66, "Input",
  CellTags->"S0.2"],
Cell[208671, 7814, 1262, 33, 103, "Output"]
}, Open  ]],
Cell[209948, 7850, 92, 1, 31, "MathCaption",
  CellTags->{"S0.2", "2.14"}],
Cell[210043, 7853, 95, 2, 70, "Input",
  CellTags->"S0.2"],

Cell[CellGroupData[{
Cell[210163, 7859, 72, 2, 70, "Input"],
Cell[210238, 7863, 116, 2, 70, "Print"]
}, Open  ]],
Cell[210369, 7868, 74, 1, 70, "MathCaption",
  CellTags->{"S0.2", "2.15"}],

Cell[CellGroupData[{
Cell[210468, 7873, 207, 6, 70, "Input",
  CellTags->"S0.2"],
Cell[210678, 7881, 3707, 93, 70, "Output"]
}, Open  ]],
Cell[214400, 7977, 93, 1, 70, "MathCaption",
  CellTags->{"S0.2", "2.16"}],
Cell[214496, 7980, 241, 7, 70, "Input",
  CellTags->"S0.2"],
Cell[214740, 7989, 136, 4, 70, "MathCaption",
  CellTags->{"S0.2", "2.17"}],

Cell[CellGroupData[{
Cell[214901, 7997, 188, 5, 70, "Input",
  CellTags->"S0.2"],
Cell[215092, 8004, 21546, 736, 70, 8813, 574, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[236653, 8743, 214, 7, 70, "Text",
  CellTags->{"S0.2", "2.18"}],
Cell[236870, 8752, 141, 4, 70, "MathCaption",
  CellTags->{"S0.2", "2.19"}],

Cell[CellGroupData[{
Cell[237036, 8760, 79, 2, 70, "Input",
  CellTags->"S0.2"],
Cell[237118, 8764, 278, 9, 70, "Output"]
}, Open  ]],
Cell[237411, 8776, 234, 7, 70, "MathCaption",
  CellTags->{"S0.2", "2.20"}],

Cell[CellGroupData[{
Cell[237670, 8787, 116, 2, 70, "Input",
  CellTags->"S0.2"],
Cell[237789, 8791, 164, 4, 70, "Output"]
}, Open  ]],
Cell[237968, 8798, 371, 11, 68, "MathCaption",
  CellTags->{"S0.2", "2.21"}],

Cell[CellGroupData[{
Cell[238364, 8813, 258, 7, 84, "Input",
  CellTags->"S0.2"],
Cell[238625, 8822, 44451, 1454, 191, 16793, 1107, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[283091, 10279, 141, 4, 31, "MathCaption",
  CellTags->{"S0.2", "2.22"}],

Cell[CellGroupData[{
Cell[283257, 10287, 267, 8, 102, "Input",
  CellTags->"S0.2"],
Cell[283527, 10297, 45508, 1487, 191, 17035, 1130, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[329050, 11787, 89, 1, 56, "Subsection",
  CellTags->{"S0.3", "3.1"}],
Cell[329142, 11790, 272, 6, 52, "Text",
  CellTags->{"S0.3", "3.2"}],
Cell[329417, 11798, 133, 3, 31, "DisplayFormula",
  CellTags->"S0.3"],
Cell[329553, 11803, 413, 15, 33, "Text",
  CellTags->{"S0.3", "3.3"}],
Cell[329969, 11820, 171, 5, 31, "MathCaption",
  CellTags->{"S0.3", "3.4"}],
Cell[330143, 11827, 143, 5, 30, "Input",
  CellTags->"S0.3"],
Cell[330289, 11834, 85, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.5"}],

Cell[CellGroupData[{
Cell[330399, 11839, 86, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[330488, 11843, 61, 2, 29, "Output"]
}, Open  ]],
Cell[330564, 11848, 76, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.6"}],

Cell[CellGroupData[{
Cell[330665, 11853, 168, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[330836, 11860, 139, 3, 29, "Output"]
}, Open  ]],
Cell[330990, 11866, 82, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.7"}],
Cell[331075, 11869, 132, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[331210, 11876, 81, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.8"}],
Cell[331294, 11879, 76, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[331373, 11883, 105, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.9"}],
Cell[331481, 11886, 117, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[331601, 11890, 355, 9, 71, "Text",
  CellTags->{"S0.3", "3.10"}],
Cell[331959, 11901, 103, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.11"}],

Cell[CellGroupData[{
Cell[332087, 11906, 158, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[332248, 11913, 4895, 133, 105, "Output"]
}, Open  ]],
Cell[337158, 12049, 95, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.12"}],

Cell[CellGroupData[{
Cell[337278, 12054, 87, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[337368, 12058, 3007, 81, 67, "Output"]
}, Open  ]],
Cell[340390, 12142, 205, 5, 48, "MathCaption",
  CellTags->{"S0.3", "3.13"}],

Cell[CellGroupData[{
Cell[340620, 12151, 109, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[340732, 12155, 728, 12, 86, "Output"]
}, Open  ]],
Cell[341475, 12170, 214, 6, 49, "MathCaption",
  CellTags->{"S0.3", "3.14"}],
Cell[341692, 12178, 147, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[341842, 12185, 90, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.15"}],

Cell[CellGroupData[{
Cell[341957, 12190, 70, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[342030, 12194, 3297, 91, 67, "Output"]
}, Open  ]],
Cell[345342, 12288, 176, 5, 32, "MathCaption",
  CellTags->{"S0.3", "3.16"}],

Cell[CellGroupData[{
Cell[345543, 12297, 143, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[345689, 12304, 141, 3, 29, "Output"]
}, Open  ]],
Cell[345845, 12310, 128, 4, 31, "MathCaption",
  CellTags->{"S0.3", "3.17"}],
Cell[345976, 12316, 212, 6, 66, "Input",
  CellTags->"S0.3"],
Cell[346191, 12324, 108, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.18"}],

Cell[CellGroupData[{
Cell[346324, 12329, 93, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[346420, 12333, 79, 2, 29, "Output"]
}, Open  ]],
Cell[346514, 12338, 155, 4, 48, "MathCaption",
  CellTags->{"S0.3", "3.19"}],
Cell[346672, 12344, 101, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[346776, 12348, 162, 5, 32, "MathCaption",
  CellTags->{"S0.3", "3.20"}],

Cell[CellGroupData[{
Cell[346963, 12357, 115, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[347081, 12361, 2193, 45, 193, "Output"]
}, Open  ]],
Cell[349289, 12409, 81, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.21"}],

Cell[CellGroupData[{
Cell[349395, 12414, 70, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[349468, 12418, 688, 9, 234, "Print"]
}, Open  ]],
Cell[350171, 12430, 89, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.22"}],

Cell[CellGroupData[{
Cell[350285, 12435, 232, 7, 84, "Input",
  CellTags->"S0.3"],
Cell[350520, 12444, 19728, 760, 186, 8936, 622, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[370263, 13207, 245, 8, 50, "MathCaption",
  CellTags->{"S0.3", "3.23"}],
Cell[370511, 13217, 145, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[370659, 13224, 114, 2, 31, "MathCaption",
  CellTags->{"S0.3", "3.24"}],

Cell[CellGroupData[{
Cell[370798, 13230, 112, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[370913, 13234, 22072, 852, 186, 9953, 697, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[393000, 14089, 179, 4, 48, "MathCaption",
  CellTags->{"S0.3", "3.25"}],

Cell[CellGroupData[{
Cell[393204, 14097, 89, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[393296, 14101, 364, 6, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[393697, 14112, 140, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[393840, 14119, 361, 6, 48, "Output"]
}, Open  ]],
Cell[394216, 14128, 82, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.26"}],

Cell[CellGroupData[{
Cell[394323, 14133, 95, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[394421, 14137, 719, 13, 86, "Output"]
}, Open  ]],
Cell[395155, 14153, 113, 2, 31, "MathCaption",
  CellTags->{"S0.3", "3.27"}],

Cell[CellGroupData[{
Cell[395293, 14159, 112, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[395408, 14163, 13991, 485, 191, 4412, 362, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[409414, 14651, 113, 2, 31, "MathCaption",
  CellTags->{"S0.3", "3.28"}],

Cell[CellGroupData[{
Cell[409552, 14657, 108, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[409663, 14661, 142, 3, 29, "Output"]
}, Open  ]],
Cell[409820, 14667, 137, 4, 31, "MathCaption",
  CellTags->{"S0.3", "3.29"}],
Cell[409960, 14673, 149, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[410112, 14680, 114, 2, 31, "MathCaption",
  CellTags->{"S0.3", "3.30"}],

Cell[CellGroupData[{
Cell[410251, 14686, 112, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[410366, 14690, 15116, 549, 191, 5204, 422, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[425497, 15242, 66, 1, 56, "Subsection",
  CellTags->{"S0.4", "4.1"}],
Cell[425566, 15245, 162, 4, 33, "Text",
  CellTags->{"S0.4", "4.2"}],
Cell[425731, 15251, 87, 1, 31, "MathCaption",
  CellTags->{"S0.4", "4.3"}],
Cell[425821, 15254, 189, 6, 66, "Input",
  CellTags->"S0.4"],
Cell[426013, 15262, 273, 7, 67, "MathCaption",
  CellTags->{"S0.4", "4.4"}],
Cell[426289, 15271, 88, 2, 30, "Input"],
Cell[426380, 15275, 117, 2, 30, "Input",
  CellTags->"S0.4"],
Cell[426500, 15279, 136, 4, 31, "MathCaption",
  CellTags->{"S0.4", "4.5"}],
Cell[426639, 15285, 117, 2, 30, "Input",
  CellTags->"S0.4"],
Cell[426759, 15289, 112, 2, 31, "MathCaption",
  CellTags->{"S0.4", "4.6"}],
Cell[426874, 15293, 149, 5, 48, "Input",
  CellTags->"S0.4"],
Cell[427026, 15300, 112, 2, 31, "MathCaption",
  CellTags->{"S0.4", "4.7"}],
Cell[427141, 15304, 149, 5, 48, "Input",
  CellTags->"S0.4"],
Cell[427293, 15311, 141, 4, 31, "MathCaption",
  CellTags->{"S0.4", "4.8"}],

Cell[CellGroupData[{
Cell[427459, 15319, 120, 2, 30, "Input",
  CellTags->"S0.4"],
Cell[427582, 15323, 57648, 2631, 186, 35764, 2356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[485245, 17957, 87, 1, 31, "MathCaption",
  CellTags->{"S0.4", "4.9"}],

Cell[CellGroupData[{
Cell[485357, 17962, 104, 2, 30, "Input",
  CellTags->"S0.4"],
Cell[485464, 17966, 37972, 1514, 186, 22701, 1320, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[523451, 19483, 99, 1, 70, "MathCaption",
  CellTags->{"S0.4", "4.10"}],

Cell[CellGroupData[{
Cell[523575, 19488, 137, 5, 70, "Input",
  CellTags->"S0.4"],
Cell[523715, 19495, 75681, 3628, 70, 54603, 3363, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

