(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    117766,       4182]*)
(*NotebookOutlinePosition[    135691,       4729]*)
(*  CellTagsIndexPosition[    133768,       4650]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Interest Rates", "Section",
  CellTags->"0.1"],

Cell["Flat Rates", "Subsection",
  CellTags->{"S0.1", "1.1"}],

Cell["\<\
The notion that money has a time value is one of the basic concepts \
in the analysis of any financial instrument. From the borrower's point of \
view, interest is the price of money. To an investor, interest is the \
compensation, or enticement, for deferring consumption to a future period. \
The interest rate is the market clearing price of money. 
The simplest possible model of interest rates is the flat rate. Simple \
interest is the amount earned on the principal without allowing for interest \
on interest. If the interest earned is automatically reinvested we have \
compound interest. \
\>", "Text",
  CellTags->{"S0.1", "1.2"}],

Cell[TextData[{
  "This loads the ",
  StyleBox["InterestRates", "MB"],
  " subpackage. We don't need to do this if we previously loaded ",
  StyleBox["Finance`", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.3"}],

Cell["<< Finance`InterestRates`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["PresentValue",
                "MR"], 
              StyleBox["[",
                "MR"], 
              
              StyleBox[\(futurevalue, \ interestrate, \ frequency, \ 
                timeinterval\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[\(compute\ the\ present\ value\ of\ an\ investment\),
              "TraditionalForm"]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["FutureValue",
                "MR"], 
              StyleBox["[",
                "MR"], 
              
              StyleBox[\(presentvalue, \ interestrate, \ frequency, \ 
                timeinterval\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[\(compute\ the\ future\ value\ of\ an\ investment\),
              "TraditionalForm"]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["NominalRate",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(interestrate, \ frequency, \ newfrequency\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(compute\ the\ nominal\ rate\ corresponding\ to\ the\ new\ 
                frequency\ given\ the\ nominal\ interest\ rate\ and\ frequency
                \),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Basis interest rates functions. ", "Caption",
  CellTags->"S0.1"],

Cell[TextData[{
  "We can use the units ",
  StyleBox["USDollar", "MB"],
  ", ",
  StyleBox["Year", "MB"],
  ", ",
  StyleBox["Day", "MB"],
  ", etc. We have to specify how many days are in a year because the day \
count basis is not predefined. "
}], "Text",
  CellTags->{"S0.1", "1.5"}],

Cell["\<\
A bank accepts a $100,000 deposit to mature in 300 days and will \
pay 7.26% per annum (p.a.) on the deposit. Here is the calculation of the \
future value of the deposit. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.6"}],

Cell[CellGroupData[{

Cell["\<\
fv = FutureValue[100000 USDollar, 7.26 Percent/Year,
   1/Year, 300 Day] /. Day -> 1/365 Year\
\>", "Input",
  CellLabel->"In[2]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(105929.607671875336`\ USDollar\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
As expected, the present value of the above future value is \
$100,000. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.7"}],

Cell[CellGroupData[{

Cell["\<\
PresentValue[fv, 7.26 Percent/Year, 1/Year, 300 Day] /.
   Day -> 1/365 Year\
\>", "Input",
  CellLabel->"In[3]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(100000.`\ USDollar\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
Suppose now that the interest rate is computed on the \"30/360\" \
day count basis. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.8"}],

Cell["\<\
FutureValue[100000 USDollar, 7.26 Percent/Year, 1/Year,
   300 Day] /. Day -> 1/360 Year\
\>", "Input",
  CellLabel->"In[4]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(106014.392050861205`\ USDollar\)], "Output",
  CellLabel->"Out[4]="],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "TraditionalForm",
              FontSlant->"Italic"], 
            StyleBox[\(default\ value\),
              "TraditionalForm",
              FontSlant->"Italic"], 
            StyleBox[" ",
              "TraditionalForm"]},
          {
            StyleBox["Compounded",
              "TraditionalForm"], 
            StyleBox["True",
              "TraditionalForm"], 
            StyleBox[\(how\ the\ interest\ rate\ is\ computed\),
              "TraditionalForm"]}
          },
        RowSpacings->1.5,
        ColumnSpacings->2,
        ColumnWidths->{0.2, 0.2, 0.6},
        ColumnAlignments->{Left, Center, Left}], NotebookDefault]], 
  "DefinitionBox",
  CellFrame->0.5,
  CellHorizontalScrolling->True,
  GeneratedCell->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  Background->RGBColor[1, 0.8, 0.6],
  GridBoxOptions->{RowLines->{True, False}}],

Cell[TextData[{
  "Option for ",
  StyleBox["FutureValue", "MR"],
  " and ",
  StyleBox["PresentValue", "MR"],
  "."
}], "Caption",
  CellTags->"S0.1"],

Cell["\<\
In finance we often want to display results with a fixed accuracy. \
There are two pre-defined functions to display results with an accuracy of \
two or three decimal places. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.10"}],

Cell[CellGroupData[{

Cell["TwoPlaces[987654321.123456789] ", "Input",
  CellLabel->"In[5]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    TagBox[
      InterpretationBox[\("987654321.12"\),
        9.8765432112345679*^8,
        AutoDelete->True],
      (NumberForm[ #, 11, ExponentFunction -> (Null&)]&)]], "Output",
  CellLabel->"Out[5]//NumberForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell["ThreePlaces[987654321.123456789]", "Input",
  CellLabel->"In[6]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    TagBox[
      InterpretationBox[\("987654321.123"\),
        9.8765432112345679*^8,
        AutoDelete->True],
      (NumberForm[ #, 12, ExponentFunction -> (Null&)]&)]], "Output",
  CellLabel->"Out[6]//NumberForm="]
}, Open  ]],

Cell["\<\
A bank accepts a $500,000 deposit to mature in three years and will \
pay 14.79% p.a. on the deposit. This is the future value of this deposit. \
\
\>", "MathCaption",
  CellTags->{"S0.1", "1.11"}],

Cell[CellGroupData[{

Cell["\<\
compound = FutureValue[500000 USDollar, 14.79 Percent /
   Year, 1 / Year, 3 Year] \
\>", "Input",
  CellLabel->"In[7]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(756279.227619499749`\ USDollar\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "Interest rates are compounded by default. For simple interest rates we \
have to set the option ",
  StyleBox["Compounded", "MB"],
  " to ",
  StyleBox["False", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.12"}],

Cell[CellGroupData[{

Cell["\<\
simple = FutureValue[500000 USDollar, 14.79 Percent /
   Year, 1 / Year, 3 Year, Compounded -> False]\
\>", "Input",
  CellLabel->"In[8]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(721849.999999999969`\ USDollar\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["This is the interest\[Hyphen]on\[Hyphen]interest in this case. ", 
  "MathCaption",
  CellTags->{"S0.1", "1.13"}],

Cell[CellGroupData[{

Cell["compound - simple // TwoPlaces", "Input",
  CellLabel->"In[9]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    RowBox[{"USDollar", " ", 
      TagBox[
        InterpretationBox[\("34429.23"\),
          34429.227619499783,
          AutoDelete->True],
        (NumberForm[ #, 7, ExponentFunction -> (Null&)]&)]}]], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  "Compound interest rates are quoted in terms of nominal percentage p.a. \
yields. The effective per annum interest rate depends on the frequency with \
which the interest is assumed to compound during each year. If the nominal \
rate is ",
  Cell[BoxData[
      \(TraditionalForm\`r\)], "InlineFormula",
    CellTags->"S0.1"],
  " and the interest rate is paid ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S0.1"],
  " times per year, the interest rate per period is ",
  Cell[BoxData[
      \(TraditionalForm\`i = r\/m\)], "InlineFormula",
    CellTags->"S0.1"],
  " and the effective interest rate p.a. is ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 + r\/m)\)\^m\)], "InlineFormula",
    CellTags->"S0.1"],
  ". "
}], "Text",
  CellTags->{"S0.1", "1.14"}],

Cell["\<\
Here is a quarterly paid nominal interest rate equivalent to the \
nominal rate of 10% p.a. paid semiannually. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.15"}],

Cell[CellGroupData[{

Cell["NominalRate[10 Percent/Year, 2/Year, 4/Year]", "Input",
  CellLabel->"In[10]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(\(4\ \((\(-1\) + \@\(21\/5\)\/2)\)\)\/Year\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["This is a numerical approximation. ", "MathCaption",
  CellTags->{"S0.1", "1.16"}],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[11]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(0.0987803063838397221`\/Year\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
The nominal rate for a unit of frequency is the effective rate for \
that frequency. Here is the calculation of the effective annual rate for a \
10% nominal rate paid semiannually. \
\>", "MathCaption",
  CellTags->{"S0.1", "1.17"}],

Cell[CellGroupData[{

Cell["NominalRate[10 Percent/Year, 2/Year, 1/Year] // N", "Input",
  CellLabel->"In[12]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(0.102499999999999991`\/Year\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["Term Structure of Interest Rates", "Subsection",
  CellTags->{"S0.2", "2.1"}],

Cell["\<\
The relation between promised security yields and security \
maturities is referred to as the term structure of interest rates. This is a \
more sophisticated approach to security valuation than the flat interest \
rates model. We can represent interest rates in a number of equivalent ways. \
\
\>", "Text",
  CellTags->{"S0.2", "2.2"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SpotRates",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["{",
                  "MR"], 
                RowBox[{
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(timeinterval1, \ rate1\),
                      FontSlant->"Italic"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(timeinterval2, \ rate2\),
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      "MR"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["...",
                    "TraditionalForm"]}], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["}",
                  "MR"]}], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(an\ interest\ rates\ object\ represented\ by\ spot\ rates\),
              "TraditionalForm"]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ForwardRates",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["{",
                  "MR"], 
                RowBox[{
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(timeinterval1, \ rate1\),
                      FontSlant->"Italic"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(timeinterval2, \ rate2\),
                      FontSlant->"Italic"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["...",
                    "TraditionalForm"]}], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["}",
                  "MR"]}], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(an\ interest\ rates\ object\ represented\ by\ forward\ rates
                \),
              "TraditionalForm"]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DiscountFactors",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["{",
                  "MR"], 
                RowBox[{
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(timeinterval1, \ rate1\),
                      FontSlant->"Italic"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(timeinterval2, \ rate2\),
                      FontSlant->"Italic"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["...",
                    "TraditionalForm"]}], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["}",
                  "MR"]}], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(an\ interest\ rates\ object\ represented\ by\ discount\ 
                factors\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Interest rates objects. ", "Caption",
  CellTags->"S0.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "TraditionalForm",
              FontSlant->"Italic"], 
            StyleBox[\(default\ value\),
              "TraditionalForm",
              FontSlant->"Italic"], 
            StyleBox[" ",
              "TraditionalForm"]},
          {
            StyleBox["InitialDate",
              "TraditionalForm"], 
            StyleBox["Automatic",
              "TraditionalForm"], 
            StyleBox[\(an\ option\ for\ interest\ rates\ objects\),
              "TraditionalForm"]}
          },
        RowSpacings->1.5,
        ColumnSpacings->2,
        ColumnWidths->{0.2, 0.2, 0.6},
        ColumnAlignments->{Left, Center, Left}], NotebookDefault]], 
  "DefinitionBox",
  CellFrame->0.5,
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  Background->RGBColor[1, 0.8, 0.6],
  GridBoxOptions->{RowLines->{True, False}}],

Cell[TextData[{
  "Option for ",
  StyleBox["SpotRates", "MR"],
  ", ",
  StyleBox["ForwardRates", "MR"],
  ", and ",
  StyleBox["DiscountFactors", "MR"],
  " objects. "
}], "Caption",
  CellTags->"S0.2"],

Cell["\<\
The Finance Pack supports spot rates, forward rates, and discount \
factors. Any of these can be used to define an interest rates object. Once an \
interest rates object is defined, in some sense it becomes independent of its \
original representation. This means that once we define the interest rates \
object we can get any other representation immediately. We will discuss this \
further in Section 3.6. We can manipulate an object to extract its class, \
description, or options. \
\>", "Text",
  CellTags->{"S0.2", "2.5"}],

Cell["Spot Rates", "Subsection",
  CellTags->{"S0.3", "3.1"}],

Cell["\<\
A spot rate is the interest rate on a pure discount bond with a \
specified maturity. In other words, it is the interest rate on a single cash \
flow received at a future time. Spot rates are represented by a list of \
ordered pairs. The first element of each pair is the time from a given \
initial date. The second element is the rate for the corresponding period. \
The pairs must be ordered so that the time intervals increase. \
\>", "Text",
  CellTags->{"S0.3", "3.2"}],

Cell[TextData[{
  "Here is an example of a spot rates object. Usually we do not need to \
specify the initial date, but we can do so with the option ",
  StyleBox["InitialDate", "MB"],
  ", which has the default value ",
  StyleBox["Automatic", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.3", "3.3"}],

Cell["\<\
spot0 = SpotRates[{{1, 0.0814},
                   {2, 0.0904},
                   {3, 0.0951},
                   {5, 0.1002},
                   {7, 0.1050},
                   {10, 0.1066},
                   {30, 0.1078}},
                   InitialDate->{7, 30, 1985}];\
\>", "Input",
  CellLabel->"In[13]:=",
  CellTags->"S0.3"],

Cell[TextData[{
  "We can use ",
  StyleBox["ListPlot", "MB"],
  " to plot the yield curve. "
}], "MathCaption",
  CellTags->{"S0.3", "3.4"}],

Cell[CellGroupData[{

Cell["ListPlot[First[%], PlotJoined->True];", "Input",
  CellLabel->"In[14]:=",
  CellTags->"S0.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0090312 0.0328407 -1.80015 22.2956 [
[.15517 -0.0125 -3 -9 ]
[.15517 -0.0125 3 0 ]
[.31938 -0.0125 -6 -9 ]
[.31938 -0.0125 6 0 ]
[.48358 -0.0125 -6 -9 ]
[.48358 -0.0125 6 0 ]
[.64778 -0.0125 -6 -9 ]
[.64778 -0.0125 6 0 ]
[.81199 -0.0125 -6 -9 ]
[.81199 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09498 -30 -4.5 ]
[-0.0125 .09498 0 4.5 ]
[-0.0125 .20646 -24 -4.5 ]
[-0.0125 .20646 0 4.5 ]
[-0.0125 .31794 -30 -4.5 ]
[-0.0125 .31794 0 4.5 ]
[-0.0125 .42941 -18 -4.5 ]
[-0.0125 .42941 0 4.5 ]
[-0.0125 .54089 -30 -4.5 ]
[-0.0125 .54089 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15517 0 m
.15517 .00625 L
s
[(5)] .15517 -0.0125 0 1 Mshowa
.31938 0 m
.31938 .00625 L
s
[(10)] .31938 -0.0125 0 1 Mshowa
.48358 0 m
.48358 .00625 L
s
[(15)] .48358 -0.0125 0 1 Mshowa
.64778 0 m
.64778 .00625 L
s
[(20)] .64778 -0.0125 0 1 Mshowa
.81199 0 m
.81199 .00625 L
s
[(25)] .81199 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.18801 0 m
.18801 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.35222 0 m
.35222 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.51642 0 m
.51642 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.68062 0 m
.68062 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.84483 0 m
.84483 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.05665 0 m
.05665 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09498 m
.00625 .09498 L
s
[(0.085)] -0.0125 .09498 1 0 Mshowa
0 .20646 m
.00625 .20646 L
s
[(0.09)] -0.0125 .20646 1 0 Mshowa
0 .31794 m
.00625 .31794 L
s
[(0.095)] -0.0125 .31794 1 0 Mshowa
0 .42941 m
.00625 .42941 L
s
[(0.1)] -0.0125 .42941 1 0 Mshowa
0 .54089 m
.00625 .54089 L
s
[(0.105)] -0.0125 .54089 1 0 Mshowa
.125 Mabswid
0 .11727 m
.00375 .11727 L
s
0 .13957 m
.00375 .13957 L
s
0 .16187 m
.00375 .16187 L
s
0 .18416 m
.00375 .18416 L
s
0 .22875 m
.00375 .22875 L
s
0 .25105 m
.00375 .25105 L
s
0 .27334 m
.00375 .27334 L
s
0 .29564 m
.00375 .29564 L
s
0 .34023 m
.00375 .34023 L
s
0 .36253 m
.00375 .36253 L
s
0 .38482 m
.00375 .38482 L
s
0 .40712 m
.00375 .40712 L
s
0 .45171 m
.00375 .45171 L
s
0 .474 m
.00375 .474 L
s
0 .4963 m
.00375 .4963 L
s
0 .5186 m
.00375 .5186 L
s
0 .07268 m
.00375 .07268 L
s
0 .05039 m
.00375 .05039 L
s
0 .02809 m
.00375 .02809 L
s
0 .0058 m
.00375 .0058 L
s
0 .56319 m
.00375 .56319 L
s
0 .58548 m
.00375 .58548 L
s
0 .60778 m
.00375 .60778 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.15517 .61178 m
.15517 .61803 L
s
.31938 .61178 m
.31938 .61803 L
s
.48358 .61178 m
.48358 .61803 L
s
.64778 .61178 m
.64778 .61803 L
s
.81199 .61178 m
.81199 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.18801 .61428 m
.18801 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.35222 .61428 m
.35222 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.51642 .61428 m
.51642 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.68062 .61428 m
.68062 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.84483 .61428 m
.84483 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.05665 .61428 m
.05665 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09498 m
1 .09498 L
s
.99375 .20646 m
1 .20646 L
s
.99375 .31794 m
1 .31794 L
s
.99375 .42941 m
1 .42941 L
s
.99375 .54089 m
1 .54089 L
s
.125 Mabswid
.99625 .11727 m
1 .11727 L
s
.99625 .13957 m
1 .13957 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .18416 m
1 .18416 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .25105 m
1 .25105 L
s
.99625 .27334 m
1 .27334 L
s
.99625 .29564 m
1 .29564 L
s
.99625 .34023 m
1 .34023 L
s
.99625 .36253 m
1 .36253 L
s
.99625 .38482 m
1 .38482 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .45171 m
1 .45171 L
s
.99625 .474 m
1 .474 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .5186 m
1 .5186 L
s
.99625 .07268 m
1 .07268 L
s
.99625 .05039 m
1 .05039 L
s
.99625 .02809 m
1 .02809 L
s
.99625 .0058 m
1 .0058 L
s
.99625 .56319 m
1 .56319 L
s
.99625 .58548 m
1 .58548 L
s
.99625 .60778 m
1 .60778 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.05665 .21538 L
.08949 .32016 L
.15517 .43387 L
.22085 .54089 L
.31938 .57656 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`00024Q8M70[V68
R59cLkK8b2m2@_ooom70[[6SU>_Tg79ZH0000;N9RI]dM=o:bUe5AOoooo3/jlc8b<2l_92=S@0007=c
Ljf][MkNg[fm_F=SHiBDU?l0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<Slo?k:b//30`820P000P6@0080004:JYkZPY`0g?0200020P1YOIbmnR800P8200000kUDJRoooc=>e
]@00_nCTi6YZJ]gMgEiNGYNGUngPh79RHVVe]KgOgcINGZ>SX`00<`00IP00V@00c00c000c<`0cIP0c
V@0cc00co`1V001V<`1VIP1VV@1Vc01Vo`2I002I<`2IIP2IV@2Ic02Io`3<003<<`3<IP3<V@3<c03<
o`3o<`3oIP3oV@3oc4000400<d00IT00VD00c400od0c040c<d0cIT0cVD0cc40cod1V041V<d1VIT1V
VD1Vc41Vod2I042I<d2IIT2IVD2Ic42Iod3<043<<d3<IT3<VD3<c43<od3o043o<d3oIT3oVD3oc43o
oh00<h00IX00VH00c800oh0c080c<h0cIX0cVH0cc80coh1V081V<h1VIX1VVH1Vc81Voh2I082I<h2I
IX2IVH2Ic82Ioh3<083<<h3<IX3<VH3<c83<oh3o083o<h3oIX3oVH3oc83ookl00;l0<kl0I[l0VKl0
c;l0oklc0;lc<klcI[lcVKlcc;lcokmV0;mV<kmVI[mVVKmVc;mVoknI0;nI<knII[nIVKnIc;nIoko<
0;o<<ko<I[o<VKo<c;o<okoo0;oo<kooI[ooVKooc;ooool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlc
c?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo
<oooI_ooVNcTgG=ZH;:SU:0Pl=WIfNo_kkno_lc<c9VIVOl08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@0004H00`4T00@10`020B00104200<18@040@<00P4Q00@10P030B400P440081
100004T000<100008`001@400001008000<100007`000`40000400030@0001h000<100000`001040
004P00030@0000H000<100007@001040004200040@000@<0001900030@0002<000D100000@020003
0@0001l000<1000010000`40000O00030@00008000@100018@000`40000500030@00020000@10001
0P000`4000010000AP030BH000D100000@0200030@0001l000@100000`4S00050@0000400P000`40
000P00040@0000<18@020@<000@100010`0004H000<100009P001@400001008000<100007`001@40
000102H000@100010P000`40000Q00040@000BD000@100010P000`4000010000AP000`40000T00<1
0`001040004O00<10`000`40000Q00040@000@8000@1000180001040004200030@00020000@10001
0P00104000430000AP040BD000<100000P020B8000@10000104Q008110020B800P4300@180020@@0
0P440000o`0Q0000o`0Q00008@3n0@40000Q008110000`40000500030@0000D000<100001P000`40
000500030@0000D000<100001P000`40000500030@0000D000<100001P000`40000500030@0000D0
00<100001P000`40000500030@0000D000<100001P000`40000500030@0000D000<100001P000`40
000500030@0000D000<100001P000`40000500030@0000D000<100001P000`40000500030@0000D0
00<100001P000`40000500030@0000D000<100000P020@40000Q00030@000?X00@4100008@000`40
000300030@000?@00@4100008@000`40000300030@000?@00@4100008@000`40000300030@000?@0
0@4100008@000`40000300030@000?@00@4100008@020@D000<10000lP020@40000Q00030@0000@0
00<10000l`010@40000Q00030@0000@000<10000l`010@40000Q00030@0000@000<10000l`010@40
000Q00030@0000@000<10000l`010@40000Q00030@0000@000<10000l`010@40000Q00811P000`40
003a00810@00024000<100001@000`40003b00410@00024000<100001@000`40003b00410@000240
00<100001@000`40003b00410@00024000<100001@000`40003b00410@0002400P4600030@000?40
0P4100008@000`40000600030@000?400@4100008@000`40000600030@000?400@4100008@000`40
000600030@000?400@4100008@000`40000600030@000?400@4100000P020@@000<100000`020@@0
0P4300<11@000`40000600030@000?400@41000000D00@000@0800040@000@8000@100011@000`40
000200811`000`40003`00810@0000050040004020001040004200040@000@D000<100000P000`40
000600030@000?400@41000000D00@000@0800040@000@<00P4300<11@000`40000700030@000?00
0@41000000D00@000@0800040@000@8000@100010P000`40000500030@0000L000<10000l0010@40
00001@01000100P000@100010P001040004200030@0000D000<100001`000`40003`00410@000080
0P4:008110020@<01044008120000`40003_00810@00024000<100001`000`40003`00410@000240
00<100001`000`40003`00410@00024000<1000020000`40003_00410@00024000<1000020000`40
003_00410@00024000<1000020000`40003_00410@0002400P4900030@000>h00P4100008@000`40
000800030@000>l00@4100008@000`40000800030@000>l00@4100008@000`40000800030@000>l0
0@4100008@000`40000900030@000>h00@4100008@000`40000900030@000>h00@4100008@020@X0
00<10000k@020@40000Q00030@0000T000<10000kP010@40000Q00030@0000T000<10000kP010@40
000Q00030@0000T000<10000kP010@40000Q00030@0000X000<10000k@010@40000Q00812`000`40
003/00810@00024000<100002P000`40003]00410@00024000<100002P000`40003]00410@000240
00<100002P000`40003]00410@00024000<100002P000`40003]00410@0000P00P4400030@0000<0
0P4300<11@000`40000;00030@000>`00@4100001`001040004800040@000@D000<100000P020@`0
00<10000j`020@40000700040@000@P000@100011@000`40000200030@0000/000<10000k0010@40
000700040@000@P000@100010`030@@000<100002`000`40003/00410@0000L000@1000120001040
004200040@000@@000<100002`000`40003/00410@0000L000@1000120001040004200040@000@@0
00<1000030000`40003[00410@0000P00P4:008110020@D000<1000030000`40003[00410@000240
0P4=00030@000>X00P4100008@000`40000<00030@000>/00@4100008@000`40000=00030@000>X0
0@4100008@000`40000=00030@000>X00@4100008@000`40000=00030@000>X00@4100008@020@l0
00<10000j0020@40000Q00030@0000h000<10000j@010@40000Q00030@0000h000<10000j@010@40
000Q00030@0000l000<10000j0010@40000Q00030@0000l000<10000j0010@40000Q00030@0000l0
00<10000j0010@40000Q008140000`40003W00810@00024000<1000040000`40003W00410@000240
00<1000040000`40003W00410@00024000<1000040000`40003W00410@00024000<100004@000`40
003V00410@00024000<100004@000`40003V00410@0002400P4B00030@000>D00P4100008@000`40
000B00030@000>D00@4100008@000`40000B00030@000>D00@4100008@000`40000B00030@000>D0
0@4100000P020@@000<100000`020@<00`4300<11@000`40000B00030@000>D00@41000000D00@00
0@0800040@000@D000<100000`000`400002008150000`40003S00810@0000050040004020001040
004500030@0000<000<100000P000`40000C00030@000>@00@41000000D00@000@0800040@000@<0
0`4200<11@000`40000D00030@000><00@41000000D00@000@0800040@000@8000@100010P000`40
000500030@0001@000<10000h`010@4000001@01000100P000@100010P001040004200030@0000D0
00<100005@000`40003R00410@0000800P4:008110020@<0104400030@0001D000<10000hP010@40
000Q00815`000`40003P00810@00024000<100005`000`40003P00410@00024000<100005`000`40
003P00410@00024000<1000060000`40003O00410@00024000<1000060000`40003O00410@000240
00<100006@000`40003N00410@0002400P4J00030@000=d00P4100008@000`40000J00030@000=d0
0@4100008@000`40000K00030@000=`00@4100008@000`40000K00030@000=`00@4100008@000`40
000L00030@000=/00@4100008@020Ad000<10000fP020@40000Q00030@0001d000<10000fP010@40
000Q00030@0001h000<10000f@010@40000Q00030@0001h000<10000f@010@40000Q00030@0001l0
00<10000f0010@40000Q00030@0001l000<10000f0010@40000Q00818@000`40003F00810@000240
00<1000080000`40003G00410@00024000<100008@000`40003F00410@00024000<100008P000`40
003E00410@0000h00P4400030@000080104400030@00028000<10000e@010@40000=00040@000@X0
00<100000`000`40000S00030@000=@00@4100003@001040004:00030@0000<00P4T00030@000=<0
0P4100003@001040004:00030@0000<000<1000090000`40003C00410@0000d000@100012P000`40
000300030@0002D000<10000dP010@40000=00040@000@P00`4500030@0002D000<10000dP010@40
000>00812`000`40000300030@0002H000<10000d@010@40000Q0081:0000`40003?00810@000240
00<100009`000`40003@00410@00024000<10000:0000`40003?00410@00024000<10000:0000`40
003?00410@00024000<10000:@000`40003>00410@00024000<10000:P000`40003=00410@000240
0P4[00030@000<`00P4100008@000`40000[00030@000<`00@4100008@000`40000/00030@000</0
0@4100008@000`40000/00030@000</00@4100008@000`40000]00030@000<X00@4100008@000`40
000]00030@000<X00@4100008@020Bl000<10000b0020@40000Q00030@0002l000<10000b0010@40
000Q00030@0002l000<10000b0010@40000Q00030@00030000<10000a`010@40000Q00030@000340
00<10000aP010@40000Q0081<P000`40003500810@00024000<10000<P000`40003500410@000240
00<10000<P000`40003500410@00024000<10000<`000`40003400410@00024000<10000=0000`40
003300410@0000800P4400030@000080104300810`030@D000<10000=0000`40003300410@000005
004000402P001@400001008000<100000`000`4000020081=P020L800P41000000D00@000@0:0005
0@0000400P000`40000300030@00008000<10000=`030L000@41000000D00@000@0:00050@000040
0P000`4000030@D000<10000>P020Kh00@41000000D00@000@0:00050@0000400P00104000470003
0@0003`00`6k00410@0000050040004020030@<000@100010P000`40000500030@0003l00`6h0041
0@0000800P4;00030@0000800P4300@110000`40001200<1]@010@40000Q0081AP030K400P410000
8@000`4000180081/0010@40000Q00030@0004X00`6]00410@00024000<10000C@0=0J000@410000
8@000`40001J01P1R0010@40000Q0081L`0H0Fl00P4100008@000`40002:01P1F0010@40000Q0003
0@000:805`5100410@00024000<10000^@0H0BT00@4100008@000`40003A01P14@010@40000Q0003
0@000>T0304500410@0002400P7j00810@00024000<1000090000`40000W00030@0002H000<10000
9`000`40000W00030@0002H000<100000`010@40000Q00030@0000<000<100001@000`4000050003
0@0000H000<100001@000`40000500030@0000H000<100001@000`40000500030@0000H000<10000
1@000`40000500030@0000H000<100001@000`40000500030@0000H000<100001@000`4000050003
0@0000H000<100001@000`40000500030@0000H000<100001@000`40000500030@0000H000<10000
1@000`40000500030@0000H000<100001@000`40000500030@0000<00@4100008@3n0@40003o0240
003o0240003o02400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.70647, 0.0778838, 
  0.120023, 0.00017679}}]
}, Open  ]],

Cell[TextData[{
  "Suppose the spot rates in the above example are not given in the right \
order. We can get the correct order in a straightforward way with ",
  StyleBox["Sort", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.3", "3.5"}],

Cell[CellGroupData[{

Cell["\<\
Sort[{{30, 0.1078},
      {2, 0.0904},
      {5, 0.1002},
      {3, 0.0951},
      {1, 0.0814},
      {7, 0.1050},
      {10, 0.1066}}]\
\>", "Input",
  CellLabel->"In[15]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"1", ",", 
            StyleBox["0.0814000000000000056`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", 
            StyleBox["0.0903999999999999914`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", 
            StyleBox["0.0951000000000000156`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5", ",", 
            StyleBox["0.1002`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7", ",", 
            StyleBox["0.105000000000000004`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"10", ",", 
            StyleBox["0.106600000000000005`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"30", ",", 
            StyleBox["0.107800000000000006`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "We can use ",
  StyleBox["Sort", "MB"],
  " inside the definition of a spot rates object. "
}], "MathCaption",
  CellTags->{"S0.3", "3.6"}],

Cell[CellGroupData[{

Cell["\<\
spot1 = SpotRates[Sort[
                {{30, 0.1078},
                 {2, 0.0904},
                 {5, 0.1002},
                 {3, 0.0951},
                 {1, 0.0814},
                 {7, 0.1050},
                 {10, 0.1066}}],
                 InitialDate->{7, 30, 1985}]\
\>", "Input",
  CellLabel->"In[16]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    RowBox[{"SpotRates", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", 
                StyleBox["0.0814000000000000056`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"2", ",", 
                StyleBox["0.0903999999999999914`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                StyleBox["0.0951000000000000156`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"5", ",", 
                StyleBox["0.1002`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"7", ",", 
                StyleBox["0.105000000000000004`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"10", ",", 
                StyleBox["0.106600000000000005`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"30", ",", 
                StyleBox["0.107800000000000006`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}]}], "}"}], ",", 
        \(InitialDate \[Rule] {7, 30, 1985}\)}], "]"}]], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
Note that we can use units. In this example, the time intervals are \
expressed in years, but we can also use days, months, bimonths, quarters, or \
periods. \
\>", "MathCaption",
  CellTags->{"S0.3", "3.7"}],

Cell["\<\
spot2 = SpotRates[
                {{1 Year, 16.97 Percent / Year},
                 {2 Year, 16.73 Percent / Year},
                 {3 Year, 16.33 Percent / Year},
                 {5 Year, 16.11 Percent / Year},
                 {7 Year, 15.71 Percent / Year},
                 {10 Year, 15.41 Percent / Year},
                 {30 Year, 14.78 Percent / Year}},
                 InitialDate->{8, 31, 1981}];\
\>", "Input",
  CellLabel->"In[17]:=",
  CellTags->"S0.3"],

Cell["Here is another example of a spot rates object. ", "MathCaption",
  CellTags->{"S0.3", "3.8"}],

Cell["\<\
spot3 = SpotRates[{{1, 0.0691},
                   {2, 0.0764},
                   {3, 0.0789},
                   {5, 0.0816},
                   {7, 0.0844},
                   {10, 0.0861},
                   {30, 0.0885}},
                   InitialDate->{7, 29, 1987}];\
\>", "Input",
  CellLabel->"In[18]:=",
  CellTags->"S0.3"],

Cell[TextData[{
  StyleBox["Mathematica", "TI"],
  " allows you to use symbols as well as numbers. "
}], "MathCaption",
  CellTags->{"S0.3", "3.9"}],

Cell[CellGroupData[{

Cell["spot4 = SpotRates[{s1, s2, s3, s4}]", "Input",
  CellLabel->"In[19]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \(SpotRates[{s1, s2, s3, s4}]\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["Head", "MB"],
  " can be used to check the type of an object. "
}], "MathCaption",
  CellTags->{"S0.3", "3.10"}],

Cell[CellGroupData[{

Cell["Head[spot1]", "Input",
  CellLabel->"In[20]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \(SpotRates\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["This extracts the description. ", "MathCaption",
  CellTags->{"S0.3", "3.11"}],

Cell[CellGroupData[{

Cell["First[spot4]", "Input",
  CellLabel->"In[21]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \({s1, s2, s3, s4}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["This shows how the options are set. ", "MathCaption",
  CellTags->{"S0.3", "3.12"}],

Cell[CellGroupData[{

Cell["Options[spot3]", "Input",
  CellLabel->"In[22]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    \({InitialDate \[Rule] {7, 29, 1987}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "We load the file ",
  StyleBox["spots.m", "TI"],
  ". It contains spot rates named ",
  StyleBox["spot[i]", "MB"],
  ", where ",
  StyleBox["i", "MB"],
  " = 1, 2, ... , 8. "
}], "MathCaption",
  CellTags->{"S0.3", "3.13"}],

Cell["Get[\"Finance`Data`spots`\"]", "Input",
  CellLabel->"In[23]:=",
  CellTags->"S0.3"],

Cell["Here is the first of these objects. ", "MathCaption",
  CellTags->{"S0.3", "3.14"}],

Cell[CellGroupData[{

Cell["spot[1]", "Input",
  CellLabel->"In[24]:=",
  CellTags->"S0.3"],

Cell[BoxData[
    RowBox[{"SpotRates", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", 
                StyleBox["0.158000000000000007`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->3]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"2", ",", 
                StyleBox["0.146300000000000007`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                StyleBox["0.136899999999999999`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"5", ",", 
                StyleBox["0.133099999999999996`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"7", ",", 
                StyleBox["0.12759999999999998`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"10", ",", 
                StyleBox["0.126400000000000023`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"30", ",", 
                StyleBox["0.123100000000000009`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}]}], "}"}], ",", 
        \(InitialDate \[Rule] {3, 31, 1980}\)}], "]"}]], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
The yield curve is the graphical representation of a spot rates \
object. This function will create a yield curve without displaying it. \
\>", 
  "MathCaption",
  CellTags->{"S0.3", "3.15"}],

Cell["\<\
yieldcurve[i_] := ListPlot[Evaluate[First[spot[i]]],
   PlotJoined -> True, DisplayFunction -> Identity];\
\>", "Input",
  CellLabel->"In[25]:=",
  CellTags->"S0.3"],

Cell["\<\
Here we display all eight yield curves. This graph proves that in \
this case the flat interest rates model is not a good approximation to the \
true term structure. \
\>", "MathCaption",
  CellTags->{"S0.3", "3.16"}],

Cell[CellGroupData[{

Cell["\<\
Show[Table[yieldcurve[i], {i, 8}],
   DisplayFunction -> $DisplayFunction,
   FrameLabel -> {\"Maturity\", \"Spot Rates\"}];\
\>", "Input",
  CellLabel->"In[26]:=",
  CellTags->"S0.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0090312 0.0328407 -0.303088 5.34123 [
[.15517 -0.0125 -3 -9 ]
[.15517 -0.0125 3 0 ]
[.31938 -0.0125 -6 -9 ]
[.31938 -0.0125 6 0 ]
[.48358 -0.0125 -6 -9 ]
[.48358 -0.0125 6 0 ]
[.64778 -0.0125 -6 -9 ]
[.64778 -0.0125 6 0 ]
[.81199 -0.0125 -6 -9 ]
[.81199 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -24 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .01739 -24 -4.5 ]
[-0.0125 .01739 0 4.5 ]
[-0.0125 .12421 -24 -4.5 ]
[-0.0125 .12421 0 4.5 ]
[-0.0125 .23104 -18 -4.5 ]
[-0.0125 .23104 0 4.5 ]
[-0.0125 .33786 -24 -4.5 ]
[-0.0125 .33786 0 4.5 ]
[-0.0125 .44468 -24 -4.5 ]
[-0.0125 .44468 0 4.5 ]
[-0.0125 .55151 -24 -4.5 ]
[-0.0125 .55151 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -39 -32 ]
[-0.01875 .30902 -24 32 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15517 0 m
.15517 .00625 L
s
[(5)] .15517 -0.0125 0 1 Mshowa
.31938 0 m
.31938 .00625 L
s
[(10)] .31938 -0.0125 0 1 Mshowa
.48358 0 m
.48358 .00625 L
s
[(15)] .48358 -0.0125 0 1 Mshowa
.64778 0 m
.64778 .00625 L
s
[(20)] .64778 -0.0125 0 1 Mshowa
.81199 0 m
.81199 .00625 L
s
[(25)] .81199 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.18801 0 m
.18801 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.35222 0 m
.35222 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.51642 0 m
.51642 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.68062 0 m
.68062 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.84483 0 m
.84483 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.05665 0 m
.05665 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Maturity) show
111.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01739 m
.00625 .01739 L
s
[(0.06)] -0.0125 .01739 1 0 Mshowa
0 .12421 m
.00625 .12421 L
s
[(0.08)] -0.0125 .12421 1 0 Mshowa
0 .23104 m
.00625 .23104 L
s
[(0.1)] -0.0125 .23104 1 0 Mshowa
0 .33786 m
.00625 .33786 L
s
[(0.12)] -0.0125 .33786 1 0 Mshowa
0 .44468 m
.00625 .44468 L
s
[(0.14)] -0.0125 .44468 1 0 Mshowa
0 .55151 m
.00625 .55151 L
s
[(0.16)] -0.0125 .55151 1 0 Mshowa
.125 Mabswid
0 .04409 m
.00375 .04409 L
s
0 .0708 m
.00375 .0708 L
s
0 .0975 m
.00375 .0975 L
s
0 .15092 m
.00375 .15092 L
s
0 .17762 m
.00375 .17762 L
s
0 .20433 m
.00375 .20433 L
s
0 .25774 m
.00375 .25774 L
s
0 .28445 m
.00375 .28445 L
s
0 .31115 m
.00375 .31115 L
s
0 .36457 m
.00375 .36457 L
s
0 .39127 m
.00375 .39127 L
s
0 .41798 m
.00375 .41798 L
s
0 .47139 m
.00375 .47139 L
s
0 .4981 m
.00375 .4981 L
s
0 .5248 m
.00375 .5248 L
s
0 .57822 m
.00375 .57822 L
s
0 .60492 m
.00375 .60492 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -124.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 11.5 translate
90 rotate
-93 -11.5 translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Spot) show
93.000000 15.000000 moveto
(Rates) show
123.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.15517 .61178 m
.15517 .61803 L
s
.31938 .61178 m
.31938 .61803 L
s
.48358 .61178 m
.48358 .61803 L
s
.64778 .61178 m
.64778 .61803 L
s
.81199 .61178 m
.81199 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.18801 .61428 m
.18801 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.35222 .61428 m
.35222 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.51642 .61428 m
.51642 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.68062 .61428 m
.68062 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.84483 .61428 m
.84483 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.05665 .61428 m
.05665 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01739 m
1 .01739 L
s
.99375 .12421 m
1 .12421 L
s
.99375 .23104 m
1 .23104 L
s
.99375 .33786 m
1 .33786 L
s
.99375 .44468 m
1 .44468 L
s
.99375 .55151 m
1 .55151 L
s
.125 Mabswid
.99625 .04409 m
1 .04409 L
s
.99625 .0708 m
1 .0708 L
s
.99625 .0975 m
1 .0975 L
s
.99625 .15092 m
1 .15092 L
s
.99625 .17762 m
1 .17762 L
s
.99625 .20433 m
1 .20433 L
s
.99625 .25774 m
1 .25774 L
s
.99625 .28445 m
1 .28445 L
s
.99625 .31115 m
1 .31115 L
s
.99625 .36457 m
1 .36457 L
s
.99625 .39127 m
1 .39127 L
s
.99625 .41798 m
1 .41798 L
s
.99625 .47139 m
1 .47139 L
s
.99625 .4981 m
1 .4981 L
s
.99625 .5248 m
1 .5248 L
s
.99625 .57822 m
1 .57822 L
s
.99625 .60492 m
1 .60492 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .54083 m
.05665 .47833 L
.08949 .42813 L
.15517 .40783 L
.22085 .37845 L
.31938 .37204 L
.97619 .35442 L
s
.02381 .16854 m
.05665 .19098 L
.08949 .19258 L
.15517 .22409 L
.22085 .23584 L
.31938 .24439 L
.97619 .2508 L
s
.02381 .60332 m
.05665 .5905 L
.08949 .56914 L
.15517 .55738 L
.22085 .53602 L
.31938 .52 L
.97619 .48635 L
s
.02381 .46071 m
.05665 .47246 L
.08949 .47246 L
.15517 .46552 L
.22085 .46445 L
.31938 .4543 L
.97619 .42759 L
s
.02381 .46284 m
.05665 .47994 L
.08949 .48635 L
.15517 .4794 L
.22085 .47994 L
.31938 .46819 L
.97619 .43988 L
s
.02381 .13169 m
.05665 .17976 L
.08949 .20486 L
.15517 .2321 L
.22085 .25774 L
.31938 .26629 L
.97619 .2727 L
s
.02381 .01472 m
.05665 .03608 L
.08949 .0473 L
.15517 .06065 L
.22085 .07561 L
.31938 .08308 L
.97619 .09697 L
s
.02381 .06599 m
.05665 .10498 L
.08949 .11834 L
.15517 .13276 L
.22085 .14771 L
.31938 .15679 L
.97619 .16961 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00/Goo0P00KGoo002bOol00`00Oomoo`1[Ool008eoo`800004Ool00000Ool40002
Ool20003Ool3000017oo000000000Woo0`000goo0P000goo00<007ooOol0Jgoo002=Ool01P00Oomo
ogoo001oo`<0009oo`06001oogoo001oo`000Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
1@00Ool007oo0000K7oo002=Ool01@00Ool007oo00000goo00@007ooOol000Aoo`04001oogoo0002
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo0000K7oo002=Ool200000goo00000002
Ool200000goo00000002000017oo000007oo0P0000=oo`0000000P0000=oo`0000000Woo100000Ao
o`00001oo`8006]oo`00SGoo0P0000=oo`0000001Woo00<007ooOol04Goo00<007ooOol0LGoo002=
Ool200000goo0000000FOol00`00Oomoo`1eOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo001AOol00`00Oomoo`0POol50002Ool00`00Oomoo`0NOol50002Ool00`00Oomoo`0O
Ool30003Ool00`00Oomoo`0NOol30003Ool00`00Oomoo`0OOol20004Ool00`00Oomoo`03Ool0051o
o`03001oo`0002=oo`07001oogooOol007oo00008Goo00L007ooOomoo`00Ool0000POol00`00Oomo
o`02Ool00`00Ool0000OOol00`00Oomoo`02Ool00`00Ool0000ROol01P00Oomoo`00Ool000Aoo`00
DWoo00<007ooOol08Goo00L007ooOomoo`00Ool0000QOol00`00Oomoo`03Ool00`00Oomoo`0OOol0
1`00Oomoogoo001oo`00021oo`03001oogoo00=oo`03001oogoo01moo`07001oogooOol007oo0000
17oo001@Ool2000TOol01`00Oomoogoo001oo`00025oo`04001oogooOol2000ROol01`00Oomoogoo
001oo`00021oo`04001oogooOol2000SOol01P00Oomoo`00Ool000Aoo`00D7oo00<007ooOol08goo
00L007ooOomoo`00Ool0000QOol01@00Oomoogoo00008Woo00<007oo00000Woo00<007oo00007goo
00<007oo00000Woo00<007ooOol087oo00<007oo00000Woo00<007oo000017oo001@Ool3000ROol2
0004Ool00`00Oomoo`0OOol20003Ool3000QOol00`00Oomoo`02Ool00`00Oomoo`0OOol01000Oomo
ogoo0`008Goo00<007ooOol00Woo00<007ooOol00goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00:goom0000Goo000[Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`03Ool10001Ool001Ioo`03001oogoo
009oo`03001oogoo009oo`04001oogooOol20005Ool00`00Oomoo`3`Ool10001Ool001Eoo`03001o
o`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00=oo`03001oogoo0>Yoo`40005o
o`005Goo00<007oo00001goo00<007oo00000Woo00<007oo000017oo0`0017oo0P00j7oo0`000Goo
000EOol00`00Ool00007Ool00`00Ool00002Ool20005Ool00`00Oomoo`06Ool00`00Oomoo`3WOol1
0001Ool001Eoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo00Moo`80
0>Moo`40005oo`005Woo00<007ooOol01goo00<007ooOol00Woo0P0017oo00<007ooOol02Goo0P00
iGoo0@000Goo000[Ool00`00Oomoo`0;Ool2003SOol10001Ool002]oo`03001oogoo00eoo`800>5o
o`40005oo`00:goo0P0047oo0`00gGoo0P000Goo000[Ool00`00Oomoo`0BOol4003JOol10001Ool0
02]oo`03001oogoo01Ioo`D00=Eoo`40005oo`00:goo00<007ooOol06goo1P00cgoo0@000Goo000[
Ool00`00Oomoo`0QOol4003;Ool10001Ool002]oo`03001oogoo02Eoo`@00<Moo`40005oo`00:goo
00<007ooOol00goo00<007ooOol08goo1000`goo0@000Goo000[Ool20005Ool00`00Oomoo`0VOol4
002nOol20001Ool002]oo`03001oogoo00Eoo`03001oogoo02Uoo`P00;Moo`40005oo`00:goo00<0
07ooOol01Woo00<007ooOol0<7oo3000Zgoo0@000Goo000[Ool00`00Oomoo`07Ool00`00Oomoo`0k
OolQ002:Ool10001Ool002]oo`03001oogoo00Moo`03001oogoo05aoocD005Eoo`40005oo`00:goo
00<007ooOol027oo00<007ooOol0T7oo=@0087oo0@000Goo000[Ool2000:Ool00`00Oomoo`34OolK
0004Ool20001Ool002]oo`03001oogoo00Yoo`03001oogoo0>=oo`40005oo`00:goo00<007ooOol0
2goo0P00hgoo0@000Goo000[Ool00`00Oomoo`0=Ool2003QOol10001Ool002]oo`03001oogoo00mo
o`<00=ioo`40005oo`005Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol04Woo0`00fgoo0@000Goo000EOol00`00Ool00007Ool00`00Ool00002Ool0
0`00Ool00004Ool00`00Oomoo`0EOol4003GOol10001Ool001Eoo`03001oo`0000Moo`03001oo`00
009oo`03001oo`0000Aoo`<001Uoo`@00=5oo`<0005oo`005Goo00<007oo00001goo00<007oo0000
0goo00<007ooOol00goo00<007ooOol07Goo1000cgoo0@000Goo000EOol00`00Ool00007Ool00`00
Ool00002Ool00`00Ool00004Ool00`00Oomoo`03Ool00`00Oomoo`0KOol5003:Ool10001Ool001Io
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo01mo
o`D00<Eoo`40005oo`00:goo00<007ooOol017oo00<007ooOol097oo1P00_goo0@000Goo000[Ool0
0`00Oomoo`05Ool00`00Oomoo`0YOol6002iOol10001Ool002]oo`8000Moo`03001oogoo02ioo`P0
0;1oo`80005oo`00:goo00<007ooOol01goo00<007ooOol0=Goo2000ZGoo0@000Goo000[Ool00`00
Oomoo`07Ool00`00Oomoo`0mOolO002:Ool10001Ool002]oo`03001oogoo00Qoo`03001oogoo05]o
ocD005Eoo`40005oo`00:goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0Sgoo=@0087oo
0@000Goo000[Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`33OolK0005Ool10001Ool0
02]oo`03001oogoo00Eoo`8000=oo`03001oogoo0>=oo`40005oo`00:goo0P0027oo00D007ooOomo
o`000>=oo`80005oo`00:goo00<007ooOol027oo00D007ooOomoo`000>=oo`40005oo`00:goo00<0
07ooOol02Goo0P000Woo0P00hGoo0@000Goo000[Ool00`00Oomoo`0;Ool9003LOol10001Ool000Eo
o`80009oo`80021oo`03001oogoo011oo`04001oogooOol2003JOol10001Ool000Eoo`03001oo`00
009oo`03001oogoo01ioo`03001oogoo015oo`8000=oo`800=Qoo`40005oo`001Goo00<007oo0000
0Woo00<007ooOol07Woo0P0057oo0P000goo0P00eGoo0P000Goo0005Ool200000goo0000000QOol0
0`00Oomoo`0EOol20003Ool2003DOol10001Ool002]oo`03001oogoo01Moo`8000=oo`800=9oo`40
005oo`001goo00<007ooOol00Woo00<007ooOol077oo00<007ooOol06Goo0P000goo0P00d7oo0@00
0Goo0007Ool6000NOol00`00Oomoo`0KOol30002Ool2003>Ool10001Ool000Moo`06001oogoo001o
o`003Woo00<007ooOol00Woo00<007ooOol01@000goo00<007ooOol07Woo0P000Woo1000bWoo0@00
0Goo0007Ool01000Oomoo`003goo00<007oo000027oo00<007ooOol00goo00<007ooOol087oo0P00
17oo1@00aGoo0@000Goo0008Ool2000@Ool00`00Ool00008Ool00`00Oomoo`03Ool3000ROol30006
Ool6002mOol30001Ool001Yoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo02Eoo`8000Yo
o`P00;Moo`40005oo`006Woo00<007oo000027oo00<007ooOol00goo00<007ooOol09goo0`003goo
3000Zgoo0@000Goo0008Ool2000AOol00`00Oomoo`06Ool20005Ool00`00Oomoo`0ZOol3000HOomF
001EOol10001Ool000Moo`04001oogoo000POol00`00Oomoo`0]Ool2001/Oom@0005Ool10001Ool0
00Moo`04001oogoo000POol00`00Oomoo`0_Ool3002nOol10001Ool000Qoo`80025oo`8003=oo`L0
0;Ioo`80005oo`00:goo00<007ooOol0>Goo3000Zgoo0@000Goo0007Ool00`00Oomoo`0QOol00`00
Oomoo`15Ool^001mOol10001Ool000Ioo`@0025oo`03001oogoo07=ooe0002eoo`40005oo`001goo
00@007ooOol0021oo`03001oogoo0<=oobP000Eoo`40005oo`001goo00@007ooOol0021oo`03001o
ogoo0?1oo`40005oo`001goo00<007oo00008Goo00<007ooOol0l7oo0@000Goo000[Ool2003`Ool2
0001Ool002]oo`03001oogoo0?1oo`40005oo`00:goo00<007ooOol0l7oo0@000Goo000[Ool00`00
Oomoo`3`Ool10001Ool002]oo`03001oogoo0?1oo`40005oo`00:goo00<007ooOol0l7oo0@000Goo
000[Ool2003`Ool20001Ool000Eoo`03001oogoo009oo`03001oogoo01ioo`03001oogoo0?1oo`40
005oo`001Goo1P0087oo00<007ooOol0l7oo0@000Goo0005Ool01P00Oomoo`00Ool0021oo`03001o
ogoo0?1oo`40005oo`001Goo00@007ooOol0029oo`03001oogoo0?1oo`40005oo`001Woo0P0000=o
o`00Ool02goo00<007ooOol00Woo00<007ooOol01@0000Aoo`00000000Aoo`03001oogoo0?1oo`40
005oo`002Woo00<007ooOol027oo00<007oo000027oo00D007ooOomoo`0000Ioo`03001oogoo0?1o
o`40005oo`005Goo00<007oo000027oo00<007ooOol00Woo00<007ooOol00goo0`00kWoo0`000Goo
0009Ool2000:Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3`Ool1
0001Ool000Moo`04001oo`00000:Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000Aoo`03001o
ogoo0?1oo`40005oo`001goo00@007oo000000]oo`03001oogoo00Ioo`8000Aoo`03001oogoo00=o
o`03001oogoo0?1oo`40005oo`001goo100087oo00<007ooOol0egoo50001Goo0@000Goo000:Ool0
0`00Oomoo`0NOol00`00Oomoo`2_OolX000IOol10001Ool000Moo`03001oogoo025oo`8008QoobP0
041oo`80005oo`001Woo10008Goo00<007ooOol0Ggoo:000JGoo0@000Goo0007Ool01000Oomoo`00
87oo00<007ooOol0@7oo7`00TGoo0@000Goo0007Ool01000Oomoo`0087oo00<007ooOol0<goo3@00
/7oo0@000Goo0007Ool00`00Ool0000QOol00`00Oomoo`0aOol2002mOol10001Ool002]oo`03001o
ogoo02moo`800;moo`40005oo`00:goo0P00;Woo0P00`7oo0P000Goo0008Ool2000QOol00`00Oomo
o`0[Ool20033Ool10001Ool000Moo`800003Ool007oo01moo`03001oogoo02Uoo`800<Eoo`40005o
o`001goo0P0000=oo`00Ool07goo00<007ooOol09goo0P00agoo0@000Goo0008Ool00`00Ool0000P
Ool00`00Oomoo`0UOol20039Ool10001Ool002]oo`03001oogoo029oo`<00<]oo`40005oo`00:goo
00<007ooOol07Woo1000cWoo0@000Goo0007Ool200000goo001oo`0OOol2000KOol4003AOol20001
Ool000Moo`800003Ool007oo01moo`03001oogoo01Ioo`@00=Ioo`40005oo`001goo0P0000=oo`00
Ool07goo00<007ooOol04goo0`00bGoo30001Goo0@000Goo0007Ool00`00Ool0000QOol00`00Oomo
o`0BOol00`00Oomoo`2cOolG000AOol10001Ool001Ioo`03001oogoo009oo`03001oogoo00D0009o
o`<000=oo`03001oogoo019oo`03001oogoo09eooaH002Qoo`40005oo`005Goo00<007oo000027oo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol0Qgoo5`00;Goo30001Goo
0@000Goo000EOol00`00Ool00008Ool01000Oomoogoo10000goo0`004Goo00<007ooOol0L7oo5`00
;Goo5`003goo0`000Goo000EOol00`00Ool00008Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo
011oo`03001oogoo05]ooaH002iooaH002Qoo`40005oo`005Goo00<007oo000027oo00<007ooOol0
0Woo0P0017oo00<007ooOol03goo00<007ooOol0AGoo5`00;Goo5`00?Woo0@000Goo000FOol00`00
Oomoo`06Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`0dOolA000]OolG001E
Ool10001Ool002]oo`03001oogoo00=oo`8000Uoo`03001oogoo02Uoo``002QooaH006aoo`40005o
o`00:goo00<007ooOol00goo00@007oo000000Ioo`03001oogoo01aoo`h001eooaL0089oo`40005o
o`00:goo00<007ooOol017oo0P0000Aoo`00000000=oo`03001oogoo00aooa0001aoo`l009Uoo`40
005oo`00:goo0P001goo0P000Woo4P0097oo2000Ygoo0P000Goo000[Ool00`00Oomoo`08Ool20002
Ool00`00Oomoo`0YOol8002`Ool10001Ool002]oo`03001oogoo00Yoo`<001=ooaP00;Qoo`40005o
o`00:goo00<007ooOol02Woo00<007ooOol010001goo2000d7oo0@000Goo000[Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool70039Ool:0005Ool10001Ool002]oo`03001oogoo00Uoo`03001oogoo0<5o
oa@000moo`40005oo`00:goo0P002Woo00<007ooOol0[Goo50008Woo0P000Goo000[Ool00`00Oomo
o`08Ool00`00Oomoo`2JOolD000gOol10001Ool002]oo`03001oogoo00Qoo`03001oogoo08Iooa@0
04]oo`40005oo`00:goo00<007ooOol01goo00<007ooOol0Lgoo5000Ggoo0@000Goo000[Ool00`00
Oomoo`07Ool00`00Oomoo`1OOolD001cOol10001Ool002]oo`03001oogoo00Ioo`03001oogoo04ao
oa@008Moo`40005oo`00:goo00<007ooOol01Woo00<007ooOol0@7oo3000Vgoo0@000Goo000[Ool2
0006Ool00`00Oomoo`0kOol6002VOol20001Ool002]oo`03001oogoo00Eoo`03001oogoo03Eoo`H0
0:eoo`40005oo`00:goo00<007ooOol017oo00<007ooOol0<7oo1P00/goo0@000Goo000[Ool00`00
Oomoo`04Ool00`00Oomoo`0[Ool5002iOol10001Ool001Ioo`03001oogoo009oo`03001oogoo00D0
0003Ool0000000Eoo`03001oogoo00=oo`03001oogoo02Uoo`<00;ioo`40005oo`005Goo00<007oo
000027oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0/Ool30031Ool10001Ool001Eoo`03001o
o`0000Qoo`07001oogooOol007oo000017oo0`00:7oo1000`Woo0`000Goo000EOol00`00Ool00008
Ool01000Oomoogoo0P001Goo00<007ooOol09Goo0`00b7oo0@000Goo000EOol00`00Ool00008Ool0
1@00Oomoogoo00001Woo00<007ooOol08Goo1000bgoo0@000Goo000FOol00`00Oomoo`06Ool20004
Ool20004Ool00`00Oomoo`0LOol5003?Ool10001Ool002]oo`03001oogoo01Ioo`H00=Aoo`40005o
o`00:goo00<007ooOol04goo0`00fWoo0@000Goo000[Ool00`00Oomoo`0AOol2003MOol10001Ool0
02]oo`80015oo`03001oogoo0=aoo`80005oo`00:goo00<007ooOol03Woo0P00h7oo0@000Goo000[
Ool00`00Oomoo`0<Ool2003ROol10001Ool002]oo`03001oogoo00Yoo`800>Aoo`40005oo`00:goo
00<007ooOol027oo0P00iWoo0@000Goo000[Ool00`00Oomoo`05Ool3003XOol10001Ool002]oo`80
00Aoo`800>Yoo`80005oo`00:goo00<007ooOol0l7oo0@000Goo000[Ool00`00Oomoo`0SOol00`00
Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`0UOol00`00
Oomoo`03Ool10001Ool002]ooo@0005oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.23444, 0.0358788, 
  0.12554, 0.000771889}}]
}, Open  ]],

Cell["Forward Rates", "Subsection",
  CellTags->{"S0.4", "4.1"}],

Cell["\<\
A forward rate is a yield on the margin between two successive spot \
rates. It is the future interest rate implicit in the yield curve. Forward \
rates are represented like spot rates except that the first number of each \
pair represents the length of the consecutive time interval instead of the \
time from a given date. The second element of each pair is the forward rate \
for that period. \
\>", "Text",
  CellTags->{"S0.4", "4.2"}],

Cell["Here we define a forward rates object. ", "MathCaption",
  CellTags->{"S0.4", "4.3"}],

Cell["\<\
forward1 = ForwardRates[
                {{1, 0.088300},
                 {1, 0.096716},
                 {1, 0.093400},
                 {2, 0.107610},
                 {2, 0.106419},
                 {3, 0.106242},
                 {20, 0.104300}},
                 InitialDate->{5, 30, 1980}];\
\>", "Input",
  CellLabel->"In[27]:=",
  CellTags->"S0.4"],

Cell["Discount Factors", "Subsection",
  CellTags->{"S0.5", "5.1"}],

Cell["\<\
Discount interest factors are multipliers that translate the future \
value of an investment into its equivalent present value. Again, discount \
factors are represented by a list of ordered pairs. As with spot rates, the \
first element of each pair represents the time from a given date. The second \
element is the actual discount factor. The pairs must be sorted in order of \
increasing time. \
\>", "Text",
  CellTags->{"S0.5", "5.2"}],

Cell["This defines a discount factors object. ", "MathCaption",
  CellTags->{"S0.5", "5.3"}],

Cell["\<\
discount1 = DiscountFactors[
                {{1, 0.943841},
                 {2, 0.884148},
                 {3, 0.826451},
                 {5, 0.719350},
                 {7, 0.619095},
                 {10, 0.49755},
                 {30, 0.11454}},
                 InitialDate -> {12, 31, 1986}];\
\>", "Input",
  CellLabel->"In[28]:=",
  CellTags->"S0.5"],

Cell["And here is the graph of the discount factors. ", "MathCaption",
  CellTags->{"S0.5", "5.4"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[First[discount1],
   FrameLabel -> {\"Time\", \"Discount Factors\"}];\
\>", "Input",
  CellLabel->"In[29]:=",
  CellTags->"S0.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0090312 0.0328407 -0.0665807 0.709759 [
[.15517 -0.0125 -3 -9 ]
[.15517 -0.0125 3 0 ]
[.31938 -0.0125 -6 -9 ]
[.31938 -0.0125 6 0 ]
[.48358 -0.0125 -6 -9 ]
[.48358 -0.0125 6 0 ]
[.64778 -0.0125 -6 -9 ]
[.64778 -0.0125 6 0 ]
[.81199 -0.0125 -6 -9 ]
[.81199 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -24 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .07537 -18 -4.5 ]
[-0.0125 .07537 0 4.5 ]
[-0.0125 .21732 -18 -4.5 ]
[-0.0125 .21732 0 4.5 ]
[-0.0125 .35927 -18 -4.5 ]
[-0.0125 .35927 0 4.5 ]
[-0.0125 .50123 -18 -4.5 ]
[-0.0125 .50123 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -33 -50 ]
[-0.01875 .30902 -18 50 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15517 0 m
.15517 .00625 L
s
[(5)] .15517 -0.0125 0 1 Mshowa
.31938 0 m
.31938 .00625 L
s
[(10)] .31938 -0.0125 0 1 Mshowa
.48358 0 m
.48358 .00625 L
s
[(15)] .48358 -0.0125 0 1 Mshowa
.64778 0 m
.64778 .00625 L
s
[(20)] .64778 -0.0125 0 1 Mshowa
.81199 0 m
.81199 .00625 L
s
[(25)] .81199 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.18801 0 m
.18801 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.35222 0 m
.35222 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.51642 0 m
.51642 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.68062 0 m
.68062 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.84483 0 m
.84483 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.05665 0 m
.05665 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .07537 m
.00625 .07537 L
s
[(0.2)] -0.0125 .07537 1 0 Mshowa
0 .21732 m
.00625 .21732 L
s
[(0.4)] -0.0125 .21732 1 0 Mshowa
0 .35927 m
.00625 .35927 L
s
[(0.6)] -0.0125 .35927 1 0 Mshowa
0 .50123 m
.00625 .50123 L
s
[(0.8)] -0.0125 .50123 1 0 Mshowa
.125 Mabswid
0 .11086 m
.00375 .11086 L
s
0 .14635 m
.00375 .14635 L
s
0 .18183 m
.00375 .18183 L
s
0 .25281 m
.00375 .25281 L
s
0 .2883 m
.00375 .2883 L
s
0 .32379 m
.00375 .32379 L
s
0 .39476 m
.00375 .39476 L
s
0 .43025 m
.00375 .43025 L
s
0 .46574 m
.00375 .46574 L
s
0 .03988 m
.00375 .03988 L
s
0 .0044 m
.00375 .0044 L
s
0 .53671 m
.00375 .53671 L
s
0 .5722 m
.00375 .5722 L
s
0 .60769 m
.00375 .60769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -136.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
111 11.5 translate
90 rotate
-111 -11.5 translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Discount) show
117.000000 15.000000 moveto
(Factors) show
159.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.15517 .61178 m
.15517 .61803 L
s
.31938 .61178 m
.31938 .61803 L
s
.48358 .61178 m
.48358 .61803 L
s
.64778 .61178 m
.64778 .61803 L
s
.81199 .61178 m
.81199 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.18801 .61428 m
.18801 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.35222 .61428 m
.35222 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.51642 .61428 m
.51642 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.68062 .61428 m
.68062 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.84483 .61428 m
.84483 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.05665 .61428 m
.05665 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07537 m
1 .07537 L
s
.99375 .21732 m
1 .21732 L
s
.99375 .35927 m
1 .35927 L
s
.99375 .50123 m
1 .50123 L
s
.125 Mabswid
.99625 .11086 m
1 .11086 L
s
.99625 .14635 m
1 .14635 L
s
.99625 .18183 m
1 .18183 L
s
.99625 .25281 m
1 .25281 L
s
.99625 .2883 m
1 .2883 L
s
.99625 .32379 m
1 .32379 L
s
.99625 .39476 m
1 .39476 L
s
.99625 .43025 m
1 .43025 L
s
.99625 .46574 m
1 .46574 L
s
.99625 .03988 m
1 .03988 L
s
.99625 .0044 m
1 .0044 L
s
.99625 .53671 m
1 .53671 L
s
.99625 .5722 m
1 .5722 L
s
.99625 .60769 m
1 .60769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.02381 .60332 Mdot
.05665 .56095 Mdot
.08949 .52 Mdot
.15517 .44398 Mdot
.22085 .37283 Mdot
.31938 .28656 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol009Moo`<0009oo`<00006Ool007oo001oo`000Woo0P00
Mgoo002HOol00`00Oomoo`02Ool02P00Oomoo`00Ool007oo001oo`00NGoo002HOol00`00Oomoo`02
Ool02@00Oomoo`00Ool007oo001oo`03001gOol009Qoo`04001oogooOol20002Ool2000017oo001o
ogoo0`00Mgoo002FOol01@00Ool007oo0000QGoo002FOol50002Ool00`00Oomoo`20Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001>Ool00`00Oomoo`0POol50002Ool00`00
Oomoo`0NOol50002Ool00`00Oomoo`0OOol30003Ool00`00Oomoo`0NOol30003Ool00`00Oomoo`0O
Ool20004Ool00`00Oomoo`06Ool004eoo`03001oo`0002=oo`07001oogooOol007oo00008Goo00L0
07ooOomoo`00Ool0000POol00`00Oomoo`02Ool00`00Ool0000OOol00`00Oomoo`02Ool00`00Ool0
000ROol01P00Oomoo`00Ool000Moo`00Cgoo00<007ooOol08Goo00L007ooOomoo`00Ool0000QOol0
0`00Oomoo`03Ool00`00Oomoo`0OOol01`00Oomoogoo001oo`00021oo`03001oogoo00=oo`03001o
ogoo01moo`07001oogooOol007oo00001goo001=Ool2000TOol01`00Oomoogoo001oo`00025oo`04
001oogooOol2000ROol01`00Oomoogoo001oo`00021oo`04001oogooOol2000SOol01P00Oomoo`00
Ool000Moo`00CGoo00<007ooOol08goo00L007ooOomoo`00Ool0000QOol01@00Oomoogoo00008Woo
00<007oo00000Woo00<007oo00007goo00<007oo00000Woo00<007ooOol087oo00<007oo00000Woo
00<007oo00001goo001=Ool3000ROol20004Ool00`00Oomoo`0OOol20003Ool3000QOol00`00Oomo
o`02Ool00`00Oomoo`0OOol01000Oomoogoo0`008Goo00<007ooOol00Woo00<007ooOol01Woo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00:7oom00017oo000XOol20004Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2
0004Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol0jGoo0P001Goo00<0
07ooOol00Woo000XOol00`00Oomoo`3YOol20005Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1o
o`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool0
0`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo0P00l7oo0P0017oo000X
Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo
00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03
001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000HOol00`00
Oomoo`02Ool01000Oomoogoo0`0017oo00<007ooOol0l7oo00<007ooOol00Woo000GOol00`00Ool0
0007Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool001Moo`03001oo`0000Qoo`03
001oogoo00=oo`<00>ioo`<000Aoo`005goo00<007oo000027oo00<007ooOol00goo00<007ooOol0
l7oo00<007ooOol00Woo000GOol00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`3`Ool00`00
Oomoo`02Ool001Qoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?1oo`03001oogoo009o
o`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool00`00Oomoo`02Ool0
02Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000X
Ool2003`Ool20004Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`0027oo00<007ooOol00Woo
00<007ooOol067oo00<007ooOol0l7oo00<007ooOol00Woo0008Ool6000JOol00`00Oomoo`3`Ool0
0`00Oomoo`02Ool000Qoo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo0?1oo`03001oogoo
009oo`0027oo00<007ooOol00Woo00<007ooOol067oo00<007ooOol0l7oo00<007ooOol00Woo0009
Ool4000KOol00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009o
o`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000XOol2003`Ool20004Ool000Yoo`04001oogoo
000JOol00`00Oomoo`3`Ool00`00Oomoo`02Ool000Qoo`03001oo`0000<001Yoo`03001oogoo0?1o
o`03001oogoo009oo`003Goo00<007ooOol067oo00<007ooOol0l7oo00<007ooOol00Woo000XOol0
0`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`002Woo0P00
00=oo`00Ool06Goo00<007ooOol0l7oo00<007ooOol00Woo000:Ool200000goo001oo`0IOol00`00
Oomoo`3`Ool00`00Oomoo`02Ool000Yoo`800003Ool007oo01Uoo`03001oogoo0?1oo`03001oogoo
009oo`002Woo00<007oo00006goo0P00l7oo0P0017oo000XOol00`00Oomoo`3`Ool00`00Oomoo`02
Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`002goo0P006goo00<007ooOol0l7oo00<007oo
Ool00Woo000:Ool01000Oomoo`006Woo00<007ooOol0l7oo00<007ooOol00Woo000:Ool01000Oomo
o`006Woo00<007ooOol0l7oo00<007ooOol00Woo000:Ool01000Oomoo`002Woo00<007ooOol00Woo
00<007ooOol00Woo0`000goo00<007ooOol0l7oo00<007ooOol00Woo000GOol00`00Ool00009Ool0
0`00Oomoo`02Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool001Moo`03001oo`0000Moo`@000=oo`<0
0>ioo`<000Aoo`002goo0P002Woo00<007oo00001goo00<007oo000017oo00<007ooOol0l7oo00<0
07ooOol00Woo000:Ool01000Oomoo`002Goo00<007oo000027oo0P0017oo00<007ooOol0l7oo00<0
07ooOol00Woo000:Ool01000Oomoo`002Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
l7oo00<007ooOol00Woo000;Ool2000KOol00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001o
ogoo0?1oo`03001oogoo009oo`002Woo00<007ooOol06goo00<007ooOol0l7oo00<007ooOol00Woo
000:Ool3000KOol00`00Oomoo`3`Ool00`00Oomoo`02Ool000eoo`03001oogoo01Qoo`03001oogoo
0?1oo`03001oogoo009oo`002Woo00<007oo00006goo0P00l7oo0P0017oo000:Ool4000JOol00`00
Oomoo`3`Ool00`00Oomoo`02Ool000eoo`03001oogoo01Qoo`03001oogoo0?1oo`03001oogoo009o
o`002Woo00@007ooOol001Yoo`03001oogoo0?1oo`03001oogoo009oo`002Woo10006Woo00<007oo
Ool0l7oo00<007ooOol00Woo000:Ool00`00Oomoo`0KOol00`00Oomoo`3`Ool00`00Oomoo`02Ool0
00Yoo`03001oogoo01]oo`03001oogoo0?1oo`03001oogoo009oo`002goo0`006Woo00<007ooOol0
l7oo00<007ooOol00Woo000=Ool00`00Oomoo`0HOol00`00Oomoo`1:Ool2002TOol00`00Oomoo`02
Ool000Yoo`03001oogoo01]oo`8004]oo`800:=oo`8000Aoo`002Goo10006goo00<007ooOol0l7oo
00<007ooOol00Woo000:Ool01000Oomoo`006Woo00<007ooOol0l7oo00<007ooOol00Woo000:Ool0
1000Oomoo`006Woo00<007ooOol0l7oo00<007ooOol00Woo000:Ool00`00Ool0000KOol00`00Oomo
o`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol0
l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`800?1oo`8000Ao
o`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool00`00Oomoo`02Ool0
02Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo0008
Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`3`Ool00`00Oomoo`02Ool000Qoo`H001Yo
o`03001oogoo0?1oo`03001oogoo009oo`0027oo00<007oo00000Woo00<007ooOol027oo00<007oo
Ool00Woo00@007ooOomoo`8000Eoo`03001oogoo0?1oo`03001oogoo009oo`0027oo00<007ooOol0
37oo00<007oo00001goo00<007oo000017oo00<007ooOol0l7oo00<007ooOol00Woo0008Ool2000=
Ool00`00Ool00007Ool00`00Ool00004Ool3003^Ool30004Ool001Moo`03001oo`0000Moo`8000Eo
o`03001oogoo0?1oo`03001oogoo009oo`0037oo0P002Goo00<007oo00001goo00<007ooOol017oo
00<007ooOol0l7oo00<007ooOol00Woo000:Ool01000Ool000002Woo00<007ooOol01goo0P0017oo
00<007ooOol0<Woo0P00_7oo00<007ooOol00Woo000:Ool01000Ool000006Woo00<007ooOol0<Woo
0P00_7oo00<007ooOol00Woo000:Ool4000JOol00`00Oomoo`3`Ool00`00Oomoo`02Ool000eoo`03
001oogoo01Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol0
0Woo000;Ool2000KOol2003`Ool20004Ool000Yoo`04001oogoo000JOol00`00Oomoo`3`Ool00`00
Oomoo`02Ool000Yoo`04001oogoo000JOol00`00Oomoo`3`Ool00`00Oomoo`02Ool000Yoo`04001o
ogoo000JOol00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009o
o`002Woo00<007ooOol06goo00<007ooOol0l7oo00<007ooOol00Woo0009Ool4000KOol00`00Oomo
o`3`Ool00`00Oomoo`02Ool000Yoo`04001oogoo000JOol00`00Oomoo`3`Ool00`00Oomoo`02Ool0
00Yoo`04001oogoo000JOol00`00Oomoo`3`Ool00`00Oomoo`02Ool000Yoo`03001oo`0001]oo`80
0?1oo`8000Aoo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool00`00
Oomoo`02Ool000]oo`8001]oo`03001oogoo029oo`800<aoo`03001oogoo009oo`002Woo00@007oo
Ool001Yoo`03001oogoo029oo`800<aoo`03001oogoo009oo`002Woo00@007ooOol001Yoo`03001o
ogoo0?1oo`03001oogoo009oo`002goo0P006goo00<007ooOol0l7oo00<007ooOol00Woo000XOol0
0`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`002Woo00@0
07ooOol001Yoo`800?1oo`8000Aoo`002Woo10006Woo00<007ooOol0l7oo00<007ooOol00Woo000:
Ool01000Oomoo`006Woo00<007ooOol0l7oo00<007ooOol00Woo000:Ool01000Oomoo`006Woo00<0
07ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001o
ogoo0?1oo`03001oogoo009oo`002Woo0P0000=oo`00Ool02Goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol0l7oo00<007ooOol00Woo000:Ool200000goo001oo`08Ool0
0`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool000Yoo`800003Ool0
07oo00Qoo`03001oo`0000Moo`03001oo`0000Aoo`<00>ioo`<000Aoo`002Woo00<007oo00002Woo
00<007oo000027oo00<007ooOol00goo00<007ooOol0l7oo00<007ooOol00Woo000GOol00`00Ool0
0007Ool00`00Ool00004Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool001Qoo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol04Woo0P00g7oo00<0
07ooOol00Woo000XOol00`00Oomoo`0BOol2003LOol00`00Oomoo`02Ool002Qoo`03001oogoo0?1o
o`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool0
0`00Oomoo`02Ool002Qoo`800?1oo`8000Aoo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000X
Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo
00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`0:Ool2003TOol00`00Oomoo`02Ool0
02Qoo`03001oogoo00Yoo`800>Aoo`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol0
0Woo000XOol2003`Ool20004Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007oo
Ool0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`Ool00`00Oomoo`02Ool002Qoo`03001oogoo
0?1oo`03001oogoo009oo`00:7oo00<007ooOol0l7oo00<007ooOol00Woo000XOol00`00Oomoo`3`
Ool00`00Oomoo`02Ool002Qoo`03001oogoo0?1oo`03001oogoo009oo`00:7oo00<007ooOol00Woo
0P00k7oo00<007ooOol00Woo000XOol20003Ool2003[Ool20004Ool002Qoo`03001oogoo02=oo`03
001oogoo02Eoo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo02Aoo`03001oogoo02Eoo`03
001oogoo00=oo`03001oogoo009oo`00:7oom00017oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.85782, -0.0632194, 
  0.12554, 0.00580878}}]
}, Open  ]],

Cell["\<\
Assuming that interest rates are piecewise linear functions of \
time, we can compute the interpolated discount factors over the given time \
range. \
\>", "Text",
  CellTags->{"S0.5", "5.5"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["InterpolatedDiscountFactors",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(object, \ timeintervals\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ interpolated\ discount\ factors\ equivalent\ to\ 
                the\ interest\ rates\ object\ for\ the\ given\ list\ of\ time
                \ intervals\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell[TextData[{
  StyleBox["InterpolatedDiscountFactors", "MR"],
  " function. "
}], "Caption",
  CellTags->"S0.5"],

Cell["\<\
This gives the discount factors for 4 and 8 years from a given \
time. \
\>", "MathCaption",
  CellTags->{"S0.5", "5.7"}],

Cell[CellGroupData[{

Cell["InterpolatedDiscountFactors[discount1, {4, 8}]", "Input",
  CellLabel->"In[30]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    \({{4, 0.771043142016061278`}, {8, 0.57559512613286774`}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[{
  "This gives the largest time interval in the ",
  StyleBox["discount1", "MB"],
  " object. "
}], "MathCaption",
  CellTags->{"S0.5", "5.8"}],

Cell[CellGroupData[{

Cell["max = Part[discount1, 1, -1, 1]", "Input",
  CellLabel->"In[31]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    \(30\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["\<\
We can produce the interpolated discount factors for all the \
intervals and define a new discount rates object. \
\>", "MathCaption",
  CellTags->{"S0.5", "5.9"}],

Cell[CellGroupData[{

Cell["\<\
discount2 = DiscountFactors[
   InterpolatedDiscountFactors[discount1,
      Range[max]]]\
\>", "Input",
  CellLabel->"In[32]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    RowBox[{"DiscountFactors", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"1", ",", 
              StyleBox["0.943841000000000107`",
                StyleBoxAutoDelete->True,
                PrintPrecision->6]}], "}"}], ",", 
          \({2, 0.884147999999999889`}\), ",", \({3, 0.826451000000000135`}\),
           ",", \({4, 0.771043142016061278`}\), ",", 
          \({5, 0.719350000000000022`}\), ",", \({6, 0.667342481976083945`}\),
           ",", \({7, 0.619094999999999817`}\), ",", 
          \({8, 0.57559512613286774`}\), ",", \({9, 0.535151712140967017`}\), 
          ",", \({10, 0.497550000000000025`}\), ",", 
          \({11, 0.462320076142665747`}\), ",", 
          \({12, 0.429584670494543807`}\), ",", 
          \({13, 0.399167154201104334`}\), ",", 
          \({14, 0.370903404931978331`}\), ",", 
          \({15, 0.34464092133398898`}\), ",", 
          \({16, 0.320238000186932536`}\), ",", 
          \({17, 0.297562971822324584`}\), ",", 
          \({18, 0.27649348967970071`}\), ",", 
          \({19, 0.256915870167160109`}\), ",", 
          \({20, 0.238724479264276556`}\), ",", 
          \({21, 0.221821162557689666`}\), ",", 
          \({22, 0.206114715634058498`}\), ",", 
          \({23, 0.191520391972790129`}\), ",", 
          \({24, 0.177959445683315475`}\), ",", 
          \({25, 0.165358706619670421`}\), ",", 
          \({26, 0.15365018557985886`}\), ",", 
          \({27, 0.142770707459782908`}\), ",", 
          \({28, 0.132661570382371962`}\), ",", 
          \({29, 0.123268228962684611`}\), ",", 
          \({30, 0.114539999999999997`}\)}], "}"}], "]"}]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["This is the graph of the interpolated discount factors. ", "MathCaption",
  CellTags->{"S0.5", "5.10"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[First[discount2],
   FrameLabel -> {\"Time\",
      \"Interpolated\\nDiscount Factors\"}];\
\>", "Input",
  CellLabel->"In[33]:=",
  CellTags->"S0.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0090312 0.0328407 -0.0665807 0.709759 [
[.15517 -0.0125 -3 -9 ]
[.15517 -0.0125 3 0 ]
[.31938 -0.0125 -6 -9 ]
[.31938 -0.0125 6 0 ]
[.48358 -0.0125 -6 -9 ]
[.48358 -0.0125 6 0 ]
[.64778 -0.0125 -6 -9 ]
[.64778 -0.0125 6 0 ]
[.81199 -0.0125 -6 -9 ]
[.81199 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -24 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .07537 -18 -4.5 ]
[-0.0125 .07537 0 4.5 ]
[-0.0125 .21732 -18 -4.5 ]
[-0.0125 .21732 0 4.5 ]
[-0.0125 .35927 -18 -4.5 ]
[-0.0125 .35927 0 4.5 ]
[-0.0125 .50123 -18 -4.5 ]
[-0.0125 .50123 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49 -50 ]
[-0.01875 .30902 -18 50 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15517 0 m
.15517 .00625 L
s
[(5)] .15517 -0.0125 0 1 Mshowa
.31938 0 m
.31938 .00625 L
s
[(10)] .31938 -0.0125 0 1 Mshowa
.48358 0 m
.48358 .00625 L
s
[(15)] .48358 -0.0125 0 1 Mshowa
.64778 0 m
.64778 .00625 L
s
[(20)] .64778 -0.0125 0 1 Mshowa
.81199 0 m
.81199 .00625 L
s
[(25)] .81199 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.18801 0 m
.18801 .00375 L
s
.22085 0 m
.22085 .00375 L
s
.25369 0 m
.25369 .00375 L
s
.28654 0 m
.28654 .00375 L
s
.35222 0 m
.35222 .00375 L
s
.38506 0 m
.38506 .00375 L
s
.4179 0 m
.4179 .00375 L
s
.45074 0 m
.45074 .00375 L
s
.51642 0 m
.51642 .00375 L
s
.54926 0 m
.54926 .00375 L
s
.5821 0 m
.5821 .00375 L
s
.61494 0 m
.61494 .00375 L
s
.68062 0 m
.68062 .00375 L
s
.71346 0 m
.71346 .00375 L
s
.74631 0 m
.74631 .00375 L
s
.77915 0 m
.77915 .00375 L
s
.84483 0 m
.84483 .00375 L
s
.87767 0 m
.87767 .00375 L
s
.91051 0 m
.91051 .00375 L
s
.94335 0 m
.94335 .00375 L
s
.12233 0 m
.12233 .00375 L
s
.08949 0 m
.08949 .00375 L
s
.05665 0 m
.05665 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .07537 m
.00625 .07537 L
s
[(0.2)] -0.0125 .07537 1 0 Mshowa
0 .21732 m
.00625 .21732 L
s
[(0.4)] -0.0125 .21732 1 0 Mshowa
0 .35927 m
.00625 .35927 L
s
[(0.6)] -0.0125 .35927 1 0 Mshowa
0 .50123 m
.00625 .50123 L
s
[(0.8)] -0.0125 .50123 1 0 Mshowa
.125 Mabswid
0 .11086 m
.00375 .11086 L
s
0 .14635 m
.00375 .14635 L
s
0 .18183 m
.00375 .18183 L
s
0 .25281 m
.00375 .25281 L
s
0 .2883 m
.00375 .2883 L
s
0 .32379 m
.00375 .32379 L
s
0 .39476 m
.00375 .39476 L
s
0 .43025 m
.00375 .43025 L
s
0 .46574 m
.00375 .46574 L
s
0 .03988 m
.00375 .03988 L
s
0 .0044 m
.00375 .0044 L
s
0 .53671 m
.00375 .53671 L
s
0 .5722 m
.00375 .5722 L
s
0 .60769 m
.00375 .60769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -144.5 -19.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
111 19.5 translate
90 rotate
-111 -19.5 translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Interpolated) show
63.000000 31.000000 moveto
(Discount) show
117.000000 31.000000 moveto
(Factors) show
159.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.15517 .61178 m
.15517 .61803 L
s
.31938 .61178 m
.31938 .61803 L
s
.48358 .61178 m
.48358 .61803 L
s
.64778 .61178 m
.64778 .61803 L
s
.81199 .61178 m
.81199 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.18801 .61428 m
.18801 .61803 L
s
.22085 .61428 m
.22085 .61803 L
s
.25369 .61428 m
.25369 .61803 L
s
.28654 .61428 m
.28654 .61803 L
s
.35222 .61428 m
.35222 .61803 L
s
.38506 .61428 m
.38506 .61803 L
s
.4179 .61428 m
.4179 .61803 L
s
.45074 .61428 m
.45074 .61803 L
s
.51642 .61428 m
.51642 .61803 L
s
.54926 .61428 m
.54926 .61803 L
s
.5821 .61428 m
.5821 .61803 L
s
.61494 .61428 m
.61494 .61803 L
s
.68062 .61428 m
.68062 .61803 L
s
.71346 .61428 m
.71346 .61803 L
s
.74631 .61428 m
.74631 .61803 L
s
.77915 .61428 m
.77915 .61803 L
s
.84483 .61428 m
.84483 .61803 L
s
.87767 .61428 m
.87767 .61803 L
s
.91051 .61428 m
.91051 .61803 L
s
.94335 .61428 m
.94335 .61803 L
s
.12233 .61428 m
.12233 .61803 L
s
.08949 .61428 m
.08949 .61803 L
s
.05665 .61428 m
.05665 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07537 m
1 .07537 L
s
.99375 .21732 m
1 .21732 L
s
.99375 .35927 m
1 .35927 L
s
.99375 .50123 m
1 .50123 L
s
.125 Mabswid
.99625 .11086 m
1 .11086 L
s
.99625 .14635 m
1 .14635 L
s
.99625 .18183 m
1 .18183 L
s
.99625 .25281 m
1 .25281 L
s
.99625 .2883 m
1 .2883 L
s
.99625 .32379 m
1 .32379 L
s
.99625 .39476 m
1 .39476 L
s
.99625 .43025 m
1 .43025 L
s
.99625 .46574 m
1 .46574 L
s
.99625 .03988 m
1 .03988 L
s
.99625 .0044 m
1 .0044 L
s
.99625 .53671 m
1 .53671 L
s
.99625 .5722 m
1 .5722 L
s
.99625 .60769 m
1 .60769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.01 w
.02381 .60332 Mdot
.05665 .56095 Mdot
.08949 .52 Mdot
.12233 .48067 Mdot
.15517 .44398 Mdot
.18801 .40707 Mdot
.22085 .37283 Mdot
.25369 .34195 Mdot
.28654 .31325 Mdot
.31938 .28656 Mdot
.35222 .26156 Mdot
.38506 .23832 Mdot
.4179 .21673 Mdot
.45074 .19667 Mdot
.48358 .17803 Mdot
.51642 .16071 Mdot
.54926 .14462 Mdot
.5821 .12966 Mdot
.61494 .11577 Mdot
.64778 .10286 Mdot
.68062 .09086 Mdot
.71346 .07971 Mdot
.74631 .06935 Mdot
.77915 .05973 Mdot
.81199 .05078 Mdot
.84483 .04247 Mdot
.87767 .03475 Mdot
.91051 .02758 Mdot
.94335 .02091 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol009ioo`<0009o
o`<00006Ool007oo001oo`000Woo0P00L7oo002OOol00`00Oomoo`02Ool02P00Oomoo`00Ool007oo
001oo`00LWoo002OOol00`00Oomoo`02Ool02@00Oomoo`00Ool007oo001oo`03001`Ool009moo`04
001oogooOol20002Ool2000017oo001oogoo0`00L7oo002MOol01@00Ool007oo0000OWoo002MOol5
0002Ool00`00Oomoo`1iOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001I
Ool00`00Oomoo`0NOol50002Ool00`00Oomoo`0MOol50002Ool00`00Oomoo`0MOol30003Ool00`00
Oomoo`0MOol30003Ool00`00Oomoo`0NOol20004Ool00`00Oomoo`02Ool005Qoo`03001oo`00025o
o`07001oogooOol007oo000087oo00L007ooOomoo`00Ool0000NOol00`00Oomoo`02Ool00`00Ool0
000NOol00`00Oomoo`02Ool00`00Ool0000QOol01P00Oomoo`00Ool000=oo`00FWoo00<007ooOol0
7goo00L007ooOomoo`00Ool0000POol00`00Oomoo`03Ool00`00Oomoo`0MOol01`00Oomoogoo001o
o`0001moo`03001oogoo00=oo`03001oogoo01ioo`07001oogooOol007oo00000goo001HOol2000R
Ool01`00Oomoogoo001oo`00021oo`04001oogooOol2000POol01`00Oomoogoo001oo`0001moo`04
001oogooOol2000ROol01P00Oomoo`00Ool000=oo`00F7oo00<007ooOol08Goo00L007ooOomoo`00
Ool0000POol01@00Oomoogoo000087oo00<007oo00000Woo00<007oo00007Woo00<007oo00000Woo
00<007ooOol07goo00<007oo00000Woo00<007oo00000goo001HOol3000POol20004Ool00`00Oomo
o`0NOol20003Ool3000OOol00`00Oomoo`02Ool00`00Oomoo`0NOol01000Oomoogoo0`0087oo00<0
07ooOol00Woo00<007ooOol00Woo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol003EoonX0
005oo`00=Goo0P000goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00@007ooOomoo`80005oo`00=Goo00<007ooOol08Goo00<007ooOol08goo00<007ooOol097oo
00<007ooOol08goo00<007ooOol08goo00<007ooOol097oo00<007ooOol00Woo0@000Goo000eOol0
0`00Oomoo`3POol20004Ool10001Ool003Eoo`03001oogoo0>1oo`8000Aoo`40005oo`00=Goo00<0
07ooOol0f7oo0P0037oo0@000Goo000eOol00`00Oomoo`3AOol20005Ool2000<Ool10001Ool003Eo
o`03001oogoo0=5oo`8001=oo`40005oo`00=Goo00<007ooOol0bGoo0P006goo0@000Goo000eOol0
0`00Oomoo`39Ool2000KOol10001Ool003Eoo`800<9oo`80029oo`80005oo`00=Goo00<007ooOol0
`Goo0P008goo0@000Goo000eOol00`00Oomoo`2jOol2000ZOol10001Ool003Eoo`03001oogoo0;Yo
o`8002Yoo`40005oo`00=Goo00<007ooOol0/Woo0P00<Woo0@000Goo000eOol00`00Oomoo`2bOol2
000bOol10001Ool002Eoo`03001oogoo009oo`04001oogooOol30004Ool00`00Oomoo`2ZOol2000j
Ool10001Ool002Aoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo0:Yoo`8003Yoo`40005o
o`0097oo00<007oo000027oo00<007ooOol00goo0P00iWoo0P000Goo000TOol00`00Ool00008Ool0
0`00Oomoo`03Ool00`00Oomoo`2SOol20011Ool10001Ool002Aoo`03001oo`0000Moo`03001oo`00
00Aoo`03001oogoo0:=oo`80045oo`40005oo`009Goo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol0Vgoo0P00BGoo0@000Goo000eOol00`00Oomoo`2KOol20019Ool10001Ool003Eoo`03001o
ogoo0>Ioo`40005oo`00=Goo00<007ooOol0Tgoo0P00DGoo0@000Goo000EOol00`00Oomoo`02Ool0
0`00Oomoo`0HOol00`00Oomoo`2COol2001AOol10001Ool001Eoo`H001Yoo`800>Ioo`80005oo`00
1Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol067oo00<007ooOol0
S7oo0P00F7oo0@000Goo0005Ool6000:Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`2<
Ool2001HOol10001Ool000Eoo`03001oogoo009oo`03001oogoo00Uoo`@001]oo`03001oogoo0>Io
o`40005oo`00=Goo00<007ooOol0Q7oo0P00H7oo0@000Goo0007Ool01000Oomoo`00:Woo00<007oo
Ool0Q7oo0P00H7oo0@000Goo0007Ool4000ZOol00`00Oomoo`3VOol10001Ool000Moo`03001oogoo
00eoo`04001oogoo000JOol00`00Oomoo`3VOol10001Ool000Moo`03001oogoo00]oo`03001oo`00
00<001Yoo`03001oogoo07aoo`8006Qoo`40005oo`0027oo0`003goo00<007ooOol067oo0P00OGoo
0P00Igoo0P000Goo000:Ool00`00Oomoo`0XOol00`00Oomoo`3VOol10001Ool000Moo`03001oogoo
02]oo`03001oogoo0>Ioo`40005oo`001Woo10003Goo0P0000=oo`00Ool06Goo00<007ooOol0MGoo
0P00Kgoo0@000Goo0007Ool01000Oomoo`0037oo0P0000=oo`00Ool06Goo00<007ooOol0MGoo0P00
Kgoo0@000Goo0007Ool01000Oomoo`0037oo0P0000=oo`00Ool06Goo00<007ooOol0iWoo0@000Goo
0007Ool00`00Ool0000=Ool00`00Ool0000KOol00`00Oomoo`3VOol10001Ool003Eoo`03001oogoo
06eoo`8007Moo`40005oo`00=Goo0P00KWoo0P00MWoo0P000Goo0008Ool2000>Ool2000KOol00`00
Oomoo`3VOol10001Ool000Moo`800003Ool007oo00]oo`04001oogoo000JOol00`00Oomoo`3VOol1
0001Ool000Moo`800003Ool007oo00]oo`04001oogoo000JOol00`00Oomoo`1UOol2001oOol10001
Ool000Qoo`03001oo`0000aoo`04001oogoo000JOol00`00Oomoo`1UOol2001oOol10001Ool003Eo
o`03001oogoo0>Ioo`40005oo`009Goo00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007oo
Ool0iWoo0@000Goo0007Ool01000Oomoo`003Goo0P002Woo00<007oo00002Goo00<007ooOol00Woo
00<007ooOol0iWoo0@000Goo0007Ool4000<Ool01000Oomoo`002Goo00<007oo00001goo10000goo
0P00Ggoo0P00QGoo0P000Goo0007Ool01000Oomoo`0037oo00@007ooOol000Uoo`03001oo`0000Mo
o`03001oo`0000Aoo`03001oogoo05ioo`8008Ioo`40005oo`001goo00@007ooOol000eoo`8000Yo
o`03001oo`0000Qoo`8000Aoo`03001oogoo0>Ioo`40005oo`009Goo00<007ooOol027oo00<007oo
Ool00Woo00<007ooOol0iWoo0@000Goo0007Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`0KOol00`00Oomoo`3VOol10001Ool000Moo`H000Yoo`<001]oo`03001oogoo05Ioo`8008ioo`40
005oo`001goo00H007ooOol007oo000=Ool00`00Oomoo`0HOol00`00Oomoo`1FOol2002>Ool10001
Ool000Moo`04001oogoo000<Ool00`00Ool0000KOol00`00Oomoo`3VOol10001Ool000Qoo`8000eo
o`@001Yoo`800>Ioo`80005oo`006Woo00<007ooOol067oo00<007ooOol0iWoo0@000Goo000GOol0
1000Oomoo`006Woo00<007ooOol0CWoo0P00UWoo0@000Goo0008Ool2000=Ool4000JOol00`00Oomo
o`1>Ool2002FOol10001Ool000Moo`04001oogoo000<Ool00`00Oomoo`0KOol00`00Oomoo`3VOol1
0001Ool000Moo`04001oogoo000<Ool00`00Oomoo`0KOol00`00Oomoo`3VOol10001Ool000Qoo`80
00ioo`<001Yoo`03001oogoo0>Ioo`40005oo`006Woo00<007ooOol067oo00<007ooOol0iWoo0@00
0Goo000GOol00`00Oomoo`0KOol00`00Oomoo`17Ool2002MOol10001Ool000Eoo`03001oogoo009o
o`03001oogoo00Uoo`@001]oo`8004Qoo`8009aoo`80005oo`001Goo1P0037oo00@007ooOol001Yo
o`03001oogoo0>Ioo`40005oo`002Woo00<007ooOol02Woo00@007ooOol001Yoo`03001oogoo0>Io
o`40005oo`005goo00<007oo00006goo00<007ooOol0iWoo0@000Goo000eOol00`00Oomoo`3VOol1
0001Ool003Eoo`03001oogoo03moo`800:Eoo`40005oo`002Goo0P00:Woo00<007ooOol0?goo0P00
YGoo0@000Goo0007Ool01000Ool00000:Woo00<007ooOol0iWoo0@000Goo0007Ool01000Ool00000
:Woo0P00iWoo0P000Goo0007Ool4000ZOol00`00Oomoo`3VOol10001Ool000Yoo`03001oogoo02Qo
o`03001oogoo0>Ioo`40005oo`001goo00<007ooOol0:goo00<007ooOol0iWoo0@000Goo0006Ool4
000;Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`0gOol2002]Ool10001Ool000Moo`04
001oogoo000:Ool6000JOol00`00Oomoo`0gOol2002]Ool10001Ool000Moo`04001oogoo000:Ool0
0`00Ool00002Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo00<007ooOol0
iWoo0@000Goo0007Ool00`00Ool0000;Ool00`00Oomoo`0<Ool00`00Ool00007Ool00`00Ool00004
Ool00`00Oomoo`3VOol10001Ool001Eoo`8000eoo`03001oo`0000Moo`03001oo`0000Aoo`800>Io
o`80005oo`0097oo00<007oo00001goo0P001Goo00<007ooOol0iWoo0@000Goo0008Ool2000?Ool2
0009Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`3VOol10001Ool000Moo`800003Ool0
07oo00]oo`04001oo`00000:Ool00`00Oomoo`07Ool20004Ool00`00Oomoo`0`Ool2002dOol10001
Ool000Moo`800003Ool007oo00]oo`04001oo`00000JOol00`00Oomoo`0`Ool2002dOol10001Ool0
00Qoo`03001oo`0000aoo`@001Yoo`03001oogoo0>Ioo`40005oo`006Woo00<007ooOol067oo00<0
07ooOol0iWoo0@000Goo000eOol00`00Oomoo`3VOol10001Ool000Qoo`8000ioo`8001]oo`800>Io
o`80005oo`001goo00@007ooOol000aoo`04001oogoo000JOol00`00Oomoo`3VOol10001Ool000Eo
o`03001oo`00009oo`03001oogoo00Yoo`04001oogoo000JOol00`00Oomoo`3VOol10001Ool000Eo
o`H000aoo`04001oogoo000JOol00`00Oomoo`0XOol2002lOol10001Ool000Yoo`03001oogoo02Qo
o`03001oogoo02Qoo`800;aoo`40005oo`005goo00<007ooOol06goo00<007ooOol0iWoo0@000Goo
000FOol4000KOol00`00Oomoo`3VOol10001Ool001Moo`04001oogoo000JOol00`00Oomoo`3VOol1
0001Ool001Moo`04001oogoo000JOol00`00Oomoo`3VOol10001Ool001Moo`03001oo`0001]oo`80
0>Ioo`80005oo`00=Goo00<007ooOol0iWoo0@000Goo000eOol00`00Oomoo`3VOol10001Ool001Qo
o`8001]oo`03001oogoo021oo`800<Aoo`40005oo`005goo00@007ooOol001Yoo`03001oogoo021o
o`800<Aoo`40005oo`005goo00@007ooOol001Yoo`03001oogoo0>Ioo`40005oo`0067oo0P006goo
00<007ooOol0iWoo0@000Goo000eOol00`00Oomoo`3VOol10001Ool003Eoo`800>Ioo`80005oo`00
5goo00@007ooOol001Yoo`03001oogoo0>Ioo`40005oo`005goo10006Woo00<007ooOol0iWoo0@00
0Goo000GOol01000Oomoo`006Woo00<007ooOol06Goo0P00bgoo0@000Goo000GOol01000Oomoo`00
6Woo00<007ooOol06Goo0P00bgoo0@000Goo000eOol00`00Oomoo`3VOol10001Ool002Eoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0>Ioo`40005oo`005goo0P0000=o
o`00Ool027oo00<007oo00001goo00<007oo000017oo00<007ooOol0iWoo0@000Goo000GOol20000
0goo001oo`08Ool00`00Ool00007Ool00`00Ool00004Ool2003VOol20001Ool001Moo`800003Ool0
07oo00Qoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo0>Ioo`40005oo`005goo00<007oo
00002Woo00<007oo00001goo00<007oo000017oo00<007ooOol0iWoo0@000Goo000UOol00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`3VOol10001Ool003Eoo`03001oogoo015oo`800==oo`40
005oo`00=Goo00<007ooOol04Goo0P00dgoo0@000Goo000eOol00`00Oomoo`3VOol10001Ool003Eo
o`03001oogoo0>Ioo`40005oo`00=Goo00<007ooOol0iWoo0@000Goo000eOol2003VOol20001Ool0
03Eoo`03001oogoo0>Ioo`40005oo`00=Goo00<007ooOol0iWoo0@000Goo000eOol00`00Oomoo`3V
Ool10001Ool003Eoo`03001oogoo0>Ioo`40005oo`00=Goo00<007ooOol02Goo0P00fgoo0@000Goo
000eOol00`00Oomoo`09Ool2003KOol10001Ool003Eoo`03001oogoo0>Ioo`40005oo`00=Goo0P00
iWoo0P000Goo000eOol00`00Oomoo`3VOol10001Ool003Eoo`03001oogoo0>Ioo`40005oo`00=Goo
00<007ooOol0iWoo0@000Goo000eOol00`00Oomoo`3VOol10001Ool003Eoo`03001oogoo0>Ioo`40
005oo`00=Goo00<007ooOol0iWoo0@000Goo000eOol00`00Oomoo`02Ool2003ROol10001Ool003Eo
o`8000=oo`800>5oo`80005oo`00=Goo00<007ooOol08Goo00<007ooOol08goo00<007ooOol097oo
00<007ooOol08goo00<007ooOol08goo00<007ooOol097oo00<007ooOol00Woo0@000Goo000eOol0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool10001Ool003EoonX0005oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.69487, -0.0866806, 
  0.130587, 0.0060423}}]
}, Open  ]],

Cell["We define a forward rates object. ", "MathCaption",
  CellTags->{"S0.5", "5.11"}],

Cell[CellGroupData[{

Cell["\<\
forward2 = ForwardRates[
                {{1, 0.1434},
                 {1, 0.149809},
                 {1, 0.150204},
                 {2, 0.144553},
                 {2, 0.14685},
                 {3, 0.139283},
                 {20, 0.136459}},
                 InitialDate -> {6, 30, 1982}]\
\>", "Input",
  CellLabel->"In[34]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    RowBox[{"ForwardRates", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", 
                StyleBox["0.143399999999999998`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", 
                StyleBox["0.149808999999999992`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->6]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", 
                StyleBox["0.150204000000000004`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->6]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"2", ",", 
                StyleBox["0.144552999999999975`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->6]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"2", ",", 
                StyleBox["0.146850000000000013`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->5]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                StyleBox["0.139283000000000001`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->6]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"20", ",", 
                StyleBox["0.136458999999999996`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->6]}], "}"}]}], "}"}], ",", 
        \(InitialDate \[Rule] {6, 30, 1982}\)}], "]"}]], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["\<\
This little function computes the sum of the intervals of a forward \
rates object. \
\>", "MathCaption",
  CellTags->{"S0.5", "5.12"}],

Cell["\<\
intervalSum[object_ForwardRates] :=
   Apply[Plus, First[Transpose[First[object]]]]\
\>", "Input",
  CellLabel->"In[35]:=",
  CellTags->"S0.5"],

Cell["\<\
You can use any of our interest rates objects to calculate the \
interpolated discount factors. Here we are using forward rates. \
\>", 
  "MathCaption",
  CellTags->{"S0.5", "5.13"}],

Cell[CellGroupData[{

Cell["\<\
InterpolatedDiscountFactors[forward2,
   Range[intervalSum[forward2]]]\
\>", "Input",
  CellLabel->"In[36]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    \({{1, 0.874584572328144105`}, {2, 0.760634655258520453`}, {3, 
        0.661304129753087721`}, {4, 0.577783754664998383`}, {5, 
        0.504811707858874569`}, {6, 0.440172392081679841`}, {7, 
        0.383809907208161416`}, {8, 0.336887241544165405`}, {9, 
        0.295701104593121577`}, {10, 0.259550177254572922`}, {11, 
        0.228384989915670466`}, {12, 0.200961926400926449`}, {13, 
        0.176831655520284014`}, {14, 0.155598799006637307`}, {15, 
        0.136915453181009905`}, {16, 0.120475488496294125`}, {17, 
        0.106009533556682744`}, {18, 0.0932805614251660308`}, {19, 
        0.082080005900050974`}, {20, 0.0722243441250858886`}, {21, 
        0.0635520895387214856`}, {22, 0.055921145891511701`}, {23, 
        0.0492064789768145693`}, {24, 0.0432980679257364897`}, {25, 
        0.038099102497966486`}, {26, 0.0335243968308284667`}, {27, 
        0.0294989936555814757`}, {28, 0.0259569361108332774`}, {29, 
        0.0228401870290378106`}, {30, 0.0200976779884164891`}}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[TextData[{
  "Of course, you can write a more sophisticated version of ",
  StyleBox["InterpolatedDiscountFactors", "MB"],
  "; this one assumes that interest rates are piecewise constant over time. "
}], "Text",
  CellTags->{"S0.5", "5.14"}],

Cell["Interest Rates Conversions", "Subsection",
  CellTags->{"S0.6", "6.1"}],

Cell[TextData[{
  StyleBox["SpotRates", "MB"],
  ", ",
  StyleBox["ForwardRates", "MB"],
  ", and ",
  StyleBox["DiscountFactors", "MB"],
  " are polymorphic in that they are interest rates objects as well as \
conversion functions. The way that interest rates are related to their \
representation is analogous to how a geometric figure is related to a \
coordinate system. You can define a set of points using one coordinate system \
and then you can describe the points using any other coordinate system. In a \
sense our object becomes independent of its initial representation. This is \
true for any of the interest rates representations. "
}], "Text",
  CellTags->{"S0.6", "6.2"}],

Cell["\<\
Suppose we have defined an interest rates object using spot rates. \
We can now use any of the representations. \
\>", "MathCaption",
  CellTags->{"S0.6", "6.3"}],

Cell["\<\
spot = SpotRates[
                {{1, 14.30 Percent},
                 {2, 14.52 Percent},
                 {3, 14.52 Percent},
                 {5, 14.39 Percent},
                 {7, 14.37 Percent},
                 {10, 14.18 Percent},
                 {30, 13.68 Percent}},
                 InitialDate -> {3, 31, 1982}];\
\>", "Input",
  CellLabel->"In[37]:=",
  CellTags->"S0.6"],

Cell["\<\
Here is the discount factors representation of the object \
originally defined using spot rates. \
\>", "MathCaption",
  CellTags->{"S0.6", "6.4"}],

Cell[CellGroupData[{

Cell["DiscountFactors[spot]", "Input",
  CellLabel->"In[38]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(DiscountFactors[{{1, 0.874890638670166254`}, {2, 
          0.762495563800809872`}, {3, 0.665818690011185765`}, {5, 
          0.510575181065990868`}, {7, 0.390674578480473009`}, {10, 
          0.265521451360236859`}, {30, 0.0213539416866492581`}}, 
      InitialDate \[Rule] {3, 31, 1982}]\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["Here is its forward rates representation. ", "MathCaption",
  CellTags->{"S0.6", "6.5"}],

Cell[CellGroupData[{

Cell["ForwardRates[spot]", "Input",
  CellLabel->"In[39]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(ForwardRates[{{1, 0.143000000000000015`}, {1, 0.147404234470691175`}, {
          1, 0.145199999999999995`}, {2, 0.141952766460357704`}, {2, 
          0.143200152972027039`}, {3, 0.137378932579746759`}, {20, 
          0.13430821672230464`}}, InitialDate \[Rule] {3, 31, 1982}]\)], 
  "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "Of course, the spot rates representation of ",
  StyleBox["spot", "MB"],
  " is the one we started with. "
}], "MathCaption",
  CellTags->{"S0.6", "6.6"}],

Cell[CellGroupData[{

Cell["SpotRates[spot]", "Input",
  CellLabel->"In[40]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(SpotRates[{{1, 0.143000000000000015`}, {2, 0.145199999999999995`}, {3, 
          0.145199999999999995`}, {5, 0.143900000000000005`}, {7, 
          0.143699999999999983`}, {10, 0.141800000000000014`}, {30, 
          0.13680000000000001`}}, InitialDate \[Rule] {3, 31, 1982}]\)], 
  "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["The \"round trip\" does not change the original object. ", "MathCaption",
  CellTags->{"S0.6", "6.7"}],

Cell[CellGroupData[{

Cell["SpotRates[ForwardRates[DiscountFactors[spot]]] == spot", "Input",
  CellLabel->"In[41]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell["We can also work with symbols. ", "MathCaption",
  CellTags->{"S0.6", "6.8"}],

Cell[CellGroupData[{

Cell["SpotRates[ForwardRates[{f1, f2, f3, f4}]]", "Input",
  CellLabel->"In[42]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(SpotRates[{f1, \(-1\) + \@\(\((1 + f1)\)\ \((1 + f2)\)\), 
        \(-1\) + \((\((1 + f1)\)\ \((1 + f2)\)\ \((1 + f3)\))\)\^\(1/3\), 
        \(-1\) + 
          \((\((1 + f1)\)\ \((1 + f2)\)\ \((1 + f3)\)\ \((1 + f4)\))\)\^\(1/4
              \)}]\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell["Simple Representation of Interest Rates", "Subsection",
  CellTags->{"S0.7", "7.1"}],

Cell["\<\
The representation of interest rates can be simplified if the time \
intervals are 1, 2, 3, 4 ... in some given unit. We no longer need a list of \
pairs because the first element of each pair is simply the position of the \
pair in the list. It is enough to know just the list of actual interest \
rates. Our package supports this representation. \
\>", "Text",
  CellTags->{"S0.7", "7.2"}],

Cell["This is the simple representation of a spot rates object. ", 
  "MathCaption",
  CellTags->{"S0.7", "7.3"}],

Cell[CellGroupData[{

Cell["\<\
spot0 = SpotRates[
                {0.08927,
                 0.08743,
                 0.08886,
                 0.08701,
                 0.08726,
                 0.09137,
                 0.09386,
                 0.08997,
                 0.08967,
                 0.09152}]\
\>", "Input",
  CellLabel->"In[43]:=",
  CellTags->"S0.7"],

Cell[BoxData[
    RowBox[{"SpotRates", "[", 
      RowBox[{"{", 
        RowBox[{
          StyleBox["0.089269999999999996`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0874300000000000032`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0888599999999999923`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0870100000000000051`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0872600000000000086`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0913700000000000045`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0938599999999999923`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0899699999999999988`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0896700000000000052`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], ",", 
          StyleBox["0.0915200000000000102`",
            StyleBoxAutoDelete->True,
            PrintPrecision->4]}], "}"}], "]"}]], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "This converts ",
  StyleBox["spot0", "MB"],
  " to the equivalent ",
  StyleBox["discount0", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.7", "7.4"}],

Cell[CellGroupData[{

Cell["discount0 = DiscountFactors[spot0]", "Input",
  CellLabel->"In[44]:=",
  CellTags->"S0.7"],

Cell[BoxData[
    \(DiscountFactors[{0.918046030827985681`, 0.845663097846815858`, 
        0.774611371035727103`, 0.716251991205060178`, 0.658162215549005757`, 
        0.5917904202832033`, 0.533663880520076361`, 0.501976796027217808`, 
        0.461684240827611258`, 0.416565235211537743`}]\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[TextData[{
  "This converts ",
  StyleBox["spot0", "MB"],
  " to the equivalent ",
  StyleBox["forward0", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.7", "7.5"}],

Cell[CellGroupData[{

Cell["forward0 = ForwardRates[spot0]", "Input",
  CellLabel->"In[45]:=",
  CellTags->"S0.7"],

Cell[BoxData[
    \(ForwardRates[{0.0892699999999999604`, 0.0855931081366416712`, 
        0.0917256439394711264`, 0.0814788378214208464`, 
        0.0882605751039637809`, 0.112154223845057243`, 0.108919756207746631`, 
        0.063124600068447334`, 0.0872729706506294533`, 0.108311980458863699`}]
      \)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell["Again the \"round trip\" does not change the original object. ", 
  "MathCaption",
  CellTags->{"S0.7", "7.6"}],

Cell[CellGroupData[{

Cell["SpotRates[ForwardRates[DiscountFactors[spot0]]] == spot0", "Input",
  CellLabel->"In[46]:=",
  CellTags->"S0.7"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell["All the representations are equivalent. ", "MathCaption",
  CellTags->{"S0.7", "7.7"}],

Cell[CellGroupData[{

Cell["forward0 == ForwardRates[discount0]", "Input",
  CellLabel->"In[47]:=",
  CellTags->"S0.7"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["spot0 == SpotRates[forward0]", "Input",
  CellLabel->"In[48]:=",
  CellTags->"S0.7"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell["\<\
The time intervals for a discount rates object do not necessarily \
have to be uniform. For example, to calculate the present value, it is only \
required that time intervals for discount factors match those of the \
corresponding cash flows. However, converting from one simple representation \
to another will cause errors. \
\>", "Text",
  CellTags->{"S0.7", "7.8"}]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{500, 350},
WindowMargins->{{-2, Automatic}, {Automatic, -2}},
StyleDefinitions -> "ApplicationManual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "0.1"->{
    Cell[1717, 49, 52, 1, 72, "Section",
      CellTags->"0.1"]},
  "S0.1"->{
    Cell[1772, 52, 61, 1, 56, "Subsection",
      CellTags->{"S0.1", "1.1"}],
    Cell[1836, 55, 651, 11, 158, "Text",
      CellTags->{"S0.1", "1.2"}],
    Cell[2490, 68, 224, 7, 50, "MathCaption",
      CellTags->{"S0.1", "1.3"}],
    Cell[2717, 77, 86, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[4922, 158, 71, 1, 16, "Caption",
      CellTags->"S0.1"],
    Cell[4996, 161, 288, 10, 53, "Text",
      CellTags->{"S0.1", "1.5"}],
    Cell[5287, 173, 232, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.6"}],
    Cell[5544, 182, 162, 5, 48, "Input",
      CellTags->"S0.1"],
    Cell[5812, 194, 132, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.7"}],
    Cell[5969, 202, 145, 5, 48, "Input",
      CellTags->"S0.1"],
    Cell[6208, 214, 144, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.8"}],
    Cell[6355, 220, 157, 5, 48, "Input",
      CellTags->"S0.1"],
    Cell[7591, 264, 151, 7, 16, "Caption",
      CellTags->"S0.1"],
    Cell[7745, 273, 236, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.10"}],
    Cell[8006, 282, 92, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[8371, 297, 93, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[8716, 310, 207, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.11"}],
    Cell[8948, 319, 152, 5, 48, "Input",
      CellTags->"S0.1"],
    Cell[9206, 331, 242, 8, 49, "MathCaption",
      CellTags->{"S0.1", "1.12"}],
    Cell[9473, 343, 170, 5, 48, "Input",
      CellTags->"S0.1"],
    Cell[9749, 355, 119, 2, 31, "MathCaption",
      CellTags->{"S0.1", "1.13"}],
    Cell[9893, 361, 91, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[10257, 375, 816, 22, 96, "Text",
      CellTags->{"S0.1", "1.14"}],
    Cell[11076, 399, 172, 4, 48, "MathCaption",
      CellTags->{"S0.1", "1.15"}],
    Cell[11273, 407, 106, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[11498, 416, 88, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.16"}],
    Cell[11611, 421, 66, 2, 30, "Input",
      CellTags->"S0.1"],
    Cell[11782, 430, 243, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.17"}],
    Cell[12050, 439, 111, 2, 30, "Input",
      CellTags->"S0.1"]},
  "1.1"->{
    Cell[1772, 52, 61, 1, 56, "Subsection",
      CellTags->{"S0.1", "1.1"}]},
  "1.2"->{
    Cell[1836, 55, 651, 11, 158, "Text",
      CellTags->{"S0.1", "1.2"}]},
  "1.3"->{
    Cell[2490, 68, 224, 7, 50, "MathCaption",
      CellTags->{"S0.1", "1.3"}]},
  "1.5"->{
    Cell[4996, 161, 288, 10, 53, "Text",
      CellTags->{"S0.1", "1.5"}]},
  "1.6"->{
    Cell[5287, 173, 232, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.6"}]},
  "1.7"->{
    Cell[5812, 194, 132, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.7"}]},
  "1.8"->{
    Cell[6208, 214, 144, 4, 31, "MathCaption",
      CellTags->{"S0.1", "1.8"}]},
  "1.10"->{
    Cell[7745, 273, 236, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.10"}]},
  "1.11"->{
    Cell[8716, 310, 207, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.11"}]},
  "1.12"->{
    Cell[9206, 331, 242, 8, 49, "MathCaption",
      CellTags->{"S0.1", "1.12"}]},
  "1.13"->{
    Cell[9749, 355, 119, 2, 31, "MathCaption",
      CellTags->{"S0.1", "1.13"}]},
  "1.14"->{
    Cell[10257, 375, 816, 22, 96, "Text",
      CellTags->{"S0.1", "1.14"}]},
  "1.15"->{
    Cell[11076, 399, 172, 4, 48, "MathCaption",
      CellTags->{"S0.1", "1.15"}]},
  "1.16"->{
    Cell[11498, 416, 88, 1, 31, "MathCaption",
      CellTags->{"S0.1", "1.16"}]},
  "1.17"->{
    Cell[11782, 430, 243, 5, 48, "MathCaption",
      CellTags->{"S0.1", "1.17"}]},
  "S0.2"->{
    Cell[12265, 448, 83, 1, 56, "Subsection",
      CellTags->{"S0.2", "2.1"}],
    Cell[12351, 451, 347, 7, 71, "Text",
      CellTags->{"S0.2", "2.2"}],
    Cell[17719, 629, 63, 1, 16, "Caption",
      CellTags->"S0.2"],
    Cell[18756, 664, 204, 9, 16, "Caption",
      CellTags->"S0.2"],
    Cell[18963, 675, 538, 9, 109, "Text",
      CellTags->{"S0.2", "2.5"}]},
  "2.1"->{
    Cell[12265, 448, 83, 1, 56, "Subsection",
      CellTags->{"S0.2", "2.1"}]},
  "2.2"->{
    Cell[12351, 451, 347, 7, 71, "Text",
      CellTags->{"S0.2", "2.2"}]},
  "2.5"->{
    Cell[18963, 675, 538, 9, 109, "Text",
      CellTags->{"S0.2", "2.5"}]},
  "S0.3"->{
    Cell[19504, 686, 61, 1, 56, "Subsection",
      CellTags->{"S0.3", "3.1"}],
    Cell[19568, 689, 485, 8, 90, "Text",
      CellTags->{"S0.3", "3.2"}],
    Cell[20056, 699, 306, 8, 67, "MathCaption",
      CellTags->{"S0.3", "3.3"}],
    Cell[20365, 709, 344, 11, 156, "Input",
      CellTags->"S0.3"],
    Cell[20712, 722, 141, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.4"}],
    Cell[20878, 731, 99, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[35127, 1303, 241, 6, 49, "MathCaption",
      CellTags->{"S0.3", "3.5"}],
    Cell[35393, 1313, 205, 10, 138, "Input",
      CellTags->"S0.3"],
    Cell[36994, 1366, 158, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.6"}],
    Cell[37177, 1375, 352, 12, 174, "Input",
      CellTags->"S0.3"],
    Cell[39181, 1433, 218, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.7"}],
    Cell[39402, 1440, 480, 12, 174, "Input",
      CellTags->"S0.3"],
    Cell[39885, 1454, 100, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.8"}],
    Cell[39988, 1457, 344, 11, 156, "Input",
      CellTags->"S0.3"],
    Cell[40335, 1470, 148, 4, 31, "MathCaption",
      CellTags->{"S0.3", "3.9"}],
    Cell[40508, 1478, 97, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[40709, 1487, 159, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.10"}],
    Cell[40893, 1496, 73, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[41052, 1505, 84, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.11"}],
    Cell[41161, 1510, 74, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[41328, 1519, 89, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.12"}],
    Cell[41442, 1524, 76, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[41630, 1533, 242, 9, 32, "MathCaption",
      CellTags->{"S0.3", "3.13"}],
    Cell[41875, 1544, 90, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[41968, 1548, 89, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.14"}],
    Cell[42082, 1553, 69, 2, 30, "Input",
      CellTags->"S0.3"],
    Cell[43813, 1601, 201, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.15"}],
    Cell[44017, 1608, 175, 5, 48, "Input",
      CellTags->"S0.3"],
    Cell[44195, 1615, 227, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.16"}],
    Cell[44447, 1624, 194, 6, 66, "Input",
      CellTags->"S0.3"]},
  "3.1"->{
    Cell[19504, 686, 61, 1, 56, "Subsection",
      CellTags->{"S0.3", "3.1"}]},
  "3.2"->{
    Cell[19568, 689, 485, 8, 90, "Text",
      CellTags->{"S0.3", "3.2"}]},
  "3.3"->{
    Cell[20056, 699, 306, 8, 67, "MathCaption",
      CellTags->{"S0.3", "3.3"}]},
  "3.4"->{
    Cell[20712, 722, 141, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.4"}]},
  "3.5"->{
    Cell[35127, 1303, 241, 6, 49, "MathCaption",
      CellTags->{"S0.3", "3.5"}]},
  "3.6"->{
    Cell[36994, 1366, 158, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.6"}]},
  "3.7"->{
    Cell[39181, 1433, 218, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.7"}]},
  "3.8"->{
    Cell[39885, 1454, 100, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.8"}]},
  "3.9"->{
    Cell[40335, 1470, 148, 4, 31, "MathCaption",
      CellTags->{"S0.3", "3.9"}]},
  "3.10"->{
    Cell[40709, 1487, 159, 5, 32, "MathCaption",
      CellTags->{"S0.3", "3.10"}]},
  "3.11"->{
    Cell[41052, 1505, 84, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.11"}]},
  "3.12"->{
    Cell[41328, 1519, 89, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.12"}]},
  "3.13"->{
    Cell[41630, 1533, 242, 9, 32, "MathCaption",
      CellTags->{"S0.3", "3.13"}]},
  "3.14"->{
    Cell[41968, 1548, 89, 1, 31, "MathCaption",
      CellTags->{"S0.3", "3.14"}]},
  "3.15"->{
    Cell[43813, 1601, 201, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.15"}]},
  "3.16"->{
    Cell[44195, 1615, 227, 5, 48, "MathCaption",
      CellTags->{"S0.3", "3.16"}]},
  "S0.4"->{
    Cell[64034, 2336, 64, 1, 56, "Subsection",
      CellTags->{"S0.4", "4.1"}],
    Cell[64101, 2339, 449, 8, 90, "Text",
      CellTags->{"S0.4", "4.2"}],
    Cell[64553, 2349, 91, 1, 31, "MathCaption",
      CellTags->{"S0.4", "4.3"}],
    Cell[64647, 2352, 366, 12, 174, "Input",
      CellTags->"S0.4"]},
  "4.1"->{
    Cell[64034, 2336, 64, 1, 56, "Subsection",
      CellTags->{"S0.4", "4.1"}]},
  "4.2"->{
    Cell[64101, 2339, 449, 8, 90, "Text",
      CellTags->{"S0.4", "4.2"}]},
  "4.3"->{
    Cell[64553, 2349, 91, 1, 31, "MathCaption",
      CellTags->{"S0.4", "4.3"}]},
  "S0.5"->{
    Cell[65016, 2366, 67, 1, 56, "Subsection",
      CellTags->{"S0.5", "5.1"}],
    Cell[65086, 2369, 451, 8, 90, "Text",
      CellTags->{"S0.5", "5.2"}],
    Cell[65540, 2379, 92, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.3"}],
    Cell[65635, 2382, 372, 12, 174, "Input",
      CellTags->"S0.5"],
    Cell[66010, 2396, 99, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.4"}],
    Cell[66134, 2401, 148, 5, 48, "Input",
      CellTags->"S0.5"],
    Cell[82835, 2999, 202, 5, 52, "Text",
      CellTags->{"S0.5", "5.5"}],
    Cell[83813, 3033, 115, 4, 16, "Caption",
      CellTags->"S0.5"],
    Cell[83931, 3039, 131, 4, 31, "MathCaption",
      CellTags->{"S0.5", "5.7"}],
    Cell[84087, 3047, 108, 2, 30, "Input",
      CellTags->"S0.5"],
    Cell[84327, 3056, 158, 5, 32, "MathCaption",
      CellTags->{"S0.5", "5.8"}],
    Cell[84510, 3065, 93, 2, 30, "Input",
      CellTags->"S0.5"],
    Cell[84682, 3074, 173, 4, 48, "MathCaption",
      CellTags->{"S0.5", "5.9"}],
    Cell[84880, 3082, 159, 6, 66, "Input",
      CellTags->"S0.5"],
    Cell[86762, 3128, 109, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.10"}],
    Cell[86896, 3133, 169, 6, 66, "Input",
      CellTags->"S0.5"],
    Cell[104764, 3765, 87, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.11"}],
    Cell[104876, 3770, 364, 12, 174, "Input",
      CellTags->"S0.5"],
    Cell[106905, 3828, 145, 4, 31, "MathCaption",
      CellTags->{"S0.5", "5.12"}],
    Cell[107053, 3834, 153, 5, 48, "Input",
      CellTags->"S0.5"],
    Cell[107209, 3841, 193, 5, 48, "MathCaption",
      CellTags->{"S0.5", "5.13"}],
    Cell[107427, 3850, 140, 5, 48, "Input",
      CellTags->"S0.5"],
    Cell[108641, 3876, 247, 5, 53, "Text",
      CellTags->{"S0.5", "5.14"}]},
  "5.1"->{
    Cell[65016, 2366, 67, 1, 56, "Subsection",
      CellTags->{"S0.5", "5.1"}]},
  "5.2"->{
    Cell[65086, 2369, 451, 8, 90, "Text",
      CellTags->{"S0.5", "5.2"}]},
  "5.3"->{
    Cell[65540, 2379, 92, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.3"}]},
  "5.4"->{
    Cell[66010, 2396, 99, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.4"}]},
  "5.5"->{
    Cell[82835, 2999, 202, 5, 52, "Text",
      CellTags->{"S0.5", "5.5"}]},
  "5.7"->{
    Cell[83931, 3039, 131, 4, 31, "MathCaption",
      CellTags->{"S0.5", "5.7"}]},
  "5.8"->{
    Cell[84327, 3056, 158, 5, 32, "MathCaption",
      CellTags->{"S0.5", "5.8"}]},
  "5.9"->{
    Cell[84682, 3074, 173, 4, 48, "MathCaption",
      CellTags->{"S0.5", "5.9"}]},
  "5.10"->{
    Cell[86762, 3128, 109, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.10"}]},
  "5.11"->{
    Cell[104764, 3765, 87, 1, 31, "MathCaption",
      CellTags->{"S0.5", "5.11"}]},
  "5.12"->{
    Cell[106905, 3828, 145, 4, 31, "MathCaption",
      CellTags->{"S0.5", "5.12"}]},
  "5.13"->{
    Cell[107209, 3841, 193, 5, 48, "MathCaption",
      CellTags->{"S0.5", "5.13"}]},
  "5.14"->{
    Cell[108641, 3876, 247, 5, 53, "Text",
      CellTags->{"S0.5", "5.14"}]},
  "S0.6"->{
    Cell[108891, 3883, 77, 1, 56, "Subsection",
      CellTags->{"S0.6", "6.1"}],
    Cell[108971, 3886, 687, 14, 129, "Text",
      CellTags->{"S0.6", "6.2"}],
    Cell[109661, 3902, 172, 4, 48, "MathCaption",
      CellTags->{"S0.6", "6.3"}],
    Cell[109836, 3908, 397, 12, 174, "Input",
      CellTags->"S0.6"],
    Cell[110236, 3922, 157, 4, 31, "MathCaption",
      CellTags->{"S0.6", "6.4"}],
    Cell[110418, 3930, 83, 2, 30, "Input",
      CellTags->"S0.6"],
    Cell[110869, 3943, 94, 1, 31, "MathCaption",
      CellTags->{"S0.6", "6.5"}],
    Cell[110988, 3948, 80, 2, 30, "Input",
      CellTags->"S0.6"],
    Cell[111426, 3961, 173, 5, 32, "MathCaption",
      CellTags->{"S0.6", "6.6"}],
    Cell[111624, 3970, 77, 2, 30, "Input",
      CellTags->"S0.6"],
    Cell[112057, 3983, 108, 1, 31, "MathCaption",
      CellTags->{"S0.6", "6.7"}],
    Cell[112190, 3988, 116, 2, 30, "Input",
      CellTags->"S0.6"],
    Cell[112387, 3997, 83, 1, 31, "MathCaption",
      CellTags->{"S0.6", "6.8"}],
    Cell[112495, 4002, 103, 2, 30, "Input",
      CellTags->"S0.6"]},
  "6.1"->{
    Cell[108891, 3883, 77, 1, 56, "Subsection",
      CellTags->{"S0.6", "6.1"}]},
  "6.2"->{
    Cell[108971, 3886, 687, 14, 129, "Text",
      CellTags->{"S0.6", "6.2"}]},
  "6.3"->{
    Cell[109661, 3902, 172, 4, 48, "MathCaption",
      CellTags->{"S0.6", "6.3"}]},
  "6.4"->{
    Cell[110236, 3922, 157, 4, 31, "MathCaption",
      CellTags->{"S0.6", "6.4"}]},
  "6.5"->{
    Cell[110869, 3943, 94, 1, 31, "MathCaption",
      CellTags->{"S0.6", "6.5"}]},
  "6.6"->{
    Cell[111426, 3961, 173, 5, 32, "MathCaption",
      CellTags->{"S0.6", "6.6"}]},
  "6.7"->{
    Cell[112057, 3983, 108, 1, 31, "MathCaption",
      CellTags->{"S0.6", "6.7"}]},
  "6.8"->{
    Cell[112387, 3997, 83, 1, 31, "MathCaption",
      CellTags->{"S0.6", "6.8"}]},
  "S0.7"->{
    Cell[112923, 4015, 90, 1, 56, "Subsection",
      CellTags->{"S0.7", "7.1"}],
    Cell[113016, 4018, 401, 7, 90, "Text",
      CellTags->{"S0.7", "7.2"}],
    Cell[113420, 4027, 113, 2, 31, "MathCaption",
      CellTags->{"S0.7", "7.3"}],
    Cell[113558, 4033, 349, 14, 210, "Input",
      CellTags->"S0.7"],
    Cell[115261, 4086, 173, 7, 32, "MathCaption",
      CellTags->{"S0.7", "7.4"}],
    Cell[115459, 4097, 96, 2, 30, "Input",
      CellTags->"S0.7"],
    Cell[115904, 4109, 172, 7, 32, "MathCaption",
      CellTags->{"S0.7", "7.5"}],
    Cell[116101, 4120, 92, 2, 30, "Input",
      CellTags->"S0.7"],
    Cell[116554, 4133, 117, 2, 31, "MathCaption",
      CellTags->{"S0.7", "7.6"}],
    Cell[116696, 4139, 118, 2, 30, "Input",
      CellTags->"S0.7"],
    Cell[116895, 4148, 92, 1, 31, "MathCaption",
      CellTags->{"S0.7", "7.7"}],
    Cell[117012, 4153, 97, 2, 30, "Input",
      CellTags->"S0.7"],
    Cell[117212, 4164, 90, 2, 30, "Input",
      CellTags->"S0.7"],
    Cell[117383, 4173, 379, 7, 90, "Text",
      CellTags->{"S0.7", "7.8"}]},
  "7.1"->{
    Cell[112923, 4015, 90, 1, 56, "Subsection",
      CellTags->{"S0.7", "7.1"}]},
  "7.2"->{
    Cell[113016, 4018, 401, 7, 90, "Text",
      CellTags->{"S0.7", "7.2"}]},
  "7.3"->{
    Cell[113420, 4027, 113, 2, 31, "MathCaption",
      CellTags->{"S0.7", "7.3"}]},
  "7.4"->{
    Cell[115261, 4086, 173, 7, 32, "MathCaption",
      CellTags->{"S0.7", "7.4"}]},
  "7.5"->{
    Cell[115904, 4109, 172, 7, 32, "MathCaption",
      CellTags->{"S0.7", "7.5"}]},
  "7.6"->{
    Cell[116554, 4133, 117, 2, 31, "MathCaption",
      CellTags->{"S0.7", "7.6"}]},
  "7.7"->{
    Cell[116895, 4148, 92, 1, 31, "MathCaption",
      CellTags->{"S0.7", "7.7"}]},
  "7.8"->{
    Cell[117383, 4173, 379, 7, 90, "Text",
      CellTags->{"S0.7", "7.8"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"0.1", 118431, 4200},
  {"S0.1", 118509, 4203},
  {"1.1", 120649, 4262},
  {"1.2", 120739, 4265},
  {"1.3", 120826, 4268},
  {"1.5", 120918, 4271},
  {"1.6", 121005, 4274},
  {"1.7", 121098, 4277},
  {"1.8", 121191, 4280},
  {"1.10", 121285, 4283},
  {"1.11", 121380, 4286},
  {"1.12", 121475, 4289},
  {"1.13", 121570, 4292},
  {"1.14", 121665, 4295},
  {"1.15", 121755, 4298},
  {"1.16", 121851, 4301},
  {"1.17", 121946, 4304},
  {"S0.2", 122042, 4307},
  {"2.1", 122422, 4318},
  {"2.2", 122514, 4321},
  {"2.5", 122601, 4324},
  {"S0.3", 122690, 4327},
  {"3.1", 124974, 4388},
  {"3.2", 125066, 4391},
  {"3.3", 125153, 4394},
  {"3.4", 125247, 4397},
  {"3.5", 125341, 4400},
  {"3.6", 125436, 4403},
  {"3.7", 125531, 4406},
  {"3.8", 125626, 4409},
  {"3.9", 125721, 4412},
  {"3.10", 125817, 4415},
  {"3.11", 125914, 4418},
  {"3.12", 126010, 4421},
  {"3.13", 126106, 4424},
  {"3.14", 126203, 4427},
  {"3.15", 126299, 4430},
  {"3.16", 126396, 4433},
  {"S0.4", 126493, 4436},
  {"4.1", 126814, 4445},
  {"4.2", 126907, 4448},
  {"4.3", 126995, 4451},
  {"S0.5", 127090, 4454},
  {"5.1", 128852, 4501},
  {"5.2", 128945, 4504},
  {"5.3", 129033, 4507},
  {"5.4", 129127, 4510},
  {"5.5", 129221, 4513},
  {"5.7", 129309, 4516},
  {"5.8", 129404, 4519},
  {"5.9", 129499, 4522},
  {"5.10", 129595, 4525},
  {"5.11", 129692, 4528},
  {"5.12", 129789, 4531},
  {"5.13", 129887, 4534},
  {"5.14", 129985, 4537},
  {"S0.6", 130076, 4540},
  {"6.1", 131164, 4569},
  {"6.2", 131258, 4572},
  {"6.3", 131349, 4575},
  {"6.4", 131445, 4578},
  {"6.5", 131541, 4581},
  {"6.6", 131636, 4584},
  {"6.7", 131732, 4587},
  {"6.8", 131828, 4590},
  {"S0.7", 131924, 4593},
  {"7.1", 133003, 4622},
  {"7.2", 133097, 4625},
  {"7.3", 133186, 4628},
  {"7.4", 133282, 4631},
  {"7.5", 133378, 4634},
  {"7.6", 133474, 4637},
  {"7.7", 133570, 4640},
  {"7.8", 133665, 4643}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 52, 1, 72, "Section",
  CellTags->"0.1"],
Cell[1772, 52, 61, 1, 56, "Subsection",
  CellTags->{"S0.1", "1.1"}],
Cell[1836, 55, 651, 11, 158, "Text",
  CellTags->{"S0.1", "1.2"}],
Cell[2490, 68, 224, 7, 50, "MathCaption",
  CellTags->{"S0.1", "1.3"}],
Cell[2717, 77, 86, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[2806, 81, 481, 16, 41, InheritFromParent],
Cell[3290, 99, 188, 5, 26, InheritFromParent],
Cell[3481, 106, 484, 16, 33, InheritFromParent],
Cell[3968, 124, 187, 5, 26, InheritFromParent],
Cell[4158, 131, 436, 14, 33, InheritFromParent],
Cell[4597, 147, 322, 9, 46, InheritFromParent],
Cell[4922, 158, 71, 1, 16, "Caption",
  CellTags->"S0.1"],
Cell[4996, 161, 288, 10, 53, "Text",
  CellTags->{"S0.1", "1.5"}],
Cell[5287, 173, 232, 5, 48, "MathCaption",
  CellTags->{"S0.1", "1.6"}],

Cell[CellGroupData[{
Cell[5544, 182, 162, 5, 48, "Input",
  CellTags->"S0.1"],
Cell[5709, 189, 88, 2, 29, "Output"]
}, Open  ]],
Cell[5812, 194, 132, 4, 31, "MathCaption",
  CellTags->{"S0.1", "1.7"}],

Cell[CellGroupData[{
Cell[5969, 202, 145, 5, 48, "Input",
  CellTags->"S0.1"],
Cell[6117, 209, 76, 2, 29, "Output"]
}, Open  ]],
Cell[6208, 214, 144, 4, 31, "MathCaption",
  CellTags->{"S0.1", "1.8"}],
Cell[6355, 220, 157, 5, 48, "Input",
  CellTags->"S0.1"],
Cell[6515, 227, 88, 2, 29, "Output"],
Cell[6606, 231, 982, 31, 61, "DefinitionBox"],
Cell[7591, 264, 151, 7, 16, "Caption",
  CellTags->"S0.1"],
Cell[7745, 273, 236, 5, 48, "MathCaption",
  CellTags->{"S0.1", "1.10"}],

Cell[CellGroupData[{
Cell[8006, 282, 92, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[8101, 286, 233, 6, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8371, 297, 93, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[8467, 301, 234, 6, 43, "Output"]
}, Open  ]],
Cell[8716, 310, 207, 5, 48, "MathCaption",
  CellTags->{"S0.1", "1.11"}],

Cell[CellGroupData[{
Cell[8948, 319, 152, 5, 48, "Input",
  CellTags->"S0.1"],
Cell[9103, 326, 88, 2, 29, "Output"]
}, Open  ]],
Cell[9206, 331, 242, 8, 49, "MathCaption",
  CellTags->{"S0.1", "1.12"}],

Cell[CellGroupData[{
Cell[9473, 343, 170, 5, 48, "Input",
  CellTags->"S0.1"],
Cell[9646, 350, 88, 2, 29, "Output"]
}, Open  ]],
Cell[9749, 355, 119, 2, 31, "MathCaption",
  CellTags->{"S0.1", "1.13"}],

Cell[CellGroupData[{
Cell[9893, 361, 91, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[9987, 365, 255, 7, 29, "Output"]
}, Open  ]],
Cell[10257, 375, 816, 22, 96, "Text",
  CellTags->{"S0.1", "1.14"}],
Cell[11076, 399, 172, 4, 48, "MathCaption",
  CellTags->{"S0.1", "1.15"}],

Cell[CellGroupData[{
Cell[11273, 407, 106, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[11382, 411, 101, 2, 86, "Output"]
}, Open  ]],
Cell[11498, 416, 88, 1, 31, "MathCaption",
  CellTags->{"S0.1", "1.16"}],

Cell[CellGroupData[{
Cell[11611, 421, 66, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[11680, 425, 87, 2, 42, "Output"]
}, Open  ]],
Cell[11782, 430, 243, 5, 48, "MathCaption",
  CellTags->{"S0.1", "1.17"}],

Cell[CellGroupData[{
Cell[12050, 439, 111, 2, 30, "Input",
  CellTags->"S0.1"],
Cell[12164, 443, 86, 2, 42, "Output"]
}, Open  ]],
Cell[12265, 448, 83, 1, 56, "Subsection",
  CellTags->{"S0.2", "2.1"}],
Cell[12351, 451, 347, 7, 71, "Text",
  CellTags->{"S0.2", "2.2"}],
Cell[12701, 460, 1465, 46, 41, InheritFromParent],
Cell[14169, 508, 225, 7, 26, InheritFromParent],
Cell[14397, 517, 1407, 44, 33, InheritFromParent],
Cell[15807, 563, 245, 8, 26, InheritFromParent],
Cell[16055, 573, 1410, 44, 33, InheritFromParent],
Cell[17468, 619, 248, 8, 26, InheritFromParent],
Cell[17719, 629, 63, 1, 16, "Caption",
  CellTags->"S0.2"],
Cell[17785, 632, 968, 30, 61, "DefinitionBox"],
Cell[18756, 664, 204, 9, 16, "Caption",
  CellTags->"S0.2"],
Cell[18963, 675, 538, 9, 109, "Text",
  CellTags->{"S0.2", "2.5"}],
Cell[19504, 686, 61, 1, 56, "Subsection",
  CellTags->{"S0.3", "3.1"}],
Cell[19568, 689, 485, 8, 90, "Text",
  CellTags->{"S0.3", "3.2"}],
Cell[20056, 699, 306, 8, 67, "MathCaption",
  CellTags->{"S0.3", "3.3"}],
Cell[20365, 709, 344, 11, 156, "Input",
  CellTags->"S0.3"],
Cell[20712, 722, 141, 5, 32, "MathCaption",
  CellTags->{"S0.3", "3.4"}],

Cell[CellGroupData[{
Cell[20878, 731, 99, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[20980, 735, 14132, 565, 186, 5334, 451, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]],
Cell[35127, 1303, 241, 6, 49, "MathCaption",
  CellTags->{"S0.3", "3.5"}],

Cell[CellGroupData[{
Cell[35393, 1313, 205, 10, 138, "Input",
  CellTags->"S0.3"],
Cell[35601, 1325, 1378, 38, 48, "Output"]
}, Open  ]],
Cell[36994, 1366, 158, 5, 32, "MathCaption",
  CellTags->{"S0.3", "3.6"}],

Cell[CellGroupData[{
Cell[37177, 1375, 352, 12, 174, "Input",
  CellTags->"S0.3"],
Cell[37532, 1389, 1634, 41, 67, "Output"]
}, Open  ]],
Cell[39181, 1433, 218, 5, 48, "MathCaption",
  CellTags->{"S0.3", "3.7"}],
Cell[39402, 1440, 480, 12, 174, "Input",
  CellTags->"S0.3"],
Cell[39885, 1454, 100, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.8"}],
Cell[39988, 1457, 344, 11, 156, "Input",
  CellTags->"S0.3"],
Cell[40335, 1470, 148, 4, 31, "MathCaption",
  CellTags->{"S0.3", "3.9"}],

Cell[CellGroupData[{
Cell[40508, 1478, 97, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[40608, 1482, 86, 2, 29, "Output"]
}, Open  ]],
Cell[40709, 1487, 159, 5, 32, "MathCaption",
  CellTags->{"S0.3", "3.10"}],

Cell[CellGroupData[{
Cell[40893, 1496, 73, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[40969, 1500, 68, 2, 29, "Output"]
}, Open  ]],
Cell[41052, 1505, 84, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.11"}],

Cell[CellGroupData[{
Cell[41161, 1510, 74, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[41238, 1514, 75, 2, 29, "Output"]
}, Open  ]],
Cell[41328, 1519, 89, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.12"}],

Cell[CellGroupData[{
Cell[41442, 1524, 76, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[41521, 1528, 94, 2, 29, "Output"]
}, Open  ]],
Cell[41630, 1533, 242, 9, 32, "MathCaption",
  CellTags->{"S0.3", "3.13"}],
Cell[41875, 1544, 90, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[41968, 1548, 89, 1, 31, "MathCaption",
  CellTags->{"S0.3", "3.14"}],

Cell[CellGroupData[{
Cell[42082, 1553, 69, 2, 30, "Input",
  CellTags->"S0.3"],
Cell[42154, 1557, 1644, 41, 67, "Output"]
}, Open  ]],
Cell[43813, 1601, 201, 5, 48, "MathCaption",
  CellTags->{"S0.3", "3.15"}],
Cell[44017, 1608, 175, 5, 48, "Input",
  CellTags->"S0.3"],
Cell[44195, 1615, 227, 5, 48, "MathCaption",
  CellTags->{"S0.3", "3.16"}],

Cell[CellGroupData[{
Cell[44447, 1624, 194, 6, 66, "Input",
  CellTags->"S0.3"],
Cell[44644, 1632, 19375, 701, 186, 7969, 555, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[64034, 2336, 64, 1, 56, "Subsection",
  CellTags->{"S0.4", "4.1"}],
Cell[64101, 2339, 449, 8, 90, "Text",
  CellTags->{"S0.4", "4.2"}],
Cell[64553, 2349, 91, 1, 31, "MathCaption",
  CellTags->{"S0.4", "4.3"}],
Cell[64647, 2352, 366, 12, 174, "Input",
  CellTags->"S0.4"],
Cell[65016, 2366, 67, 1, 56, "Subsection",
  CellTags->{"S0.5", "5.1"}],
Cell[65086, 2369, 451, 8, 90, "Text",
  CellTags->{"S0.5", "5.2"}],
Cell[65540, 2379, 92, 1, 31, "MathCaption",
  CellTags->{"S0.5", "5.3"}],
Cell[65635, 2382, 372, 12, 174, "Input",
  CellTags->"S0.5"],
Cell[66010, 2396, 99, 1, 31, "MathCaption",
  CellTags->{"S0.5", "5.4"}],

Cell[CellGroupData[{
Cell[66134, 2401, 148, 5, 48, "Input",
  CellTags->"S0.5"],
Cell[66285, 2408, 16535, 588, 186, 6737, 462, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[82835, 2999, 202, 5, 52, "Text",
  CellTags->{"S0.5", "5.5"}],
Cell[83040, 3006, 431, 14, 41, InheritFromParent],
Cell[83474, 3022, 336, 9, 42, InheritFromParent],
Cell[83813, 3033, 115, 4, 16, "Caption",
  CellTags->"S0.5"],
Cell[83931, 3039, 131, 4, 31, "MathCaption",
  CellTags->{"S0.5", "5.7"}],

Cell[CellGroupData[{
Cell[84087, 3047, 108, 2, 30, "Input",
  CellTags->"S0.5"],
Cell[84198, 3051, 114, 2, 29, "Output"]
}, Open  ]],
Cell[84327, 3056, 158, 5, 32, "MathCaption",
  CellTags->{"S0.5", "5.8"}],

Cell[CellGroupData[{
Cell[84510, 3065, 93, 2, 30, "Input",
  CellTags->"S0.5"],
Cell[84606, 3069, 61, 2, 29, "Output"]
}, Open  ]],
Cell[84682, 3074, 173, 4, 48, "MathCaption",
  CellTags->{"S0.5", "5.9"}],

Cell[CellGroupData[{
Cell[84880, 3082, 159, 6, 66, "Input",
  CellTags->"S0.5"],
Cell[85042, 3090, 1705, 35, 162, "Output"]
}, Open  ]],
Cell[86762, 3128, 109, 1, 31, "MathCaption",
  CellTags->{"S0.5", "5.10"}],

Cell[CellGroupData[{
Cell[86896, 3133, 169, 6, 66, "Input",
  CellTags->"S0.5"],
Cell[87068, 3141, 17681, 621, 186, 7219, 487, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[104764, 3765, 87, 1, 31, "MathCaption",
  CellTags->{"S0.5", "5.11"}],

Cell[CellGroupData[{
Cell[104876, 3770, 364, 12, 174, "Input",
  CellTags->"S0.5"],
Cell[105243, 3784, 1647, 41, 67, "Output"]
}, Open  ]],
Cell[106905, 3828, 145, 4, 31, "MathCaption",
  CellTags->{"S0.5", "5.12"}],
Cell[107053, 3834, 153, 5, 48, "Input",
  CellTags->"S0.5"],
Cell[107209, 3841, 193, 5, 48, "MathCaption",
  CellTags->{"S0.5", "5.13"}],

Cell[CellGroupData[{
Cell[107427, 3850, 140, 5, 48, "Input",
  CellTags->"S0.5"],
Cell[107570, 3857, 1056, 16, 162, "Output"]
}, Open  ]],
Cell[108641, 3876, 247, 5, 53, "Text",
  CellTags->{"S0.5", "5.14"}],
Cell[108891, 3883, 77, 1, 56, "Subsection",
  CellTags->{"S0.6", "6.1"}],
Cell[108971, 3886, 687, 14, 129, "Text",
  CellTags->{"S0.6", "6.2"}],
Cell[109661, 3902, 172, 4, 48, "MathCaption",
  CellTags->{"S0.6", "6.3"}],
Cell[109836, 3908, 397, 12, 174, "Input",
  CellTags->"S0.6"],
Cell[110236, 3922, 157, 4, 31, "MathCaption",
  CellTags->{"S0.6", "6.4"}],

Cell[CellGroupData[{
Cell[110418, 3930, 83, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[110504, 3934, 350, 6, 67, "Output"]
}, Open  ]],
Cell[110869, 3943, 94, 1, 31, "MathCaption",
  CellTags->{"S0.6", "6.5"}],

Cell[CellGroupData[{
Cell[110988, 3948, 80, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[111071, 3952, 340, 6, 67, "Output"]
}, Open  ]],
Cell[111426, 3961, 173, 5, 32, "MathCaption",
  CellTags->{"S0.6", "6.6"}],

Cell[CellGroupData[{
Cell[111624, 3970, 77, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[111704, 3974, 338, 6, 67, "Output"]
}, Open  ]],
Cell[112057, 3983, 108, 1, 31, "MathCaption",
  CellTags->{"S0.6", "6.7"}],

Cell[CellGroupData[{
Cell[112190, 3988, 116, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[112309, 3992, 63, 2, 29, "Output"]
}, Open  ]],
Cell[112387, 3997, 83, 1, 31, "MathCaption",
  CellTags->{"S0.6", "6.8"}],

Cell[CellGroupData[{
Cell[112495, 4002, 103, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[112601, 4006, 307, 6, 74, "Output"]
}, Open  ]],
Cell[112923, 4015, 90, 1, 56, "Subsection",
  CellTags->{"S0.7", "7.1"}],
Cell[113016, 4018, 401, 7, 90, "Text",
  CellTags->{"S0.7", "7.2"}],
Cell[113420, 4027, 113, 2, 31, "MathCaption",
  CellTags->{"S0.7", "7.3"}],

Cell[CellGroupData[{
Cell[113558, 4033, 349, 14, 210, "Input",
  CellTags->"S0.7"],
Cell[113910, 4049, 1336, 34, 48, "Output"]
}, Open  ]],
Cell[115261, 4086, 173, 7, 32, "MathCaption",
  CellTags->{"S0.7", "7.4"}],

Cell[CellGroupData[{
Cell[115459, 4097, 96, 2, 30, "Input",
  CellTags->"S0.7"],
Cell[115558, 4101, 331, 5, 48, "Output"]
}, Open  ]],
Cell[115904, 4109, 172, 7, 32, "MathCaption",
  CellTags->{"S0.7", "7.5"}],

Cell[CellGroupData[{
Cell[116101, 4120, 92, 2, 30, "Input",
  CellTags->"S0.7"],
Cell[116196, 4124, 343, 6, 48, "Output"]
}, Open  ]],
Cell[116554, 4133, 117, 2, 31, "MathCaption",
  CellTags->{"S0.7", "7.6"}],

Cell[CellGroupData[{
Cell[116696, 4139, 118, 2, 30, "Input",
  CellTags->"S0.7"],
Cell[116817, 4143, 63, 2, 29, "Output"]
}, Open  ]],
Cell[116895, 4148, 92, 1, 31, "MathCaption",
  CellTags->{"S0.7", "7.7"}],

Cell[CellGroupData[{
Cell[117012, 4153, 97, 2, 30, "Input",
  CellTags->"S0.7"],
Cell[117112, 4157, 63, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117212, 4164, 90, 2, 30, "Input",
  CellTags->"S0.7"],
Cell[117305, 4168, 63, 2, 29, "Output"]
}, Open  ]],
Cell[117383, 4173, 379, 7, 90, "Text",
  CellTags->{"S0.7", "7.8"}]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

