(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13790,        463]*)
(*NotebookOutlinePosition[     21088,        696]*)
(*  CellTagsIndexPosition[     20347,        661]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["ADDITIVE GmbH\n",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["Abt. Engineering & Science",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Bold",
    Background->GrayLevel[0.666667]],
  StyleBox["\nRohrwiesenstra\[SZ]e 2\nD-61381 Friedrichsdorf/Ts.\n  Tel.:  \
+49 6172 5905 30\n  Fax:  +49 6172 77613\n  email: ",
    FontSize->14,
    FontWeight->"Bold"],
  ButtonBox["mathematica@additive-net.de",
    ButtonData:>{
      URL[ "mailto:mathematica@additive-net.de"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\n  www:  ",
    FontSize->14,
    FontWeight->"Bold"],
  ButtonBox["http://www.additive.net.de",
    ButtonData:>{
      URL[ "http://www.additive-net.de"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  Background->GrayLevel[0.666667]],

Cell[CellGroupData[{

Cell[TextData[{
  "Die ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Applications Library"
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Mathematica hat sich in den vergangenen Jahren als unentbehrliches Werkzeug \
im Ingenieurwesen etabliert. Es bietet dem professionellen Anwender, durch \
seinen m\[ADoubleDot]chtigen und fortschrittlichen Funktionsumfang, eine \
unerreichte Flexibilit\[ADoubleDot]t bei der Analyse, Modellierung und \
Visualisierung der w\[ADoubleDot]hrend der t\[ADoubleDot]glichen \
Ingenieurarbeit anfallenden Daten. Im Sommer 1994 startete Wolfram Research \
die Ver\[ODoubleDot]ffentlichung der Mathematica Anwendungs-Pakete, die dem \
Benutzer sofort einsetzbare Funktionen aus speziellen Anwendungsbereichen \
bieten. Dem Anwender wird durch diese Pakete der schrittweise Einstieg in die \
Thematik bis zum Expertenwissen leicht gemacht. Die Zahl der Zusatzpakete \
wurde seit dieser Zeit auf \[UDoubleDot]ber 30 Zusatzpakete erweitert.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Ein \[CapitalUDoubleDot]bersicht zu den Zusatzpaketen ist aktuell im INTERNET \
zu finden.\
\>", "Text"],

Cell[TextData[ButtonBox["http://www.additive-net.de/software/mathematica/\
packages/mma.packages.shtml",
  ButtonData:>{
    URL[ "http://www.additive-net.de/software/mathematica/packages/mma.\
packages.shtml"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Open  ]],

Cell["Getting Started Finance Pack", "Section",
  CellTags->"0.1"],

Cell["About the Package", "Subsection",
  CellTags->{"S0.1", "1.1"}],

Cell[TextData[{
  "You can solve many kinds of mathematical problems with the standard \
version of ",
  StyleBox["Mathematica", "TI"],
  ". However, financial experts need functions that are not built into ",
  StyleBox["Mathematica", "TI"],
  " or included in any of the standard packages. The Finance Pack is designed \
to provide an introduction to using ",
  StyleBox["Mathematica", "TI"],
  " in financial analysis. Some very elementary examples of ",
  StyleBox["Mathematica", "TI"],
  " programming are presented in order to stimulate users to write their own \
financial programs and packages. To use the Finance Pack, basic familiarity \
with the ",
  StyleBox["Mathematica", "TI"],
  " kernel and the notebook front end is assumed. The Finance Pack has three \
components: packages, data files, and notebooks. \nPackages are the main part \
of the Finance Pack. They are files written in the ",
  StyleBox["Mathematica", "TI"],
  " language that contain definitions that extend the system. You may modify \
or use them in your own algorithms. They are just like packages from the \
standard ",
  StyleBox["Mathematica", "TI"],
  " distribution. The notebook front end is not required to use them. \nThe \
data files are needed to reproduce some of the examples from this guide. \n",
  StyleBox["Mathematica", "TI"],
  " notebooks are interactive documents combining ",
  StyleBox["Mathematica", "TI"],
  " input, output, text, and graphics. For more information see the user's \
guide for your ",
  StyleBox["Mathematica", "TI"],
  " front end. The notebooks provided with the Finance Pack are the on\
\[Hyphen]line version of this document. "
}], "Text",
  CellTags->{"S0.1", "1.2"}],

Cell["Installing the Finance Pack", "Subsection",
  CellTags->{"S0.3", "3.1"}],

Cell[TextData[{
  "The Finance Pack is easy to install. Make sure you have ",
  StyleBox["Mathematica", "TI"],
  " installed on your computer and follow the steps described on the \
installation card. The installation program will (if needed) create a \
directory for the ",
  StyleBox["Mathematica", "TI"],
  " applications and subdirectories for the Finance Pack. Then it will copy \
what you choose from the distribution media into the right directories. Just \
follow the directions on the screen."
}], "Text",
  CellTags->{"S0.3", "3.2"}],

Cell["Loading the Finance Pack", "Subsection",
  CellTags->{"S0.4", "4.1"}],

Cell[TextData[{
  "After starting a ",
  StyleBox["Mathematica", "TI"],
  " session we load the package. "
}], "Text",
  CellTags->{"S0.4", "4.2"}],

Cell["Here is the most convenient way to load the package. ", "MathCaption",
  CellTags->{"S0.4", "4.3"}],

Cell["<< Finance`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"S0.4"],

Cell["\<\
Now all the functions from the Finance Pack are available. Any \
subpackages that are needed will be loaded automatically. \
\>", "Text",
  CellTags->{"S0.4", "4.4"}],

Cell["The Finance Pack includes the following subpackages: ", "Text",
  CellTags->{"S0.4", "4.7"}],

Cell[TextData[{
  "\t",
  StyleBox["Finance`Calendar`", "MB",
    FontWeight->"Plain"],
  " \n\t",
  StyleBox["Finance`InterestRates`", "MB",
    FontWeight->"Plain"],
  " \n\t",
  StyleBox["Finance`Bonds`", "MB",
    FontWeight->"Plain"],
  " \n\t",
  StyleBox["Finance`Options`", "MB",
    FontWeight->"Plain"],
  " \n\t",
  StyleBox["Finance`Examples`", "MB",
    FontWeight->"Plain"],
  " \n\t",
  StyleBox["Finance`Common`", "MB",
    FontWeight->"Plain"],
  " \n\t",
  StyleBox["Finance`Kernel`init`", "MB",
    FontWeight->"Plain"]
}], "Program",
  CellFrame->False],

Cell[TextData[{
  "To instruct ",
  StyleBox["Mathematica", "TI"],
  " to load an individual subpackage, use the command ",
  StyleBox["<<", "MB"],
  " ",
  StyleBox["filename", "TI"],
  " or ",
  StyleBox["Get", "MB"],
  "[\"",
  StyleBox["filename", "TI"],
  "\"] or ",
  StyleBox["Needs", "MB"],
  "[\"",
  StyleBox["context", "TI"],
  "\"]. If the package directory is in the current search path, then ",
  StyleBox["Mathematica", "TI"],
  " will find the package and load it. You can also include the full path \
name of the package. In that case ",
  StyleBox["Mathematica", "TI"],
  " will look only in the place you have specified. "
}], "Text"],

Cell[TextData[{
  "This loads the subpackage ",
  StyleBox["Finance`Bonds`", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.4", "4.8"}],

Cell["<< Finance`Bonds`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"S0.4"],

Cell["The Concept of Finance Objects", "Subsection",
  CellTags->{"S0.5", "5.1"}],

Cell[TextData[{
  "The functions used in finance are mostly polymorphic; that is, the way \
they work depends on the type of arguments they use. They might also have a \
variable number of arguments. ",
  StyleBox["Mathematica", "TI"],
  " can handle either situation easily and correctly. The package implements \
the concept of a finance object. "
}], "Text",
  CellTags->{"S0.5", "5.2"}],

Cell["<< Finance`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"S0.5"],

Cell["These are the available classes of finance objects. ", "MathCaption",
  CellTags->{"S0.5", "5.3"}],

Cell[CellGroupData[{

Cell["?FinanceClasses", "Input",
  CellLabel->"In[2]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    \("SpotRates \nForwardRates \nDiscountFactors \nBond \nOption \nCashFlows\
\n"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "This is the general way to define a finance object ",
  Cell[BoxData[
      \(TraditionalForm\`f\)], "InlineFormula",
    CellTags->"S0.5"],
  "."
}], "Text",
  CellTags->{"S0.5", "5.4"}],

Cell[TextData[{
  StyleBox["f",
    FontSlant->"Italic"],
  " = ",
  StyleBox["Class",
    FontSlant->"Italic"],
  "[",
  StyleBox["description",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  "]"
}], "DisplayFormula"],

Cell[TextData[{
  "The description is a list of parameters necessary to define an object. It \
is important to keep them in the right order. Setting the second argument \
modifies the behavior of the functions that act on the object. Don't confuse \
",
  StyleBox["options", "TI"],
  " with the finance object ",
  StyleBox["Option", "MB"],
  ". "
}], "Text",
  CellTags->{"S0.5", "5.5"}],

Cell[TextData[{
  "This defines the finance object ",
  StyleBox["xyzft", "MB"],
  ". Here we use only the first argument. "
}], "MathCaption",
  CellTags->{"S0.5", "5.6"}],

Cell[CellGroupData[{

Cell["xyzft = Option[{\"Put\", XYZ, 40, {12, 20, 1992}}]", "Input",
  CellLabel->"In[3]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    \(Option[{"Put", XYZ, 40, {12, 20, 1992}}]\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  "Here is another finance object, ",
  StyleBox["bond3", "MB"],
  ", defined using the option ",
  StyleBox["CountDayBasis -> \"30/360\"", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.5", "5.7"}],

Cell[CellGroupData[{

Cell["\<\
bond3 = Bond[{.10, {9, 15, 1993}, 1000 USDollar, 2},
   CountDayBasis -> \"30/360\"]\
\>", "Input",
  CellLabel->"In[4]:=",
  CellTags->"S0.5"],

Cell[BoxData[
    RowBox[{"Bond", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["0.1`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2], ",", \({9, 15, 1993}\), ",", 
            \(1000\ USDollar\), ",", "2"}], "}"}], ",", 
        \(CountDayBasis \[Rule] "30/360"\)}], "]"}]], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
We will discuss how to create and use finance objects in detail in \
the following sections. \
\>", "Text",
  CellTags->{"S0.5", "5.8"}],

Cell["Names", "Subsection",
  CellTags->{"S0.6", "6.1"}],

Cell[TextData[{
  "The convention that has been adopted for built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " objects is to use full English names with the first letter of each word \
comprising the name capitalized, for example, ",
  StyleBox["PresentValue", "MR",
    FontWeight->"Bold"],
  ", ",
  StyleBox["YieldToMaturity", "MR",
    FontWeight->"Bold"],
  ", etc. You may prefer to use your own naming system. "
}], "Text",
  CellTags->{"S0.6", "6.2"}],

Cell["Here is an example of a present value calculation. ", "MathCaption",
  CellTags->{"S0.6", "6.4"}],

Cell[CellGroupData[{

Cell["PresentValue[1000 USDollar, 7.26 Percent, 1, 2]", "Input",
  CellLabel->"In[5]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(869.209400854307645`\ USDollar\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "Here we define the alias ",
  StyleBox["PV", "MB"],
  " for ",
  StyleBox["PresentValue", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.6", "6.5"}],

Cell[CellGroupData[{

Cell["PV = PresentValue", "Input",
  CellLabel->"In[6]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(PresentValue\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["PV", "MB"],
  " works in exactly the same way as ",
  StyleBox["PresentValue", "MB"],
  ". Note that using short names and aliases instead of full names sometimes \
leads to confusion. "
}], "MathCaption",
  CellTags->{"S0.6", "6.6"}],

Cell[CellGroupData[{

Cell["PV[1000 USDollar, 7.26 Percent, 1, 2]", "Input",
  CellLabel->"In[7]:=",
  CellTags->"S0.6"],

Cell[BoxData[
    \(869.209400854307645`\ USDollar\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "You can create a file defining your aliases and read it in at the \
beginning of your ",
  StyleBox["Mathematica", "TI"],
  " session or you can define aliases in the file ",
  StyleBox["init.m", "TI"],
  " so that they will be available for each ",
  StyleBox["Mathematica", "TI"],
  " session. "
}], "Text",
  CellTags->{"S0.6", "6.7"}]
},
FrontEndVersion->"4.0 f\\374r Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, 1},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          StyleBox[ 
            OptionValueBox[ "FileName"], FontSize -> 10]}], "Header"], Cell[ 
        TextData[ {"- ", 
          StyleBox[ 
          "printed by Mathematica", FontSlant -> "Italic", FontSize -> 10], 
          " - "}], "PageHeader"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          ValueBox[ "Day"], ".", 
          ValueBox[ "Month"], ".", 
          ValueBox[ "Year"]}], "Text"], Cell[ 
        TextData[ {
          StyleBox[ "\[Copyright]2001 Additive GmbH", FontSize -> 10]}], 
        "PageFooter"], Cell[ 
        TextData[ {
          StyleBox[ 
          "Abt. Engineering & Science", FontSlant -> "Italic", FontSize -> 
            10]}], "PageHeader"]}},
PageFooterLines->{Inherited, True},
CellLabelAutoDelete->True,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "0.1"->{
    Cell[3997, 115, 66, 1, 59, "Section",
      CellTags->"0.1"]},
  "S0.1"->{
    Cell[4066, 118, 68, 1, 47, "Subsection",
      CellTags->{"S0.1", "1.1"}],
    Cell[4137, 121, 1695, 34, 185, "Text",
      CellTags->{"S0.1", "1.2"}]},
  "1.1"->{
    Cell[4066, 118, 68, 1, 47, "Subsection",
      CellTags->{"S0.1", "1.1"}]},
  "1.2"->{
    Cell[4137, 121, 1695, 34, 185, "Text",
      CellTags->{"S0.1", "1.2"}]},
  "S0.3"->{
    Cell[5835, 157, 78, 1, 47, "Subsection",
      CellTags->{"S0.3", "3.1"}],
    Cell[5916, 160, 543, 11, 71, "Text",
      CellTags->{"S0.3", "3.2"}]},
  "3.1"->{
    Cell[5835, 157, 78, 1, 47, "Subsection",
      CellTags->{"S0.3", "3.1"}]},
  "3.2"->{
    Cell[5916, 160, 543, 11, 71, "Text",
      CellTags->{"S0.3", "3.2"}]},
  "S0.4"->{
    Cell[6462, 173, 75, 1, 47, "Subsection",
      CellTags->{"S0.4", "4.1"}],
    Cell[6540, 176, 147, 5, 33, "Text",
      CellTags->{"S0.4", "4.2"}],
    Cell[6690, 183, 105, 1, 25, "MathCaption",
      CellTags->{"S0.4", "4.3"}],
    Cell[6798, 186, 72, 2, 30, "Input",
      CellTags->"S0.4"],
    Cell[6873, 190, 176, 4, 33, "Text",
      CellTags->{"S0.4", "4.4"}],
    Cell[7052, 196, 98, 1, 33, "Text",
      CellTags->{"S0.4", "4.7"}],
    Cell[8385, 247, 138, 5, 26, "MathCaption",
      CellTags->{"S0.4", "4.8"}],
    Cell[8526, 254, 78, 2, 30, "Input",
      CellTags->"S0.4"]},
  "4.1"->{
    Cell[6462, 173, 75, 1, 47, "Subsection",
      CellTags->{"S0.4", "4.1"}]},
  "4.2"->{
    Cell[6540, 176, 147, 5, 33, "Text",
      CellTags->{"S0.4", "4.2"}]},
  "4.3"->{
    Cell[6690, 183, 105, 1, 25, "MathCaption",
      CellTags->{"S0.4", "4.3"}]},
  "4.4"->{
    Cell[6873, 190, 176, 4, 33, "Text",
      CellTags->{"S0.4", "4.4"}]},
  "4.7"->{
    Cell[7052, 196, 98, 1, 33, "Text",
      CellTags->{"S0.4", "4.7"}]},
  "4.8"->{
    Cell[8385, 247, 138, 5, 26, "MathCaption",
      CellTags->{"S0.4", "4.8"}]},
  "S0.5"->{
    Cell[8607, 258, 81, 1, 47, "Subsection",
      CellTags->{"S0.5", "5.1"}],
    Cell[8691, 261, 390, 8, 52, "Text",
      CellTags->{"S0.5", "5.2"}],
    Cell[9084, 271, 72, 2, 30, "Input",
      CellTags->"S0.5"],
    Cell[9159, 275, 104, 1, 25, "MathCaption",
      CellTags->{"S0.5", "5.3"}],
    Cell[9288, 280, 76, 2, 30, "Input",
      CellTags->"S0.5"],
    Cell[9491, 289, 206, 7, 33, "Text",
      CellTags->{"S0.5", "5.4"}],
    Cell[9958, 313, 388, 10, 53, "Text",
      CellTags->{"S0.5", "5.5"}],
    Cell[10349, 325, 172, 5, 26, "MathCaption",
      CellTags->{"S0.5", "5.6"}],
    Cell[10546, 334, 111, 2, 30, "Input",
      CellTags->"S0.5"],
    Cell[10773, 343, 217, 7, 26, "MathCaption",
      CellTags->{"S0.5", "5.7"}],
    Cell[11015, 354, 153, 5, 48, "Input",
      CellTags->"S0.5"],
    Cell[11559, 374, 146, 4, 33, "Text",
      CellTags->{"S0.5", "5.8"}]},
  "5.1"->{
    Cell[8607, 258, 81, 1, 47, "Subsection",
      CellTags->{"S0.5", "5.1"}]},
  "5.2"->{
    Cell[8691, 261, 390, 8, 52, "Text",
      CellTags->{"S0.5", "5.2"}]},
  "5.3"->{
    Cell[9159, 275, 104, 1, 25, "MathCaption",
      CellTags->{"S0.5", "5.3"}]},
  "5.4"->{
    Cell[9491, 289, 206, 7, 33, "Text",
      CellTags->{"S0.5", "5.4"}]},
  "5.5"->{
    Cell[9958, 313, 388, 10, 53, "Text",
      CellTags->{"S0.5", "5.5"}]},
  "5.6"->{
    Cell[10349, 325, 172, 5, 26, "MathCaption",
      CellTags->{"S0.5", "5.6"}]},
  "5.7"->{
    Cell[10773, 343, 217, 7, 26, "MathCaption",
      CellTags->{"S0.5", "5.7"}]},
  "5.8"->{
    Cell[11559, 374, 146, 4, 33, "Text",
      CellTags->{"S0.5", "5.8"}]},
  "S0.6"->{
    Cell[11708, 380, 56, 1, 47, "Subsection",
      CellTags->{"S0.6", "6.1"}],
    Cell[11767, 383, 465, 12, 54, "Text",
      CellTags->{"S0.6", "6.2"}],
    Cell[12235, 397, 103, 1, 25, "MathCaption",
      CellTags->{"S0.6", "6.4"}],
    Cell[12363, 402, 108, 2, 30, "Input",
      CellTags->"S0.6"],
    Cell[12577, 411, 170, 7, 26, "MathCaption",
      CellTags->{"S0.6", "6.5"}],
    Cell[12772, 422, 78, 2, 30, "Input",
      CellTags->"S0.6"],
    Cell[12938, 431, 262, 7, 26, "MathCaption",
      CellTags->{"S0.6", "6.6"}],
    Cell[13225, 442, 98, 2, 30, "Input",
      CellTags->"S0.6"],
    Cell[13429, 451, 357, 10, 52, "Text",
      CellTags->{"S0.6", "6.7"}]},
  "6.1"->{
    Cell[11708, 380, 56, 1, 47, "Subsection",
      CellTags->{"S0.6", "6.1"}]},
  "6.2"->{
    Cell[11767, 383, 465, 12, 54, "Text",
      CellTags->{"S0.6", "6.2"}]},
  "6.4"->{
    Cell[12235, 397, 103, 1, 25, "MathCaption",
      CellTags->{"S0.6", "6.4"}]},
  "6.5"->{
    Cell[12577, 411, 170, 7, 26, "MathCaption",
      CellTags->{"S0.6", "6.5"}]},
  "6.6"->{
    Cell[12938, 431, 262, 7, 26, "MathCaption",
      CellTags->{"S0.6", "6.6"}]},
  "6.7"->{
    Cell[13429, 451, 357, 10, 52, "Text",
      CellTags->{"S0.6", "6.7"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"0.1", 15565, 511},
  {"S0.1", 15644, 514},
  {"1.1", 15812, 519},
  {"1.2", 15903, 522},
  {"S0.3", 15993, 525},
  {"3.1", 16159, 530},
  {"3.2", 16250, 533},
  {"S0.4", 16338, 536},
  {"4.1", 16942, 553},
  {"4.2", 17033, 556},
  {"4.3", 17119, 559},
  {"4.4", 17212, 562},
  {"4.7", 17298, 565},
  {"4.8", 17383, 568},
  {"S0.5", 17477, 571},
  {"5.1", 18375, 596},
  {"5.2", 18466, 599},
  {"5.3", 18552, 602},
  {"5.4", 18645, 605},
  {"5.5", 18731, 608},
  {"5.6", 18818, 611},
  {"5.7", 18912, 614},
  {"5.8", 19006, 617},
  {"S0.6", 19094, 620},
  {"6.1", 19783, 639},
  {"6.2", 19875, 642},
  {"6.4", 19963, 645},
  {"6.5", 20057, 648},
  {"6.6", 20151, 651},
  {"6.7", 20245, 654}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 821, 25, 198, "Text"],

Cell[CellGroupData[{
Cell[2563, 78, 166, 7, 59, "Section",
  Evaluatable->False],
Cell[2732, 87, 874, 13, 90, "Text",
  Evaluatable->False],
Cell[3609, 102, 114, 3, 33, "Text"],
Cell[3726, 107, 256, 5, 33, "Text"]
}, Open  ]],
Cell[3997, 115, 66, 1, 59, "Section",
  CellTags->"0.1"],
Cell[4066, 118, 68, 1, 47, "Subsection",
  CellTags->{"S0.1", "1.1"}],
Cell[4137, 121, 1695, 34, 185, "Text",
  CellTags->{"S0.1", "1.2"}],
Cell[5835, 157, 78, 1, 47, "Subsection",
  CellTags->{"S0.3", "3.1"}],
Cell[5916, 160, 543, 11, 71, "Text",
  CellTags->{"S0.3", "3.2"}],
Cell[6462, 173, 75, 1, 47, "Subsection",
  CellTags->{"S0.4", "4.1"}],
Cell[6540, 176, 147, 5, 33, "Text",
  CellTags->{"S0.4", "4.2"}],
Cell[6690, 183, 105, 1, 25, "MathCaption",
  CellTags->{"S0.4", "4.3"}],
Cell[6798, 186, 72, 2, 30, "Input",
  CellTags->"S0.4"],
Cell[6873, 190, 176, 4, 33, "Text",
  CellTags->{"S0.4", "4.4"}],
Cell[7052, 196, 98, 1, 33, "Text",
  CellTags->{"S0.4", "4.7"}],
Cell[7153, 199, 573, 23, 127, "Program"],
Cell[7729, 224, 653, 21, 53, "Text"],
Cell[8385, 247, 138, 5, 26, "MathCaption",
  CellTags->{"S0.4", "4.8"}],
Cell[8526, 254, 78, 2, 30, "Input",
  CellTags->"S0.4"],
Cell[8607, 258, 81, 1, 47, "Subsection",
  CellTags->{"S0.5", "5.1"}],
Cell[8691, 261, 390, 8, 52, "Text",
  CellTags->{"S0.5", "5.2"}],
Cell[9084, 271, 72, 2, 30, "Input",
  CellTags->"S0.5"],
Cell[9159, 275, 104, 1, 25, "MathCaption",
  CellTags->{"S0.5", "5.3"}],

Cell[CellGroupData[{
Cell[9288, 280, 76, 2, 30, "Input",
  CellTags->"S0.5"],
Cell[9367, 284, 109, 2, 139, "Print"]
}, Open  ]],
Cell[9491, 289, 206, 7, 33, "Text",
  CellTags->{"S0.5", "5.4"}],
Cell[9700, 298, 255, 13, 25, "DisplayFormula"],
Cell[9958, 313, 388, 10, 53, "Text",
  CellTags->{"S0.5", "5.5"}],
Cell[10349, 325, 172, 5, 26, "MathCaption",
  CellTags->{"S0.5", "5.6"}],

Cell[CellGroupData[{
Cell[10546, 334, 111, 2, 30, "Input",
  CellTags->"S0.5"],
Cell[10660, 338, 98, 2, 29, "Output"]
}, Open  ]],
Cell[10773, 343, 217, 7, 26, "MathCaption",
  CellTags->{"S0.5", "5.7"}],

Cell[CellGroupData[{
Cell[11015, 354, 153, 5, 48, "Input",
  CellTags->"S0.5"],
Cell[11171, 361, 373, 10, 29, "Output"]
}, Open  ]],
Cell[11559, 374, 146, 4, 33, "Text",
  CellTags->{"S0.5", "5.8"}],
Cell[11708, 380, 56, 1, 47, "Subsection",
  CellTags->{"S0.6", "6.1"}],
Cell[11767, 383, 465, 12, 54, "Text",
  CellTags->{"S0.6", "6.2"}],
Cell[12235, 397, 103, 1, 25, "MathCaption",
  CellTags->{"S0.6", "6.4"}],

Cell[CellGroupData[{
Cell[12363, 402, 108, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[12474, 406, 88, 2, 29, "Output"]
}, Open  ]],
Cell[12577, 411, 170, 7, 26, "MathCaption",
  CellTags->{"S0.6", "6.5"}],

Cell[CellGroupData[{
Cell[12772, 422, 78, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[12853, 426, 70, 2, 29, "Output"]
}, Open  ]],
Cell[12938, 431, 262, 7, 26, "MathCaption",
  CellTags->{"S0.6", "6.6"}],

Cell[CellGroupData[{
Cell[13225, 442, 98, 2, 30, "Input",
  CellTags->"S0.6"],
Cell[13326, 446, 88, 2, 29, "Output"]
}, Open  ]],
Cell[13429, 451, 357, 10, 52, "Text",
  CellTags->{"S0.6", "6.7"}]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

